*! version 1.0.1  13apr2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.2  29jan2012  by Marc Muendler     muendler@ucsd.edu

version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "braxpmkt/logs/country-data-2000.log", replace

// WTF country mapping
tempfile wdimap
use wdi* wtf* using "brazaux/conc/countries/country-table.dta", clear
drop if wdicountry==""
* Drop unused country codes in WTF data 2000
drop if wtfkey==138960 | wtfkey==447200 | wtfkey==558960 | wtfkey==582000 | wtfkey==582780 | wtfkey==688100
* Backward compatibility with country-table 2007-04-13
drop if ( wtfkey==368960 & wdikey=="ASM" ) | ( wtfkey==368960 & wdikey=="GUM" ) | ( wtfkey==450000 & wdikey=="TMP" ) | ( wtfkey== . & wdikey=="IMY" )
replace wdicountry="GERMANY" if ( wtfkey==532760 & wdikey=="DEU") 
replace wdicountry="GERMANY" if ( wtfkey==532800 & wdikey=="DEU") 
replace wdikey="" if ( wtfkey==532760 & wdikey=="DEU") 
replace wdikey="" if ( wtfkey==532800 & wdikey=="DEU") 
replace wdicountry="UNITED STATES" if ( wtfkey==368960 & wdikey=="PRI" )
replace wdikey="USA" if ( wtfkey==368960 & wdikey=="PRI" )
* Compatibility with SECEX
replace wtfkey=532760 if wtfkey==532800  // SECEX compatibility: Former West Germany reset to Germany
replace wtfcountry="Germany" if wtfkey==532760
replace wtfkey=481560 if wtfkey==481561 | wtfkey==481562  // SECEX compatibility: China FTZ and SC reset to China
replace wtfcountry="China" if wtfkey==481560
replace wtfkey=448870 if wtfkey==448860  // SECEX compatibility: Former Yemen AR reset to Yemen
replace wtfcountry="Yemen" if wtfkey==448870
replace wtfkey=582210 if wtfkey==598900 | wtfkey==598910  // SECEX compatibility: Former Yugoslavia and Yugoslavia reset to Serbia and Montenegro (E Europe NES)
replace wtfcountry="E Europe NES" if wtfkey==582210
replace wtfkey=725400 if wtfkey==166380  // SECEX compatibility: Fr Ind O reset to New Calednia
replace wtfcountry="New Calednia" if wtfkey==725400
* Remove nonunique WDI-WTF mappings
sort wdicountry wtfkey
drop if ( wdicountry==wdicountry[_n-1] | wdicountry==wdicountry[_n+1] ) & wtfcountry=="Oth.Oceania"  // Norway mapped from Norway only, not from Antarctica
drop if ( wdicountry==wdicountry[_n-1] | wdicountry==wdicountry[_n+1] ) & wtfcountry=="US NES"  // US mapped from US only, not from US NES
duplicates drop
sort wtfkey wdicountry
drop if ( wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] ) & wdicountry==""
sort wdicountry wtfkey
drop if ( wdicountry==wdicountry[_n-1] | wdicountry==wdicountry[_n+1] ) & wtfkey==.
sort wtfkey wdicountry
list if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1]
sort wdicountry wtfkey
list if wdicountry==wdicountry[_n-1] | wdicountry==wdicountry[_n+1]
replace wtfkey=358960 if wdicountry=="ARUBA"  // backward compatibility with 2007-04-13
replace wdicountry="GUINEA-BISSEAU" if wtfkey==166240  // backward compatibility with 2007-04-13
replace wdicountry="YUGOSLAVIA, FED. REP." if wtfkey==582210  // backward compatibility with 2007-04-13
sort wdicountry wtfkey
save `wdimap'

// Check country mapping in WDI Data for 2000
use country wdicountry year if year==2000 using "fdilabor/countries/ext-data.dta", clear
drop year
duplicates drop
sort country wdicountry
list if country==country[_n-1] | country==country[_n+1]
sort wdicountry country
list if wdicountry==wdicountry[_n-1] | wdicountry==wdicountry[_n+1]

// WDI Data (undeflated) for 2000
use country wdicountry year population gdp_usd gdp_cap_usd consum_expend_usd hh_consum_expend_usd if year==2000 using "fdilabor/countries/ext-data.dta", clear
drop country year
duplicates drop  // zero observations are duplicates
sort wdicountry
joinby wdicountry using `wdimap', _merge(_merge) unmatched(both)
tab wdicountry if _m==2
drop if _m==2
drop wdi* wtfcountry
order wtfkey
sort wtfkey
qui do "braxpmkt/conc/wtfkey.do"
label values wtfkey wtfkey
drop _merge

// OECD dummies
gen byte indoecd90=0
label var indoecd90 "Indic.: OECD member 1990"
replace indoecd90=1 if wtfkey==710360 // Australia 7 June 1971
replace indoecd90=1 if wtfkey==550400 // Austria 29 September 1961 
replace indoecd90=1 if wtfkey==530560 // Belgium-Lux 13 September 1961, 7 December 1961
replace indoecd90=1 if wtfkey==211240 // Canada 10 April 1961
replace indoecd90=1 if wtfkey==532080 // Denmark 30 May 1961
replace indoecd90=1 if wtfkey==552460 // Finland 28 January 1969
replace indoecd90=1 if wtfkey==532500 // France,Monac 7 August 1961
replace indoecd90=1 if wtfkey==532760 // Germany 27 September 1961
replace indoecd90=1 if wtfkey==533000 // Greece 27 September 1961
replace indoecd90=1 if wtfkey==553520 // Iceland 5 June 1961
replace indoecd90=1 if wtfkey==533720 // Ireland 7 August 1961
replace indoecd90=1 if wtfkey==533800 // Italy 29 March 1962
replace indoecd90=1 if wtfkey==413920 // Japan 28 April 1964
replace indoecd90=1 if wtfkey==535280 // Netherlands 13 November 1961
replace indoecd90=1 if wtfkey==715540 // New Zealand 29 May 1973
replace indoecd90=1 if wtfkey==555780 // Norway 4 July 1961
replace indoecd90=1 if wtfkey==536200 // Portugal 4 August 1961
replace indoecd90=1 if wtfkey==537240 // Spain 3 August 1961
replace indoecd90=1 if wtfkey==557520 // Sweden 28 September 1961
replace indoecd90=1 if wtfkey==557560 // Switz.Liecht 28 September 1961
replace indoecd90=1 if wtfkey==447920 // Turkey 2 August 1961
replace indoecd90=1 if wtfkey==538260 // UK 2 May 1961
replace indoecd90=1 if wtfkey==218400 // USA 12 April 1961
gen byte indoecd00=indoecd90
label var indoecd00 "Indic.: OECD member 2000"
replace indoecd00=1 if wtfkey==582030 // Czech Rep 21 December 1995
replace indoecd00=1 if wtfkey==583480 // Hungary 7 May 1996
replace indoecd00=1 if wtfkey==454100 // Korea Rep. 12 December 1996
replace indoecd00=1 if wtfkey==334840 // Mexico 18 May 1994
replace indoecd00=1 if wtfkey==586160 // Poland 22 November 1996
replace indoecd00=1 if wtfkey==587030 // Slovakia 14 December 2000

count
sort wtfkey
save "braxpmkt/ext/country-data-2000.dta", replace

log close
