*! version 1.0.1  14apr2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.2  09mar2008  by Oana Hirakawa     otocoian@ucsd.edu

version 8.2
clear
set logtype text
set more off
set matsize 200
set mem 100m

capture log close
log using "braxpmkt/logs/distance-data-chile.log", replace

* Country concordance iso3code and wtfkey
tempfile wtf
use iso3code isoname indold wtfkey wtfcountry using "brazaux/conc/countries/country-table.dta", clear
* list if iso3code=="PAL" | iso3code=="TMP" | iso3code=="YUG" | iso3code=="ZAR"
drop if wtfkey==.
duplicates drop
sort wtfkey
* WTF aggregate countries
list iso3code isoname wtfkey wtfcountry if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1]
* check country information
replace wtfkey=582210 if iso3code=="YUG"
replace isoname="Serbia and Montenegro" if iso3code=="YUG"
replace indold=0 if iso3code=="YUG"
replace wtfcountry="E Europe NES" if iso3code=="YUG"
replace iso3code="SCG" if iso3code=="YUG"
replace wtfcountry="China" if wtfkey==481561
replace wtfkey=481560 if wtfkey==481561
replace wtfkey=532760 if wtfkey==532800  // CEPII compatibility: Former West Germany reset to Germany
replace wtfcountry="Germany" if wtfkey==532760
replace wtfkey=481560 if wtfkey==481561 | wtfkey==481562  // CEPII compatibility: China FTZ and SC reset to China
replace wtfcountry="China" if wtfkey==481560
replace wtfkey=448870 if wtfkey==448860  // CEPII compatibility: Former Yemen AR reset to Yemen
replace wtfcountry="Yemen" if wtfkey==448870
replace wtfkey=582030 if wtfkey==582000  // CEPII compatibility: Czechoslovakia reset to Czech Rep
replace wtfcountry="Czech Rep" if wtfkey==582030
replace wtfkey=532760 if wtfkey==532800  // CEPII compatibility: Fm German FR reset to Germany
replace wtfcountry="Germany" if wtfkey==448870
replace wtfkey=582210 if wtfkey==598900 | wtfkey==598910  // CEPII compatibility: Former Yugoslavia and Yugoslavia reset to Serbia and Montenegro (E Europe NES)
replace wtfcountry="E Europe NES" if wtfkey==582210
replace wtfkey=725400 if wtfkey==166380  // CEPII compatibility: Fr Ind O reset to New Calednia
replace wtfcountry="New Calednia" if wtfkey==725400
sort wtfkey
drop if ( wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] ) & indold==1  // remaining obs.: 253
duplicates drop
preserve
  keep iso3code wtfkey wtfcountry indold
  duplicates drop
  sort wtfkey iso3code
  list if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1]
  sort iso3code wtfkey
  list if iso3code==iso3code[_n-1] | iso3code==iso3code[_n+1]
  list if iso3code=="SCG" | iso3code=="YUG" | iso3code=="ATB" | iso3code=="PCZ"
restore
qui do "braxpmkt/conc/wtfkey-chile.do"
label values wtfkey wtfkey
keep iso3code wtfkey
sort iso3code
save `wtf'

* Bilateral distance data
tempfile geo dist
use "fdilabor/countries/geo_cepii", clear
keep iso3 dis_int
rename iso3 iso_o
sort iso_o
save `geo'
use "fdilabor/countries/dist_cepii", clear
rename dist distcit
keep iso_o iso_d contig comlang_off distw distcit
label var distcit "Mean distance (cities km)"
label var distw "Mean distance (cities pop-wt km)"
label var contig "Common borders"
label var comlang_off "Common language"
sort iso_o
merge iso_o using `geo'
tab _m
drop _m
rename iso_o reporter 
rename iso_d partner
label var reporter "Reporter ISO (3166-1) code"
label var partner "Partner ISO (3166-1) code"
* Treat Romania
replace reporter="ROU" if reporter=="ROM"
replace partner="ROU" if partner=="ROM"
drop if reporter=="" | partner==""
sort reporter partner

* Chile-specific distance measures
keep if reporter==upper("chl")
drop reporter
rename partner iso3code
gen lndist=ln(distcit)
label var iso3code "Three-letter ISO (3166-1) code"
* label var lndistw "Log Distance (pop-wt cities)"
label var lndist "Log Distance (city mean, no wt)"
order iso3code
compress
sort iso3code

* Transform to WTF level
replace iso3code="PSE" if iso3code=="PAL" // Correct code for Occ. Pal. Terr
replace iso3code="TLS" if iso3code=="TMP" // East Timor reset to Timor-Leste
replace iso3code="SCG" if iso3code=="YUG" // Former Yugoslavia and Yugoslavia reset to Serbia and Montenegro (E Europe NES)
replace iso3code="COD" if iso3code=="ZAR" // Zaire reset to Congo, The Democratic Republic of the
sort iso3code
merge iso3code using `wtf'
tab _m
list iso3code wtfkey if _m==1
list iso3code wtfkey if _m==2
drop if _m==2
foreach var in contig comlang_off distcit distw dis_int lndist {
  local lbl`var' : variable label `var'
  }
collapse (min) min_contig=contig min_comlang_off=comlang_off min_distcit=distcit min_distw=distw min_dis_int=dis_int min_lndist=lndist (mean) avg_contig=contig avg_comlang_off=comlang_off avg_distcit=distcit avg_distw=distw avg_dis_int=dis_int avg_lndist=lndist (max) max_contig=contig max_comlang_off=comlang_off max_distcit=distcit max_distw=distw max_dis_int=dis_int max_lndist=lndist, by(wtfkey)
foreach var in contig comlang_off distcit distw dis_int lndist {
  label var min_`var' "Min `lbl`var''"
  label var avg_`var' "Avg `lbl`var''"
  label var max_`var' "Max `lbl`var''"
  }
* Keep regional means for distance measures with WTF aggregates
foreach var in distcit distw dis_int lndist {
  drop min_`var' max_`var'
  rename avg_`var' `var'
  label var `var' "`lbl`var''"
  }
* Check for effect of aggregation on border and language dummies
foreach var in contig comlang_off {
  qui count if min_`var'~=max_`var'
  if `r(N)'==0 {
    drop min_`var' max_`var'
    rename avg_`var' `var'
    label var `var' "`lbl`var''"
    }
  else {
    list wtfkey min_`var' max_`var' if min_`var'~=max_`var'
    replace min_`var'=. if min_`var'~=max_`var'
    drop max_`var'
    rename min_`var' `var'
    label var `var' "`lbl`var''"
    }
  }
order wtfkey distcit distw dis_int lndist contig comlang_off avg_comlang_off

count
sort wtfkey
save "braxpmkt/ext/distance-data-chile.dta", replace

log close
