*! version 1.0.1  10apr2007  by Marc Muendler     muendler@ucsd.edu

// used:
* 10 digit HS to 5 digit SITC rev.2 (311k)
* From the NBER Trade Data CD 1
* http://www.macalester.edu/research/economics/page/haveman/Trade.Resources/Concordances/FromHS/NBER/hts.sitc2

// not used:
* HS 1988 to SITC Rev. 3 (SITC3-HS88.zip)
* http://unstats.un.org/unsd/cr/registry/regdntransfer.asp?f=41
* HS 1996 to SITC Rev. 3 (SITC3-HS96.zip)
* http://unstats.un.org/unsd/cr/registry/regdntransfer.asp?f=56
* HS 2002 to SITC Rev. 3 (SITC3-HS02.zip)
* http://unstats.un.org/unsd/cr/registry/regdntransfer.asp?f=30
* SITC Rev. 3 to SITC Rev. 2 (SITC3-SITC2.zip)
* http://unstats.un.org/unsd/cr/registry/regdntransfer.asp?f=61

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/hs2sitc.log", replace

// SITC revision 2 in text format (UN Comtrade, CommoditiesS2.txt, Mon, Dec 04 2006)
// http://comtrade.un.org/cf/files/folders/19/download.aspx
tempfile sitc2
insheet using "braxpmkt/conc/tcommoditiess2.txt", clear
keep v1 v2
rename v1 sitc2
rename v2 sitcdesc
keep if length(sitc2)==4
duplicates drop
qui count if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]
if `r(N)'>0  STOP
label var sitc2 "SITC (Rev.2) 4-digit sector"
label var sitcdesc "SITC (Rev.2) 4-digit description"
compress
sort sitc2
save `sitc2'

// 10-digit HS to 5-digit SITC rev.2 (311k)
infix using "braxpmkt/conc/hts.sitc2.dct", using("braxpmkt/conc/hts.sitc2") clear
format hs10dgt %10.0f
format sitc5dgt %5.0f
gen hs6dgt = int(hs10dgt/10000)
label var hs6dgt "Harmonized System 6-digit code"
gen str4 sitc2 = string(int(sitc5dgt/10))
replace sitc2 = "0" + sitc2 if length(sitc2)<4
replace sitc2 = "0" + sitc2 if length(sitc2)<4
replace sitc2 = "0" + sitc2 if length(sitc2)<4
replace sitc2="" if sitc2=="000."
label var sitc2 "SITC (Rev.2) 4-digit sector"
drop hs10dgt sitc5dgt
duplicates drop
qui do "braxpmkt/conc/hs6dgt.do"
label values hs6dgt hs6dgt

* remove one-to-many mappings
sort sitc2
merge sitc2 using `sitc2', nokeep
tab _m
list hs6dgt sitc2 if _m==1
drop _m
sort hs6dgt sitc2
list hs6dgt sitc2 if hs6dgt==hs6dgt[_n-1] | hs6dgt==hs6dgt[_n+1]
* browse hs6dgt sitcdesc sitc2 if hs6dgt==hs6dgt[_n-1] | hs6dgt==hs6dgt[_n+1]
drop if hs6dgt==151920 & sitc2=="5121"
drop if hs6dgt==210690 & sitc2=="0585"
drop if hs6dgt==220290 & sitc2=="0585"
drop if hs6dgt==271000 & sitc2=="3341" // (non-crude oil 3344) problem case for later SITC-to-ISIC mapping
drop if hs6dgt==271000 & sitc2=="3342" // (non-crude oil 3344) problem case for later SITC-to-ISIC mapping
drop if hs6dgt==271000 & sitc2=="3343" // (non-crude oil 3344) problem case for later SITC-to-ISIC mapping
drop if hs6dgt==271000 & sitc2=="3345"
drop if hs6dgt==392321 & sitc2=="8931"
drop if hs6dgt==981000 & sitc2=="6649"
drop if hs6dgt==981000 & sitc2=="7742"
drop if hs6dgt==981000 & sitc2=="8720"
drop if hs6dgt==981000 & sitc2=="8960"
drop if hs6dgt==981000 & sitc2=="9310"
drop if hs6dgt==981700 & sitc2=="8947"
sort hs6dgt sitc2
qui count if hs6dgt==hs6dgt[_n-1] | hs6dgt==hs6dgt[_n+1]
if `r(N)'>0  STOP

drop sitcdesc
sort hs6dgt sitc2
save "braxpmkt/conc/hs2sitc.dta", replace

log close
cd "$home"
