*! version 1.0.1  14sep2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.2  09mar2008  by Oana Hirakawa     otocoian@ucsd.edu
*! version 1.0.3  18jan2012  by Marc Muendler     muendler@ucsd.edu

version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "braxpmkt/logs/product-data-chile.log", replace


* RAUCH DIFFERENTIATION DATA (July 2007 revision)
* Coding Scheme
*  w=goods traded on an organized exchange (homogeneous goods)
*  r=reference priced
*  n=differentiated products
* Source: Rauch, James E. "Networks Versus Markets in International Trade," Journal of International Economics 48(1) (June 1999): 7-35.
tempfile rauch
insheet using "braxpmkt/ext/rauch-classification-rev2.csv", comma clear
rename sitc4 sitc4dgt
label var sitc4dgt "SITC (Rev.2) 4-digit sector"
capture label drop scheme
label define scheme 1 "homogeneous good (on org. exch.)" 2 "reference priced" 3 "differentiated product"
foreach var in con lib {
  gen byte _`var' = 1 if `var'=="w"
  replace  _`var' = 2 if `var'=="r"
  replace  _`var' = 3 if `var'=="n"
  label values _`var' scheme
  drop `var'
  rename _`var' `var'
  }
label var con "Conservative classification"
label var lib "Liberal classification"
sort sitc4dgt
compress
save `rauch'

// map to HS 6-digit
use "braxpmkt/conc/hs2sitc.dta", clear
gen int sitc4dgt = int(real(sitc2))
label var sitc4dgt "SITC (Rev.2) 4-digit sector"
sort sitc4dgt
merge sitc4 using `rauch'
tab _m
drop sitc2 lib _m
sort hs6dgt sitc4 con
drop sitc4 
drop if hs6dgt==.
duplicates drop
sort hs6dgt
assert hs6dgt~=hs6dgt[_n-1]
compress
save `rauch', replace


* WTF IMPORT POPULARITY CONSTRUCTS
tempfile wtf
use icode importer ecode exporter sitc4 value using "$extdata/brazaux/intl/nber/wtf00.dta", clear
drop if icode=="100000" | icode=="999990" | ecode=="100000" | ecode=="999990"  // world or intl organizations
drop if exporter=="Chile" | importer=="Chile" // drop Chilean exports and imports
collapse (sum) value, by(icode sitc4) fast
gen wtfkey = real(icode)
drop icode
label var wtfkey "Six-digit WTF code"
label var sitc4 "SITC (rev. 2) 4 digits"
label var value "Imports (current US$)"
qui do "braxpmkt/conc/wtfkey-chile.do"
label values wtfkey wtfkey
order wtfkey
sort wtfkey sitc4

// OECD and Mercosur dummies
gen byte indoecd90=0
label var indoecd90 "Indic.: OECD member 1990"
replace indoecd90=1 if wtfkey==710360 // Australia 7 June 1971
replace indoecd90=1 if wtfkey==550400 // Austria 29 September 1961 
replace indoecd90=1 if wtfkey==530560 // Belgium-Lux 13 September 1961, 7 December 1961
replace indoecd90=1 if wtfkey==211240 // Canada 10 April 1961
replace indoecd90=1 if wtfkey==532080 // Denmark 30 May 1961
replace indoecd90=1 if wtfkey==552460 // Finland 28 January 1969
replace indoecd90=1 if wtfkey==532500 // France,Monac 7 August 1961
replace indoecd90=1 if wtfkey==532760 // Germany 27 September 1961
replace indoecd90=1 if wtfkey==533000 // Greece 27 September 1961
replace indoecd90=1 if wtfkey==553520 // Iceland 5 June 1961
replace indoecd90=1 if wtfkey==533720 // Ireland 7 August 1961
replace indoecd90=1 if wtfkey==533800 // Italy 29 March 1962
replace indoecd90=1 if wtfkey==413920 // Japan 28 April 1964
replace indoecd90=1 if wtfkey==535280 // Netherlands 13 November 1961
replace indoecd90=1 if wtfkey==715540 // New Zealand 29 May 1973
replace indoecd90=1 if wtfkey==555780 // Norway 4 July 1961
replace indoecd90=1 if wtfkey==536200 // Portugal 4 August 1961
replace indoecd90=1 if wtfkey==537240 // Spain 3 August 1961
replace indoecd90=1 if wtfkey==557520 // Sweden 28 September 1961
replace indoecd90=1 if wtfkey==557560 // Switz.Liecht 28 September 1961
replace indoecd90=1 if wtfkey==447920 // Turkey 2 August 1961
replace indoecd90=1 if wtfkey==538260 // UK 2 May 1961
replace indoecd90=1 if wtfkey==218400 // USA 12 April 1961
gen byte indmerc = ( wtfkey==330320 | wtfkey==336000 | wtfkey==338580 )
label var indmerc "Indic.: Mercosur member"

// collapse to worldwide
replace value = value/1000000
gen oecdimp = indoecd90*value
gen mercimp = indmerc*value
collapse (sum) wwimp=value oecdimp mercimp (count) wwdest=wtfkey, by(sitc4) fast
gen byte indi0oecd = (oecdimp==0)
gen byte indi0merc = (mercimp==0)
label var wwimp "Worldwide imports (US$ mill)"
label var oecdimp "OECD imports (US$ mill)"
label var mercimp "Mercosur imports (US$ mill)"
label var wwdest "Worldwide No. of Destinations"
label var indi0oecd "Indic.: Zero OECD imports"
label var indi0merc "Indic.: Zero Mercosur imports"
gen lnwwimp = ln(wwimp)
label var lnwwimp "Log Wrldw. Imp. (US$ mill)"
gen lnoecdimp = ln(oecdimp)
replace lnoecdimp = 0 if indi0oecd==1
label var lnoecdimp "Log nonzero OECD Imp. (US$ mill)"
gen lnmercimp = ln(mercimp)
replace lnmercimp = 0 if indi0merc==1
label var lnmercimp "Log nonz. Mrcos. Imp. (US$ mill)"
gen lnwwdest = ln(wwdest)
label var lnwwdest "Log Wrldw. No. of Destinations"
sort sitc4
compress
save `wtf'

// BALASSA COMPARATIVE ADVANTAGE DATA (OTH - Feb 16, 2008)
** note: balcadv is now defined at the SITC Rev. 2 4-digit level
** for Brazil data, it was averaged up to ISIC Rev. 2 3-digit level
    use icode importer ecode exporter sitc4 value using "$extdata/brazaux/intl/nber/wtf00.dta", clear
    keep if importer=="World"
    keep if exporter=="World" | exporter=="Chile"
    gen chile_exp = value if exporter=="Chile"
    gen wrld_exp = value if exporter=="World"
    egen chile_tot = sum(chile_exp)
    egen wrld_tot = sum(wrld_exp)
    collapse (max) *_exp *_tot, by(sitc4)
    * Balassa revealed comparative advantage measure
    gen balcadv = (chile_exp/chile_tot) / (wrld_exp/wrld_tot)
    label var balcadv "Balassa (1965) comp. advantage"
    keep sitc4 balcadv
    sort sitc4
    merge sitc4 using `wtf'
    assert _merge==3
    drop _merge

rename sitc4 sitc2
sort sitc2
compress
save `wtf', replace

// map to HS 6-digit
use "braxpmkt/conc/hs2sitc.dta", clear
sort sitc2
merge sitc2 using `wtf'
tab _m
drop sitc2 _m
sort hs6dgt
drop if hs6dgt==.
qui duplicates drop
sort hs6dgt
assert hs6dgt~=hs6dgt[_n-1]
compress
save `wtf', replace


* BALASSA COMPARATIVE ADVANTAGE DATA
    ** old Brazil version (now this is done above, before the HS 6-digit mapping, lines 132-150)
/*  tempfile bala
    use "brazaux/intl/balassa-compadv-isic2.dta", clear
    keep if year==2000
    drop year wrld_exp wrld_tot braz_exp braz_tot balarank
    sort isic2
    gen int _isic2 = int(isic2/10)
    label var _isic2 "ISIC (Rev.2) 3-digit sector"
    collapse (mean) balcadv, by(_isic2)
    label var balcadv "Balassa comp. advantage (2000)"
    rename _isic2 isic2
    sort isic2
    compress
    save `bala'
*/      

// merge with Rauch and WTF data, and map to HS 6-digit
use `rauch', clear
sort hs6dgt
merge hs6dgt using `wtf'
assert _m==3
drop _m

/* old merge with Balassa data:
    sort hs6dgt
    merge hs6dgt using "braxpmkt/conc/hs2isic.dta"
    tab _m
    drop if hs6dgt==.
    drop _m
    sort isic2
    * tab isic2, nolab
    merge isic2 using `bala'
    tab _m
    drop _m isic2
*/

tab con, gen(indcon)
label var indcon1 "Indic.: Homogeneous good"
label var indcon2 "Indic.: Reference priced"
label var indcon3 "Indic.: Differentiated product"
order hs6dgt balcadv con indcon?

drop if hs6dgt==.
sort hs6dgt
compress
save "braxpmkt/ext/product-data-chile.dta", replace

log close
