*! version 1.0.3  13apr2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.4  09mar2008  by Oana Hirakawa     otocoian@ucsd.edu
*! version 1.1.1  17jan2012  by Oana Hirakawa     otocoian@ucsd.edu
*! version 1.1.2  29jan2012  by Marc Muendler     muendler@ucsd.edu

version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "braxpmkt/logs/sector-country-data-2000-chile.log", replace

capture program drop mklbl
program define mklbl
  local var = "`1'"
  local lblname = "`2'"
  * qui replace `var' = lower(`var')
  local num = _N
  * Shorten label names
  local lblname = substr("`lblname'",1,8)
  * English labels
  forvalues i = 1/`num' {
    local lblnum = `2'[`i']
    local lblstr = `1'[`i']
    label define `lblname' `lblnum' "`lblstr'", modify
    }
  label values `2' `lblname'
  label list `lblname'
  label save `lblname' using "braxpmkt/conc/`lblname'-chile", replace
end

// Original WTF data for consistency checks (similar to %01/wtf-data.do)
  use icode importer ecode exporter sitc4 value using "$extdata/brazaux/intl/nber/wtf00.dta", clear
  drop if icode=="100000" | icode=="999990" | ecode=="100000" | ecode=="999990" // world or intl organizations
  keep if exporter=="Chile"
  drop ecode exporter
  rename icode wtfkey
  label var wtfkey "Six-digit WTF code"
  rename importer wtfcountry
  label var wtfcountry "Country name WTF (English)"
  rename value chilexp
  label var chilexp "Chile's SITC4 exports to dest."
  sort wtfkey sitc4
  collapse (sum) chilexp, fast
  local totwtfexp = chilexp[1] * 1000
  * local totwtfexp = 20045340 * 1000

// WTF country labels
use wtfkey wtfcountry using "brazaux/conc/countries/country-table.dta", clear
duplicates drop
drop if wtfkey==.
mklbl wtfcountry wtfkey

// Sector mapping from SITC Rev. 2 to ISIC Rev. 2

* 3-digit and higher-level sectors with non-unique mappings from sitc to isic are excluded
* as a consequence, WTF records with nnnA or nnnX SITC sectors for minor trade volumes (less than $100,000) are cut if they cannot be uniquely mapped
tempfile sitc4map sitc3map sitc2map sitc1map sitc3rest sitc2rest sitc1rest sitc3freq sitc2freq sitc1freq
use sitc2 isic2 using "braxpmkt/conc/sitc2isic.dta", clear
save `sitc4map'
local adddash ""
forvalues i = 3(-1)1 {
  local adddash "`adddash'-"
  replace sitc2 = substr(sitc2,1,`i') + "`adddash'"
  duplicates drop
  duplicates tag sitc2, gen(_dupl)
  preserve
    keep if _dupl>0  // keep 3-digit and higher-level sectors with many-to rather than one-to mappings from sitc to isic, those are excluded otherwise
    drop _dupl
    sort sitc2
    qui count
    if `r(N)'>0  save `sitc`i'rest'
  restore, preserve
    drop if _dupl>0  // 3-digit and higher-level sectors with many-to rather than one-to mappings from sitc to isic are excluded
    drop _dupl
    sort sitc2
    qui count
    if `r(N)'>0  save `sitc`i'map'
  restore
  drop _dupl
  }
* nonunique aggregate mappings, split-up by counts of HS products in ISIC-2 per SITC-2 aggregate
forvalues i = 3(-1)1 {
  if `i'==1  local adddash "---"
  if `i'==2  local adddash "--"
  if `i'==3  local adddash "-"
  use if sitc2~="" using "braxpmkt/conc/hs2sitc.dta", clear
  replace sitc2 = substr(sitc2,1,`i') + "`adddash'"
  sort sitc2
  merge sitc2 using `sitc`i'rest'
  drop if _m==1
  drop _m
  collapse (count) count=hs6dgt, by(sitc2 isic2) fast
  egen mapfreq = sum(count), by(sitc2)
  replace mapfreq = count/mapfreq
  drop count
  label var mapfreq "HS 6-digit frequency weight"
  qui count if mapfreq==. | isic2==.
  if `r(N)'>0  STOP
  sort sitc2 isic2
  qui count
  if `r(N)'>0  save `sitc`i'freq'
  }


/* WTF data */
/*----------*/

tempfile wtf
use isocode isoname indold wtfkey wtfcountry un3num using "brazaux/conc/countries/country-table.dta", clear
drop if ( wtfkey==368960 & isocode=="as" & un3num== 16 & indold==. ) | ( wtfkey==368960 & isocode=="gu" & un3num==316 & indold==. ) | ( wtfkey==537240 & isocode=="ea" & un3num==724 & indold==0 ) | ( wtfkey==537240 & isocode=="ic" & un3num==724 & indold==. )    // remove updates for backward compatibility to country-table from 2007-04-13
replace wtfkey=358960 if isocode=="aw"  // backward compatibility to country-table from 2007-04-13
replace wtfcountry="Carib. NES" if isocode=="aw"  // backward compatibility to country-table from 2007-04-13
drop if wtfkey==.
duplicates drop
sort wtfkey isocode un3num indold
drop if ( wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] ) & indold==1  // remaining obs.: 253 in absence and in presence of un3num

* WTF aggregate countries
sort wtfkey isocode un3num indold
list isocode isoname wtfkey wtfcountry if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1]
count if isocode=="ea"  // Ceuta/Melilla, not separately reported from Spain in WTF
count if isocode=="ic"  // Canary Islands, not separately reported from Spain in WTF
tab un3num wtfkey if isocode=="ea" | isocode=="ic"
drop if isocode=="ea" | isocode=="ic"  //  drop to avert triple counting of "es" in WTF

* obtain WTF country-sector data
sort wtfkey
joinby wtfkey using "braxpmkt/ext/wtf-data-2000-chile.dta", _merge(_merge) unmatched(both)  // uniquely identified by wtfkey sitc4
list isocode isoname wtfkey wtfcountry if _m==1  // countries with no WTF records in 2000
drop if _m==1  // mostly historic countries by 2000, some existing countries with no records
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
compress
order isocode wtfkey un3num sitc4
sort isocode wtfkey un3num sitc4
tab isocode if indold

* check country information
preserve
  keep isocode un3num indold
  duplicates drop
  sort un3num isocode
  list if un3num==un3num[_n-1] | un3num==un3num[_n+1]
  sort isocode un3num
  list if isocode==isocode[_n-1] | isocode==isocode[_n+1]
restore, preserve
  keep isocode wtfkey wtfcountry indold
  duplicates drop
  sort wtfkey isocode
  list if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1]
  sort isocode wtfkey
  list if isocode==isocode[_n-1] | isocode==isocode[_n+1]
  list if isocode=="cs" | isocode=="yu" | isocode=="bq" | isocode=="pz"
restore
count if isocode=="yu"  // formerly "Yugoslavia" (un3num 891, isocode "yu", wtfkey 598910 in 2000, secexkey 388)
count if isocode=="cs"  // now "Serbia and Montenegro" (un3num 891, isocode "cs", wtfkey 582210, secexkey 388)
replace isoname="Serbia and Montenegro" if isocode=="yu"
replace indold=0 if isocode=="yu"
replace wtfkey=582210 if isocode=="yu"
replace wtfcountry="E Europe NES" if isocode=="yu"
replace isocode="cs" if isocode=="yu"
count if wtfkey==481562  // China SC, to be consolidated with China
count if wtfkey==481561  // China FTZ, to be consolidated with China
count if wtfkey==481560  // China
replace wtfkey=481560 if wtfkey==481561 | wtfkey==481562  // SECEX compatibility: China FTZ and SC reset to China
replace wtfcountry="China" if wtfkey==481560
replace wtfkey=532760 if wtfkey==532800  // SECEX compatibility: Former West Germany reset to Germany
replace wtfcountry="Germany" if wtfkey==532760
replace wtfkey=448870 if wtfkey==448860  // SECEX compatibility: Former Yemen AR reset to Yemen
replace wtfcountry="Yemen" if wtfkey==448870
replace wtfkey=582210 if wtfkey==598900 | wtfkey==598910  // SECEX compatibility: Former Yugoslavia and Yugoslavia reset to Serbia and Montenegro (E Europe NES)
replace wtfcountry="E Europe NES" if wtfkey==582210
collapse (sum) exports imports chilexp, by(isocode wtfkey un3num sitc4 isoname indold wtfcountry) fast
label var exports "SITC4 exports from source"
label var imports "SITC4 imports to dest."
label var chilexp "Chile's SITC4 exports to dest."

// missing sector information
list isocode exports imports chilexp if sitc4==""
replace sitc4="9310" if sitc4==""

// adjustments for sitc 0901, 6344, 6553, 9000; using SITC3 | SITC4
* 091.0 - Margarine; edible mixtures or preparations of animal or vegetable fats or oils or of fractions of different such fats or oils, other than vegetable fats or oils or their fractions of subgroup 431.2
replace sitc4="0914" if sitc4=="0901"  //  0914 "Margarine, imitation lard and other prepared edible fats, nes"
* 634.4 - Other veneered panels and similar laminated wood
replace sitc4="6343" if sitc4=="6344"  //  6343 "Improved wood and reconstituted wood"
* (655.3 not found in an SITC) 655.2 - Other knitted or crocheted fabrics, not impregnated, coated, covered or laminated
replace sitc4="6552" if sitc4=="6553"  //  6552 "Knitted, not elastic nor rubberized, of fibres other than synthetic"
* 900.0 - Commodities and transactions not classified elsewhere in the SITC
replace sitc4="9310" if sitc4=="9000"  //  9310 "Special transactions, commodity not classified according to class"
* duplicates tag isocode wtfkey sitc4, gen(_dupl)
* qui count if _dupl>0
* if `r(N)'>0  STOP // commodity reclassification results in duplicates
collapse (sum) exports imports chilexp, by(isocode wtfkey sitc4 isoname indold wtfcountry un3num) fast
label var exports "SITC4 exports from source"
label var imports "SITC4 imports to dest."
label var chilexp "Chile's SITC4 exports to dest."
duplicates tag isocode wtfkey sitc4, gen(_dupl)
qui count if _dupl>0
if `r(N)'>0  STOP // commodity reclassification results in duplicates
drop _dupl

// first WTF consistency check (similar to %01/wtf-data.do)
preserve
  sort wtfkey sitc4
  by wtfkey sitc4: keep if _n==1
  collapse (sum) chilexp, fast
  local newwtfexp = chilexp[1]
  disp in gr "Check total WTF exports from Chile:" in ye %9.0f `totwtfexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %9.0f `newwtfexp'
  if `totwtfexp'~=`newwtfexp'  STOP
restore

// merge clean SITC-to-ISIC mappings in four waves, accounting for A and X sector information
gen str sitc2 = subinstr(subinstr(sitc4,"A","-",.),"X","-",.)
replace sitc2 = "9310" if sitc2=="9---"
sort sitc2
merge sitc2 using `sitc4map'
tab _m
qui count if _m~=3 & subinstr(subinstr(sitc4,"A","-",.),"X","-",.)==sitc4 & sitc4~=""
if `r(N)'>0  STOP  // non-standard SITC Rev. 2 sectors
* tab sitc4 if _m~=3 & subinstr(subinstr(sitc4,"A","-",.),"X","-",.)==sitc4 & sitc4~=""  // in absence of above adjustments, no maps for sitc 0901, 6344, 6553, 9000
drop _m
forvalues i = 3(-1)1 {
  sort sitc2
  merge sitc2 using `sitc`i'map', update nokeep
  tab _m
  qui count if _m~=3 & subinstr(subinstr(sitc4,"A","-",.),"X","-",.)==sitc4 & sitc4~="" & isic2==.
  if `r(N)'>0  STOP  // non-standard SITC Rev. 2 sectors
  * tab sitc4 if _m~=3 & subinstr(subinstr(sitc4,"A","-",.),"X","-",.)==sitc4 & sitc4~="" & isic2==.
  drop _m
  }

// simplify sitc4 (with A and X markers) to sitc2 (with - markers only)
collapse (sum) exports imports chilexp, by(isocode wtfkey un3num isoname indold wtfcountry sitc2 isic2) fast
label var exports "SITC2 exports from source"
label var imports "SITC2 imports to dest."
label var chilexp "Chile's SITC2 exports to dest."
sort isocode wtfkey un3num sitc2 isic2
duplicates tag isocode wtfkey un3num sitc2 isic2, gen(_dupl)
qui count if _dupl>0
if `r(N)'>0  STOP  // nonunique observations not permissible before dirty mappings start
drop _dupl

// merge remaining dirty SITC-to-ISIC mappings in three waves, for imperfect SITC-aggregate-to-ISIC mappings when A and X sectors occur
tab sitc2 if isic2==.  // number dirty SITC-to-ISIC b/c of A and X sectors
gen mapfreq = 1 if isic2~=.
label var mapfreq "HS 6-digit frequency weight"
forvalues i = 3(-1)1 {
  sort sitc2 isic2 isocode
  joinby sitc2 using `sitc`i'freq', _merge(_merge) unmatched(master) update
  tab _m
  qui count if index(substr(sitc2,1,`i'),"-")>0 & _m==3
  if `r(N)'>0  STOP  // even dirty mapping incomplete, revisit
  * tab sitc4 if index(substr(sitc2,1,`i'),"-")>0 & _m==3
  drop _m
  }
qui count if isic2==.
if `r(N)'>0  STOP  // even dirty mapping incomplete, revisit

// second WTF consistency check (similar to %01/wtf-data.do)
preserve
  sort wtfkey sitc2
  by wtfkey sitc2: keep if _n==1
  collapse (sum) chilexp, fast
  local newwtfexp = chilexp[1]
  disp in gr "Check total WTF exports from Chile:" in ye %9.0f `totwtfexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %9.0f `newwtfexp'
  if `totwtfexp'~=`newwtfexp'  STOP
restore

// finalize WTF data
sort isocode wtfkey un3num sitc2 isic2
duplicates tag isocode wtfkey un3num sitc2 isic2, gen(_dupl)
qui count if _dupl>0
if `r(N)'>0  STOP  // nonunique observations not permissible before collapse
foreach var in exports imports chilexp {
  replace `var' = `var' * mapfreq
  }
replace isic2=311 if isic2==312  // create single food products sector
collapse (sum) wtf_exports=exports wtf_imports=imports wtf_chilexp=chilexp, by(isocode wtfkey un3num isoname wtfcountry isic2) fast
label var wtf_exports "ISIC2 exports from source"
label var wtf_imports "ISIC2 imports to dest."
label var wtf_chilexp "Chile's ISIC2 exports to dest."
note: Totals of wtf_exports, wtf_imports and wtf_chilexp are only correct at wtfkey level: 
note: keep isic2 wtfkey wtf_*; 
note: sort isic2 wtfkey; 
note: by isic2 wtfkey: 
note: keep if _n==1;
order un3num isocode wtfkey isoname wtfcountry isic2
sort un3num isocode wtfkey isoname wtfcountry isic2
save `wtf'

// final WTF consistency check (similar to %01/wtf-data.do)
preserve
  sort wtfkey isic2
  by wtfkey isic2: keep if _n==1
  collapse (sum) wtf_chilexp, fast
  local newwtfexp = wtf_chilexp[1]
  disp in gr "Check total WTF exports from Chile:" in ye %9.0f `totwtfexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %9.0f `newwtfexp'
  if float(`totwtfexp')~=float(`newwtfexp')  STOP
restore


/* UNIDO data */
/*------------*/

// UNIDO country-sector data for consistency checks
  use un3num isic2 output_usd using "braxpmkt/ext/unido-2000-undefl-us-dollars.dta", clear
  drop if isic2==300  // drop total manufacturing
  sort un3num isic2
  collapse (sum) output_usd, fast
  local totunoexp = output_usd[1]
  * local totunoexp = 1.44504684e+13

// UNIDO data preparation
use isocode isoname indold wtfkey wtfcountry un3num unname using "brazaux/conc/countries/country-table.dta", clear
drop if ( wtfkey==368960 & isocode=="as" & un3num== 16 & indold==. ) | ( wtfkey==368960 & isocode=="gu" & un3num==316 & indold==. ) | ( wtfkey==537240 & isocode=="ea" & un3num==724 & indold==0 ) | ( wtfkey==537240 & isocode=="ic" & un3num==724 & indold==. )    // remove updates for backward compatibility to country-table from 2007-04-13
replace un3num=590 if un3num==591  // Panama listed as former Panama Canal Zone in Unido 2000 data
replace wtfkey=358960 if isocode=="aw"  // backward compatibility to country-table from 2007-04-13
replace wtfcountry="Carib. NES" if isocode=="aw"  // backward compatibility to country-table from 2007-04-13
drop if un3num==.
replace indold=0 if indold==.  // reset missing to "current"
duplicates drop
sort un3num
drop if ( un3num==un3num[_n-1] | un3num==un3num[_n+1] ) & indold==1  // remaining obs.: 261 in presence of wtfkey

* UNIDO aggregate countries
sort un3num isocode wtfkey
list isocode un3num unname wtfkey wtfcountry if un3num==un3num[_n-1] | un3num==un3num[_n+1]
drop if isocode=="cn" & un3num==156 & wtfkey~=481560
drop if (isocode=="ea" | isocode=="ic") & un3num==724 & wtfkey==537240  // Ceuta/Melilla and Canary Islands reported with Spain
duplicates tag un3num wtfkey, gen(_dupl)
qui count if _dupl>0
if `r(N)' >0  STOP  // data should be uniquely identified by un3num wtfkey at this point
sort un3num wtfkey

* obtain UNIDO country-sector data
sort un3num
joinby un3num using "braxpmkt/ext/unido-2000-undefl-us-dollars.dta", _merge(_merge) unmatched(both)
keep isocode isoname indold wtfkey wtfcountry un3num unname isic2 output_usd _m
list isocode un3num unname if _m==1  // countries with no UNIDO records in 2000
drop if _m==1  // limited UNIDO records
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
drop if isic2==300  // drop total manufacturing
compress
order isocode un3num wtfkey isic2 
sort isocode un3num wtfkey isic2 
tab isocode if indold
drop indold
replace un3num=591 if un3num==590  // Panama listed as former Panama Canal Zone in Unido 2000 data; reset for compatibility with WTF data

// first Unido data consistency check
preserve
  sort un3num isic2
  by un3num isic2: keep if _n==1
  collapse (sum) output_usd, fast
  local newunoexp = output_usd[1]
  disp in gr "Check total Unido USD output:" in ye %9.0f `totunoexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %9.0f `newunoexp'
  if float(`totunoexp')~=float(`newunoexp')  STOP
restore

* check country information
preserve
  keep isocode un3num
  duplicates drop
  sort un3num isocode
  list if un3num==un3num[_n-1] | un3num==un3num[_n+1]
  sort isocode un3num
  list if isocode==isocode[_n-1] | isocode==isocode[_n+1]
restore, preserve
  keep isocode wtfkey wtfcountry
  duplicates drop
  sort wtfkey isocode
  list if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1]  // Afr.Other NS not exhaustive compared to WTF; Belgium-Lux exhaustive
  sort isocode wtfkey
  list if isocode==isocode[_n-1] | isocode==isocode[_n+1]
  list if isocode=="cs" | isocode=="yu" | isocode=="bq" | isocode=="pz"  // "Serbia and Montenegro" well defined (un3num 891, isocode "cs", wtfkey 582210, secexkey 388)
restore
rename output_usd un3_output
replace wtfkey=481560 if wtfkey==481561 | wtfkey==481562  // SECEX compatibility: China FTZ and SC reset to China
replace wtfcountry="China" if wtfkey==481560
replace wtfkey=532760 if wtfkey==532800  // SECEX compatibility: Former West Germany reset to Germany
replace wtfcountry="Germany" if wtfkey==532760
replace wtfkey=448870 if wtfkey==448860  // SECEX compatibility: Former Yemen AR reset to Yemen
replace wtfcountry="Yemen" if wtfkey==448870
replace wtfkey=582210 if wtfkey==598900 | wtfkey==598910  // SECEX compatibility: Former Yugoslavia and Yugoslavia reset to Serbia and Montenegro (E Europe NES)
replace wtfcountry="E Europe NES" if wtfkey==582210

// create single food products sector
replace isic2=311 if isic2==312

// no missing sector information
list isocode un3_output if isic2==.

// aggregate output to WTF country-level and isic2 single sectors
collapse (sum) un3_output, by(un3num isocode wtfkey isoname wtfcountry isic2) fast
label var un3_output "ISIC2 output"
egen wtf_output = sum(un3_output), by(wtfkey isic2)
label var wtf_output "ISIC2 output"
tab isocode if wtf_output~=un3_output & un3_output~=. // aggregation effective only for Belgium-Luxemburg
drop un3_output

// final Unido data consistency check
preserve
  sort wtfkey isic2 isocode un3num
  by wtfkey isic2: keep if _n==1
  collapse (sum) wtf_output, fast
  local newunoexp = wtf_output[1]
  disp in gr "Check total Unido USD output:" in ye %12.0f `totunoexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %12.0f `newunoexp'
  if float(`totunoexp')~=float(`newunoexp')  STOP
restore


/* FINALIZE JOINT UNIDO-WTF DATA AND COUNTRY MAPPING */
/*---------------------------------------------------*/

sort un3num isocode wtfkey isoname wtfcountry isic2 
joinby un3num isocode wtfkey isoname wtfcountry isic2 using `wtf', _merge(_merge) unmatched(both)
egen _wtf_output = min(wtf_output), by(wtfkey isic2)  // spread wtf_output information across newly merged observations
drop wtf_output
rename _wtf_output wtf_output
label var wtf_output "ISIC2 output"
notes
tab _m

// merged WTF and Undio consistency check (similar to %01/wtf-data.do)
preserve
  sort wtfkey isic2 isocode un3num
  by wtfkey isic2: keep if _n==1
  collapse (sum) wtf_chilexp wtf_output, fast
  local newwtfexp = wtf_chilexp[1]
  disp in gr "Check total WTF exports from Chile:" in ye %9.0f `totwtfexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %9.0f `newwtfexp'
  if float(`totwtfexp')~=float(`newwtfexp')  STOP
  local newunoexp = wtf_output[1]
  disp in gr "Check total Unido USD output:" in ye %12.0f `totunoexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %12.0f `newunoexp'
  if float(`totunoexp')~=float(`newunoexp')  STOP
restore

sort wtfkey isic2 isocode un3num
summ wtf_output if wtfkey==168960 & isic2~=isic2[_n-1]
local africarem = `r(sum)'  // 3.664e+08 (366391890)
replace wtf_output=. if wtfkey==168960  // Afr.Other NS not exhaustive compared to WTF

// final overall data consistency check
preserve
   sort wtfkey isic2 isocode un3num
   by wtfkey isic2: keep if _n==1
   collapse (sum) wtf_chilexp wtf_output, fast
   local newwtfexp = wtf_chilexp[1]
   disp in gr "Check total WTF exports from Chile:" in ye %9.0f `totwtfexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %9.0f `newwtfexp'
   if float(`totwtfexp')~=float(`newwtfexp')  STOP
   local newunoexp = wtf_output[1] + `africarem'
   disp in gr "Check total Unido USD output:" in ye %12.0f `totunoexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %12.0f `newunoexp'
   if float(`totunoexp')~=float(`newunoexp')  STOP
restore

sort isocode wtfkey un3num isic2
duplicates tag isocode wtfkey un3num isic2, gen(_dupl)
assert _dupl==0  // nonunique observations not permissible
drop _dupl
preserve
  keep un3num isocode
  duplicates drop
  sort un3num isocode
  qui count if ( un3num==un3num[_n-1] | un3num==un3num[_n+1] ) & un3num~=.
  if `r(N)'>0  STOP  // non-unique un3num-isocode association
  sort isocode un3num
  qui count if ( isocode==isocode[_n-1] | isocode==isocode[_n+1] ) & isocode~=""
  if `r(N)'>0  STOP  // non-unique isocode-un3num association  
restore
drop un3num _m
qui do "braxpmkt/conc/isic2.do"
label values isic2 isic2
order isocode isoname wtfkey wtfcountry isic2
sort isocode wtfkey isic2

count
notes drop _dta
preserve
  keep isocode wtfkey isic2
  duplicates drop
  qui do "braxpmkt/conc/wtfkey-chile.do"
  label values wtfkey wtfkey
  sort wtfkey isic2 isocode
  save "braxpmkt/ext/sector-country-data-conc-2000-chile.dta", replace
restore

keep wtfkey isic2 wtf_*
sort wtfkey isic2
qui do "braxpmkt/conc/wtfkey-chile.do"
label values wtfkey wtfkey
* duplicates tag wtfkey isic2, gen(_dupl)
* list if _dupl>0, nolab
* drop _dupl
by wtfkey isic2: keep if _n==1

// final overall data consistency check
preserve
   sort wtfkey isic2
   by wtfkey isic2: keep if _n==1
   collapse (sum) wtf_chilexp wtf_output, fast
   local newwtfexp = wtf_chilexp[1]
   disp in gr "Check total WTF exports from Chile:" in ye %9.0f `totwtfexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %9.0f `newwtfexp'
   if float(`totwtfexp')~=float(`newwtfexp')  STOP
   local newunoexp = wtf_output[1] + `africarem'
   disp in gr "Check total Unido USD output:" in ye %12.0f `totunoexp' in gr ", compared to sector-country-data-2000-chile.dta: " in ye %12.0f `newunoexp'
   if float(`totunoexp')~=float(`newunoexp')  STOP
restore

// preserve world total

count
sort wtfkey isic2
save "braxpmkt/ext/sector-country-data-2000-chile.dta", replace
notes

log close
