*! version 1.0.2  09sep2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.2.3  21sep2010  by Marc Muendler  muendler@ucsd.edu

global sigma = 7.49    // as in main calibration (Figure fig:matlab-comp)
global beta = .334989  // see beta estimate in %01/simulation-data-2000.do

version 9.2
clear
set logtype text
set more off
set matsize 200
set mem 500m

capture log close
log using "braxpmkt/logs/simulation-data-2000-smplslct.log", replace

* NOTE: all data in plain USD

* -slct: move countries with no gamma observation to ROW (alternatively move SELECT problem countries to ROW)
*------------------------------------------------------------------------------------------------------------

tempfile zerolst  // alternative
clear
input str12 country
  "Croatia"     //  24. Croatia
  "ElSalvador"  //  30. ElSalvador
  "Honduras"    //  40. Honduras
  "Kyrgyzstan"  //  54. Kyrgyzstan
  "Libya"       //  56. Libya
  "Lithuania"   //  57. Lithuania
  "Madagascar"  //  59. Madagascar
  "Niger"       //  68. Niger
  "Slovakia"    //  81. Slovakia
  "Zambia"      // 101. Zambia
end
sort country
save `zerolst'

tempfile prbllst  // potientially add-to-ROW under alternative
clear
input str12 country
  "Australia"     //   3. Australia
  "Burundi"       //  15. Burundi
  "Mauritius"     //  61. Mauritius
  "Philippines"   //  73. Philippines
  "Poland"        //  74. Poland
  "SaudiArabia"   //  79. SaudiArabia
  "Sweden"        //  88. Sweden
  "TrinidadTbg"   //  90. TrinidadTbg
  "WestBankGaza"  // 100. WestBankGaza
end
sort country
save `prbllst'

tempfile nogamma  // currently active
  use exp_country gamma using "braxpmkt/ext/simulation-data-2000.dta", clear
  rename exp_country country
  bysort country: keep if _n==1
  keep if gamma==.
  drop gamma
  sort country
save `nogamma'

use exp_country imp_country bilattrd tbwtf gdp ca tbg tbgs mfva gamma mfab using "braxpmkt/ext/simulation-data-2000.dta", clear
foreach trd in exp imp {
  rename `trd'_country country
  sort country
  merge country using `nogamma'
  gen byte _ind2row = (_merge==3)
  replace country="_RestOfWorld" if _ind2row==1
  replace country="_RestOfWorld" if country=="Estonia" | country=="Moldova"
  rename country `trd'_country
  drop _m _ind2row
  }
foreach var in bilat tbwtf gdp {
  qui summ `var', meanonly
  disp in gr "Total " in ye "`var'" in gr ": " in ye `r(sum)'
  }
summ gamma if exp_country=="_RestOfWorld"  // gamma exists for ROW (see note)
* note: ROW from WTF is (see "tab `trd'_wtfcountry if _m==1" in simulation-data-2000.log): Afghanistan, Afr.OtherNS, Algeria, AreasNES, AsiaNES, AsiaWestNS, Bermuda, Br.Antr.Terr, CACMNES, Carib.NES, Cent.Afr.Rep, Chad, Cuba, Dem.Rp.Congo, EEuropeNES, EECNES, Eq.Guinea, Eur.OtherNE, FalklandIs, FrIndO, Gambia, Gibraltar, Greenland, Guadeloupe, GuineaBissau, Iraq, Kiribati, KoreaDPRp, Lebanon, Liberia, Mauritania, Myanmar, Neth.Ant.Aru, NeutralZone, NewCalednia, Oth.Oceania, Qatar, Samoa, Somalia, St.Helena, St.PierreMq, Taiwan, Tajikistan, Turkmenistan, USNES, UntdArabEm, Uzbekistan, Yugoslavia, Zimbabwe; and (see "list country // content of `rowlst'" in simulation-data-2000.log) Albania, Angola, Azerbaijan, Bahamas, Benin, BosniaHerzeg, Congo, Cyprus, Djibouti, Ethiopia, Gabon, Ghana, Greece, Guinea, India, LaoPDR, Malawi, Mali, Mongolia, Mozambique, Oman, Panama, PapuaNGuinea, Paraguay, Senegal, SierraLeone, StKtNevAn, Suriname, Syria, Tanzania, Togo, Yemen
*       ROW from WDI is "WLD" (see "drop if wdikey==..." in simulation-data-2000.do; ignore "tab wdicountry if _m==1" in simulation-data-2000.log): replace wdikey="_RW" if wdikey=="WLD" in simulation-data-2000.do
*       so gamma exists for ROW from a mix of WTF-excluded-country information and WDI-worldwide information
collapse (sum) bilattrd tbwtf gdp ca tbg tbgs mfva mfab (mean) gamma, by(exp_country imp_country) fast
foreach var in bilattrd tbwtf gdp ca tbg tbgs mfva mfab gamma {
  replace `var'=. if `var'==0
  }
label var bilattrd "Bilat. trade WTF-Mf. [curr. US$]"
label var tbwtf "Trade bal. WTF-Mf. [curr. US$]"
label var gdp "GDP [current US$]"
label var ca  "Current account bal. [curr. US$]"
label var tbg "Trade bal. goods [curr. US$]"
label var tbgs "Trade bal. gds&srvcs [curr. US$]"
label var mfva "Manufct. Value added [curr. US$]"
label var mfab "Manufct. Absorption [curr. US$]"
label var gamma_mfab "Mf. Share in val. add. and trade"
foreach var in bilat tbwtf gdp {
  qui summ `var', meanonly
  disp in gr "Total " in ye "`var'" in gr ": " in ye `r(sum)'
  }
replace bilattrd=. if exp_country==imp_country  // diagonal entries removed in accordance with reset of RestOfWorld
sort exp_country imp_country
save "braxpmkt/ext/simulation-data-2000-slct.dta", replace

* Excel matrix "gdp_00r" for Matlab
use "braxpmkt/ext/simulation-data-2000-slct.dta", clear
keep exp_country gdp
rename exp_country country
bysort country: keep if _n==1
outsheet using "braxpmkt/matlab/gdp_00r.csv", comma nonames replace

* Excel matrix "catb_00r" for Matlab
use "braxpmkt/ext/simulation-data-2000-slct.dta", clear
keep exp_country ca tbgs  // tbwtf left out as in DEK07
rename exp_country country
bysort country: keep if _n==1
order country ca tbgs
sort country
outsheet using "braxpmkt/matlab/catb_00r.csv", comma names replace

* Excel matrix "trade_00r" for Matlab
use "braxpmkt/ext/simulation-data-2000-slct.dta", clear
keep exp_country imp_country bilattrd
rename bilattrd imp_
reshape wide imp_, i(exp_country) j(imp_country) string
rename exp_country _exp
local falsdiag = 0
qui count
forvalues i=1/`r(N)' {
  local wtf = _exp[`i']
  if imp_`wtf'[`i']~=. {
    disp in red "False diagonal entry for WTF key " in ye "`wtf'"
    local falsdiag = `falsdiag' + 1
    }
  }
if `falsdiag'>0  STOP  // No region can have exports to self (ROW-to-ROW dropped in data preparation before) 
unab varlist : imp_*
foreach var in `varlist' {
  qui replace `var'=0 if `var'==.
  }
outsheet using "braxpmkt/matlab/trade_00r.csv", comma names replace

* Excel matrix "gamma_00r" for Matlab (country mean gamma to RestOfWorld)
use "braxpmkt/ext/simulation-data-2000-slct.dta", clear
keep exp_country gamma
rename exp_country country
bysort country: keep if _n==1
summ gamma if country~="_RestOfWorld", meanonly
replace gamma = `r(mean)' if country=="_RestOfWorld"  // assign country mean gamma to RestOfWorld
order country gamma
sort country
outsheet using "braxpmkt/matlab/gamma_00r.csv", comma names replace

* Excel matrix "mfab_00r" for Matlab (manuf. absorpt. for RestOfWorld is imputed from country mean gamma and RestOfWorld data)
use "braxpmkt/ext/simulation-data-2000-slct.dta", clear
keep exp_country mfab gamma_mfab gdp tbgs tbwtf
rename exp_country country
bysort country: keep if _n==1
summ gamma if country~="_RestOfWorld", meanonly
replace gamma = `r(mean)' if country=="_RestOfWorld"  // assign country mean gamma to RestOfWorld
replace mfab=(gamma_mfab*(gdp-tbgs)+(1-$beta)*(1-1/$sigma)*tbwtf)/(1-(1-$beta)*(1-1/$sigma)) if country=="_RestOfWorld"
drop gamma_mfab gdp tbgs tbwtf
order country mfab
sort country
outsheet using "braxpmkt/matlab/mfab_00r.csv", comma names replace


* -minset: Keep countries with BETA estimate, map rest to ROW
*------------------------------------------------------------

tempfile corelst  // manual construct
clear
input str12 country
  "Australia"    //  1.    Australia
  "Austria"      //  2.      Austria
  "BelgmLuxNthl" //  3. BelgmLuxNthl
  "Bolivia"      //  4.      Bolivia
  "Bulgaria"     //  5.     Bulgaria
  "Canada"       //  6.       Canada
  "Chile"        //  7.        Chile
  "ChinaHKG"     //  8.     ChinaHKG
  "Colombia"     //  9.     Colombia
  "CostaRica"    // 10.    CostaRica
  "Estonia"      // 11.      Estonia
  "Finland"      // 12.      Finland
  "FranceMonaco" // 13. FranceMonaco
  "Germany"      // 14.      Germany
  "Hungary"      // 15.      Hungary
  "IndMalSgThai" // 16. IndMalSgThai
  "Iran"         // 17.         Iran
  "Ireland"      // 18.      Ireland
  "Israel"       // 19.       Israel
  "Italy"        // 20.        Italy
  "Japan"        // 21.        Japan
  "Jordan"       // 22.       Jordan
  "Kenya"        // 23.        Kenya
  "Kuwait"       // 24.       Kuwait
  "Latvia"       // 25.       Latvia
  "Malta"        // 26.        Malta
  "Mexico"       // 27.       Mexico
  "Moldova"      // 28.      Moldova
  "Morocco"      // 29.      Morocco
  "Norway"       // 30.       Norway
  "Poland"       // 31.       Poland
  "Portugal"     // 32.     Portugal
  "Romania"      // 33.      Romania
  "RussianFed"   // 34.   RussianFed
  "Slovenia"     // 35.     Slovenia
  "SouthKorea"   // 36.   SouthKorea
  "Spain"        // 37.        Spain
  "SriLanka"     // 38.     SriLanka
  "Sweden"       // 39.       Sweden
  "TrinidadTbg"  // 40.  TrinidadTbg
  "Tunisia"      // 41.      Tunisia
  "Turkey"       // 42.       Turkey
  "UK"           // 43.           UK
  "USA"          // 44.          USA
  "Uruguay"      // 45.      Uruguay
  "VietNam"      // 46.      VietNam
  "_RestOfWorld" // 47. _RestOfWorld
end
sort country
save `corelst'
clear

tempfile hasbetgam  // currently active
  use exp_country beta using "braxpmkt/ext/simulation-data-2000.dta", clear
  rename exp_country country
  bysort country: keep if _n==1
  keep if beta~=.
  drop beta
  sort country
  merge country using `nogamma', nokeep
  tab _m
  list country if _m==3
  drop if _m==3
  keep country
  sort country
save `hasbetgam'

use exp_country imp_country bilattrd tbwtf gdp ca tbg tbgs mfva gamma beta mfab using "braxpmkt/ext/simulation-data-2000.dta", clear
foreach trd in exp imp {
  rename `trd'_country country
  sort country
  merge country using `hasbetgam'
  /* keep country _merge; bysort country _merge: keep if _n==1; count if _m==3 */
  gen byte _ind2row = (_merge~=3)
  replace country="_RestOfWorld" if _ind2row==1
  replace country="_RestOfWorld" if country=="Estonia" | country=="Moldova"
  rename country `trd'_country
  drop _m _ind2row
  }
foreach var in bilat tbwtf gdp {
  qui summ `var', meanonly
  disp in gr "Total " in ye "`var'" in gr ": " in ye `r(sum)'
  }
collapse (sum) bilattrd tbwtf gdp ca tbg tbgs mfva mfab (mean) gamma beta, by(exp_country imp_country) fast
foreach var in bilattrd tbwtf gdp ca tbg tbgs mfva mfab gamma beta {
  replace `var'=. if `var'==0
  }
label var bilattrd "Bilat. trade WTF-Mf. [curr. US$]"
label var tbwtf "Trade bal. WTF-Mf. [curr. US$]"
label var gdp "GDP [current US$]"
label var ca  "Current account bal. [curr. US$]"
label var tbg "Trade bal. goods [curr. US$]"
label var tbgs "Trade bal. gds&srvcs [curr. US$]"
label var mfva "Manufct. Value added [curr. US$]"
label var mfab "Manufct. Absorption [curr. US$]"
label var gamma_mfab "Mf. Share in val. add. and trade"
label var beta "Share Mf. val. add in Mf. output"
foreach var in bilat tbwtf gdp {
  qui summ `var', meanonly
  disp in gr "Total " in ye "`var'" in gr ": " in ye `r(sum)'
  }
replace bilattrd=. if exp_country==imp_country  // diagonal entries removed in accordance with reset of RestOfWorld
sort exp_country imp_country
save "braxpmkt/ext/simulation-data-2000-minset.dta", replace

* Excel matrix "gdp_00m" for Matlab
use "braxpmkt/ext/simulation-data-2000-minset.dta", clear
keep exp_country gdp
rename exp_country country
bysort country: keep if _n==1
outsheet using "braxpmkt/matlab/gdp_00m.csv", comma nonames replace

* Excel matrix "catb_00m" for Matlab
use "braxpmkt/ext/simulation-data-2000-minset.dta", clear
keep exp_country ca tbgs  // tbwtf left out as in DEK07
rename exp_country country
bysort country: keep if _n==1
order country ca tbgs
sort country
outsheet using "braxpmkt/matlab/catb_00m.csv", comma names replace

* Excel matrix "trade_00m" for Matlab
use "braxpmkt/ext/simulation-data-2000-minset.dta", clear
keep exp_country imp_country bilattrd
rename bilattrd imp_
reshape wide imp_, i(exp_country) j(imp_country) string
rename exp_country _exp
local falsdiag = 0
qui count
forvalues i=1/`r(N)' {
  local wtf = _exp[`i']
  if imp_`wtf'[`i']~=. {
    disp in red "False diagonal entry for WTF key " in ye "`wtf'"
    local falsdiag = `falsdiag' + 1
    }
  }
if `falsdiag'>0  STOP  // No region can have exports to self (ROW-to-ROW dropped in data preparation before) 
unab varlist : imp_*
foreach var in `varlist' {
  qui replace `var'=0 if `var'==.
  }
outsheet using "braxpmkt/matlab/trade_00m.csv", comma names replace

* Excel matrix "gamma_00m" for Matlab (country mean gamma to RestOfWorld)
use "braxpmkt/ext/simulation-data-2000-minset.dta", clear
keep exp_country gamma_mfab
rename gamma_mfab gamma
rename exp_country country
bysort country: keep if _n==1
summ gamma if country~="_RestOfWorld", meanonly
replace gamma = `r(mean)' if country=="_RestOfWorld"  // assign country mean gamma to RestOfWorld
order country gamma
sort country
outsheet using "braxpmkt/matlab/gamma_00m.csv", comma names replace

* Excel matrix "beta_00m" for Matlab
use "braxpmkt/ext/simulation-data-2000-minset.dta", clear
keep exp_country beta
rename exp_country country
bysort country: keep if _n==1
* note: ROW from UNIDO is (see "tab un3num if _m==1" in simulation-data-2000.log): Botswana (Pula), Myanmar (Kyats), CookIslands (Dollars), Cyprus (Pounds), Ethiopia (Birr), Eritrea (Nakfa), India (Rupees), Oman (Rials), NetherlandsAntilles (Guilders), Panama (Balboas), PuertoRico (Dollars), Qatar (Riyals), Senegal (CFAFrancs), Yemen (Rials), SerbiaandMontenegro (Dinars)
*       to match ROW more plausibly, reset BETA to sample average (excluding UNIDO ROW from average)
qui summ beta if country~="_RestOfWorld", meanonly
replace beta = `r(mean)' if country=="_RestOfWorld"
order country beta
sort country
outsheet using "braxpmkt/matlab/beta_00m.csv", comma names replace

* Excel matrix "mfab_00m" for Matlab (manuf. absorpt. for RestOfWorld is imputed from country mean gamma and RestOfWorld data)
use "braxpmkt/ext/simulation-data-2000-minset.dta", clear
keep exp_country mfab gamma_mfab gdp tbgs tbwtf
rename exp_country country
bysort country: keep if _n==1
summ gamma if country~="_RestOfWorld", meanonly
replace gamma = `r(mean)' if country=="_RestOfWorld"  // assign country mean gamma to RestOfWorld
replace mfab=(gamma_mfab*(gdp+tbgs)-(1-$beta)*(1-1/$sigma)*tbwtf)/(1-(1-$beta)*(1-1/$sigma)) if country=="_RestOfWorld"
drop gamma_mfab gdp tbgs tbwtf
order country mfab
sort country
outsheet using "braxpmkt/matlab/mfab_00m.csv", comma names replace

log close
