*! version 1.0.3  02aug2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.1.2  10sep2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.2.3  21sep2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.3.2  29jan2012  by Marc Muendler  muendler@ucsd.edu

global sigma = 7.49    // as in main calibration (Figure fig:matlab-comp)
global beta = .334989  // see beta estimate below

version 9.2
clear
set logtype text
set more off
set matsize 200
set mem 500m

capture log close
log using "braxpmkt/logs/simulation-data-2000.log", replace

* NOTE: all data in single USD
* NOTE: RestOfWorld is reported World total (there is World in WTF and WDI but not in Unido) less Sample total

capture program drop cntryset
program define cntryset
  args var
  capture rename `var' country
  * DEK: collapse (i) Hong Kong, Macao and mainland China, (ii) Belgium, Luxembourg and the Netherlands, and (iii) Indonesia, Malaysia, Singapore, and Thailand into single entities
  replace country="BelgmLuxNthl" if country=="BelgiumLux"
  replace country="BelgmLuxNthl" if country=="Netherlands"
  replace country="IndMalSgThai" if country=="Indonesia"
  replace country="IndMalSgThai" if country=="Malaysia"
  replace country="IndMalSgThai" if country=="Singapore"
  replace country="IndMalSgThai" if country=="Thailand"
  * DEK: move Saudi Arabia, Poland, Iran, and the Czech Republic into ROW [United Arab Emirates, Puerto Rico not in our data]
  * replace country="_RestOfWorld" if country=="SaudiArabia"
  * replace country="_RestOfWorld" if country=="Poland"
  * replace country="_RestOfWorld" if country=="Iran"
  * replace country="_RestOfWorld" if country=="CzechRep"
  capture rename country `var'
end

capture program drop amcountry
program define amcountry
  replace wtfcountry=subinstr(subinstr(subinstr(subinstr(wtfcountry,",","",.)," ","",.),"-","",.),".","",.)
  replace wtfcountry="SouthKorea" if wtfkey==454100
  replace wtfcountry="DominicanRep" if wtfkey==352140
  replace wtfcountry="LaoPDR" if wtfkey==454180
  replace wtfcountry="FranceMonaco" if wtfkey==532500
  replace wtfcountry="Switzerland" if wtfkey==557560
  replace wtfcountry="Moldova" if wtfkey==584980
  replace wtfcountry="BosniaHerzeg" if wtfkey==590700
  replace wtfcountry="MacedoniaFYR" if wtfkey==598070
  replace wtfcountry="PapuaNGuinea" if wtfkey==725980
  replace wtfcountry="WestBankGaza" if wtfkey==442750
  replace wtfcountry="ChinaHKG" if wtfkey==481560  // Hong Kong to be collapsed with China
  rename wtfcountry country
  label var country "Country name (AM10)"
end


/* READY CONCORDANCE SITC manufacturing products (WTF) */
tempfile sitc4mf
use "braxpmkt/conc/sitc2isic.dta", clear
keep if isic2>=300 & isic2<=390
keep sitc2  // string SITC (Rev.2) 4-digit sector
rename sitc2 sitc4  // variable name in WTF
bysort sitc4: keep if _n==1
sort sitc4
save `sitc4mf'

/* RAW CONCORDANCE SITC manufacturing products (UN Comtrade India) as in %01/sitc2isic.do */
infix using "braxpmkt/conc/sitc2isic.dct", using("braxpmkt/conc/sitc2.isic2.txt") clear
* CORRECTIONS OF MAPPINGS (ISIC 380 does not exist in Rev. 2)
replace isic5="37---" if isic5=="38---" & sitc5=="282--" // Ferrous waste and scrap; remelting scrap ingots of iron or steel
replace isic5="371--" if isic5=="380--" & sitc5=="282--" // Ferrous waste and scrap; remelting scrap ingots of iron or steel
replace isic5="3710-" if isic5=="3801-" & sitc5=="282--" // Ferrous waste and scrap; remelting scrap ingots of iron or steel
replace isic5="37---" if isic5=="38---" & sitc5=="2882-" // Other non-ferrous base metal waste and scrap, n.e.s.
replace isic5="372--" if isic5=="380--" & sitc5=="2882-" // Other non-ferrous base metal waste and scrap, n.e.s.
replace isic5="3720-" if isic5=="3801-" & sitc5=="2882-" // Other non-ferrous base metal waste and scrap, n.e.s.
replace isic5="37---" if isic5=="38---" & sitc5=="68914" // Magnesium waste and scrap
replace isic5="372--" if isic5=="380--" & sitc5=="68914" // Magnesium waste and scrap
replace isic5="3720-" if isic5=="3801-" & sitc5=="68914" // Magnesium waste and scrap
qui count if substr(isic5,1,3)=="380"
if `r(N)'>0  STOP
* SITC (rev. 2) 4 digits
gen str4 sitc2 = substr(sitc5,1,4) if substr(sitc5,5,1)=="-"
label var sitc2 "SITC (Rev.2) 4-digit sector"
drop sitc5
order sitc2 map isic5
drop if sitc2==""
* ISIC (Rev.2) 3-digit
sort isic5
gen int isic2 = real(substr(isic5,1,3))
label var isic2 "ISIC (Rev.2) 3-digit sector"
qui do "braxpmkt/conc/unido-isic2.do"
* qui do "braxpmkt/conc/isic2.do"
label values isic2 isic2
drop if isic2==.
keep if substr(isic5,4,2)=="--"
* ONE-TO-ONE or ONE-TO-MANY ISIC MAPPING (remove ambiguities)
tempfile sitcoecd
drop if substr(map,1,1)=="-"
drop if length(map)==3 & int(real(substr(map,2,2)))<50
drop isic5 map
rename sitc2 sitc4mf
sort sitc4mf isic2
compress
save `sitcoecd'


/* WTF DATA preparation */

* UN Comtrade India exporter concordance (comtrade.un.org 2010/08/02)
tempfile uncntry india
use unname wtfkey wtfcountry using "brazaux/conc/countries/country-table.dta", clear
duplicates drop
drop if unname==""
duplicates tag unname, gen(_dupl)
list if _dupl>0
drop if wtfkey==532800 | wtfkey==448860 | wtfkey==598910 | wtfkey==481561 | wtfkey==481562
drop _dupl
duplicates tag unname, gen(_dupl)
list if _dupl>0
qui count if _dupl>0
if `r(N)'>0  STOP
drop _dupl
sort unname
save `uncntry'

* UN Comtrade India data (comtrade.un.org 2010/08/02)
insheet using "braxpmkt/ext/uncomtrade/uncomtrade-india-2000.csv", comma clear
qui summ period
if `r(mean)'~=2000  STOP
tab tradeflow
tab reporter
keep reporter partner commodity* tradevalue
rename reporter importer
gen str6 icode="453560"
* exporter match (reset to wtf standard names)
rename partner unname
replace unname="Bolivia" if unname=="Bolivia (Plurinational State of)"
replace unname="Botswana" if unname=="Benin" // both mapped to Afr.Other NS in WTF
replace unname="Bosnia and Herzegovina" if unname=="Bosnia Herzegovina"
replace unname="Central African Republic" if unname=="Central African Rep."
replace unname="Hong Kong Special Administrative Region of China" if unname=="China, Hong Kong SAR"
replace unname="Macao Special Administrative Region of China" if unname=="China, Macao SAR"
replace unname="Australia" if unname=="Christmas Isds"
replace unname="Czech Republic" if unname=="Czech Rep."
replace unname="Cte d'Ivoire" if unname=="Côte d'Ivoire"
replace unname="Democratic People's Republic of Korea" if unname=="Dem. People's Rep. of Korea"
replace unname="Democratic Republic of the Congo" if unname=="Dem. Rep. of the Congo"
replace unname="Democratic Republic of the Congo" if unname=="Dominican Rep."
replace unname="Faeroe Islands" if unname=="Faeroe Isds"
replace unname="Iran (Islamic Republic of)" if unname=="Iran"
replace unname="Libyan Arab Jamahiriya" if unname=="Libya"
replace unname="Netherlands Antilles" if unname=="Neth. Antilles"
replace unname="Republic of Korea" if unname=="Rep. of Korea"
replace unname="Republic of Moldova" if unname=="Rep. of Moldova"
replace unname="Solomon Islands" if unname=="Solomon Isds"
replace unname="Syrian Arab Republic" if unname=="Syria"
replace unname="The former Yugoslav Republic of Macedonia" if unname=="TFYR of Macedonia"
replace unname="Turks and Caicos Islands" if unname=="Turks and Caicos Isds"
replace unname="United States of America" if unname=="USA"
replace unname="United Kingdom of Great Britain and Northern Ireland" if unname=="United Kingdom"
replace unname="United Republic of Tanzania" if unname=="United Rep. of Tanzania"
sort unname
merge unname using `uncntry', nokeep
tab _m
tab unname if _m~=3
replace wtfcountry="Areas NES" if unname=="Areas, nes"
replace wtfcountry="Asia NES" if unname=="Other Asia, nes"
replace wtfcountry="World" if unname=="World"
replace wtfcountry="Neth.Ant.Aru" if unname=="Aruba"  // former mistake in country-table.dta (now corrected)
replace wtfkey=908960 if wtfcountry=="Areas NES"
replace wtfkey=450000 if wtfcountry=="Asia NES"
replace wtfkey=100000 if wtfcountry=="World"
replace wtfkey=355320 if wtfcountry=="Neth.Ant.Aru"  // former mistake in country-table.dta (now corrected)
qui count if wtfkey==. | wtfcountry==""
if `r(N)'>0  STOP
list unname if wtfkey==. | wtfcountry==""
drop _m unname
rename wtfkey exp_wtfkey
rename wtfcountry exporter
gen str ecode=string(exp_wtfkey)
drop exp_wtfkey
order icode importer ecode exporter commoditycode tradevalue
label var icode "Importer Six-digit WTF code"
label var ecode "Exporter Six-digit WTF code"
label var importer "Importer Country name WTF"
label var exporter "Exporter Country name WTF"
* keep manufacturing products only; check in waves
gen str sitc4 = substr(subinstr(commoditycode,"S2-","",.),1,4)
replace sitc4 = sitc4 + "-" if length(sitc4)<4
replace sitc4 = sitc4 + "-" if length(sitc4)<4
replace sitc4 = sitc4 + "-" if length(sitc4)<4
qui summ tradevalue, meanonly
disp in gr "Exports from India: " in ye `r(sum)'
rename sitc4 sitc4mf
sort sitc4mf
merge sitc4mf using `sitcoecd', nokeep
tab _m
rename sitc4mf sitc4
drop _m
gen str sitc4mf = substr(sitc4,1,3) + "-"
sort sitc4mf
merge sitc4mf using `sitcoecd', nokeep update
tab _m
drop sitc4mf _m
gen str sitc4mf = substr(sitc4,1,2) + "--"
sort sitc4mf
merge sitc4mf using `sitcoecd', nokeep update
tab _m
drop sitc4mf _m
gen str sitc4mf = substr(sitc4,1,1) + "---"
sort sitc4mf
merge sitc4mf using `sitcoecd', nokeep update
tab _m
drop sitc4mf _m
replace isic2=300 if int(real(substr(commoditycode,4,1)))>=5 & int(real(substr(commoditycode,4,1)))<=8 & int(real(substr(commoditycode,4,3)))~=896  // reassign to general manufacturing, except art work
* tab commoditydescription if isic2==300
keep if isic2>=300 & isic2<=390  // manufacturing only
gen double value00=tradevalue
collapse (sum) value00=value00, by(icode importer ecode exporter) fast
replace value00 = value00/1000   // transform to 1,000 USD (for comparability to WTF)
sort icode ecode
save `india'

* GENERAL WTF
use icode importer ecode exporter sitc4 value using "$extdata/brazaux/intl/nber/wtf00.dta", clear
sort sitc4
* keep manufacturing products only
merge sitc4 using `sitc4mf'
tab _m
drop if _m~=3
gen double value00=value
collapse (sum) value00, by(icode importer ecode exporter) fast
label var value00 "Exports 2000 [current US$]"
label var icode "Importer Six-digit WTF code"
label var ecode "Exporter Six-digit WTF code"
label var importer "Importer Country name WTF"
label var exporter "Exporter Country name WTF"

* treatment of India
sort icode ecode
merge icode ecode using `india'
tab _m
qui count if _m==3
if `r(N)'>0  STOP
drop _m
qui summ value00 if ecode=="453560", meanonly
disp in gr "Manufacturing Exports from India: " in ye `r(sum)'
qui summ value00 if icode=="453560", meanonly
disp in gr "Manufacturing Imports to India: " in ye `r(sum)'

* finalize manufacturing WTF (including India)
tempfile wtfmain
replace value00 = value00 * 1000  // transform to single USD (from 1,000 USD)
sort icode ecode
save `wtfmain'  // note: China HK SAR, China MC SAR separate from China; Netherlands separate from Belgium-Lux; Indonesia, Malaysia, Singapore, Thailand separate from each other

* check totals
drop if icode=="100000" | ecode=="100000"  // remove World to avoid double counting
drop if icode=="999990" | ecode=="999990"  // remove Intl Org for consistency
summ value00
disp `r(sum)'


/* WDI DATA preparation */

tempfile wdidata
insheet using "braxpmkt/ext/wdi-gdf-data.csv", comma clear names
foreach var of varlist v* {
  local year : variable label `var'
  rename `var' val`year'
  }
keep seriescode seriesname countrycode countryname val2000  // note: subsequent code general to accomodate more years such as val2000-val2009 if needed
keep if substr(seriescode,1,2)=="BM" | substr(seriescode,1,2)=="BN" | substr(seriescode,1,2)=="BX" | substr(seriescode,1,2)=="NY" | substr(seriescode,1,2)=="NV" | substr(seriescode,1,2)=="NE"
reshape long val, i(seriescode seriesname countrycode countryname) j(year)

keep if seriesname=="Current account balance (BoP, current US$)" | seriesname=="GDP (current US$)" | seriesname=="Net trade in goods (BoP, current US$)" | seriesname=="Net trade in goods and services (BoP, current US$)" | seriesname=="Manufacturing, value added (current US$)" | seriesname=="Gross national expenditure (current US$)"
* WDI
* current account balance (bop, current US$): BN.CAB.XOKA.CD (sum of net exports of goods, services, net income, and net current transfers; data in current U.S. dollars)
* GDP (current US$): NY.GDP.MKTP.CD (GDP at purchaser's prices is the sum of gross value added by all resident producers in the economy plus any product taxes and minus any subsidies not included in the value of the products; it is calculated without making deductions for depreciation of fabricated assets or for depletion and degradation of natural resources; data in current U.S. dollars; dollar figures for GDP are converted from domestic currencies using single year official exchange rates; for a few countries where the official exchange rate does not reflect the rate effectively applied to actual foreign exchange transactions, an alternative conversion factor is used)
* net trade in goods (bop, current US$): BN.GSR.MRCH.CD (net trade in goods is the difference between exports and imports of goods; category includes goods previously included in services: goods received or sent for processing and their subsequent export or import in the form of processed goods, repairs on goods, and goods procured in ports by carriers; trade in services is not included; data in current U.S. dollars)
* net trade in goods and services (bop, current US$): BN.GSR.GNFS.CD (net trade in goods and services is derived by offsetting imports of goods and services against exports of goods and services; exports and imports of goods and services comprise all transactions involving a change of ownership of goods and services between residents of one country and the rest of the world; data in current U.S. dollars)
* manufacturing, value added (current US$): NV.IND.MANF.CD (manufacturing refers to industries belonging to ISIC divisions 15-37; value added is the net output of a sector after adding up all outputs and subtracting intermediate inputs; it is calculated without making deductions for depreciation of fabricated assets or depletion and degradation of natural resources; the origin of value added is determined by the International Standard Industrial Classification (ISIC), revision 3; data in current U.S. dollars)
* domestic absorption/gross national expenditure (current US$): NE.DAB.TOTL.CD (gross national expenditure (formerly domestic absorption) is the sum of household final consumption expenditure (formerly private consumption), general government final consumption expenditure (formerly general government consumption), and gross capital formation (formerly gross domestic investment). Data are in current U.S. dollars)

sort seriescode countrycode year
order countrycode countryname seriescode seriesname val
sort countrycode seriescode
replace seriescode = "ca" if seriesname=="Current account balance (BoP, current US$)"
replace seriescode = "gdp" if seriesname=="GDP (current US$)"
replace seriescode = "tbg" if seriesname=="Net trade in goods (BoP, current US$)"
replace seriescode = "tbgs" if seriesname=="Net trade in goods and services (BoP, current US$)"
replace seriescode = "mfva" if seriesname=="Manufacturing, value added (current US$)"
replace seriescode = "ab" if seriesname=="Gross national expenditure (current US$)"

drop seriesname
rename val val_
reshape wide val_, i(countrycode countryname year) j(seriescode) string
drop year
foreach var in ca gdp tbg tbgs mfva ab {
  rename val_`var' `var'
  }
label var ca "Current account bal. [curr. US$]"  // from BoP
label var gdp "GDP [current US$]"   // from national accounts
label var tbg "Net trade goods [curr. US$]"  // from BoP
label var tbgs "Net trade goods&srvcs [cur. US$]"  // from BoP
label var mfva "Manufct. Value added [curr. US$]"  // from national accounts
label var ab "Absorption [curr. US$]"  // from national accounts
rename countrycode wdikey
rename countryname wdicountry
drop if gdp==.  // missing GDP excludes country
list wdikey wdicountry if ca==. & tbg~=.
list wdikey wdicountry if ca==. & tbgs~=.
drop if ca==.  // no observations with missing CA but reported Net trade balance, so drop ca==.
sort wdikey
save `wdidata'  // Hong Kong SAR China and China separate; Belgium, Luxembourg, Netherlands separate from each other; Indonesia, Malaysia, Singapore, Thailand separate from each other


/* Country CONCORDANCE WTF-WDI */

* WTF list (only keep balanced exporter-importer pairs)
tempfile wtfexp wtflist
use ecode exporter value00 using `wtfmain', clear
drop if value00==.
drop value00
bysort ecode: keep if _n==1
drop if ecode=="100000" | ecode=="999990"
rename ecode wtfkeystr
sort wtfkeystr
save `wtfexp'
use icode importer value00 using `wtfmain', clear
drop if value00==.
drop value00
bysort icode: keep if _n==1
drop if icode=="100000" | icode=="999990"
rename icode wtfkeystr
sort wtfkeystr
merge wtfkeystr using `wtfexp'
sort wtfkeystr
tab _m  // 1: importer only, 2: exporter only, 3: importer and exporter
list if _m~=3
drop if _m~=3  // note for later: drop Eur. EFTA NS; collapse China FTZ with China mainland into single entity
keep wtfkeystr
gen long wtfkey = real(wtfkeystr)
qui count if wtfkey==. | wtfkeystr==""
if `r(N)'>0  STOP
drop wtfkeystr
sort wtfkey
save `wtflist'

* WDI list
tempfile wdilist
use `wdidata'
bysort wdikey: keep if _n==1
sort wdikey
save `wdilist'

* Joint list
use wtf* wdi* using "brazaux/conc/countries/country-table.dta", clear
duplicates drop
drop if wtfkey==. & wdikey==""
* backward compatibility with country-table 2007-04-13 (as in country-data-2000.do)
drop if ( wtfkey==537240 & wdikey=="" ) | ( wtfkey==368960 & wdikey=="ASM" ) | ( wtfkey==368960 & wdikey=="GUM" ) | ( wtfkey==450000 & wdikey=="TMP" ) | ( wtfkey== . & wdikey=="IMY" )
replace wdicountry="GERMANY" if ( wtfkey==532760 & wdikey=="DEU") 
replace wdicountry="GERMANY" if ( wtfkey==532800 & wdikey=="DEU") 
replace wdikey="" if ( wtfkey==532760 & wdikey=="DEU") 
replace wdikey="" if ( wtfkey==532800 & wdikey=="DEU") 
replace wdicountry="UNITED STATES" if ( wtfkey==368960 & wdikey=="PRI" )
replace wdikey="USA" if ( wtfkey==368960 & wdikey=="PRI" )
* make list
replace wdikey="DEU" if wdicountry=="GERMANY"
sort wdikey
merge wdikey using `wdilist'
tab _m
sort _m wdikey
list wdikey wdicountry wtfcountry _m if _m~=3
drop if _m==2  // WDI country groups, no single entity
gen byte indwdi = (_m==3)
label var indwdi "Indic.: WDI information"
drop _m
sort wtfkey
merge wtfkey using `wtflist'
tab _m
sort _m wtfkey
list wtfkey wtfcountry wdicountry _m if _m~=3
drop if _m~=3  // drop Eur. EFTA NS, China FTZ with China mainland into single entity
gen byte indwtf = (_m==3)
label var indwtf "Indic.: WTF information"
order wtfkey wtfcountry wdikey wdicountry indwtf indwdi
drop _m
drop if wdikey=="" | wtfkey==.
list wtfcountry wdicountry indwtf indwdi if indwdi~=indwtf
compress

* Treat bad matches
gen byte _indmissg = (indwdi~=indwtf)
egen byte _ind2del = max(_indmissg), by(wtfkey)
tab wtfcountry if _indmissg
* drop if _indmissg
tab wtfcountry if _ind2del
duplicates tag wtfkey, gen(_indduplwtf)
duplicates tag wdikey, gen(_indduplwdi)
tab _inddupl*
list wtfcountry wdicountry indwtf indwdi _ind2del if _indduplwtf
list wtfcountry wdicountry indwtf indwdi _ind2del if _indduplwdi
replace _ind2del=0 if wtfkey==557560 // wtf: Switz.Liecht wdi: LIECHTENSTEIN
replace _ind2del=0 if wtfkey==557560 // wtf: Switz.Liecht wdi: SWITZERLAND
replace _ind2del=0 if wtfkey==530560 // wtf: Belgium-Lux wdi: BELGIUM
replace _ind2del=0 if wtfkey==530560 // wtf: Belgium-Lux wdi: LUXEMBOURG
* NOTE: aggregate regions in WTF are incompletely matched by WDI. 
*       Afr.Other NS in WTF includes ERITREA, SWAZILAND, COMOROS, NAMIBIA, CAPE VERDE, BOTSWANA, LESOTHO, SAO TOME AND PRINCIPE, but WDI excludes COMOROS, LESOTHO
*       US NES in WTF includes NORTHERN MARIANA ISLANDS, but WDI excludes NORTHERN MARIANA ISLANDS
*       Asia NES in WTF includes MALDIVES, MAYOTTE, BHUTAN, but WDI excludes MAYOTTE, BHUTAN
*       EEC NES in WTF includes SAN MARINO, ANDORRA, but WDI excludes SAN MARINO, ANDORRA
*       Oth.Oceania in WTF incldues VANUATU, MARSHALL ISLANDS, PALAU, SOLOMON ISLANDS, TONGA, MICRONESIA FED. STS., NORWAY, FRENCH POLYNESIA, but WDI excludes MARSHALL ISLANDS, PALAU, TONGA, MICRONESIA FED. STS., FRENCH POLYNESIA
drop if _ind2del  // removing aggregate WTF regions because of unclear matches
drop _indmissg _ind2del _inddupl*
duplicates tag wtfkey, gen(_indduplwtf)
list wtf* if _indduplwtf
duplicates tag wdikey, gen(_indduplwdi)
list wdi* if _indduplwdi
summ indwtf indwdi
list if indwdi==0
drop if indwdi==0  // LIECHTENSTEIN is missing
drop if wtfkey==578960 & wdikey=="FRO"  // FAEROE ISLANDS is not well matched 
drop if wtfkey==453440 & wdikey=="HKG"  // Hong Kong to be collapsed with China
  list if index(wtfcountry,".")>0 | index(wtfcountry,"-")>0 | index(wtfcountry," ")>0 | index(wtfcountry,",")>0
  amcountry
preserve
  tempfile wdiuse
  keep wdikey country
  bysort wdikey: keep if _n==1
  order wdikey
  sort wdikey
  save `wdiuse'
  cntryset
  keep country
  bysort country: keep if _n==1
restore, preserve
  tempfile wtfuse
  keep wtfkey country
  bysort wtfkey: keep if _n==1
  sort wtfkey
  save `wtfuse'
  cntryset
  keep country
  bysort country: keep if _n==1
restore


/* WTF Bilateral Data */

* bilateral trade data in 2000
tempfile wtfbilat wtftrdbl
use icode importer ecode exporter value00 using `wtfmain', clear
drop if icode=="999990" | ecode=="999990" // intl organizations (keep World for ROW computation)
drop if value00==.
order ecode exporter icode importer
rename ecode exp_wtfkey
rename icode imp_wtfkey
rename exporter exp_wtfcountry
rename importer imp_wtfcountry
label var exp_wtfkey "Exporter Six-digit WTF code"
label var imp_wtfkey "Importer Six-digit WTF code"
label var exp_wtfcountry "Exporter Country name WTF"
label var imp_wtfcountry "Importer Country name WTF"
label var value00 "Exports 2000 [current US$]"

* treatments
replace exp_wtfkey="481560" if exp_wtfkey=="481561"  // join China FTZ with China mainland into single entity
replace imp_wtfkey="481560" if imp_wtfkey=="481561"  // join China FTZ with China mainland into single entity
replace exp_wtfkey="481560" if exp_wtfkey=="453440"  // join Hong Kong with China mainland into single entity
replace imp_wtfkey="481560" if imp_wtfkey=="453440"  // join Hong Kong with China mainland into single entity
replace exp_wtfkey="481560" if exp_wtfkey=="454460"  // join Macao with China mainland into single entity
replace imp_wtfkey="481560" if imp_wtfkey=="454460"  // join Macao with China mainland into single entity
replace exp_wtfcountry="China/Hong Kong" if exp_wtfkey=="481560"
replace imp_wtfcountry="China/Hong Kong" if imp_wtfkey=="481560"
gen double value=value00
collapse (sum) value, by(exp_wtfkey exp_wtfcountry imp_wtfkey imp_wtfcountry) fast
replace value=. if value==0
rename value value00
label var value00 "Exports 2000 [current US$]"

* check totals
preserve 
  drop if imp_wtfkey=="100000" | exp_wtfkey=="100000"  // remove World to avoid double counting
  drop if imp_wtfkey=="999990" | exp_wtfkey=="999990"  // remove Intl Org for consistency
  summ value00
  disp `r(sum)'
restore

* mark-to-drop countries with missing WDI information
foreach trd in exp imp {
  rename `trd'_wtfkey wtfkeystr
  gen long wtfkey = real(wtfkeystr)
  qui count if wtfkey==. | wtfkeystr==""
  if `r(N)'>0  NO MISSING EXPECTED
  drop wtfkeystr
  sort wtfkey
  merge wtfkey using `wtfuse', nokeep
  tab _m
  tab `trd'_wtfcountry if _m==1
  * tab `trd'_wtfcountry if _m==2  // no observations
  gen byte _ind_`trd'2del = (_m~=3)
  drop _m
  rename wtfkey `trd'_wtfkey
  drop `trd'_wtfcountry
  rename country `trd'_country
  }
label var exp_wtfkey "Exporter Six-digit WTF code"
label var imp_wtfkey "Importer Six-digit WTF code"
label var exp_country "Exporter Country (AM10)"
label var imp_country "Importer Country (AM10)"
order exp_wtfkey exp_country imp_wtfkey imp_country value00

* Set "exports to self" to zero (such as trade between China/Hong Kong)
sort exp_wtfkey imp_wtfkey
list if exp_wtfkey==imp_wtfkey
qui summ value00 if exp_wtfkey~=100000 & imp_wtfkey~=100000 & imp_wtfkey~=453560 // World Total ex India importer (pure WTF data)
disp in gr "Total exports by summation: " in ye `r(sum)' in gr " and by report: " in ye value[1]
replace value00=0 if exp_wtfkey==imp_wtfkey
qui summ value00 if exp_wtfkey~=100000 & imp_wtfkey~=100000 & imp_wtfkey~=453560 // Reset World Total ex India importer (pure WTF data)
local totexp = `r(sum)'
replace value00 = `totexp' in 1
disp in gr "Reset total exports by summation: " in ye `r(sum)' in gr " and reset in data: " in ye value[1]

* prepare bilateral WORLD trade for later ROW inference
* imports from WORLD
preserve
  tempfile wtfimpwld
  drop if imp_wtfkey==100000 | exp_wtfkey==100000  // remove World to avoid double counting
  drop if imp_wtfkey==999990 | exp_wtfkey==999990  // remove Intl Org for consistency
  replace imp_wtfkey=999999 if _ind_imp2del
  replace imp_country="_RestOfWorld" if _ind_imp2del
  gen double value=value00
  collapse (sum) wldvalue00=value, by(imp_wtfkey imp_country) fast
  replace wldvalue00=. if wldvalue00==0
  label var wldvalue00 "WLD Exports 2000 [curr US$]"
  keep imp_wtfkey imp_country wldvalue00
  sort imp_wtfkey
  save `wtfimpwld'
  summ wldvalue00
  disp `r(sum)'
* exports to WORLD
restore, preserve
  tempfile wtfexpwld
  drop if exp_wtfkey==100000 | imp_wtfkey==100000  // remove World to avoid double counting
  drop if exp_wtfkey==999990 | imp_wtfkey==999990  // remove Intl Org for consistency
  replace exp_wtfkey=999999 if _ind_exp2del
  replace exp_country="_RestOfWorld" if _ind_exp2del
  gen double value=value00
  collapse (sum) wldvalue00=value, by(exp_wtfkey exp_country) fast
  replace wldvalue00=. if wldvalue00==0
  label var wldvalue00 "WLD Exports 2000 [curr US$]"
  keep exp_wtfkey exp_country wldvalue00
  sort exp_wtfkey
  save `wtfexpwld'
  summ wldvalue00
  disp `r(sum)'
restore

* create temporary ROW (to be overwritten)
drop if imp_wtfkey==100000 | exp_wtfkey==100000
replace imp_wtfkey=999999 if _ind_imp2del
replace imp_country="_RestOfWorld" if _ind_imp2del
replace exp_wtfkey=999999 if _ind_exp2del
replace exp_country="_RestOfWorld" if _ind_exp2del
gen double value=value00
collapse (sum) value00=value, by(exp_wtfkey exp_country imp_wtfkey imp_country) fast
replace value00=. if value00==0
label var value00 "Exports 2000 [current US$]"
drop if exp_wtfkey==imp_wtfkey
qui summ value00 if exp_wtfkey~=100000 & imp_wtfkey~=100000  // World Total
local totexp = `r(sum)'
replace value00=0 if exp_wtfkey==imp_wtfkey
qui summ value00 if exp_wtfkey~=100000 & imp_wtfkey~=100000  // World Total
disp in gr "Total exports by summation, including ROW-to-ROW: " in ye `totexp' in gr ", excluding ROW-to-ROW: " in ye `r(sum)' in gr " (" in ye 100*(`totexp'-`r(sum)')/`totexp' in gr "%)" 
codebook *_wtfkey

* infer ROW from WORLD less SMPL
* imports from ROW
preserve
  tempfile wtfimprow
  drop if exp_wtfkey==999999  // drop exports to ROW (remove this line to check that SMPL=WLD if ROW kept)
  gen double value=value00
  collapse (sum) splvalue00=value, by(imp_wtfkey imp_country) fast
  drop if imp_wtfkey==100000
  replace splvalue00=. if splvalue00==0
  label var splvalue00 "SPL Exports 2000 [curr US$]"
  keep imp_wtfkey imp_country splvalue00
  sort imp_wtfkey
  merge imp_wtfkey using `wtfimpwld'
  qui count if _m~=3
  if `r(N)'>0  STOP
  drop _m
  gen rowvalue00 = wldvalue00 - splvalue00
  summ rowvalue00 if imp_wtfkey~=999999
  disp `r(sum)'
  drop if imp_wtfkey==999999
  gen long exp_wtfkey=999999
  gen str12 exp_country = "_RestOfWorld"
  keep imp_wtfkey imp_country exp_wtfkey exp_country rowvalue00
  rename rowvalue00 value00
  sort imp_wtfkey
  save `wtfimprow'
* exports to ROW
restore, preserve
  tempfile wtfexprow
  drop if imp_wtfkey==999999  // drop import from ROW (remove this line to check that SMPL=WLD if ROW kept)
  gen double value=value00
  collapse (sum) splvalue00=value, by(exp_wtfkey exp_country) fast
  drop if exp_wtfkey==100000
  replace splvalue00=. if splvalue00==0
  label var splvalue00 "SPL Exports 2000 [curr US$]"
  keep exp_wtfkey exp_country splvalue00
  sort exp_wtfkey
  merge exp_wtfkey using `wtfexpwld'
  qui count if _m~=3
  if `r(N)'>0  STOP
  drop _m
  gen rowvalue00 = wldvalue00 - splvalue00
  summ rowvalue00 if exp_wtfkey~=999999
  disp `r(sum)'
  drop if exp_wtfkey==999999
  gen long imp_wtfkey=999999
  gen str12 imp_country = "_RestOfWorld"
  keep exp_wtfkey exp_country imp_wtfkey imp_country rowvalue00
  rename rowvalue00 value00
  sort exp_wtfkey
  save `wtfexprow'
restore

* reset ROW
drop if imp_wtfkey==999999 | exp_wtfkey==999999  // remove temporary ROW information
qui count if imp_wtfkey==100000 | exp_wtfkey==100000
if `r(N)'>0  STOP
qui count if imp_wtfkey==999990 | exp_wtfkey==999990
if `r(N)'>0  STOP
count
append using `wtfimprow'  // append proper ROW information
count
append using `wtfexprow'  // append proper ROW information
count
summ value
disp `r(sum)'

* reset countries
drop exp_wtfkey imp_wtfkey
cntryset exp_country
cntryset imp_country
collapse (sum) value00, by(exp_country imp_country) fast
replace value00=. if value00==0
label var value00 "Exports 2000 [current US$]"
replace value00=. if exp_country==imp_country  // diagonal entries removed in accordance with cntryset
sort exp_country imp_country
save `wtfbilat'


/* WTF-UNIDO Manufacturing Absorption (identical to tabsorp in %02/replication-data-2000.do, but Brazil added) */

* manufacturing output for Brazil 2000 from IBGE  // missing from UNIDO
insheet using "braxpmkt/ext/ibge-pia/valorbruto-pianova.csv", comma clear  // in 1,000 BRL
keep v5  // year 2000
drop if v5==.
local mfabbraz = v5[2]*1000/1.15704698  // June 2000 exchange rate, similar to brazexp/%02/firmagg-secex.do
* disp "`mfabbraz'"

* absorption construction identical to EKK-2004 replication data construction
tempfile absdata
use "braxpmkt/ext/sector-country-data-2000.dta", clear
keep if isic2>300 & isic2<=399  // manufacturing only (cut agriculture, mining and nec [999])
collapse (sum) wtf_output wtf_exports wtf_imports, by(wtfkey)
label var wtf_output  "Manuf. output"   // from UNIDO "braxpmkt/ext/unido-2000-undefl-us-dollars.dta" in %01/sector-country-data-2000.do (initially by un3num and isic2, then by wtfkey isic2)
label var wtf_exports "Manuf. exports from source"  // from WTF "braxpmkt/ext/wtf-data-2000.dta" in %01/wtf-data (initially by wtfkey and sitc4, then by wtfkey isic2)
label var wtf_imports "Manuf. imports to dest."  // from WTF "braxpmkt/ext/wtf-data-2000.dta" in %01/wtf-data (initially by wtfkey and sitc4, then by wtfkey isic2)
replace wtf_output = `mfabbraz' if wtfkey==330760  // update Brazil
replace wtf_output = . if wtf_output==0
gen mfab = wtf_output + wtf_imports - wtf_exports  // Manufacturing absorption (production+imports-exports), by destination 2000 [OECD Stan & Unido for production, exports/imports for trade]
drop wtf_output wtf_exports wtf_imports
label var mfab "Manufct. Absorption [curr. US$]"  // from UNIDO and WTF

* country resetting (similar to `wtfbilat'), country names
preserve
  tempfile wtfcntry
  use wtfkey wtfcountry using "brazaux/conc/countries/country-table.dta", clear
  bysort wtfkey wtfcountry: keep if _n==1
  sort wtfkey
  save `wtfcntry'
restore
sort wtfkey
merge wtfkey using `wtfcntry', nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
gen wtfkeystr = string(wtfkey)
qui count if length(wtfkeystr)~=6
if `r(N)'>0  STOP
drop wtfkey
rename wtfkeystr wtfkey
drop if wtfkey=="999990" // intl organizations (keep World for ROW computation)
drop if mfab==.
order wtfkey wtfcountry mfab

* treatments (similar to `wtfbilat')
replace wtfkey="481560" if wtfkey=="481561"  // join China FTZ with China mainland into single entity
replace wtfkey="481560" if wtfkey=="453440"  // join Hong Kong with China mainland into single entity
replace wtfkey="481560" if wtfkey=="454460"  // join Macao with China mainland into single entity
replace wtfcountry="China/Hong Kong" if wtfkey=="481560"
gen double mfab00=mfab
collapse (sum) mfab=mfab00, by(wtfkey wtfcountry) fast
replace mfab=. if mfab==0
rename mfab mfab00
label var mfab00 "Manufct. Absorption [curr. US$]"

* mark-to-drop countries with missing WDI information (similar to `wtfbilat')
  rename wtfkey wtfkeystr
  gen long wtfkey = real(wtfkeystr)
  qui count if wtfkey==. | wtfkeystr==""
  if `r(N)'>0  NO MISSING EXPECTED
  drop wtfkeystr
  sort wtfkey
  merge wtfkey using `wtfuse', nokeep
  tab _m
  tab wtfcountry if _m==1
  * tab wtfcountry if _m==2  // no observations
  gen byte _ind_wtf2del = (_m~=3)
  drop _m
label var wtfkey "Exporter Six-digit WTF code"
label var country "Exporter Country (AM10)"
order wtfkey country mfab00

* create ROW (similar to `wtfbilat'; reset to missing below b/c no valid observation of World total)
drop if wtfkey==100000
replace wtfkey=999999 if _ind_wtf2del
replace country="_RestOfWorld" if _ind_wtf2del
gen double mfab=mfab00
collapse (sum) mfab00=mfab, by(wtfkey country) fast
replace mfab00=. if mfab00==0
label var mfab "Manufct. Absorption [curr. US$]"

* reset countries (similar to `wtfbilat')
drop wtfkey
cntryset country
collapse (sum) mfab00, by(country) fast
replace mfab00=. if mfab00==0
rename mfab00 mfab
label var mfab "Manufct. Absorption [curr. US$]"
replace mfab=. if country=="_RestOfWorld"  // ROW reset to missing b/c no valid observation of World total
sort country
save `absdata'


/* WTF Trade Balance Data */

tempfile tb
foreach trd in exp imp {
  tempfile tb`trd'
  use `wtfbilat', clear
  keep `trd'_country value00
  gen double value=value00
  collapse (sum) value00=value, by(`trd'_country) fast
  replace value00=. if value00==0
  rename `trd'_country country
  rename value00 `trd'
  local lbl = upper(substr("`trd'"),1,1) + lower(substr("`trd'"),2,2) + "orts 2000 [current US$]"
  label var `trd' "`lbl'"
  label var country "Country (AM10)"
  compress
  sort country
  save `tb`trd''
  }
use `tbexp'
merge country using `tbimp'
qui count if _m~=3
if `r(N)'>0  STOP
drop _
gen double tbwtf = exp-imp
drop exp imp
label var tbwtf "Trade bal. WTF-Mf. [curr. US$]"
sort country
save `tb'


/* WDI GDP and CA data */

tempfile gdpca
use `wdidata'
keep wdikey wdicountry gdp ca tbg tbgs mfva ab
merge wdikey using `wdiuse'
tab _m
tab wdicountry if _m==1
gen byte _ind_2del = (_m~=3)
drop _m

* treatments
replace country="ChinaHKG" if wdikey=="HKG"  // join Hong Kong with China mainland into single entity
replace wdikey="CHN" if wdikey=="HKG"  // join Hong Kong with China mainland into single entity
replace _ind_2del=0 if country=="ChinaHKG"
replace country="BelgiumLux" if wdikey=="BEL"  // collapse Belgium and Luxembourg into single entity
replace wdikey="BLX" if wdikey=="BEL"  // collapse Belgium and Luxembourg into single entity
replace country="BelgiumLux" if wdikey=="LUX"  // collapse Belgium and Luxembourg into single entity
replace wdikey="BLX" if wdikey=="LUX"  // collapse Belgium and Luxembourg into single entity
replace _ind_2del=0 if country=="BelgiumLux"
list wdikey wdicountry country gdp if _ind_2del
drop if wdikey=="EAP" | wdikey=="ECA" | wdikey=="EMU" | wdikey=="HIC" | wdikey=="HPC" | wdikey=="LAC" | wdikey=="LDC" | wdikey=="LIC" | wdikey=="LMC" | wdikey=="LMY" | wdikey=="MIC" | wdikey=="MNA" | wdikey=="NOC" | wdikey=="OEC" | wdikey=="SAS" | wdikey=="SSA" | wdikey=="UMC"  // remove WDI aggregates, except WORLD (wdikey=="WLD")
list wdikey wdicountry country gdp if _ind_2del
foreach var in gdp ca tbg tbgs mfva ab {
  gen double `var'00=`var'
  }
collapse (sum) gdp00 ca00 tbg00 tbgs00 mfva00 ab00, by(wdikey country _ind_2del) fast
foreach var in gdp ca tbg tbgs mfva ab {
  replace `var'00=. if `var'00==0
  }
label var gdp00 "GDP [current US$]"
label var ca00 "Current account bal. [curr. US$]"
label var tbg00 "Trade bal. goods [curr. US$]"
label var tbgs00 "Trade bal. gds&srvcs [curr. US$]"
label var mfva00 "Manufct. Value added [curr. US$]"
label var ab00 "Absorption [curr. US$]"

* prepare WORLD wide variables for later ROW check
mkmat gdp00 ca00 tbg00 tbgs00 mfva00 ab00 if wdi=="WLD", matrix(wdiwld)
matname wdiwld wld, rows(1) explicit
matrix wdiwld[1,colnumb(wdiwld,"tbg00")] = 0  // replace missing with 0
matrix wdiwld[1,colnumb(wdiwld,"tbgs00")] = 0  // replace missing with 0

* Alternative code for ROW (sums to less than WDI reported world totals in wdikey=="WLD")
* replace wdikey="_RW" if _ind_2del
* replace country="_RestOfWorld" if _ind_2del
* foreach var in gdp ca tbg tbgs mfva {
*   gen double `var'00=`var'
*   }
* collapse (sum) gdp00 ca00 tbg00 tbgs00 mfva00, by(country) fast  // collapses Belgium-Luxembourg, China-HongKong and RestOfWorld
* foreach var in gdp ca tbg tbgs mfva {
*   replace `var'00=. if `var'00==0
*   }
* label var gdp "GDP [current US$]"
* label var ca "Current account bal. [curr. US$]"
* label var tbg "Trade bal. goods [curr. US$]"
* qui summ gdp  // World Total
* local totgdp = `r(sum)'
* qui summ gdp if country~="_RestOfWorld"  // World Total excluding RestOfWorld
* disp in gr "Total GDP by summation, including ROW: " in ye `totgdp' in gr ", excluding ROW: " in ye `r(sum)' in gr " (" in ye 100*(`totgdp'-`r(sum)')/`totgdp' in gr "%)" 
drop if _ind_2del & wdikey~="WLD"
drop _ind_2del
matrix wdismpl = J(1,6,.)
matrix rownames wdismpl = wld
matrix colnames wdismpl = gdp00 ca00 tbg00 tbgs00 mfva00 ab00
foreach var in gdp ca tbg tbgs mfva ab {
  rename `var'00 `var'
  replace `var'=0 if `var'==. & wdikey=="WLD"  // replace missing trade balances for world total with zero trade balances
  qui summ `var' if wdikey=="WLD"
  local wld = `r(sum)'
  qui summ `var' if wdikey~="WLD"
  local smpltot = `r(sum)'
  replace `var' = `wld' - `smpltot' if wdikey=="WLD"
  mat wdismpl[1,colnumb(wdismpl,"`var'00")] = `smpltot'
  }
mkmat gdp ca tbg tbgs mfva ab if wdi=="WLD", matrix(wdichk)
matname wdichk wld, rows(1) explicit
mat _chk = (wdiwld - wdismpl - wdichk) * J(6,1,1)
local chk = _chk[1,1]
if `chk'~=0  STOP
replace wdikey="_RW" if wdikey=="WLD"
replace country="_RestOfWorld" if wdikey=="_RW"
drop wdikey
* reset ca, tbg and tbgs to zero average and save (tbwtf is zero average by construction with double storage type)
sort country
qui count if country~=country[_n-1]
local cntrycnt = `r(N)'
foreach var in ca tbg tbgs {
  qui summ `var', meanonly
  local adjst = `r(sum)'/`cntrycnt'
  replace `var' = `var' - `adjst'
  summ `var'
  }

* reset countries
cntryset country
collapse (sum) gdp ca tbg tbgs mfva ab, by(country) fast
foreach var in gdp ca tbg tbgs mfva ab {
  replace `var'=. if `var'==0
  }
label var gdp "GDP [current US$]"
label var ca  "Current account bal. [curr. US$]"
label var tbg "Trade bal. goods [curr. US$]"
label var tbgs "Trade bal. gds&srvcs [curr. US$]"
label var mfva "Manufct. Value added [curr. US$]"
label var ab "Absorption [curr. US$]"
sort country
save `gdpca'


/* COMBINED WDI-WTF data */

use `wtfbilat', clear
rename value00 bilattrd
label var bilattrd "Bilat. trade WTF-Mf. [curr. US$]"
rename exp_country country
sort country imp_country
merge country using `tb', keep(tbwtf)
qui count if _m~=3  
if `r(N)'>0  STOP
drop _m
sort country imp_country
merge country using `absdata', keep(mfab)
tab _m  // note: there are 74 unmatched and 60 matched countries after merge (keep country _m; bysort country _m: keep if _n==1; tab _m;)
qui count if _m==2
if `r(N)'>0  STOP
drop _m
sort country imp_country
merge country using `gdpca', keep(gdp ca tbg tbgs mfva ab)
qui count if _m~=3  
if `r(N)'>0  STOP
drop _m
rename country exp_country
sort exp_country imp_country

* Computation of alternative gammas, plausibility checks
preserve
  keep exp_country gdp tbgs mfva tbg tbwtf mfab
  rename exp_country country
  bysort country: keep if _n==1
  gen double gamma_tbg = (mfva-tbg)/(gdp-tbgs)
  count if gamma_tbg<=0
  summ gamma_tbg if gamma_tbg>0
  gen double gamma_tbwtf = (mfva-tbwtf)/(gdp-tbgs)
  count if gamma_tbwtf<=0
  summ gamma_tbwtf if gamma_tbwtf>0
  count if gamma_tbg<=0 | gamma_tbwtf<=0
  gen double gamma_mfab = (mfab-(1-$beta)*(1-1/$sigma)*(mfab+tbwtf))/(gdp-tbgs)
  count if gamma_mfab<=0
  summ gamma_mfab if gamma_mfab>0
  list country gamma* if gamma_mfab<0  // Panama is single problem country with negative gamma_mfab
  * note: EKK10 (footnote 53) say "The value of gamma lies in the interval (0.15,0.55) for 100 of our 113 countries. The average is 0.36."
  
* Reset implausible countries to RestOfWorld
  tempfile rowlst
  keep country gamma_mfab
  keep if gamma_mfab<=0
  drop gamma_mfab
  sort country
  save `rowlst'
  list country // content of `rowlst'
restore
foreach trd in exp imp {
  rename `trd'_country country
  sort country
  merge country using `rowlst'
  gen byte _ind2row = (_merge==3)
  replace country="_RestOfWorld" if _ind2row==1
  rename country `trd'_country
  drop _m _ind2row
  }
* check consistency
preserve
  keep exp_country gdp
  rename exp_country country
  duplicates drop
  duplicates tag country, gen(_dupl)
  qui count if _dupl>0 & country~="_RestOfWorld"
  if `r(N)'>0  STOP
restore
foreach var in bilat tbwtf gdp {
  qui summ `var', meanonly
  disp in gr "Total " in ye "`var'" in gr ": " in ye `r(sum)'
  }
preserve
  tempfile clpsuni
  keep exp_country tbwtf gdp ca tbg tbgs mfva ab mfab
  duplicates drop
  duplicates tag exp_country, gen(_dupl)
  qui count if _dupl>0 & exp_country~="_RestOfWorld"
  if `r(N)'>0  STOP
  collapse (sum) tbwtf gdp ca tbg tbgs mfva ab mfab, by(exp_country) fast
  sort exp_country
  save `clpsuni'
restore
collapse (sum) bilattrd, by(exp_country imp_country) fast
sort exp_country imp_country
merge exp_country using `clpsuni'
tab _m
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
* check consistency
preserve
  keep exp_country gdp
  rename exp_country country
  duplicates drop
  duplicates tag country, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP
restore

foreach var in bilattrd tbwtf gdp ca tbg tbgs mfva ab mfab {
  replace `var'=. if `var'==0
  }
label var bilattrd "Bilat. trade WTF-Mf. [curr. US$]"
label var tbwtf "Trade bal. WTF-Mf. [curr. US$]"
label var gdp "GDP [current US$]"
label var ca  "Current account bal. [curr. US$]"
label var tbg "Trade bal. goods [curr. US$]"
label var tbgs "Trade bal. gds&srvcs [curr. US$]"
label var mfva "Manufct. Value added [curr. US$]"
label var ab "Absorption [curr. US$]"
label var mfab "Manufct. Absorption [curr. US$]"
foreach var in bilat tbwtf gdp {
  qui summ `var', meanonly
  disp in gr "Total " in ye "`var'" in gr ": " in ye `r(sum)'
  }
replace bilattrd=. if exp_country==imp_country  // diagonal entries removed in accordance with reset of RestOfWorld

sort exp_country imp_country
* save "braxpmkt/ext/simulation-data-2000.dta", replace
* check consistency
preserve
  keep exp_country gdp
  rename exp_country country
  duplicates drop
  duplicates tag country, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP
restore

* final GAMMA estimate
tempfile gamma
preserve
  keep exp_country gdp tbgs mfab tbg tbwtf
  rename exp_country country
  bysort country: keep if _n==1
  gen double gamma_mfab = (mfab-(1-$beta)*(1-1/$sigma)*(mfab+tbwtf))/(gdp-tbgs)
  qui summ gamma_mfab if country=="_RestOfWorld"
  if `r(mean)'<=0 {  // implausible RestOfWorld
    qui summ gamma_mfab if country~="_RestOfWorld"
    replace gamma_mfab = `r(mean)' if country=="_RestOfWorld"  // reset RestOfWorld to world mean
    }
  qui count if gamma_mfab<=0
  if `r(N)'>0  STOP  // more than RestOfWorld implausible
  keep country gamma
  bysort country: keep if _n==1
  summ gamma_mfab if gamma_mfab>0
  count if gamma_mfab~=.
  rename country exp_country
  sort exp_country
  save `gamma'
restore
count
merge exp_country using `gamma'
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete match
drop _m
count
label var gamma_mfab "Mf. Share in val. add. and trade"
sort exp_country imp_country
save "braxpmkt/ext/simulation-data-2000.dta", replace   // temporary saving, will be resaved below with additional UNIDO variable (BETA)


/* UNIDO DATA for BETA */

* Obtain country sample and concordance to unido
tempfile un3lst
use wtf* un3num using "brazaux/conc/countries/country-table.dta", clear
bysort wtfkey un3num: keep if _n==1
drop if wtfkey==.
* treatments
replace wtfkey=481560 if wtfkey==481561  // join China FTZ with China mainland into single entity
replace wtfkey=481560 if wtfkey==453440  // join Hong Kong with China mainland into single entity
replace wtfkey=481560 if wtfkey==454460  // join Macao with China mainland into single entity
replace wtfcountry="China/Hong Kong" if wtfkey==481560
replace wtfcountry="China/Hong Kong" if wtfkey==481560
amcountry
cntryset
drop wtfkey
sort country un3num
duplicates tag country, gen(_dupl)
drop if un3num==. & _dupl>0
sort country
save `un3lst'

* Use actual country sample
tempfile smpllst
use "braxpmkt/ext/simulation-data-2000.dta", clear
keep exp_country
rename exp_country country
bysort country: keep if _n==1
merge country using `un3lst'
drop if country=="_RestOfWorld"
gen byte indsmpl = (_m==3)
label var indsmpl "Indic.: In simulation data"
drop _m _dupl
order un3num country
drop if indsmpl~=1
drop indsmpl
sort un3num country
duplicates drop
duplicates tag un3num, gen(_dupl)
qui count if _dupl>0
if `r(N)'>0  STOP
drop _dupl
save `smpllst'

* final BETA estimate
tempfile beta
use un3num isic2 output_usd valadd_usd using "braxpmkt/ext/unido-2000-undefl-us-dollars.dta", clear
drop if output_usd==. | valadd_usd==.
* select countries with overall manufacturing information
gen byte _ind300 = (isic2==300)
egen byte _indtot = max(_ind300), by(un3num)
drop _ind300
drop if _indtot & isic2~=300  // remove individual industries
drop _indtot
* for remaining countries, collapse reported industries to average
collapse (mean) output_usd valadd_usd, by(un3num) fast
label var output_usd "Output [USD]"
label var valadd_usd "Value added [USD]"
gen beta = valadd_usd/output_usd
sort un3num
merge un3num using `smpllst'
tab un3num if _m==1
order un3num country
replace country="_RestOfWorld" if _m==1
count if _m==2
drop _m
summ beta
drop if beta==.
collapse (mean) beta, by(country)
summ beta
list country
keep country beta
rename country exp_country
label var beta "Share Mf. val. add in Mf. output"
compress
sort exp_country
save `beta'


/* EXCEL TABLES FOR PLAUSIBLE SAMPLE */

* Excel matrix "gdp_00" for Matlab
use "braxpmkt/ext/simulation-data-2000.dta", clear
keep exp_country gdp
rename exp_country country
bysort country: keep if _n==1
outsheet using "braxpmkt/matlab/gdp_00.csv", comma nonames replace

* Excel matrix "catb_00" for Matlab
use "braxpmkt/ext/simulation-data-2000.dta", clear
keep exp_country ca tbgs  // tbwtf left out as in DEK07
rename exp_country country
bysort country: keep if _n==1
order country ca tbgs
sort country
outsheet using "braxpmkt/matlab/catb_00.csv", comma names replace

* Excel matrix "trade_00" for Matlab
use "braxpmkt/ext/simulation-data-2000.dta", clear
keep exp_country imp_country bilattrd
rename bilattrd imp_
reshape wide imp_, i(exp_country) j(imp_country) string
rename exp_country _exp
local falsdiag = 0
qui count
forvalues i=1/`r(N)' {
  local wtf = _exp[`i']
  if imp_`wtf'[`i']~=. {
    disp in red "False diagonal entry for WTF key " in ye "`wtf'"
    local falsdiag = `falsdiag' + 1
    }
  }
if `falsdiag'>0  STOP  // No region can have exports to self (ROW-to-ROW dropped above) 
unab varlist : imp_*
foreach var in `varlist' {
  qui replace `var'=0 if `var'==.
  }
outsheet using "braxpmkt/matlab/trade_00.csv", comma names replace


* FINALIZE FULL DATA
use "braxpmkt/ext/simulation-data-2000.dta", clear   // temporarily saved file, to be resaved with BETA variable
merge exp_country using `beta'
tab _m
qui count if _m==2
if `r(N)'>0  STOP  // wrong match
drop _m
sort exp_country imp_country
save "braxpmkt/ext/simulation-data-2000.dta", replace   // final saving


* COUNTRIES WITH GAMMA
use exp_country imp_country gamma using "braxpmkt/ext/simulation-data-2000.dta", clear
codebook gamma
drop imp_country
rename exp_country country
bysort country: keep if _n==1
list if gamma~=.

* COUNTRIES WITH BETA
use exp_country imp_country beta using "braxpmkt/ext/simulation-data-2000.dta", clear
codebook beta
drop imp_country
rename exp_country country
bysort country: keep if _n==1
list if beta~=.


/* List of individual countries that would consistently belong to ROW for WTF and WDI (ROW overlap) */

* WTF
tempfile wtfrow
use ecode exporter using `wtfmain', clear
bysort ecode exporter: keep if _n==1
rename ecode wtfkeystr
gen long wtfkey = real(wtfkeystr)
qui count if wtfkey==. | wtfkeystr==""
if `r(N)'>0  NO MISSING EXPECTED
drop wtfkeystr
rename exporter exp_country
qui do "braxpmkt/conc/wtfkey.do"
label values wtfkey wtfkey
drop exp_country
sort wtfkey
merge wtfkey using `wtfuse', nokeep
tab _m
gen byte _ind_2del = (_m~=3)
drop _m country
drop if wtfkey==100000  // remove World
drop if wtfkey==481561  // join China FTZ with China mainland into single entity
keep if _ind_2del==1
drop _ind_2del
sort wtfkey
save `wtfrow'

* WDI
tempfile wdirow
use wdikey wdicountry using `wdidata'
bysort wdikey: keep if _n==1
sort wdikey
merge wdikey using `wdiuse'
tab _m
gen byte _ind_2del = (_m~=3)
drop if wdikey=="EAP" | wdikey=="ECA" | wdikey=="EMU" | wdikey=="HIC" | wdikey=="HPC" | wdikey=="LAC" | wdikey=="LDC" | wdikey=="LIC" | wdikey=="LMC" | wdikey=="LMY" | wdikey=="MIC" | wdikey=="MNA" | wdikey=="NOC" | wdikey=="OEC" | wdikey=="SAS" | wdikey=="SSA" | wdikey=="UMC"  // remove WDI aggregates, except WORLD (wdikey=="WLD")
drop _m wdicountry country
drop if wdikey=="WLD"  // remove World
drop if wdikey=="HKG"  // remove Hong Kong; joint with China mainland into single entity
keep if _ind_2del==1
drop _ind_2del
sort wdikey
save `wdirow'

* ROW Overlap WTF and WDI
use wtf* wdi* using "brazaux/conc/countries/country-table.dta", clear
duplicates drop
drop if wtfkey==. & wdikey==""
* backward compatibility with country-table 2007-04-13 (as in country-data-2000.do)
drop if ( wtfkey==537240 & wdikey=="" ) | ( wtfkey==368960 & wdikey=="ASM" ) | ( wtfkey==368960 & wdikey=="GUM" ) | ( wtfkey==450000 & wdikey=="TMP" ) | ( wtfkey== . & wdikey=="IMY" )
replace wdicountry="GERMANY" if ( wtfkey==532760 & wdikey=="DEU") 
replace wdicountry="GERMANY" if ( wtfkey==532800 & wdikey=="DEU") 
replace wdikey="" if ( wtfkey==532760 & wdikey=="DEU") 
replace wdikey="" if ( wtfkey==532800 & wdikey=="DEU") 
replace wdicountry="UNITED STATES" if ( wtfkey==368960 & wdikey=="PRI" )
replace wdikey="USA" if ( wtfkey==368960 & wdikey=="PRI" )
* overlap
replace wdikey="DEU" if wdicountry=="GERMANY"
sort wtfkey
merge wtfkey using `wtfrow'
gen byte _indwtfrow = (_m==3)
drop _m
sort wdikey
merge wdikey using `wdirow'
gen byte _indwdirow = (_m==3)
drop _m
tab _ind*
keep if _indwtfrow==1 & _indwdirow==1
drop _ind*
list

log close
