*! version 1.0.2  11apr2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.3  07jan2009  by Marc Muendler     muendler@ucsd.edu

* 5 digit SITC (rev 2) to ISIC (rev. 2)
* http://www.macalester.edu/research/economics/page/haveman/Trade.Resources/Concordances/FromSITC/sitc2.isic2.txt
* Courtesy of the OECD, Manufacturing ISIC industries only

* ISIC (Rev. 2) descriptions
* http://unstats.un.org/unsd/cr/registry/regdntransfer.asp?f=16

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/sitc2isic.log", replace

capture program drop mklbl
program define mklbl
  local var = "`1'"
  local lblname = "`2'"
  * qui replace `var' = lower(`var')
  local num = _N
  * Shorten label names
  local lblname = substr("`lblname'",1,8)
  * English labels
  forvalues i = 1/`num' {
    local lblnum = `2'[`i']
    local lblstr = `1'[`i']
    label define `lblname' `lblnum' "`lblstr'", modify
    }
  label values `2' `lblname'
  label list `lblname'
  label save `lblname' using "braxpmkt/conc/`lblname'", replace
end


// SITC revision 2 in text format (UN Comtrade, CommoditiesS2.txt, Mon, Dec 04 2006)
// http://comtrade.un.org/cf/files/folders/19/download.aspx
tempfile sitc2
insheet using "braxpmkt/conc/tcommoditiess2.txt", clear
keep v1 v2
rename v1 sitc2
rename v2 sitcdesc
keep if length(sitc2)<=4  // 59895 description empty but dropped b/c 5-digit
replace sitcdesc = upper(substr(substr(sitcdesc[_n+1],index(sitcdesc[_n+1],"except")+7,.),1,1)) + substr(substr(sitcdesc[_n+1],index(sitcdesc[_n+1],"except")+7,.),2,.) if sitcdesc==""  // correct missing 0751
qui count if sitcdesc==""
if `r(N)'>0  STOP
gen str _sitcrepl = sitcdesc if substr(sitcdesc,1,2)~="--"
qui count if substr(sitcdesc,1,4)=="----"
if `r(N)'>0  STOP
forvalues i = 1/9 {
  replace _sitcrepl = sitcdesc[_n-`i'] if _sitcrepl=="" & sitc2[_n-`i']==substr(sitc2,1,3)
  replace _sitcrepl = subinstr(_sitcrepl," textile fabrics not"," textile, not",.)
  }
gen str _sitcrepl1 = trim(substr(_sitcrepl,1,index(_sitcrepl," outerwear,")))    if index(_sitcrepl," outerwear,")>0
gen str _sitcrepl2 = trim(substr(_sitcrepl,index(_sitcrepl," outerwear,")+11,.)) if index(_sitcrepl," outerwear,")>0
replace sitcdesc = subinstr(sitcdesc," of textile fabrics, not knitted, crocheted","",.) if substr(sitcdesc,1,2)=="--"
replace sitcdesc = trim(_sitcrepl1) + subinstr(sitcdesc,"--","",.) + ", " + trim(_sitcrepl2) if substr(sitcdesc,1,2)=="--" & _sitcrepl2~=""
replace sitcdesc = "Men's and boys' under garments shirts, textile, not knitted or crocheted" if sitc2=="8441"
replace sitcdesc = "Men's and boys' under garments other than shirts, textile, not knitted or crocheted" if sitc2=="8442"
replace sitcdesc = "Womens, girls, infants, under garments, textile, not knitted or crocheted" if sitc2=="8443"
replace sitcdesc = "Jerseys, pullovers, slip-overs, etc, knitted or crocheted, not elastic" if sitc2=="8451"
replace sitcdesc = "Womens, girls, infants suits, dresses, etc, knitted or crocheted, not elastic" if sitc2=="8452"
replace sitcdesc = "Other outerwear clothing accessories, knitted or crocheted, not elastic" if sitc2=="8459"
replace _sitcrepl1 = "Under garments " if _sitcrepl=="Under-garments, knitted or crocheted"
replace _sitcrepl2 = ", knitted or crocheted, not elastic" if _sitcrepl=="Under-garments, knitted or crocheted"
replace sitcdesc = _sitcrepl1 + subinstr(subinstr(subinstr(sitcdesc,"-- ","",.),", not elastic nor rubberized","",.)," not elastic nor rubberized","",.) + _sitcrepl2 if substr(sitcdesc,1,2)=="--" & _sitcrepl=="Under-garments, knitted or crocheted"
drop _sitcrepl*
qui count if substr(sitcdesc,1,2)=="--"
if `r(N)'>0  STOP
keep if length(sitc2)==4
duplicates drop
qui count if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]
if `r(N)'>0  STOP
label var sitc2 "SITC (Rev.2) 4-digit sector"
label var sitcdesc "SITC (Rev.2) 4-digit description"
compress
sort sitc2
save `sitc2'


// ISIC (Rev. 2) STRUCTURE

infix using "braxpmkt/conc/isic.dct", using("braxpmkt/conc/isic_rev_2_english_structure.txt") clear
drop in 1
keep if length(isic2)==3 | length(isic2)==7
expand 2 if isic2=="311-312"
sort isic2
replace isic2 = "311" if isic2=="311-312" & isic2[_n+1]=="311-312"
replace isic2 = "312" if isic2=="311-312" & isic2[_n-1]=="311"
gen _isic2 = real(isic2)
drop isic2
rename _isic2 isic2
order isic2
compress
mklbl isicdesc isic2


// SITC-ISIC OECD CONCORDANCE

infix using "braxpmkt/conc/sitc2isic.dct", using("braxpmkt/conc/sitc2.isic2.txt") clear

* CORRECTIONS OF MAPPINGS (ISIC 380 does not exist in Rev. 2)

replace isic5="37---" if isic5=="38---" & sitc5=="282--" // Ferrous waste and scrap; remelting scrap ingots of iron or steel
replace isic5="371--" if isic5=="380--" & sitc5=="282--" // Ferrous waste and scrap; remelting scrap ingots of iron or steel
replace isic5="3710-" if isic5=="3801-" & sitc5=="282--" // Ferrous waste and scrap; remelting scrap ingots of iron or steel
replace isic5="37---" if isic5=="38---" & sitc5=="2882-" // Other non-ferrous base metal waste and scrap, n.e.s.
replace isic5="372--" if isic5=="380--" & sitc5=="2882-" // Other non-ferrous base metal waste and scrap, n.e.s.
replace isic5="3720-" if isic5=="3801-" & sitc5=="2882-" // Other non-ferrous base metal waste and scrap, n.e.s.
replace isic5="37---" if isic5=="38---" & sitc5=="68914" // Magnesium waste and scrap
replace isic5="372--" if isic5=="380--" & sitc5=="68914" // Magnesium waste and scrap
replace isic5="3720-" if isic5=="3801-" & sitc5=="68914" // Magnesium waste and scrap
qui count if substr(isic5,1,3)=="380"
if `r(N)'>0  STOP

* SITC (rev. 2) 4 digits
gen str4 sitc2 = substr(sitc5,1,4) if substr(sitc5,5,1)=="-"
label var sitc2 "SITC (Rev.2) 4-digit sector"
drop sitc5
order sitc2 map isic5
drop if sitc2==""

* ISIC (Rev.2) 3-digit
sort isic5
gen isic2 = real(substr(isic5,1,3))
label var isic2 "ISIC (Rev.2) 3-digit sector"
qui do "braxpmkt/conc/unido-isic2.do"
* qui do "braxpmkt/conc/isic2.do"
label values isic2 isic2
drop if isic2==.
keep if substr(isic5,4,2)=="--"

* ONE-TO-ONE or ONE-TO-MANY ISIC MAPPING (remove ambiguities)

tempfile sitcoecd
drop if substr(map,1,1)=="-"
drop if length(map)==3 & int(real(substr(map,2,2)))<50
drop isic5 map
sort sitc2 isic2
compress
save `sitcoecd'


// APPLICATION OF SITC-ISIC CONCORDANCE

use sitc4 using "braxpmkt/ext/wtf-data-2000.dta", clear
duplicates drop

* sector mapping SITC 4-digit to ISIC Rev. 2 (in waves of mappings, finest first)
drop if sitc4==""
replace sitc4 = subinstr(subinstr(sitc4,"X","-",.),"A","-",.)
rename sitc4 sitc2
sort sitc2
joinby sitc2 using `sitcoecd', _merge(_merge) unmatched(both)
tab _m
drop if _m==2
drop _m
rename isic2 isic2_0
rename sitc2 sitc4
forvalues i = 1/3 {
  local cuti = 4 - `i'
  local adddash ""
  forvalues j = 1/`i' {
    local adddash "`adddash'-"
    }
  gen str sitc2 = substr(sitc4,1,`cuti') + "`adddash'"
  sort sitc2
  joinby sitc2 using `sitcoecd', _merge(_merge) unmatched(both)
  tab _m
  drop if _m==2
  drop _m
  rename isic2 isic2_`i'
  drop sitc2
  }
gen int isic2 = isic2_0
forvalues i = 1/3 {
  replace isic2 = isic2_`i' if isic2==.
  }
drop isic2_*

// list of incomplete mappings
* preserve
  keep sitc4 isic2
  duplicates drop
  sort sitc4
  count if sitc4~=""
  count if isic2==.
  list sitc4 if isic2==.
* restore


// SITC-ISIC CONSTRUCTED CONCORDANCE FROM HS CONCORDANCES

use "braxpmkt/conc/hs2isic.dta", clear
order hs6dgt isic2
merge hs6dgt using "braxpmkt/conc/hs2sitc.dta"
tab _m
drop hs6dgt _m
duplicates drop
replace isic2=999 if isic2==.
sort sitc2 isic2
rename isic2 _isic2_hsinfer
joinby sitc2 using `sitcoecd', _merge(_merge) unmatched(both)
tab _m
drop if _isic2_hsinfer==. & substr(sitc2,-1,1)=="-"
tab _m
sort sitc2 isic2 _isic2_hsinfer
count if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]
list sitc2 _isic2_hsinfer if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]

// remove duplicates with contradictory `sitcoecd' information
* list sitc2 _isic2_hsinfer if ( sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] ) & _isic2_hsinfer~=isic2 & isic2~=. & ( sitc2=="0901" | sitc2=="2120" | sitc2=="2820" | sitc2=="3341" | sitc2=="3342" | sitc2=="3343" | sitc2=="3415" | sitc2=="6344" | sitc2=="6553" | sitc2=="8830" | sitc2=="8960" | sitc2=="9000" | sitc2=="9310" )
count if ( sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] ) & _isic2_hsinfer~=isic2 & isic2~=.
drop if ( sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] ) & _isic2_hsinfer~=isic2 & isic2~=.
sort sitc2 isic2 _isic2_hsinfer
count if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]

// remove "unclassified" if duplicate in specific sector
* list sitc2 _isic2_hsinfer if ( sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] ) & _isic2_hsinfer==999 & ( sitc2=="0901" | sitc2=="2120" | sitc2=="2820" | sitc2=="3341" | sitc2=="3342" | sitc2=="3343" | sitc2=="3415" | sitc2=="6344" | sitc2=="6553" | sitc2=="8830" | sitc2=="8960" | sitc2=="9000" | sitc2=="9310" )
count if ( sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] ) & _isic2_hsinfer==999
drop if ( sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] ) & _isic2_hsinfer==999
sort sitc2 isic2 _isic2_hsinfer
count if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]

// remove "other" if duplicate in specific sector
* list sitc2 _isic2_hsinfer if ( sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] ) & _isic2_hsinfer==390 & ( sitc2=="0901" | sitc2=="2120" | sitc2=="2820" | sitc2=="3341" | sitc2=="3342" | sitc2=="3343" | sitc2=="3415" | sitc2=="6344" | sitc2=="6553" | sitc2=="8830" | sitc2=="8960" | sitc2=="9000" | sitc2=="9310" )
count if ( sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] ) & _isic2_hsinfer==390
drop if ( sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] ) & _isic2_hsinfer==390
sort sitc2 isic2 _isic2_hsinfer
count if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]

// manual corrections, resolving overlaps between non-manufacturing and manufacturing (and within agriculture in one occasion)
count if ( sitc2=="0711" & _isic2_hsinfer~=111 ) | ( sitc2=="2440" & _isic2_hsinfer~=121 ) | ( sitc2=="2651" & _isic2_hsinfer~=111 ) | ( sitc2=="2772" & _isic2_hsinfer~=290 ) | ( sitc2=="2871" & _isic2_hsinfer~=230 ) | ( sitc2=="2872" & _isic2_hsinfer~=230 ) | ( sitc2=="2873" & _isic2_hsinfer~=230 ) | ( sitc2=="2911" & _isic2_hsinfer~=130 ) | ( sitc2=="2919" & _isic2_hsinfer~=130 ) | ( sitc2=="2929" & _isic2_hsinfer~=121 ) | ( sitc2=="2120" & _isic2_hsinfer~=113 )
drop if sitc2=="0711" & _isic2_hsinfer~=111
drop if sitc2=="2440" & _isic2_hsinfer~=121
drop if sitc2=="2651" & _isic2_hsinfer~=111
drop if sitc2=="2772" & _isic2_hsinfer~=290
drop if sitc2=="2871" & _isic2_hsinfer~=230
drop if sitc2=="2872" & _isic2_hsinfer~=230
drop if sitc2=="2873" & _isic2_hsinfer~=230
drop if sitc2=="2911" & _isic2_hsinfer~=130
drop if sitc2=="2919" & _isic2_hsinfer~=130
drop if sitc2=="2929" & _isic2_hsinfer~=121
drop if sitc2=="2120" & _isic2_hsinfer~=113
sort sitc2 isic2 _isic2_hsinfer
* tab sitc2 if sitc2=="0711" | sitc2=="2440" | sitc2=="2651" | sitc2=="2772" | sitc2=="2871" | sitc2=="2872" | sitc2=="2873" | sitc2=="2911" | sitc2=="2919" | sitc2=="2929" | sitc2=="2120"
list sitc2 _isic2_hsinfer if sitc2=="0711" | sitc2=="2440" | sitc2=="2651" | sitc2=="2772" | sitc2=="2871" | sitc2=="2872" | sitc2=="2873" | sitc2=="2911" | sitc2=="2919" | sitc2=="2929" | sitc2=="2120"
count if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]

// for remaining manufacturing-non-manufacturing overlaps, remove non-manufacturing product
* list sitc2 _isic2_hsinfer if ( ( sitc2==sitc2[_n-1] & _isic2_hsinfer<300 & _isic2_hsinfer[_n-1]>=300 ) | (sitc2==sitc2[_n+1] & _isic2_hsinfer<300 & _isic2_hsinfer[_n+1]>=300) ) & ( sitc2=="0901" | sitc2=="2120" | sitc2=="2820" | sitc2=="3341" | sitc2=="3342" | sitc2=="3343" | sitc2=="3415" | sitc2=="6344" | sitc2=="6553" | sitc2=="8830" | sitc2=="8960" | sitc2=="9000" | sitc2=="9310" )
count if ( sitc2==sitc2[_n-1] & _isic2_hsinfer<300 & _isic2_hsinfer[_n-1]>=300 ) | (sitc2==sitc2[_n+1] & _isic2_hsinfer<300 & _isic2_hsinfer[_n+1]>=300) 
drop if ( sitc2==sitc2[_n-1] & _isic2_hsinfer<300 & _isic2_hsinfer[_n-1]>=300 ) | (sitc2==sitc2[_n+1] & _isic2_hsinfer<300 & _isic2_hsinfer[_n+1]>=300) 
sort sitc2 isic2 _isic2_hsinfer
drop _merge isic2
rename _isic2_hsinfer isic2
count if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]
count
* browse if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1]
sort sitc2 isic2
merge sitc2 using `sitc2', nokeep
tab _m
drop _m
count

// manual corrections within manufacturing, inspired by OECD mapping
sort sitc2 isic2
* qui do "braxpmkt/conc/isic2.do"
* label values isic2 isic2
* outsheet if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] using "braxpmkt/conc/sitc2isic-problems.csv", comma replace
* erase "braxpmkt/conc/sitc2isic-problems.csv"
* drop duplicates; drop observations with less than maximum strikes in OECD concordance for manufacturing industries (counting +50 as strike but not - and +49)
count if sitc2=="" | sitc2=="0564" | sitc2=="0819" | sitc2=="5121" | sitc2=="5221" | sitc2=="5335" | sitc2=="5622" | sitc2=="5983" | sitc2=="5989" | sitc2=="6573" | sitc2=="6618" | sitc2=="6931" | sitc2=="6954" | sitc2=="7148" | sitc2=="7149" | sitc2=="7499" | sitc2=="7732" | sitc2=="7758" | sitc2=="7788" | sitc2=="7861" | sitc2=="7919" | sitc2=="7928" | sitc2=="8124" | sitc2=="8212" | sitc2=="8219" | sitc2=="8510" | sitc2=="8959" | sitc2=="8993" | sitc2=="6123"
drop if sitc2=="" & isic2==999
drop if sitc2=="0564" & isic2~=311  // 311: xxx, 312: xx
drop if sitc2=="0819" & isic2~=312  // 311: xxx, 312: xxxx, 313: xx
drop if sitc2=="5121" & isic2~=351  // 351: xxxx, 352: xx
drop if sitc2=="5221" & isic2~=351  // 351: xx (but higher level mappings), 352: xx
drop if sitc2=="5335" & isic2~=352  // 351: xx, 352: xxxx
drop if sitc2=="5622" & isic2~=351  // 351: xxx (by description), 371: xxx
drop if sitc2=="5983" & isic2~=352  // 351: xx, 352: xxx
drop if sitc2=="5989" & isic2~=352  // 351: xxxx, 352: xxxxxxx, 354: -, 385: xxx
drop if sitc2=="6573" & isic2~=321  // 321: xxxxx, 355: xxx
drop if sitc2=="6618" & isic2~=369  // 354: xxx, 369: xxxx
drop if sitc2=="6931" & isic2~=371  // no relevant information (wrong oecd mapping)
drop if sitc2=="6954" & isic2~=382  // 381: x, 382: xxxx
drop if sitc2=="7148" & isic2~=382  // 382: xx (by description), 384: xx
drop if sitc2=="7149" & isic2~=384  // 382: xx, 384: xx (by description)
drop if sitc2=="7499" & isic2~=382  // 381: -, 382: xx
drop if sitc2=="7732" & isic2~=362  // 356: -, 361: xxxx, 362: xxxx (by description)
drop if sitc2=="7758" & isic2~=383  // 321: -, 383: x
drop if sitc2=="7788" & isic2~=383  // 381: -, 383: xxxxxxxxxxx, 385: xx
drop if sitc2=="7861" & isic2~=384  // 382: -, 384: xx
drop if sitc2=="7919" & isic2~=384  // 381: -, 384: x
drop if sitc2=="7928" & isic2~=384  // 381: -, 384: xx
drop if sitc2=="8124" & isic2~=381  // 362: xxx, 381: xxxx
drop if sitc2=="8212" & isic2~=385  // 332: x, 385: xxx
drop if sitc2=="8219" & isic2~=381  // 332: -, 381: xxx
drop if sitc2=="8510" & isic2~=324  // 324: - (8510 is only footwear category), 356: xxx
drop if sitc2=="8959" & isic2~=352  // 352: xxxxxx, 356: xxx
drop if sitc2=="8993" & isic2~=352  // 351: -, 352: xxxx
replace isic2=324 if sitc2=="6123"  // footwear parts (as in oecd mapping)
sort sitc2 isic2
list sitc2 sitcdesc isic2 if sitc2=="" | sitc2=="0564" | sitc2=="0819" | sitc2=="5121" | sitc2=="5221" | sitc2=="5335" | sitc2=="5622" | sitc2=="5983" | sitc2=="5989" | sitc2=="6573" | sitc2=="6618" | sitc2=="6931" | sitc2=="6954" | sitc2=="7148" | sitc2=="7149" | sitc2=="7499" | sitc2=="7732" | sitc2=="7758" | sitc2=="7788" | sitc2=="7861" | sitc2=="7919" | sitc2=="7928" | sitc2=="8124" | sitc2=="8212" | sitc2=="8219" | sitc2=="8510" | sitc2=="8959" | sitc2=="8993" | sitc2=="6123", nolab
count if sitc2==sitc2[_n-1] | sitc2==sitc2[_n+1] 
if `r(N)'>0  STOP


// final adjustments
qui count
expand 4 if sitc2=="3344"
replace sitc2="3341" if sitc2=="3344" & _n==`r(N)'+1
replace sitc2="3342" if sitc2=="3344" & _n==`r(N)'+2
replace sitc2="3343" if sitc2=="3344" & _n==`r(N)'+3

// finalize
gen sitc4dgt = real(sitc2)
compress sitc4dgt
label var sitc4dgt "SITC (Rev.2) 4 digits (numeric)"
mklbl sitcdesc sitc4dgt
drop sitcdesc
qui do "braxpmkt/conc/sitc4dgt.do"
label values sitc4dgt sitc4dgt
qui do "braxpmkt/conc/isic2.do"
label values isic2 isic2
order sitc2 sitc4dgt isic2

sort sitc2 isic2
save "braxpmkt/conc/sitc2isic.dta", replace
count

* save "c:/documents and settings/marc/my documents/computing/website econ.ucsd.edu/download/conc/sitc2isic.dta", replace
* outsheet using "c:/documents and settings/marc/my documents/computing/website econ.ucsd.edu/download/conc/sitc2isic.csv", comma replace nolab

log close
cd "$home"

