*! version 1.0.3  07apr2007  by Marc Muendler     muendler@ucsd.edu

// similar to "fdilabor/%stata/%00prepare-external/unido-data-read.do"

* Read in data from UNIDO Industrial Statistics Database at the 3-digit level of ISIC Code (Rev. 2)
* "INDSTAT3 2005 ISIC Rev. 2"

# delimit ;

capture log close;
clear;
set matsize 800;
set memory 300m;
set more off;

log using "braxpmkt/logs/unido-data-read.log", replace;

capture program drop mklbl;
program define mklbl;
  local lblname = trim(lower("`2'"));
  local num = _N;
  forvalues i = 1/`num' {;
    local lblnum = `1'[`i'];
    local lbltxt = `2'[`i'];
    label define `lblname' `lblnum' "`lbltxt'", modify;
    };
  label values `1' `lblname';
  label list `lblname';
end;

tempfile isocntry;
infile using "braxpmkt/conc/unido-countries.dct", clear;
drop if un3==.;
duplicates drop;
compress;
sort un3num;
save `isocntry';

capture program drop mklbl;
program define mklbl;
  local lblname = trim(lower("`2'"));
  local num = _N;
  forvalues i = 1/`num' {;
    local lblnum = `1'[`i'];
    local lbltxt = `2'[`i'];
    label define `lblname' `lblnum' "`lbltxt'", modify;
    };
  label values `1' `lblname';
  label list `lblname';
end;

foreach infile in "us-dollars" "natl-curr" {;

insheet tablecode un3num year isic2 isic2comb value tabledefcode source updateyear unit using "$extdata/fdilabor/wages/indstat3-2005-isic-rev2-complete-`infile'.csv", comma clear;

drop tabledefcode source updateyear isic2comb unit;

gen v=real(value); /* missings are coded as "..." so value is read as string */
drop value;

/* 6 out of 705715 obs are duplicates so reshape would fail:
   values of these 6 obs are missing (see listings below for the case of natl-curr) */
duplicates drop un3num isic2 year tablecode, force;

reshape wide v, i(un3num isic2 year) j(tablecode);

label var un3num "Three-digit UN country number";
label var year "Calendar year";
label var isic2 "ISIC (Rev.2) 3-digit sector";

if "`infile'"=="natl-curr"   local lbl "for. curr";
if "`infile'"=="us-dollars"  local lbl "USD";
label var v1  "Number of establishments";
label var v4  "Employment";
label var v5  "Wages and salaries [`lbl']";
label var v14 "Output [`lbl']";
label var v20 "Value added [`lbl']";
label var v21 "Gr. fixd captl. form. [`lbl']";
if "`infile'"=="natl-curr"  label var v21 "Gr. fixd captl. form. [for. cur]";
label var v31 "Number of female employees";
label var v51 "Index of industrial production";

if "`infile'"=="natl-curr"   local ext "lcu";
if "`infile'"=="us-dollars"  local ext "usd";
rename v1 establ;
rename v4 empl;
rename v5 wagebill_`ext';
rename v14 output_`ext';
rename v20 valadd_`ext';
rename v21 invest_`ext';
rename v31 femempl;
rename v51 prodidx;

label define isic2
300 "[300] Total manufacturing"
311 "[311] Food products"
312 "[312] Food products"
313 "[313] Beverages"
314 "[314] Tobacco"
321 "[321] Textiles"
322 "[322] Wearing apparel, except footwear"
323 "[323] Leather products"
324 "[324] Footwear, except rubber or plastic"
331 "[331] Wood products, except furniture"
332 "[332] Furniture, except metal"
341 "[341] Paper and products"
342 "[342] Printing and publishing"
351 "[351] Industrial chemicals"
352 "[352] Other chemicals"
353 "[353] Petroleum refineries"
354 "[354] Misc. petroleum and coal products"
355 "[355] Rubber products"
356 "[356] Plastic products"
361 "[361] Pottery, china, earthenware"
362 "[362] Glass and products"
369 "[369] Other non-metallic mineral products"
371 "[371] Iron and steel"
372 "[372] Non-ferrous metals"
381 "[381] Fabricated metal products"
382 "[382] Machinery, except electrical"
383 "[383] Machinery, electric"
384 "[384] Transport equipment"
385 "[385] Professional & scientific equipment"
390 "[390] Other manufactured products";
label values isic2 isic2;
label save isic2 using "braxpmkt/conc/unido-isic2", replace;

sort un3num;
merge un3num using `isocntry', nokeep;
count if _m~=3;
if `r(N)'>0 {;
  disp as err "Incomplete country match";
  tab un3 if _m~=3;
  STOP;
  };
drop _m;
mklbl un3num unidolbl;
label save unidolbl using "braxpmkt/conc/unido-un3num", replace;
drop unidolbl;

keep if year==2000;
drop year;
compress;
sort un3num isic2;
save "braxpmkt/ext/unido-2000-undefl-`infile'", replace;

};

log close;
