*! version 1.0.1  07apr2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.2  04feb2008  by Oana Hirakawa     otocoian@ucsd.edu
*! version 1.0.3  18jan2012  by Marc Muendler     muendler@ucsd.edu

version 8.2
clear
set logtype text
set more off
set matsize 200
set mem 900m

capture log close
log using "braxpmkt/logs/wtf-data-chile.log", replace

* exports by product and country in 2000
tempfile exp
use icode importer ecode exporter sitc4 value using "$extdata/brazaux/intl/nber/wtf00.dta", clear
drop if icode=="100000" | icode=="999990" | ecode=="100000" | ecode=="999990" // world or intl organizations
collapse (sum) value, by(ecode exporter sitc4) fast
rename ecode wtfkey
label var wtfkey "Six-digit WTF code"
rename exporter wtfcountry
label var wtfcountry "Country name WTF (English)"
rename value exports
label var exports "SITC4 exports from source"
sort wtfkey sitc4
save `exp'

* imports by product and country in 2000
tempfile imp
use icode importer ecode exporter sitc4 value using "$extdata/brazaux/intl/nber/wtf00.dta", clear
drop if icode=="100000" | icode=="999990" | ecode=="100000" | ecode=="999990" // world or intl organizations
collapse (sum) value, by(icode importer sitc4) fast
rename icode wtfkey
label var wtfkey "Six-digit WTF code"
rename importer wtfcountry
label var wtfcountry "Country name WTF (English)"
rename value imports
label var imports "SITC4 imports to dest."
sort wtfkey sitc4
save `imp'

* annual bilateral destination-country trade data in 2000
tempfile chilexp
use icode importer ecode exporter sitc4 value using "$extdata/brazaux/intl/nber/wtf00.dta", clear
drop if icode=="100000" | icode=="999990" | ecode=="100000" | ecode=="999990" // world or intl organizations
keep if exporter=="Chile"
drop ecode exporter
rename icode wtfkey
label var wtfkey "Six-digit WTF code"
rename importer wtfcountry
label var wtfcountry "Country name WTF (English)"
rename value chilexp
label var chilexp "Chile's SITC4 exports to dest."
sort wtfkey sitc4
save `chilexp'
collapse (sum) chilexp, fast
local totwtfexp = chilexp[1]

// single data set
use `exp', clear
merge wtfkey sitc4 using `imp'
tab _m
drop _m
sort wtfkey sitc4
merge wtfkey sitc4 using `chilexp'
tab _m
drop _m
label var sitc4 "SITC (rev. 2) 4 digits"
gen _wtfkey = real(wtfkey)
drop wtfkey
rename _wtfkey wtfkey
label var wtfkey "Six-digit WTF code"
compress

// check consistency
preserve
  collapse (sum) chilexp, fast
  local newwtfexp = chilexp[1]
  disp in gr "Check total WTF exports from Chile:" in ye %9.0f `totwtfexp' in gr ", compared to wtf-data-2000-chile.dta: " in ye %9.0f `newwtfexp'
  if `totwtfexp'~=`newwtfexp'  STOP
restore

// transform to single USD (from 1,000 USD)
foreach var in exports imports chilexp {
  replace `var' = `var' * 1000
  }

order wtfkey wtfcountry sitc4
sort wtfkey sitc4
save "braxpmkt/ext/wtf-data-2000-chile.dta", replace

log close
