*! version 1.0.1  14apr2007  by Marc Muendler     muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/complete-hs2isic-conc-2000.log", replace


// Completion of HS 6-digit to ISIC2 mapping
tempfile problem help
use hs6dgt using "braxpmkt/secex/firms-2000.dta", clear
duplicates drop
sort hs6dgt
merge hs6dgt using "braxpmkt/conc/hs2isic.dta", nokeep
tab _m
keep if _m==1  // problem cases
drop _m isic2
duplicates drop
gen str hs6str = string(hs6dgt)
replace hs6str = "0" + hs6str if length(hs6str)<6
label var hs6str "Harmonized System 6-digit string"
qui count if length(hs6str)<6
if `r(N)'>0  STOP // missing digits in hs6str
drop hs6dgt
sort hs6str
save `problem'
use "braxpmkt/conc/hs2isic.dta", clear
gen str hs6str = string(hs6dgt)
replace hs6str = "0" + hs6str if length(hs6str)<6
label var hs6str "Harmonized System 6-digit string"
qui count if length(hs6str)<6
if `r(N)'>0  STOP // missing digits in hs6str
drop hs6dgt
sort hs6str
save `help'
local adddash ""
forvalues i = 1/4 {
  tempfile hs`i'up solve`i' altsolve`i'
  use `help'
  local adddash "`adddash'-"
  replace hs6str = substr(hs6str,1,6-`i') + "`adddash'"
  duplicates drop
  sort hs6str isic2
  save `hs`i'up'  // save higher-up mapping
  use `problem'
  replace hs6str = substr(hs6str,1,6-`i') + "`adddash'"
  duplicates drop
  sort hs6str
  joinby hs6str using `hs`i'up', _merge(_merge) unmatched(master) update // keep higher-up mappings only for remaining problem cases
  tab _m
  replace isic2=999 if _m==1 & substr(hs6str,1,1)=="9"
  sort hs6str isic2 _m
  drop if _m==1 & isic2==.
  drop _m
  sort hs6str isic2
  qui count if ( hs6str==hs6str[_n-1] | hs6str==hs6str[_n+1] ) & isic2~=.
  if `r(N)'>0 {
    preserve
    keep if hs6str==hs6str[_n-1] | hs6str==hs6str[_n+1]
    sort hs6str isic2
    by hs6str: gen _dupl = _n
    rename isic2 isic2_
    reshape wide isic2_, i(hs6str) j(_dupl)
    sort hs6str
    save `altsolve`i''  // offer alternative solutions if one-to-many at higher-up mappings
    restore
    }
  drop if hs6str==hs6str[_n-1] | hs6str==hs6str[_n+1]
  sort hs6str
  save `solve`i''  // save solved problem cases
  use `problem'
  replace hs6str = substr(hs6str,1,6-`i') + "`adddash'"
  duplicates drop
  sort hs6str
  merge hs6str using `solve`i''
  tab _m
  keep if _m==1
  drop _m isic2
  sort hs6str
  save `problem', replace  // save remaining problem cases to be resolved
  }

// Report remaining problem cases (for manual solution)
use `problem'
list

// Complete mapping for HS codes in SECEX data 2000
use hs6dgt using "braxpmkt/secex/firms-2000.dta", clear
duplicates drop
sort hs6dgt
gen str hs6str = string(hs6dgt)
replace hs6str = "0" + hs6str if length(hs6str)<6
label var hs6str "Harmonized System 6-digit string"
qui count if length(hs6str)<6
if `r(N)'>0  STOP // missing digits in hs6str
sort hs6dgt
merge hs6dgt using "braxpmkt/conc/hs2isic.dta", nokeep
tab _m
drop _m
local adddash ""
forvalues i = 1/4 {
  local adddash "`adddash'-"
  replace hs6str = substr(hs6str,1,6-`i') + "`adddash'"
  sort hs6str
  merge hs6str using `solve`i'', update
  tab _m
  drop _m
  }
list if isic2==.

// Report alternative solutions if one-to-many at higher-up mappings
preserve
use `altsolve4', clear
forvalues i = 3(-1)1 {
  capture append using `altsolve`i''
  }
sort hs6str
list, nolab
restore
* list if isic2==., nolab

// Manual adjustments for remaining problem cases
replace isic=312  if hs6dgt== 90190  // Coffee substitutes with coffee;coffee husks,skins
replace isic=351  if hs6dgt==382410  // Prepared binders for foundry molds or cores
replace isic=351  if hs6dgt==382420  // Naphthenic acids, water-insoluble salts & esters
replace isic=351  if hs6dgt==382430  // Nonagglomerated metal carbide mixed w metallic etc
replace isic=351  if hs6dgt==382440  // Prepared additives for cements, mortars/concretes
replace isic=351  if hs6dgt==382450  // Nonrefractory mortars and concretes
replace isic=351  if hs6dgt==382471  // Acyclic deriv perhalogenated w fluorine & chlorine
replace isic=351  if hs6dgt==382490  // Products and residuals of chemical industry, nesoi
replace isic=362  if hs6dgt==701940  // Narrow fabrics, woven, of glass fiber rovings
replace isic=321  if hs6dgt==701951  // Other woven narrow fabrics, nesoi
replace isic=362  if hs6dgt==701959  // Other woven fabrics of glass fibers, nesoi
replace isic=383  if hs6dgt==854340  // Electric fence energizers

qui count if isic2==.
if `r(N)'>0  STOP  // still incomplete hs to isic2 mapping

keep hs6dgt isic2
qui do "braxpmkt/conc/isic2.do"
label values isic2 isic2
compress
sort hs6dgt isic2
save "braxpmkt/conc/hs2isic-2000.dta", replace

log close
cd "$home"
