*! version 1.0.3  07oct2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.2  29jan2012  by Marc Muendler     muendler@ucsd.edu

* http://www.foreign-trade.com/reference/hscode.htm

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/prep-firms-2000-2001.log", replace

** Country concordance **
tempfile wtfmap
use secexkey secexname wtfkey using "brazaux/conc/countries/country-table.dta", clear  
drop if secexkey==678  // new entry over 2007-04-13: SECEX 678 "Saint Kitts e Nevis"; note: secexkey==695 is "S. Crist. e Nevis" and designates same island
replace wtfkey=358960 if secexkey==65  // new mapping after 2007-04-13: Aruba previously part of Caribbean NES
qui do "braxpmkt/conc/wtfkey.do"
label values wtfkey wtfkey
drop if secexkey==.
duplicates drop
sort secexkey wtfkey
list if wtfkey==.
// SECEX to WTF compatibility (ruling out many-to-one mappings from SECEX to WTF)
replace wtfkey=532760 if wtfkey==532800  // Former West Germany reset to Germany
replace wtfkey=481560 if wtfkey==481561 | wtfkey==481562  // China FTZ and SC reset to China
replace wtfkey=448870 if wtfkey==448860  // Former Yemen AR reset to Yemen
replace wtfkey=582210 if wtfkey==598900 | wtfkey==598910  // Former Yugoslavia and Yugoslavia reset to Serbia and Montenegro (E Europe NES)
replace wtfkey=725400 if wtfkey==166380  // Fr Ind O reset to New Calednia
* check country information
preserve
  keep wtfkey secexkey secexname
  duplicates drop
  sort secexkey wtfkey
  list if secexkey==secexkey[_n-1] | secexkey==secexkey[_n+1]  // no remaining many-to-one mappings from SECEX to WTF
  sort wtfkey secexkey
  list if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1]  // one-to-many mappings from SECEX to WTF
restore
drop secexname
sort secexkey wtfkey
save `wtfmap'


** Read 2000 and 2001 csv files and save in Stata 8 format **

// Annual exporter-destination-product data for 2001
* note: "secex/csv/exp01_prod.csv" contains no firm data (only port level)
insheet using "$extdata/secex/csv/exp01_emp.csv", double comma clear
* replace pais=695 if pais==678  // SECEX 678 "Saint Kitts e Nevis" and SECEX 695 "S. Crist. e Nevis" designate same island; no replacement for backward compatibility
drop ano tipo  // 2001 only, tipo: unknown variable
rename ncm prodctid
label var prodctid "Product Nomenclature (NCM)"
gen hs6dgt = int(prodctid/100)
label var hs6dgt "Harmonized System 6-digit code"
qui do "braxpmkt/conc/hs6dgt.do"
qui do "braxpmkt/conc/ncm-999.do"
label values hs6dgt hs6dgt
rename pais secexkey
label var secexkey "Country"
qui do "secex/conc/pais.do"
label values secexkey pais
gen double firmid = int(cgc/1000000)
label var firmid "Firm Tax Number (CGC)"
format firmid %8.0f
gen plantid = cgc - firmid*1000000
label var plantid "Plant ID (within firm)"
format plantid %8.0f
label var cgc "Plant Tax Number (CGC)"
label var uf "UF (federal unit)"
qui do "secex/conc/uf.do"
label values uf uf
rename valor value
label var value "Value (current US$ fob)"
rename mes month
label var month "Calendar month"
sort secexkey
merge secexkey using `wtfmap', nokeep
tab _m
drop _m
order firmid plantid cgc secexkey wtfkey prodctid hs6dgt month value uf
sort firmid plantid secexkey prodctid hs6dgt month
codebook
list secexkey hs6dgt month value if wtfkey==. & hs6dgt<=999800
// Collapse to firm 
collapse (sum) value, by(firmid wtfkey hs6dgt) fast
label var value "Value (current US$ fob)"
sort firmid wtfkey hs6dgt
save "braxpmkt/secex/firms-2001.dta", replace


// Annual exporter-destination-product data for 2000
insheet using "$extdata/secex/csv/exp00.csv", double comma clear
* replace pais=695 if pais==678  // SECEX 678 "Saint Kitts e Nevis" and SECEX 695 "S. Crist. e Nevis" designate same island; no replacement for backward compatibility
drop ano  // 2000 only
drop if cpf~=.  // drop private individuals
drop cgcv cpf   // drop private ids and mixed exporter ids
rename ncm prodctid
label var prodctid "Product Nomenclature (NCM)"
gen hs6dgt = int(prodctid/100)
label var hs6dgt "Harmonized System 6-digit code"
qui do "braxpmkt/conc/hs6dgt.do"
qui do "braxpmkt/conc/ncm-999.do"
label values hs6dgt hs6dgt
rename pais secexkey
label var secexkey "Country"
qui do "secex/conc/pais.do"
label values secexkey pais
gen double firmid = int(cgc/1000000)
label var firmid "Firm Tax Number (CGC)"
format firmid %8.0f
gen plantid = cgc - firmid*1000000
label var plantid "Plant ID (within firm)"
format plantid %8.0f
label var cgc "Plant Tax Number (CGC)"
label var uf "UF (federal unit)"
qui do "secex/conc/uf.do"
label values uf uf
rename valor value
label var value "Value (current US$ fob)"
rename mes month
label var month "Calendar month"
rename quant quantity
label var quantity "Quantity"
rename peso mass
label var mass "Mass in kg"
sort secexkey
merge secexkey using `wtfmap', nokeep
tab _m
drop _m
order firmid plantid cgc secexkey wtfkey prodctid hs6dgt month value uf
sort firmid plantid secexkey prodctid hs6dgt month
codebook
list secexkey hs6dgt month value if wtfkey==. & hs6dgt<=999800
// Collapse to firm 
collapse (sum) value quantity mass, by(firmid wtfkey hs6dgt) fast
label var value "Value (current US$ fob)"
label var quantity "Quantity"
label var mass "Mass in kg"
sort firmid wtfkey hs6dgt
save "braxpmkt/secex/firms-2000.dta", replace


// Annual exporter-destination-product data for 2000, at Southern Cone Common Nomenclature 8-digit level
insheet using "$extdata/secex/csv/exp00.csv", double comma clear
* replace pais=695 if pais==678  // SECEX 678 "Saint Kitts e Nevis" and SECEX 695 "S. Crist. e Nevis" designate same island; no replacement for backward compatibility
drop ano  // 2000 only
drop if cpf~=.  // drop private individuals
drop cgcv cpf   // drop private ids and mixed exporter ids
rename ncm prodctid
label var prodctid "Product Nomenclature (NCM)"
rename pais secexkey
label var secexkey "Country"
qui do "secex/conc/pais.do"
label values secexkey pais
gen double firmid = int(cgc/1000000)
label var firmid "Firm Tax Number (CGC)"
format firmid %8.0f
gen plantid = cgc - firmid*1000000
label var plantid "Plant ID (within firm)"
format plantid %8.0f
label var cgc "Plant Tax Number (CGC)"
label var uf "UF (federal unit)"
qui do "secex/conc/uf.do"
label values uf uf
rename valor value
label var value "Value (current US$ fob)"
rename mes month
label var month "Calendar month"
rename quant quantity
label var quantity "Quantity"
rename peso mass
label var mass "Mass in kg"
sort secexkey
merge secexkey using `wtfmap', nokeep
tab _m
drop _m
order firmid plantid cgc secexkey wtfkey prodctid month value uf
sort firmid plantid secexkey prodctid month
codebook
list secexkey prodctid month value if wtfkey==. & prodctid<=99980000
// Collapse to firm 
collapse (sum) value quantity mass, by(firmid wtfkey prodctid) fast
label var value "Value (current US$ fob)"
label var quantity "Quantity"
label var mass "Mass in kg"
sort firmid wtfkey prodctid
save "braxpmkt/secex/firms-2000-ncm8dgt.dta", replace


log close
cd "$home"
