*! version 1.0.5  15sep2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.6  09mar2008  by Oana Hirakawa     otocoian@ucsd.edu
*! version 1.0.7  27may2008  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.8  17jul2010  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.0  17jan2012  by Marc Muendler     muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/prodsales-data-2000-chile.log", replace

// Read file, rename variables
tempfile exp
use "braxpmkt/chile/exports-2000.dta", clear
desc
rename rut firmid
rename pr8 hs8dgt
assert year ==2000
drop year gdppc
rename q quantity
rename exp value
rename isic isic_plnt
sort wbcode firmid hs8dgt
save `exp'

// Do country concordance
use "brazaux/conc/countries/country-table.dta", clear
drop if wtfkey==481561  // backward compatibility with 2007-04-13: China FTZ never considered for Chile
qui do "braxpmkt/conc/wtfkey-chile.do"
label define wtfkey 0 `"World Total"', modify
label values wtfkey wtfkey
rename wdikey wbcode
replace wbcode="AND" if isoname=="Andorra"
replace wbcode="ARB" if isoname=="Aruba"
replace wbcode="ASM" if isoname=="American Samoa"
replace wbcode="GER" if wtfcountry=="Germany"
replace wbcode="MCO" if isoname=="Monaco"
replace wbcode="YSR" if isoname=="Yugoslavia"
replace wtfkey=358960 if wbcode=="ARB"  // backward compatibility: Aruba lumped with Caribbean NES
keep wbcode wtfkey
duplicates drop
drop if wbcode==""
sort wbcode wtfkey

** note that the matching is not unique by wbcode; in the case of USA, this was creating problems later on
duplicates list wbcode
** manual fix for all wbcodes with multiple wtfkeys: USA, CHN, CZE, MAR, NCL, NOR, YEM, YSR

drop if wbcode=="USA" & wtfkey~=218400
drop if wbcode=="CHN" & wtfkey~=481560
drop if wbcode=="CZE" & wtfkey~=582030
drop if wbcode=="MAR" & wtfkey~=135040
drop if wbcode=="NCL" & wtfkey~=725400
drop if wbcode=="NOR" & wtfkey~=555780
drop if wbcode=="YEM" & wtfkey~=448870
drop if wbcode=="YSR" & wtfkey~=598910
duplicates list wbcode

sort wbcode
merge wbcode using `exp'
tab _merge
assert _merge~=2
drop if _merge==1
drop _merge cname wbcode
collapse (sum) quantity value, by(wtfkey firmid hs8dgt isic_plnt)


// Collapse to HS 6-digit, merge with ISIC2 concordance
gen hs6dgt = int(hs8dgt/100)
collapse (sum) quantity value, by(wtfkey isic_plnt firmid hs6dgt)
sort hs6dgt
merge hs6dgt using "braxpmkt/conc/hs2isic.dta"
*, nokeep
rename isic2 isic_prdct
tab _merge if _merge~=2

** Almost 6% of observations have unmatched HS 6-digit information - these correspond to 211 unique HS 6-digit codes
** <investigate the HS mismatch>
    preserve
        collapse (sum) value (count) num_obs=value (mean) isic_plnt, by(_merge hs6dgt isic_prdct)
        tab _merge
        order hs6dgt isic_plnt _merge isic_prdct num_obs value
        sort _merge hs6dgt
        outsheet using "braxpmkt/conc/unmatched-hs6dgt-chile.csv", comma replace
        
        /*gen manuf = (isic_prdct>=300 & isic_prdct<400)
        gen hs2dgt = int(hs6dgt/10000)
        egen incl_manuf = max(manuf), by(hs2dgt)
        */
        
        drop if _merge==2
        *keep if _merge==1
        gen matched=(_merge==3)
        drop _merge
        sort hs6dgt
        merge hs6dgt using "braxpmkt/conc/hs-chile.dta", nokeep  // .dta version of "hs97.6.txt" for Chilean code, all commas replaced with ";"
        tab _merge
        sort hs6dgt
        outsheet using "braxpmkt/conc/unmatched-hs6dgt-names-chile.csv", comma replace
    restore

    preserve
        drop if _merge==2
        collapse (sum) value, by(_merge)
        sort _merge
        list _merge value
        local perc_value_unmatched = round(10000*value[1]/(value[1]+value[2]))/100
        disp "`perc_value_unmatched'% of total value is in HS6digit codes that weren't matched"
    restore

    preserve
        drop if _merge==2
        gen flag_invalid_hs6dgt = (hs6dgt<10000)
        collapse (sum) value, by(flag_invalid_hs6dgt)
        sort flag*
        list flag* value
        local perc_value_invalid = round(10000*value[2]/(value[1]+value[2]))/100
        disp "`perc_value_invalid'% of total value corresponds to invalid HS6digit codes"
    restore
** </investigate the HS mismatch>

*keep if _merge==3
drop if _merge==2
drop _merge
sort hs6dgt
save `exp', replace

** compare "isic" that came with the data to our concordance:
gen flag=(isic_plnt==isic_prdct) if isic_prdct~=.
tab flag  
** only 2/3 of isic codes agree - could be that the Chile data used a different revision 
*tab isic_plnt if ~flag
egen rank_prod = rank(value), unique by(firmid)
tab flag if rank_prod==1

** Each firm has multiple isic_plnt codes:
preserve
    keep firmid isic_plnt
    duplicates drop
    duplicates report firmid
    egen num_isic = count(isic_plnt), by(firmid)
    sum num_isic, det
restore

drop rank_prod flag

** Add the concordance written by hand 
insheet hs6dgt isic2 using "braxpmkt/conc/adhoc-hs2isic.csv", comma clear
sort hs6dgt
merge hs6dgt using `exp'
tab _merge
assert isic_prdct==. if _merge==3
replace isic_prdct = isic2 if _merge==3
drop isic2
gen flag_ad_hoc_conc = (_merge==3)
gen flag=(isic_plnt==isic_prdct) if flag_ad_hoc_conc
tab flag  
* about the same ratio of agreement between isic_plnt and isic_prdct (2/3)
drop flag _merge

count
count if isic_prdct==.

preserve
    egen total_country = sum(value), by(wtfkey)
    keep if isic_prdct==.
    collapse (mean) total_country (sum) value, by(wtfkey hs* isic_plnt)
    gen perc_of_total = 100*value/total_country
    levelsof hs6dgt, local(hs_codes)
    foreach hs of local hs_codes {
        list hs6dgt isic_plnt wtfkey perc_of_total if hs6dgt==`hs'
        }
restore

* drop 3-digit unmatched HS 6-digit codes
drop if hs6dgt<1000

* compute exports across all countries for each firm-product combination
egen expvalue = sum(value), by(hs6dgt firmid)
egen _maxval = max(expvalue), by(firmid)
gen _isicmax = isic_prdct if _maxval ==expvalue
egen isic_frm = min(_isicmax), by(firmid)  // if tie: low isic
drop _* expvalue

/* note: there are duplicates by hs6dgt left if we keep isic_plnt
    ** have to drop isic_plnt and do another collapse, since there are some 50 duplicates of hs6dgt left because of isic_plnt
    collapse (sum) quantity value, by(wtfkey isic_prdct firmid hs6dgt)
*/
duplicates report wtfkey firmid hs6dgt
duplicates report wtfkey firmid hs6dgt isic_plnt

// use ISIC code from original data 
* (alternatives: ISIC code from HS6digit-ISIC matching or isic_prdct code of top selling product for the firm)
gen isic2 = isic_frm

// Merge country-sector data
sort wtfkey isic2
merge wtfkey isic2 using "braxpmkt/ext/sector-country-data-2000-chile.dta"
tab _m
tab wtfkey if _m==2
tab isic2 if _m==2
tab wtfkey if _m==1
label var wtf_exports "ISIC2 exports from dest."
label var wtf_imports "ISIC2 imports to dest."
label var wtf_chilexp "Chile's ISIC2 exports to dest."
label var wtf_output  "ISIC2 output at dest."

// Statistics on merge success
preserve
  egen chl_chilexp = sum(value), by(wtfkey isic2)
  egen _aggmerge = mean(_m), by(wtfkey isic2)
  sort wtfkey isic2
  by wtfkey isic2: keep if _n==1
  keep wtfkey isic2 chl_chilexp wtf_chilexp _aggmerge
  format wtf_chilexp chl_chilexp %9.0g
  summ chl_chilexp, meanonly
  local totexp = `r(sum)'
  summ chl_chilexp if _aggmerge==1
  local wtfexp = `r(sum)'
  disp in gr "Share of Chilean Chile data exports with no WTF information:" in ye %9.4f `wtfexp'/`totexp'
  summ wtf_chilexp if wtfkey~=wtfkey[_n-1] & isic2~=isic2[_n-1], meanonly
  local totexp = `r(sum)'
  summ wtf_chilexp if _aggmerge==2 & wtfkey~=wtfkey[_n-1] & isic2~=isic2[_n-1]
  local wtfexp = `r(sum)'
  disp in gr "Share of Chilean WTF exports in WTF total, with NO Chile data information for WTF destination-sector:" in ye %9.4f `wtfexp'/`totexp'
restore
drop _m

// Check for Chile data/WTF disparity in world data, all sectors
preserve
  local totwtfexp = 20045340 * 1000 // (see %01/sector-country-data-2000-chile.do)
  egen chl_chilexp = sum(value), by(wtfkey isic2)
  sort wtfkey isic2
  by wtfkey isic2: keep if _n==1
  collapse (sum) chl_chilexp wtf_chilexp, fast
  disp in gr "Disparity (ratio) between Chilean exports and WTF information:" in ye %9.4f chl_chilexp[1]/wtf_chilexp[1]
  disp in gr "Total WTF exports from Chile:" in ye %9.0f wtf_chilexp[1] in gr ", compared to Chile data in prodsales-data-2000-chile.dta: " in ye %9.0f chl_chilexp[1]
  disp in gr "Check total WTF exports from Chile:" in ye %9.0f `totwtfexp' in gr ", compared to WTF in prodsales-data-2000-chile.dta: " in ye %9.0f wtf_chilexp[1]
  if float(`totwtfexp')~=float(wtf_chilexp[1])  STOP

// Check for Chile data/WTF disparity in world data, manufactures exports
restore, preserve 
  keep if isic2>=300 & isic2<=399  // manufactures exports
  egen chl_chilexp = sum(value), by(wtfkey isic2)
  sort wtfkey isic2
  by wtfkey isic2: keep if _n==1
  collapse (sum) chl_chilexp wtf_chilexp, fast
  disp in gr "Disparity (ratio) between Chile data manufacturing exports and WTF manufacturing information:" in ye %9.4f chl_chilexp[1]/wtf_chilexp[1]
  disp in gr "Total WTF manufacturing exports from Chile:" in ye %9.0f wtf_chilexp[1] in gr ", compared to Chile data manufactures in prodsales-data-2000-chile.dta: " in ye %9.0f chl_chilexp[1]

// Check for Chile data/WTF disparity in world data, manufacturing exporters and manufactures exports
restore, preserve 
*  keep if cnae>=15000 & cnae<=36999  // manufacturing exporters 
  keep if isic2>=300 & isic2<=399  // manufactures exports
  egen chl_chilexp = sum(value), by(wtfkey isic2)
  sort wtfkey isic2
  by wtfkey isic2: keep if _n==1
  collapse (sum) chl_chilexp wtf_chilexp, fast
  disp in gr "Disparity (ratio) between Chile data manufacturing firms' exports and WTF manufacturing information:" in ye %9.4f chl_chilexp[1]/wtf_chilexp[1]
  disp in gr "Total WTF manufacturing exports from Chile:" in ye %9.0f wtf_chilexp[1] in gr ", compared to Chile data manufacturing firms in prodsales-data-2000-chile.dta: " in ye %9.0f chl_chilexp[1]
restore
// Merge country data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/country-data-2000.dta"
replace indoecd90=0 if indoecd90==.
replace indoecd00=0 if indoecd00==.
tab wtfkey if _m==2
tab wtfkey if _m==1
preserve 
  egen chl_chilexp = sum(value), by(wtfkey)
  egen _aggmerge = mean(_m), by(wtfkey)
  tab _aggmerge
  sort wtfkey isic2
  by wtfkey: keep if _n==1
  keep wtfkey chl_chilexp wtf_chilexp _aggmerge
  format wtf_chilexp chl_chilexp %9.0g
  summ chl_chilexp, meanonly
  local totexp = `r(sum)'
  summ chl_chilexp if _aggmerge==1
  local wdiexp = `r(sum)'
  disp in gr "Share of Chilean exports with no WDI information:" in ye %9.4f `wdiexp'/`totexp'
restore
drop _m
summ indoecd*

// Merge destination data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/distance-data-chile.dta"
tab wtfkey if _m==2
tab wtfkey if _m==1
preserve
  egen chl_chilexp = sum(value), by(wtfkey)
  egen _aggmerge = mean(_m), by(wtfkey)
  tab _aggmerge
  sort wtfkey isic2
  by wtfkey: keep if _n==1
  keep wtfkey chl_chilexp wtf_chilexp _aggmerge
  format wtf_chilexp chl_chilexp %9.0g
  summ chl_chilexp, meanonly
  local totexp = `r(sum)'
  summ chl_chilexp if _aggmerge==1
  local cepiiexp = `r(sum)'
  disp in gr "Share of Chilean exports to destination with no CEPII information:" in ye %9.4f `cepiiexp'/`totexp'
restore
drop _m

order firmid wtfkey hs6dgt isic2
compress


// Aggregate over all destinations: wtfkey==0
tempfile firmagg secagg
preserve
  collapse (sum) value quantity, by(firmid hs6dgt isic2) fast
  gen byte wtfkey = 0
  label var wtfkey      "Six-digit WTF code"
  label var value       "Value (current US$ fob)"
  label var quantity    "Quantity"
  *label var mass        "Mass in kg"
  sort firmid hs6dgt isic2
  save `firmagg'
restore
append using `firmagg'
label define wtfkey 0 "World Total", modify
preserve
  use "braxpmkt/ext/sector-country-data-2000-chile.dta", clear
  collapse (sum) wtf_output wtf_exports wtf_imports wtf_chilexp, by(isic2) fast
  gen byte wtfkey = 0
  label var wtfkey      "Six-digit WTF code"
  label var wtf_output  "ISIC2 output at dest."
  label var wtf_exports "ISIC2 exports from dest."
  label var wtf_imports "ISIC2 imports to dest."
  label var wtf_chilexp "Chile's ISIC2 exports to dest."
  sort wtfkey isic2
save `secagg'
restore
sort wtfkey isic2
merge wtfkey isic2 using `secagg', update
tab _m
drop _m


// Finalize
drop if firmid==""
** 492 firms out of 5,284 have a "K" at the end of the firm code; remove this K and destring
** (need to destring, otherwise tabl2tex crashes later in "prodsales-stats.do")
gen temp = subinstr(firmid,"K","",1)
** check that by cutting out the "K" we didn't create firmid duplicates after conversion to numeric (0's at the beginning):
preserve 
    gen K=(length(temp)==9)
    tab K
    keep temp K
    duplicates drop
    destring temp, replace
    duplicates report temp
    assert r(unique_value)==r(N)
restore
destring temp, replace
drop firmid
rename temp firmid
order firmid wtfkey hs6dgt isic2
qui do "braxpmkt/conc/hs6dgt.do"
label value hs6dgt hs6dgt
label var firmid "Firm Number (RUT)"
label var isic_plnt  "ISIC (Rev.2) 3-digit of plant"
label var isic_frm   "ISIC (Rev.2) 3-digit of firm"
label var isic_prdct "ISIC (Rev.2) 3-digit of product"
label var flag_ad_hoc_conc "Indic.: Manual HSxISIC conc."
label var hs6dgt "Harmonized System 6-digit code"
label var value "Value (current US$ fob)"
label var quantity "Quantity"
compress
sort firmid wtfkey hs6dgt
save "braxpmkt/chile/prodsales-data-2000-chile.dta", replace

log close
cd "$home"
