*! version 1.0.1  03jul2011  by Marc Muendler     muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/prodsales-data-2000-ncm8.log", replace


// Mapping from ISIC rev. 2 to SIC (as in EKK 2004)

tempfile isic2ekk
insheet using "braxpmkt/ekk/ekk-sic-isic2-conc.csv", comma clear names
qui count if index(isic2,",") > 0
local chk = `r(N)'
while `chk'>0 {
  sort sic
  qui gen byte _exp_cnt = ( index(isic2,",") > 0 ) + 1
  qui expand _exp_cnt if index(isic2,",") > 0
  sort sic isic2
  by sic isic2: gen byte _cnt = _n
  qui replace isic2 = trim(substr(isic2,1,index(isic2,",")-1)) if _exp_cnt>1 & _cnt==1
  qui replace isic2 = trim(substr(isic2,index(isic2,",")+1,.)) if _exp_cnt>1 & _cnt>1
  qui drop _*
  qui count if index(isic2,",") > 0
  local chk = `r(N)'
  }
gen isic2num = int(real(isic2))
compress
drop isic2
rename isic2num isic2
order isic2
sort isic2
qui do "braxpmkt/conc/unido-isic2.do"
label values isic2 isic2
replace sic = "99" if sic=="0"
gen _sicind = "[" + sic + "] " + industry
encode _sicind, generate(sicekk) label(sicekk)
drop _sicind
keep isic2 sicekk
tab sicekk
label var isic2 "ISIC 2.0 (3-digit)"
label var sicekk "EKK (SIC) industries"
compress
sort isic2
save `isic2ekk'


// Read SECEX data, keep firms from all sectors
// Drop exports to no distinct destination (including on-board aircraft consumption of combustibles and other goods)

use "braxpmkt/secex/firms-2000-ncm8dgt.dta", clear
rename prodctid ncm8dgt

// Firm-level sector information (manufacturing firms: cnae>=15000 & cnae<=36999)
merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
drop _m n_pis rem_dezembro n_cnpj_estbl n_municipio ind*
rename mod_clas_cnae_95 cnae
order firmid wtfkey cnae ncm8dgt value quantity mass

// Export share
tab ncm8dgt if wtfkey==.
egen _totexports = sum(value)
gen expshare = value/_totexports
label var expshare "Exports share in 2000 total"
table ncm8dgt if wtfkey==., c(sum value sum expshare)
drop _totexports expshare
drop if wtfkey==.

// Map HS-6 to ISIC2 (manufacturing products: isic2>=300 & isic2<=399)
gen hs6dgt = int(ncm8dgt/100)
label var hs6dgt "Harmonized System 6-digit code"
qui do "braxpmkt/conc/hs6dgt.do"
label values hs6dgt hs6dgt
sort hs6dgt
merge hs6dgt using "braxpmkt/conc/hs2isic-2000.dta"
tab _m
drop _m hs6dgt

// Merge country-sector data
sort wtfkey isic2
merge wtfkey isic2 using "braxpmkt/ext/sector-country-data-2000.dta"
tab wtfkey if _m==2
tab isic2 if _m==2
tab wtfkey if _m==1
label var wtf_exports "ISIC2 exports from dest."
label var wtf_imports "ISIC2 imports to dest."
label var wtf_brazexp "Brazil's ISIC2 exports to dest."
label var wtf_output  "ISIC2 output at dest."

// Statistics on merge success
preserve
  egen scx_brazexp = sum(value), by(wtfkey isic2)
  egen _aggmerge = mean(_m), by(wtfkey isic2)
  sort wtfkey isic2
  by wtfkey isic2: keep if _n==1
  keep wtfkey isic2 scx_brazexp wtf_brazexp _aggmerge
  format wtf_brazexp scx_brazexp %9.0g
  summ scx_brazexp, meanonly
  local totexp = `r(sum)'
  summ scx_brazexp if _aggmerge==1
  local wtfexp = `r(sum)'
  disp in gr "Share of Brazilian SECEX exports with no WTF information:" in ye %9.4f `wtfexp'/`totexp'
  summ wtf_brazexp if wtfkey~=wtfkey[_n-1] & isic2~=isic2[_n-1], meanonly
  local totexp = `r(sum)'
  summ wtf_brazexp if _aggmerge==2 & wtfkey~=wtfkey[_n-1] & isic2~=isic2[_n-1]
  local wtfexp = `r(sum)'
  disp in gr "Share of Brazilian WTF exports in WTF total, with NO SECEX information for WTF destination-sector:" in ye %9.4f `wtfexp'/`totexp'
restore
drop _m

// Check for SECEX/WTF disparity in world data, all sectors
preserve
  local totwtfexp = 60985226 * 1000 // (see %02/sector-country-data-2000.do)
  egen scx_brazexp = sum(value), by(wtfkey isic2)
  sort wtfkey isic2
  by wtfkey isic2: keep if _n==1
  collapse (sum) scx_brazexp wtf_brazexp, fast
  disp in gr "Disparity (ratio) between Brazilian SECEX exports and WTF information:" in ye %9.4f scx_brazexp[1]/wtf_brazexp[1]
  disp in gr "Total WTF exports from Brazil:" in ye %9.0f wtf_brazexp[1] in gr ", compared to SECEX in prodsales-data-2000.dta: " in ye %9.0f scx_brazexp[1]
  disp in gr "Check total WTF exports from Brazil:" in ye %9.0f `totwtfexp' in gr ", compared to WTF in prodsales-data-2000.dta: " in ye %9.0f wtf_brazexp[1]
  if float(`totwtfexp')~=float(wtf_brazexp[1])  STOP

// Check for SECEX/WTF disparity in world data, manufactures exports
restore, preserve 
  keep if isic2>=300 & isic2<=399  // manufactures exports
  egen scx_brazexp = sum(value), by(wtfkey isic2)
  sort wtfkey isic2
  by wtfkey isic2: keep if _n==1
  collapse (sum) scx_brazexp wtf_brazexp, fast
  disp in gr "Disparity (ratio) between SECEX manufacturing exports and WTF manufacturing information:" in ye %9.4f scx_brazexp[1]/wtf_brazexp[1]
  disp in gr "Total WTF manufacturing exports from Brazil:" in ye %9.0f wtf_brazexp[1] in gr ", compared to SECEX manufactures in prodsales-data-2000.dta: " in ye %9.0f scx_brazexp[1]

// Check for SECEX/WTF disparity in world data, manufacturing exporters and manufactures exports
restore, preserve 
  keep if cnae>=15000 & cnae<=36999  // manufacturing exporters 
  keep if isic2>=300 & isic2<=399  // manufactures exports
  egen scx_brazexp = sum(value), by(wtfkey isic2)
  sort wtfkey isic2
  by wtfkey isic2: keep if _n==1
  collapse (sum) scx_brazexp wtf_brazexp, fast
  disp in gr "Disparity (ratio) between SECEX manufacturing firms' exports and WTF manufacturing information:" in ye %9.4f scx_brazexp[1]/wtf_brazexp[1]
  disp in gr "Total WTF manufacturing exports from Brazil:" in ye %9.0f wtf_brazexp[1] in gr ", compared to SECEX manufacturing firms in prodsales-data-2000.dta: " in ye %9.0f scx_brazexp[1]

// Check for SECEX/WTF disparity in world data, EKK-SIC definition
restore, preserve 
  rename isic2 goods_isic2
  gen cnaestr = string(int(cnae/10))
  replace cnaestr = "0" + cnaestr if length(cnaestr)<4
  drop cnae
  rename cnaestr cnae
  label var cnae "CNAE sector (annual mode)"
  sort cnae
  merge cnae using "brazcomp/filters/cnae-isic2"
  tab _m
  * list cnae value if _m==1
  * list cnae isic2 if _m==2
  drop if _m~=3
  drop _m cnae_desc cnae
  order firmid isic2dgt3
  rename isic2dgt3 isic2
  qui do "braxpmkt/conc/unido-isic2.do"
  label values isic2 isic2
  sort isic2
  merge isic2 using `isic2ekk'
  tab _m
  drop if _m==1  // EKK manufacturing firms only
  drop _m isic2
  order firmid sicekk
  drop if sicekk==1 | sicekk==18  // drop petroleum refineries and manufacturing total, 16 sectors remains (numbered 2-17)
  sort firmid sicekk wtfkey ncm8dgt
  egen scx_brazexp = sum(value), by(wtfkey goods_isic2)
  sort wtfkey sicekk
  by wtfkey sicekk: keep if _n==1
  collapse (sum) scx_brazexp wtf_brazexp, fast
  disp in gr "Disparity (ratio) between SECEX manufacturing firms' exports and WTF manufacturing information:" in ye %9.4f scx_brazexp[1]/wtf_brazexp[1]
  disp in gr "Total WTF manufacturing exports from Brazil:" in ye %9.0f wtf_brazexp[1] in gr ", compared to SECEX manufacturing firms in prodsales-data-2000.dta: " in ye %9.0f scx_brazexp[1]
restore


// Merge country data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/country-data-2000.dta"
replace indoecd90=0 if indoecd90==.
replace indoecd00=0 if indoecd00==.
tab wtfkey if _m==2
tab wtfkey if _m==1
preserve 
  egen scx_brazexp = sum(value), by(wtfkey)
  egen _aggmerge = mean(_m), by(wtfkey)
  tab _aggmerge
  sort wtfkey isic2
  by wtfkey: keep if _n==1
  keep wtfkey scx_brazexp wtf_brazexp _aggmerge
  format wtf_brazexp scx_brazexp %9.0g
  summ scx_brazexp, meanonly
  local totexp = `r(sum)'
  summ scx_brazexp if _aggmerge==1
  local wdiexp = `r(sum)'
  disp in gr "Share of Brazilian exports with no WDI information:" in ye %9.4f `wdiexp'/`totexp'
restore
drop _m
summ indoecd*

// Merge destination data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/distance-data.dta"
tab wtfkey if _m==2
tab wtfkey if _m==1
preserve
  egen scx_brazexp = sum(value), by(wtfkey)
  egen _aggmerge = mean(_m), by(wtfkey)
  tab _aggmerge
  sort wtfkey isic2
  by wtfkey: keep if _n==1
  keep wtfkey scx_brazexp wtf_brazexp _aggmerge
  format wtf_brazexp scx_brazexp %9.0g
  summ scx_brazexp, meanonly
  local totexp = `r(sum)'
  summ scx_brazexp if _aggmerge==1
  local cepiiexp = `r(sum)'
  disp in gr "Share of Brazilian exports to destination with no CEPII information:" in ye %9.4f `cepiiexp'/`totexp'
restore
drop _m

order firmid cnae wtfkey ncm8dgt isic2
compress


// Aggregate over all destinations: wtfkey==0
tempfile firmagg secagg
preserve
  collapse (sum) value quantity mass, by(firmid cnae ncm8dgt isic2) fast
  gen byte wtfkey = 0
  label var wtfkey      "Six-digit WTF code"
  label var value       "Value (current US$ fob)"
  label var quantity    "Quantity"
  label var mass        "Mass in kg"
  sort firmid cnae ncm8dgt isic2
  save `firmagg'
restore
append using `firmagg'
label define wtfkey 0 "World Total", modify
preserve
  use "braxpmkt/ext/sector-country-data-2000.dta", clear
  collapse (sum) wtf_output wtf_exports wtf_imports wtf_brazexp, by(isic2) fast
  gen byte wtfkey = 0
  label var wtfkey      "Six-digit WTF code"
  label var wtf_output  "ISIC2 output at dest."
  label var wtf_exports "ISIC2 exports from dest."
  label var wtf_imports "ISIC2 imports to dest."
  label var wtf_brazexp "Brazil's ISIC2 exports to dest."
  sort wtfkey isic2
save `secagg'
restore
sort wtfkey isic2
merge wtfkey isic2 using `secagg', update
tab _m
drop _m

// Finalize
drop if firmid==.
order firmid cnae wtfkey ncm8dgt isic2
compress
sort firmid wtfkey ncm8dgt
save "braxpmkt/secex/prodsales-data-2000-ncm8.dta", replace

log close
cd "$home"
