*! version 1.0.2  30apr2011  by Marc Muendler     muendler@ucsd.edu

version 10.1
set more off
set virtual on
clear
set mem 500m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/prodsales-rais-2000-addons.log", replace

* Minimum Wage in Deflated BRL
tempfile minwage
use "brazaux/auxil/minwage", clear
keep day salusd
gen year = year(day)
gen _mo = month(day)
keep if _mo==12
drop _mo day
order year
replace year = year - 1900
sort year
compress
keep if year>=86 & year<=101
mkmat salusd, matrix(salusd)
matname salusd 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101, rows(1..16) explicit
mat list salusd

// SECEX 2000 firm list

tempfile secexlst
use firmid using "braxpmkt/secex/prodsales-data-2000.dta", clear
duplicates drop
sort firmid
saveold `secexlst'

// JPOOLE Inward FDI list

tempfile fdicc
use identificad ano fdi_cc if ano==2000 using "rais/bcb-fdi/all-fdi.dta", clear
drop ano
tsset, clear
replace identificad = int(identificad/1000000)
rename identificad firmide
label var firmid "Firm Tax Number (CGC)"
rename fdi_cc indfdicc
label var indfdicc "Indic.: Inward FDI stock (BCB)"
compress
sort firmid
saveold `fdicc'

// RAIS log-wage FE

tempfile raisfe
use "$extdata/brazhimr/estmat/plantfe/firmpred-edu-allsec-2000.dta", clear
rename cnpj_radic firmid
sort firmid
merge firmid using `secexlst'
tab _m
drop if _m==1
drop _m
sort firmid
saveold `raisfe'

// RAIS MNE status (CNPJ_RADIC firms as in %2/rais-cnpj-cnae.do)

tempfile raismne
forvalues year=1995/2001 {
tempfile cnae`year'
* note: final education definitions include dropouts 
*       (missing education information implicitly assigned to primary schooling; occurs in 3.3% of cnpjradic for aggcnpj_a)
*       (missing occupation information unassigned; occurs in 9.7% of cnpjradic for aggcnpj_a)
forvalues i=1/10 {
  tempfile cnpj`i'
  local file = "aggcnpj_" + lower(char(64+`i'))
  use cnpj_radic ano mod_nat_jurid sum_rem_dezembro if ano==`year' using "rais/base-agg/cnpjradic/`file'", clear
  * annual BRL wage, deflated
  local yr = `year'-1900
  local minw = salusd[`yr'-85,1]
  gen wagebill = real(subinstr(subinstr(sum_rem_dezembro,".","",.),",",".",.)) * `minw' 
  label var wagebill "Wage Bill Dec. (curr. USD)"
  drop sum_rem_dezembro
  save `cnpj`i''
  }
use `cnpj1'
forvalues i=2/10 {
  append using `cnpj`i''
  }
format cnpj_radic %8.0f
rename cnpj_radic firmid
sort firmid
save `cnae`year''
}
use `cnae2000'
foreach year in 2001 1999 1998 1997 1996 1995 {
  sort firmid
  merge firmid using `cnae`year'', update
  tab _m
  drop _m
  }
label var firmid "Firm Tax Number (CGC)"
order firmid mod_nat_jurid
gen byte indmne = (mod_nat_jurid==2178)  // 2178 "Branch or office of foreign company"
label var indmne "Indic.: For. MNE branch (RAIS)"
rename ano rais_ano
label var rais_ano "Year of RAIS/MNE info"
drop mod_nat_jurid
* deflation to USD-2000 comparable to brazexp/%stata/%02secex-prep/firmagg-secex.do
replace wagebill = (wagebill/1.02271)*1.167785235 if rais_ano==1995
replace wagebill = (wagebill/1.06442953)*1.167785235 if rais_ano==1996
replace wagebill = (wagebill/1.082550336)*1.167785235 if rais_ano==1997
replace wagebill = (wagebill/1.1)*1.167785235 if rais_ano==1998
replace wagebill = (wagebill/1.129530201)*1.167785235 if rais_ano==1999
replace wagebill = (wagebill/1.18590604)*1.167785235 if rais_ano==2001
sort firmid
saveold `raismne'

// FINALIZE

use `raisfe', clear
merge using `raismne', nokeep
tab _m
drop _m
merge using `fdicc', nokeep
tab _m
drop _m
replace indfdicc = 0 if indfdicc==.
keep firmid n_pis wagebill avgpsihat indfdicc indmne rais_ano
order firmid n_pis wagebill avgpsihat indfdicc indmne rais_ano
sort firmid
saveold "braxpmkt/secex/prodsales-rais-2000-addons.dta", replace

tab indmne indfdi

log close
cd "$home"
