*! version 1.0.5  10jan2011  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.9  29jan2012  by Marc Muendler     muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/replication-data-2000-expitems-chile.log", replace


// Mapping from ISIC rev. 2 to SIC (as in EKK 2004)

tempfile isic2ekk
insheet using "braxpmkt/ekk/ekk-sic-isic2-conc.csv", comma clear names
qui count if index(isic2,",") > 0
local chk = `r(N)'
while `chk'>0 {
  sort sic
  qui gen byte _exp_cnt = ( index(isic2,",") > 0 ) + 1
  qui expand _exp_cnt if index(isic2,",") > 0
  sort sic isic2
  by sic isic2: gen byte _cnt = _n
  qui replace isic2 = trim(substr(isic2,1,index(isic2,",")-1)) if _exp_cnt>1 & _cnt==1
  qui replace isic2 = trim(substr(isic2,index(isic2,",")+1,.)) if _exp_cnt>1 & _cnt>1
  qui drop _*
  qui count if index(isic2,",") > 0
  local chk = `r(N)'
  }
gen isic2num = int(real(isic2))
compress
drop isic2
rename isic2num isic2
order isic2
sort isic2
qui do "braxpmkt/conc/unido-isic2.do"
label values isic2 isic2
replace sic = "99" if sic=="0"
gen _sicind = "[" + sic + "] " + industry
encode _sicind, generate(sicekk) label(sicekk)
drop _sicind
keep isic2 sicekk
tab sicekk
label var isic2 "ISIC 2.0 (3-digit)"
label var sicekk "EKK (SIC) industries"
compress
sort isic2
save `isic2ekk'


// Read external data, aggregate for manufacturing
tempfile wtfdata
use "braxpmkt/ext/sector-country-data-2000-chile.dta", clear
keep if isic2>300 & isic2<=399  // manufacturing only
collapse (sum) wtf_output wtf_exports wtf_imports wtf_chilexp, by(wtfkey)
label var wtf_output  "Manuf. output"
label var wtf_exports "Manuf. exports from source"
label var wtf_imports "Manuf. imports to dest."
label var wtf_chilexp "Brazil's manuf. exports to dest."
sort wtfkey
save `wtfdata'


// Read CHILEAN data
// Drop exports to no distinct destination (including on-board aircraft consumption of combustibles and other goods)
// Clean up ISIC sector mapping as in prodsales-data-2000-chile.do

// Read SECEX data, keep manufacturing firms only

tempfile exp
use "braxpmkt/chile/exports-2000.dta", clear
desc
rename rut firmid
rename pr8 hs8dgt
assert year ==2000
drop year gdppc
rename q quantity
rename exp value
rename isic isic_plnt
sort wbcode firmid hs8dgt
save `exp'

// Do country concordance
use "brazaux/conc/countries/country-table.dta", clear
drop if wtfkey==481561  // backward compatibility with 2007-04-13: China FTZ never considered for Chile
qui do "braxpmkt/conc/wtfkey-chile.do"
label define wtfkey 0 `"World Total"', modify
label values wtfkey wtfkey
rename wdikey wbcode
replace wbcode="AND" if isoname=="Andorra"
replace wbcode="ARB" if isoname=="Aruba"
replace wbcode="ASM" if isoname=="American Samoa"
replace wbcode="GER" if wtfcountry=="Germany"
replace wbcode="MCO" if isoname=="Monaco"
replace wbcode="YSR" if isoname=="Yugoslavia"
replace wtfkey=358960 if wbcode=="ARB"  // backward compatibility: Aruba lumped with Caribbean NES
keep wbcode wtfkey
duplicates drop
drop if wbcode==""
sort wbcode wtfkey

** note that the matching is not unique by wbcode; in the case of USA, this was creating problems later on
duplicates list wbcode
** manual fix for all wbcodes with multiple wtfkeys: USA, CHN, CZE, MAR, NCL, NOR, YEM, YSR

drop if wbcode=="USA" & wtfkey~=218400
drop if wbcode=="CHN" & wtfkey~=481560
drop if wbcode=="CZE" & wtfkey~=582030
drop if wbcode=="MAR" & wtfkey~=135040
drop if wbcode=="NCL" & wtfkey~=725400
drop if wbcode=="NOR" & wtfkey~=555780
drop if wbcode=="YEM" & wtfkey~=448870
drop if wbcode=="YSR" & wtfkey~=598910
duplicates list wbcode

sort wbcode
merge wbcode using `exp'
tab _merge
assert _merge~=2
drop if _merge==1
drop _merge cname wbcode
collapse (sum) quantity value, by(wtfkey firmid hs8dgt isic_plnt)

// Collapse to HS 6-digit, merge with ISIC2 concordance
gen hs6dgt = int(hs8dgt/100)
collapse (sum) quantity value, by(wtfkey isic_plnt firmid hs6dgt)
sort hs6dgt
merge hs6dgt using "braxpmkt/conc/hs2isic.dta"
*, nokeep
rename isic2 isic_prdct
tab _merge if _merge~=2
drop if _merge==2
drop _merge
sort hs6dgt
save `exp', replace

** Add the concordance written by hand 
insheet hs6dgt isic2 using "braxpmkt/conc/adhoc-hs2isic.csv", comma clear
sort hs6dgt
merge hs6dgt using `exp'
tab _merge
assert isic_prdct==. if _merge==3
replace isic_prdct = isic2 if _merge==3
drop isic2
gen flag_ad_hoc_conc = (_merge==3)
gen flag=(isic_plnt==isic_prdct) if flag_ad_hoc_conc
tab flag  
* about the same ratio of agreement between isic_plnt and isic_prdct (2/3)
drop flag _merge
count
count if isic_prdct==.

* drop 3-digit unmatched HS 6-digit codes
drop if hs6dgt<1000

* compute exports across all countries for each firm-product combination
egen expvalue = sum(value), by(hs6dgt firmid)
egen _maxval = max(expvalue), by(firmid)
gen _isicmax = isic_prdct if _maxval ==expvalue
egen isic_frm = min(_isicmax), by(firmid)  // if tie: low isic
drop _* expvalue
duplicates report wtfkey firmid hs6dgt  // note: there are duplicates by hs6dgt left if we keep isic_plnt
duplicates report wtfkey firmid hs6dgt isic_plnt

// use ISIC code from original data 
* (alternatives: ISIC code from HS6digit-ISIC matching or isic_prdct code of top selling product for the firm)
gen isic2 = isic_frm
* check unique sector assignment
preserve
  keep firmid isic2
  duplicates drop
  duplicates report firmid
restore

// done preparing data comparable to SECEX
sort firmid wtfkey hs6dgt
keep firmid wtfkey hs6dgt isic2 value

// Keep exporters from SIC-EKK manufacturing sectors only
qui do "braxpmkt/conc/unido-isic2.do"
label values isic2 isic2
sort isic2
merge isic2 using `isic2ekk'
tab _m
drop if _m==1  // EKK manufacturing firms only
drop _m isic2
order firmid sicekk
drop if sicekk==1 | sicekk==18  // drop petroleum refineries and manufacturing total, 16 sectors remains (numbered 2-17)
sort firmid sicekk wtfkey hs6dgt
* check unique sector assignment
preserve
  keep firmid sicekk
  duplicates drop
  duplicates report firmid
restore

// Export share
tab hs6dgt if wtfkey==.
egen _totexports = sum(value)
gen expshare = value/_totexports
label var expshare "Exports share in 2000 total"
capture noi table hs6dgt if wtfkey==., c(sum value sum expshare)
drop _totexports expshare
drop if wtfkey==.

// Do not collapse SECEX data over products
rename value itvfte
label var itvfte "Export Item itvfte (US$ fob)"
drop if itvfte == 0
sort firmid hs6dgt wtfkey

// Merge external data
sort wtfkey
merge wtfkey using `wtfdata'
tab wtfkey if _m==2
tab wtfkey if _m==1
summ itvfte, meanonly
local totexp = `r(N)'*`r(mean)'
summ itvfte if _m==1
local wtfexp = `r(N)'*`r(mean)'
disp in gr "Share of Brazilian exports to destination with no WTF information:" in ye %9.4f `wtfexp'/`totexp'
drop _m

// itpctl: Percentile of item-destination exports
summ itvfte, detail
sort itvfte firmid hs6dgt wtfkey
gen _itpctl = itvfte in 1
replace _itpctl = itvfte + _itpctl[_n-1] in 2/`r(N)'
disp in gr "Total exports: " in ye `r(N)'*`r(mean)' in gr " (comparison: " in ye _itpctl[`r(N)'] in gr ")"
gen itpctl = int( _itpctl*100 / (`r(sum)') )
label var itpctl "Item-destination percentile"
drop _itpctl
order firmid hs6dgt wtfkey sicekk itvfte itpctl

// itpctlitem: Percentile of item exports
tempfile itpctlitem
preserve
  collapse (sum) itvfte, by(firmid hs6dgt) fast
  summ itvfte, detail
  sort itvfte firmid hs6dgt
  gen _itpctl = itvfte in 1
  replace _itpctl = itvfte + _itpctl[_n-1] in 2/`r(N)'
  disp in gr "Total exports: " in ye `r(N)'*`r(mean)' in gr " (comparison: " in ye _itpctl[`r(N)'] in gr ")"
  gen itpctlitem = int( _itpctl*100 / (`r(N)'*`r(mean)') )
  label var itpctlitem "Item percentile"
  drop _itpctl
  sort firmid hs6dgt
  save `itpctlitem'
restore
sort firmid hs6dgt
merge firm hs6dgt using `itpctlitem'
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
sort firmid hs6dgt wtfkey
order firmid hs6dgt wtfkey sicekk itvfte itpctl itpctlitem

// svfte: Total item sales from Brazilian manufacturers to a given destination
egen svfte = sum(itvfte), by(wtfkey)
label var svfte "Total SCX sales to dest."
order firmid hs6dgt wtfkey sicekk itvfte svfte itpctl itpctlitem

// svftesic: Total item sales from Brazilian manufacturers to a given destination and SIC-EKK industry
egen svftesic = sum(itvfte), by(wtfkey sicekk)
label var svftesic "Tot. SCX sales to dst. ind."
order firmid hs6dgt wtfkey sicekk itvfte svfte svftesic itpctl itpctlitem

// itmin: Minimum item sales from Brazilian manufacturers to a given destination
egen itmin = min(itvfte), by(wtfkey)
label var itmin "Min. SCX item sales to dest."
order firmid hs6dgt wtfkey sicekk itvfte svfte svftesic itmin itpctl itpctlitem

// itsunb: Number of Brazilian items exported to a given destination
egen itsunb = count(itvfte), by(wtfkey)
label var itsunb "No. of SCX items to destin."
order firmid hs6dgt wtfkey sicekk itvfte itsunb svfte svftesic itmin itpctl itpctlitem

// itsunbsic: Number of Brazilian items exported to a given destination and SIC-EKK industry
egen itsunbsic = count(itvfte), by(wtfkey sicekk)
label var itsunbsic "No. of SCX items to dest. ind."
order firmid hs6dgt wtfkey sicekk itvfte itsunb itsunbsic svfte svftesic itmin itpctl itpctlitem

// itvftebav: Mean item sales from Brazilian manufacturers to a given destination
gen itvftebav = svfte/itsunb
label var itvftebav "Mean SCX item sales to dest."
order firmid hs6dgt wtfkey sicekk itvfte itsunb itsunbsic svfte svftesic itmin itvftebav itpctl itpctlitem

// itvftebavsic: Mean item sales from Brazilian manufacturers to a given destination and SIC-EKK industry
gen itvftebavsic = svftesic/itsunbsic
label var itvftebavsic "Mean SCX item sales to dst. ind."
order firmid hs6dgt wtfkey sicekk itvfte itsunb itsunbsic svfte svftesic itmin itvftebav itvftebavsic itpctl itpctlitem

// itvfteb`pc': Sales of the item at the `pc'th percentile, by destination
// itvfterel`pc': Sales of the item at the `pc'th percentile, by destination, normalized by mean sales
foreach pc in 01 05 10 25 50 75 80 85 90 95 99 {
  egen itvfteb`pc' = pctile(itvfte), p(`pc') by(wtfkey)
  local pcstr = "`pc'th"
  if `pc'==01  local pcstr = " 1st"
  if `pc'==05  local pcstr = " 5th" 
  label var itvfteb`pc' "`pcstr' pctl SCX item sales by dst."
  qui gen itvfterel`pc' = itvfteb`pc'/itvftebav
  label var itvfterel`pc' "`pcstr' ptl SCX itm sls/mean by dst"
  }
order firmid hs6dgt wtfkey sicekk itvfte itsunb itsunbsic svfte svftesic itmin itvftebav itvfteb?? itvfterel?? itpctl itpctlitem

// svfteagg: WTF manufacturing exports from Brazil to a given destination
rename wtf_chilexp svfteagg
order firmid hs6dgt wtfkey sicekk itvfte itsunb itsunbsic svfte svftesic itmin svfteagg itvftebav itvftebavsic itvfteb?? itvfterel?? itpctl itpctlitem

// tabsorp: Manufacturing absorption (production+imports-exports), by destination 2000/01 [OECD Stan & Unido for production, exports/imports for trade]
replace wtf_output = . if wtf_output==0
gen tabsorp = wtf_output + wtf_imports - wtf_exports
drop wtf_output wtf_exports
label var tabsorp "Manuf. absorption at dest."
order firmid hs6dgt wtfkey sicekk itvfte itsunb itsunbsic svfte svftesic itmin svfteagg tabsorp itvftebav itvftebavsic itvfteb?? itvfterel?? itpctl itpctlitem

// ittfshare: Brazilian item share in manufacturing absorption by destination, svfte/tabsorp
gen ittfshare = svfte/tabsorp
label var ittfshare "SCX sh. in manf. absrpt. at dst."
order firmid hs6dgt wtfkey sicekk itvfte itsunb itsunbsic svfte svftesic itmin svfteagg tabsorp ittfshare itvftebav itvftebavsic itvfteb?? itvfterel?? itpctl itpctlitem

// imshare: Brazilian manufacturers share in manufacturing imports by destination, svfte/wtf_imports
gen imshare = svfte/wtf_imports
label var imshare "SCX sh. in manf. imports at dst."
drop wtf_imports
order firmid hs6dgt wtfkey sicekk itvfte itsunb itsunbsic svfte svftesic itmin svfteagg tabsorp ittfshare imshare itvftebav itvftebavsic itvfteb?? itvfterel?? itpctl itpctlitem

// pop_00: Population at destination in 2000
sort wtfkey
joinby wtfkey using "braxpmkt/ext/country-data-2000.dta", _merge(_merge) unmatched(both)
replace indoecd90=0 if indoecd90==.
replace indoecd00=0 if indoecd00==.
tab wtfkey if _m==2
tab wtfkey if _m==1
summ itvfte, meanonly
local totexp = `r(N)'*`r(mean)'
summ itvfte if _m==1
local wtfexp = `r(N)'*`r(mean)'
disp in gr "Share of Brazilian exports to destination with no WDI information:" in ye %9.4f `wtfexp'/`totexp'
drop _m
foreach var in population gdp_usd gdp_cap_usd consum_expend_usd hh_consum_expend_usd {
  local lbl : variable label `var'
  local lbl  = subinstr("`lbl'","[curr. USD]","at dest.",.)
  local lbl  = subinstr("`lbl'","(total)","at dest.",.)
  label var `var' "`lbl'"
  } 

gen double firmnum = int(real(subinstr(firmid,"K","0",.)))
label var firmnum "Numeric firm ID"
format firmnum %10.0f
compress firmnum
qui count if ( firmnum==. | firmnum==0 ) & firmid~=""
if `r(N)'>0  STOP  // improper numeric firm ID
preserve
  keep firmid firmnum
  bysort firmid firmnum: keep if _n==1
  duplicates tag firmnum, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP  // surplus firm numbers
restore
order firmid firmnum

drop if firmid==""
qui count if ( firmnum==. | firmnum==0 )
if `r(N)'>0  STOP  // improper numeric firm ID
compress
sort firmid hs6dgt wtfkey
save "braxpmkt/chile/replication-data-2000-expitems-chile.dta", replace

log close
cd "$home"
