*! version 1.0.1  03jul2011  by Marc Muendler     muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/replication-data-2000-ncm8.log", replace


// Mapping from ISIC rev. 2 to SIC (as in EKK 2004)

tempfile isic2ekk
insheet using "braxpmkt/ekk/ekk-sic-isic2-conc.csv", comma clear names
qui count if index(isic2,",") > 0
local chk = `r(N)'
while `chk'>0 {
  sort sic
  qui gen byte _exp_cnt = ( index(isic2,",") > 0 ) + 1
  qui expand _exp_cnt if index(isic2,",") > 0
  sort sic isic2
  by sic isic2: gen byte _cnt = _n
  qui replace isic2 = trim(substr(isic2,1,index(isic2,",")-1)) if _exp_cnt>1 & _cnt==1
  qui replace isic2 = trim(substr(isic2,index(isic2,",")+1,.)) if _exp_cnt>1 & _cnt>1
  qui drop _*
  qui count if index(isic2,",") > 0
  local chk = `r(N)'
  }
gen isic2num = int(real(isic2))
compress
drop isic2
rename isic2num isic2
order isic2
sort isic2
qui do "braxpmkt/conc/unido-isic2.do"
label values isic2 isic2
replace sic = "99" if sic=="0"
gen _sicind = "[" + sic + "] " + industry
encode _sicind, generate(sicekk) label(sicekk)
drop _sicind
keep isic2 sicekk
tab sicekk
label var isic2 "ISIC 2.0 (3-digit)"
label var sicekk "EKK (SIC) industries"
compress
sort isic2
save `isic2ekk'


// Read external data, aggregate for manufacturing
tempfile wtfdata
use "braxpmkt/ext/sector-country-data-2000.dta", clear
keep if isic2>300 & isic2<=399  // manufacturing only
collapse (sum) wtf_output wtf_exports wtf_imports wtf_brazexp, by(wtfkey)
label var wtf_output  "Manuf. output"
label var wtf_exports "Manuf. exports from source"
label var wtf_imports "Manuf. imports to dest."
label var wtf_brazexp "Brazil's manuf. exports to dest."
sort wtfkey
save `wtfdata'


// Read SECEX data, keep manufacturing firms only
// Drop exports to no distinct destination (including on-board aircraft consumption of combustibles and other goods)

use "braxpmkt/secex/firms-2000-ncm8dgt.dta", clear
rename prodctid ncm8dgt

// Obtain CNAE information by firm from RAIS
merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
drop _m n_pis rem_dezembro n_cnpj_estbl n_municipio ind*
rename mod_clas_cnae_95 cnae
drop if cnae==.
order firmid wtfkey cnae ncm8dgt value quantity mass

// Keep exporters from SIC-EKK manufacturing sectors only
gen cnaestr = string(int(cnae/10))
replace cnaestr = "0" + cnaestr if length(cnaestr)<4
drop cnae
rename cnaestr cnae
label var cnae "CNAE sector (annual mode)"
sort cnae
merge cnae using "brazcomp/filters/cnae-isic2"
tab _m
list cnae value if _m==1
list cnae isic2 if _m==2
drop if _m~=3
drop _m cnae_desc cnae
order firmid isic2dgt3
rename isic2dgt3 isic2
qui do "braxpmkt/conc/unido-isic2.do"
label values isic2 isic2
sort isic2
merge isic2 using `isic2ekk'
tab _m
drop if _m==1  // EKK manufacturing firms only
drop _m isic2
order firmid sicekk
drop if sicekk==1 | sicekk==18  // drop petroleum refineries and manufacturing total, 16 sectors remains (numbered 2-17)
sort firmid sicekk wtfkey ncm8dgt

// Export share
tab ncm8dgt if wtfkey==.
egen _totexports = sum(value)
gen expshare = value/_totexports
label var expshare "Exports share in 2000 total"
table ncm8dgt if wtfkey==., c(sum value sum expshare)
drop _totexports expshare
drop if wtfkey==.

// Collapse SECEX data over products to firm-destination level (destination at wtfkey level)
collapse (sum) vfte=value, by(firmid wtfkey sicekk) fast
label var vfte "Exports vfte (current US$ fob)"
drop if vfte == 0
sort firmid wtfkey

// Merge external data
sort wtfkey
merge wtfkey using `wtfdata'
tab wtfkey if _m==2
tab wtfkey if _m==1
summ vfte, meanonly
local totexp = `r(N)'*`r(mean)'
summ vfte if _m==1
local wtfexp = `r(N)'*`r(mean)'
disp in gr "Share of Brazilian exports to destination with no WTF information:" in ye %9.4f `wtfexp'/`totexp'
drop _m

// Consistency check
preserve
   local totwtfexp = 60985226 * 1000
   local totunoexp = 1.44504684e+13 + 366391890
   sort wtfkey
   by wtfkey: keep if _n==1
   collapse (sum) wtf_brazexp wtf_output, fast
   local newwtfexp = wtf_brazexp[1]
   disp in gr "Check total WTF exports from Brazil:" in ye %9.0f `totwtfexp' in gr ", compared to manuf. replication-data-2000.dta: " in ye %9.0f `newwtfexp'
   if float(`totwtfexp')<=float(`newwtfexp')  STOP
   local newunoexp = wtf_output[1]
   disp in gr "Check total Unido USD output:" in ye %12.0f `totunoexp' in gr ", compared to manuf. replication-data-2000.dta: " in ye %12.0f `newunoexp'
   if float(`totunoexp')<=float(`newunoexp')  STOP
restore

// pctl: Percentile of firm-destination exports
summ vfte, detail
sort vfte firmid wtfkey
gen _pctl = vfte in 1
replace _pctl = vfte + _pctl[_n-1] in 2/`r(N)'
disp in gr "Total exports: " in ye `r(N)'*`r(mean)' in gr " (comparison: " in ye _pctl[`r(N)'] in gr ")"
gen pctl = int( _pctl*100 / (`r(N)'*`r(mean)') )
label var pctl "Firm-destination percentile"
drop _pctl
order firmid wtfkey sicekk vfte pctl

// pctlfirm: Percentile of firm exports
tempfile pctlfirm
preserve
  collapse (sum) vfte, by(firm) fast
  summ vfte, detail
  sort vfte firmid
  gen _pctl = vfte in 1
  replace _pctl = vfte + _pctl[_n-1] in 2/`r(N)'
  disp in gr "Total exports: " in ye `r(N)'*`r(mean)' in gr " (comparison: " in ye _pctl[`r(N)'] in gr ")"
  gen pctlfirm = int( _pctl*100 / (`r(N)'*`r(mean)') )
  label var pctlfirm "Firm percentile"
  drop _pctl
  sort firm
  save `pctlfirm'
restore
sort firm
merge firm using `pctlfirm'
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
sort firmid wtfkey
order firmid wtfkey sicekk vfte pctl pctlfirm

// svfte: Total exports of Brazilian manufacturers to a given destination
egen svfte = sum(vfte), by(wtfkey)
label var svfte "Total SCX sales to destination"
order firmid wtfkey sicekk vfte svfte pctl pctlfirm

// svftesic: Total exports of Brazilian manufacturers to a given destination and SIC-EKK industry
egen svftesic = sum(vfte), by(wtfkey sicekk)
label var svftesic "Total SCX sales to dest. ind."
order firmid wtfkey sicekk vfte svfte svftesic pctl pctlfirm

// min: Minimum exports of Brazilian manufacturers to a given destination
egen min = min(vfte), by(wtfkey)
label var min "Min. SCX sales to destination"
order firmid wtfkey sicekk vfte svfte svftesic min pctl pctlfirm

// sunb: Number of Brazilian manufacturers exporting to a given destination
egen sunb = count(firmid), by(wtfkey)
label var sunb "No. of SCX exporters to destin."
order firmid wtfkey sicekk vfte sunb svfte svftesic min pctl pctlfirm

// sunbsic: Number of Brazilian manufacturers exporting to a given destination and SIC-EKK industry
egen sunbsic = count(firmid), by(wtfkey sicekk)
label var sunbsic "No. of SCX exp'rs to dest. ind."
order firmid wtfkey sicekk vfte sunb sunbsic svfte svftesic min pctl pctlfirm

// vftebav: Mean exports of Brazilian manufacturers to a given destination
gen vftebav = svfte/sunb
label var vftebav "Mean SCX sales to destination"
order firmid wtfkey sicekk vfte sunb sunbsic svfte svftesic min vftebav pctl pctlfirm

// vfteb`pc': Sales of the firm at the `pc'th percentile, by destination
// vfterel`pc': Sales of the firm at the `pc'th percentile, by destination, normalized by mean sales
foreach pc in 01 05 10 25 50 75 80 85 90 95 99 {
  egen vfteb`pc' = pctile(vfte), p(`pc') by(wtfkey)
  local pcstr = "`pc'th"
  if `pc'==01  local pcstr = " 1st"
  if `pc'==05  local pcstr = " 5th" 
  label var vfteb`pc' "`pcstr' prctl. SCX sales by destin."
  gen vfterel`pc' = vfteb`pc'/vftebav
  label var vfterel`pc' "`pcstr' pctl SCX sales/mean by dst."
  }
order firmid wtfkey sicekk vfte sunb sunbsic svfte svftesic min vftebav vfteb?? vfterel?? pctl pctlfirm

// svfteagg: WTF manufacturing exports from Brazil to a given destination
rename wtf_brazexp svfteagg
order firmid wtfkey sicekk vfte sunb sunbsic svfte svftesic min svfteagg vftebav vfteb?? vfterel?? pctl pctlfirm

// tabsorp: Manufacturing absorption (production+imports-exports), by destination 2000/01 [OECD Stan & Unido for production, exports/imports for trade]
replace wtf_output = . if wtf_output==0
gen tabsorp = wtf_output + wtf_imports - wtf_exports
drop wtf_output wtf_exports
label var tabsorp "Manuf. absorption at dest."
order firmid wtfkey sicekk vfte sunb sunbsic svfte svftesic min svfteagg tabsorp vftebav vfteb?? vfterel?? pctl pctlfirm

// tfshare: Brazilian manufacturers share in manufacturing absorption by destination, svfte/tabsorp
gen tfshare = svfte/tabsorp
label var tfshare "SCX sh. in manf. absrpt. at dst."
order firmid wtfkey sicekk vfte sunb sunbsic svfte svftesic min svfteagg tabsorp tfshare vftebav vfteb?? vfterel?? pctl pctlfirm

// imshare: Brazilian manufacturers share in manufacturing imports by destination, svfte/wtf_imports
gen imshare = svfte/wtf_imports
label var imshare "SCX sh. in manf. imports at dst."
drop wtf_imports
order firmid wtfkey sicekk vfte sunb sunbsic svfte svftesic min svfteagg tabsorp tfshare imshare vftebav vfteb?? vfterel?? pctl pctlfirm

// pop_00: Population at destination in 2000
sort wtfkey
joinby wtfkey using "braxpmkt/ext/country-data-2000.dta", _merge(_merge) unmatched(both)
replace indoecd90=0 if indoecd90==.
replace indoecd00=0 if indoecd00==.
tab wtfkey if _m==2
tab wtfkey if _m==1
summ vfte, meanonly
local totexp = `r(N)'*`r(mean)'
summ vfte if _m==1
local wtfexp = `r(N)'*`r(mean)'
disp in gr "Share of Brazilian exports to destination with no WDI information:" in ye %9.4f `wtfexp'/`totexp'
drop _m
foreach var in population gdp_usd gdp_cap_usd consum_expend_usd hh_consum_expend_usd {
  local lbl : variable label `var'
  local lbl  = subinstr("`lbl'","[curr. USD]","at dest.",.)
  local lbl  = subinstr("`lbl'","(total)","at dest.",.)
  label var `var' "`lbl'"
  } 

drop if firmid==.
compress
sort firmid wtfkey
save "braxpmkt/secex/replication-data-2000-ncm8.dta", replace

log close
cd "$home"
