*! version 1.0.1  13apr2007  by Marc Muendler  muendler@ucsd.edu
* (see ekk/marc1.do and ekk/marc2.do)

version 8.2
set more on
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture log close
log using "braxpmkt/logs/extension-stats.log", replace


// DATA AND GRAPH FOR PERCENTILES OF FIRMS

use wtfkey vfterel?? sunb using "braxpmkt/secex/replication-data-2000.dta", clear
sort wtfkey
by wtfkey: keep if _n==1
rename vfterel01 vfterel1
rename vfterel05 vfterel5
reshape long vfterel, i(wtfkey sunb) j(pval)
drop if vfterel==.
replace pval = pval/100
gen onempval = 1 - pval
label var vfterel "Prctl. SCX sales/mean by destin."
label var pval "Percentile"
label var onempval "1 - percentile"
sort wtfkey pval

* log variables
gen lnvfterel=ln(vfterel)
label var lnvfterel "Log pctl. SCX sales/mean by dest."
gen lnpval=ln(1-pval)
label var lnvfterel "Log (1 - percentile)"

* Argentina
graph7 vfterel onempval if wtfkey==330320, xlog ylog xlabel(.00001 .0001 .001 .01 .10 .50 .99) ylabel(.0001 .001 .01 .1 1 10 100 1000 10000) l1title("Percentile / mean") b2title("1 - p") b1title("Distribution of Brazilian Firms' Exports to Argentina")
more
* USA
graph7 vfterel onempval if wtfkey==218400, xlog ylog xlabel(.00001 .0001 .001 .01 .10 .50 .99) ylabel(.0001 .001 .01 .1 1 10 100 1000 10000) l1title("Percentile / mean") b2title("1 - p") b1title("Distribution of Brazilian Firms' Exports to the United States")
more


// EXPORT SALES, FIRM ENTRY AND MARKET SIZE
// ALPHA AND GAMMA COEFFICIENTS IN THE MODEL

use "braxpmkt/secex/replication-data-2000.dta", clear

* data construction
gen lnabsorppercap = ln(tabsorp/population*1000000000)
gen lnpopulation =ln(population)
gen lnfirshar = ln(sunb/tfshare*100)
gen lnabsorp = ln(tabsorp)
gen lnsunb = ln(sunb)
gen lntfshare = ln(tfshare/100)
gen populationmil = population/1000000
gen entryn = sunb/tfshare*100
gen absorppercap = tabsorp/populationmil
gen entrynpop = sunb/tfshare/(absorppercap)^0.69
gen entrynabsorppercap = sunb/tfshare/(populationmil)^0.56
gen entrynthous =entryn/1000
sort wtfkey

* REGRESSIONS

reg lnfirshar lnabsorppercap lnpopulation 
test lnabsorppercap=lnpopulation
more

reg lnfirshar lnabsorp 
reg lnsunb lntfshare lnabsorppercap lnpopulation 
test lnabsorppercap=lnpopulation
more

reg lnsunb lntfshare lnabsorp 
reg lnfirshar lnabsorppercap lnpopulation, robust
reg lnfirshar lnabsorp, robust
reg lnsunb lntfshare lnabsorppercap lnpopulation, robust
 
constraint define 1 _cons=-3.4
reg lnsunb lntfshare lnabsorp, robust
more

* GRAPHS

* Entry and absorption
graph7 entrynthous tabsorp, xlog ylog xlabel(.01 .1 1 10 100 1000 10000) ylabel(1 10 100 1000 10000) l1title("Thousands of Brazilian entrants / Brazilian share ") b2title("Market size (USD billions)") 
more

* Firms, entry and population size
graph7 sunb populationmil if sunb>=1, xlog ylog xlabel(1 10 100 1000) ylabel(10 100 1000 10000) l1title("Exporters (thousands)") b2title("Population (millions)") b1title("Firms and Population Size")
more
graph7 entryn populationmil, xlog ylog xlabel(1 10 100 1000) ylabel(10 100 1000 10000) l1title("Export entrants  (thousands)") b2title("Population (millions)") b1title("Entry and Population Size")
more
graph7 entrynpop populationmil, xlog ylog xlabel(1 10 100 1000) ylabel(10 100 1000 10000) l1title("Export entrants, absorppercap adjusted (thousands)") b2title("Population (millions)") b1title("Wage-adjusted Entry and Population Size")
more

* Firms, entry and manufacturing incomes
graph7 sunb absorppercap if sunb>=1, xlog ylog xlabel(0.1 1 10) ylabel(1 10 100 1000) l1title("Exporters (thousands)") b2title("Per-capita income (USD thousands)") b1title("Entry and Absorption per Capita")
more
graph7 entryn absorppercap, xlog ylog xlabel(0.1 1 10) ylabel(1 10 100 1000) l1title("Export entrants (thousands)") b2title("Per-capita income (USD thousands)") b1title("Entry and Absorption per Capita")
more
graph7 entrynabsorppercap absorppercap, xlog ylog xlabel(0.1 1 10) ylabel(10 100 1000) l1title("Export entrants, absorppercap adjusted (thousands)") b2title("Per-capita income (USD thousands)") b1title("Wage-adjusted Entry and Absorption per Capita")
more

log close
set more off
