*! version 1.0  11jan2011  by Marc Muendler     muendler@ucsd.edu

* INPUT

global inpath  "braxpmkt/ext"          // XXX set input directory
global outpath "braxpmkt/eps/ext-ekk"  // XXX set output directory
local totnum = 100000  // XXX count of universe of country's manufacturing firms

capture mkdir "$outpath"

* Expected variables in outside data (all numeric)
* firmid: Firm Tax Number
* year: Calendar year (4-digit)
* sectorid: Sector ID
* destid: Destination ID
* hs6dgt: Harmonized System 6-digit code
* value: Value (current US$ fob)

* Expected sectors: any classification possible; 
*   drop commands below are meant to make coverage similar to SIC as in EKK 04

* SIC industries in Eaton/Kortum/Kramarz (AEA-PP 2004)
* ----------------------------------------------------
* [20, 21] Food and tobacco products
* [22, 23] Textiles and apparel
* [24, 25] Lumber and furniture
* [26] Paper and allied products
* [27] Printing and publishing
* [28] Chemicals, etc.
* [30] Rubber and plastics
* [31] Leather and leather products
* [32] Stone, clay, glass, and concrete
* [33] Primary metal industries
* [34] Fabricated metal products
* [35] Machinery and computer equipment
* [36] Electronic and electrical equipmen
* [37] Transportation equipment
* [38] Instruments, etc.
* [39] Miscellaneous manufacturing
* Note: no agriculture, no mining, no petroleum processing

capture log close
log using "$outpath/outside-data.log", replace


* FIRM COUNT BY NUMBER OF MARKETS (from %03/replication-stats.do)

use "$inpath/outside-testdata.dta", clear
keep if year==2000
drop year
collapse (sum) vfte=value, by(firmid destid sectorid) fast
label var vfte "Exports vfte (current US$ fob)"
drop if vfte == 0
sort firmid destid
drop if sectorid==. | sectorid==99  // XXX drop SIC sectors not in Eaton-Kortum-Kramarz (2004) [see above]
collapse (count) ncntry=destid, by(firmid)
collapse (count) nfirms=firmid, by(ncntry)
replace ncntry = ncntry+1
expand 2 in 1  // add observation
replace ncntry=1 in 1
replace nfirms = `totnum' if ncntry==1
label var ncntry "Number of markets per firm"
label var nfirms "Number of country's firms"
sort ncntry
graph twoway scatter nfirms ncntry, ysca(log) ylab(1 10 100 1000 "1,000" 10000 "10,000" 100000 "100,000" 1000000 "1,000,000", angle(horizontal))  xsca(log) xlab(1 2 4 8 16 32 64 128) graphregion(color(white)) scheme(sj)
graph export "$outpath/ekk-fig1.eps", replace

gen lnncntry = ln(ncntry)
gen lnnfirms = ln(nfirms)
label var lnncntry "Log No. of Markets per firm"
label var lnnfirms "Log No. of country's firms"
reg lnnfirms lnncntry
disp in gr "Elasticity of number of firms with respect to number of markets: " in yellow _b[lnncntry] in green " (standard error " in yellow _se[lnncntry] in green ")"
reg lnnfirms lnncntry if ncntry>1  // only exporters, omitting domestic market
disp in gr "Elasticity of number of exporters with respect to number of export destinations: " in yellow _b[lnncntry] in green " (standard error " in yellow _se[lnncntry] in green ")"


* TWOWAY SCATTER PLOTS (from %03/prodsales-stats.do)

use "$inpath/outside-testdata.dta", clear
drop if value==0
keep if year==2000
drop year
sort hs6dgt
merge hs6dgt using "$inpath/hs2isic.dta", nokeep  /* XXX perhaps change directory */
tab _m
drop if _m~=3
drop _m
keep if sectorid>=0 & sectorid<=100 & isic2>=300 & isic2<=399   // XXX manufacturing firms and products
keep if destid==218400  // XXX exports to USA
order firmid sectorid destid hs6dgt isic2 value
sort firmid destid hs6dgt

collapse (sum) value, by(firmid sectorid hs6dgt) fast  // collapse over destinations
gsort firmid -value
by firmid: gen gndidx = _n
egen goods = max(gndidx), by(firmid)
label var gndidx "Product rank (HS 6-digit)"
label var goods  "Exporter scope (HS 6-digit)"

collapse (sum) sumsales=value (count) goods=value, by(firmid sectorid) fast  // collapse over goods
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per product (US$ mill fob)"

gen lngoods=ln(goods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(sumsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(gsales)
label var lngsales "Log exports/product (US$ mill fob)"
sort goods

egen ranksales=rank(sumsales), unique
label var ranksales "Rank of total exports"
egen rankgoods=rank(goods), unique
label var rankgoods "Rank of number of products"
egen rankgsales=rank(gsales), unique
label var rankgsales "Rank of mean exports per product"

sort firmid
count if firmid~=firmid[_n-1]
local firms = `r(N)'
gen pcsales=ranksales/`firms'
label var pcsales  "Firm percentile: Tot. exports"
gen pcgoods=rankgoods/`firms'
label var pcgoods  "Firm percentile: No. of products"
gen pcgsales=rankgsales/`firms'
label var pcgsales "Firm percentile: Exports/product"

* twoway scatter sumsales pcsales
preserve
  order pcsales sumsales firmid
  keep firmid sumsales pcsales
  sort pcsales sumsales
  * graph twoway scatter sumsales pcsales, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Total Exports (US$ million fob)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  gen byte pctl = int(pcsales*100)
  keep sumsales pctl
  sort pctl sumsales
  by pctl: keep if _n==1
  replace pctl=pctl/100
  graph twoway scatter sumsales pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Total Exports (US$ million fob)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  graph export "$outpath/sumsales-pcsales-usa.eps", replace
restore

* twoway scatter goods pcgoods
preserve
  order pcgoods goods firmid
  keep firmid goods pcgoods
  sort pcgoods goods
  * graph twoway scatter goods pcgoods, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Number of Products Shipped") yscale(log) ylabel(1 10 100 1000) ytick(1 10 100 1000) yline(1 10 100 1000, lcolor(gs13)) ytitle("Number of Products (HS 6-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  gen byte pctl = int(pcgoods*100)
  keep goods pctl
  sort pctl goods
  by pctl: keep if _n==1
  replace pctl=pctl/100
  graph twoway scatter goods pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Number of Products Shipped") yscale(log) ylabel(1 10 100 1000) ytick(1 10 100 1000) yline(1 10 100 1000, lcolor(gs13)) ytitle("Number of Products (HS 6-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  graph export "$outpath/goods-pcgoods-usa.eps", replace
restore

log close
