*! version 1.0.1  06dec2007  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.2  21dec2008  by Marc Muendler  muendler@ucsd.edu
*! version 1.1.1  31jul2011  by Marc Muendler  muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 100m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/srvc-firms"
capture mkdir "braxpmkt/eps/comrc-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/eps/allsec/bycntry"
capture mkdir "braxpmkt/eps/manf-goods/bycntry"
capture mkdir "braxpmkt/eps/manf-firms/bycntry"
capture mkdir "braxpmkt/eps/srvc-firms/bycntry"
capture mkdir "braxpmkt/eps/comrc-firms/bycntry"
capture mkdir "braxpmkt/eps/manf-ekk/bycntry"

capture mkdir "braxpmkt/tex/allsec"
capture mkdir "braxpmkt/tex/manf-goods"
capture mkdir "braxpmkt/tex/manf-firms"
capture mkdir "braxpmkt/tex/srvc-firms"
capture mkdir "braxpmkt/tex/comrc-firms"
capture mkdir "braxpmkt/tex/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-avgscope-wgsales-pcsales-bycountry.log", replace


local alphsigls1 = 2.69  //  expprodint_restud, column "mx-wtf-rcnae-phipctl"
local max = 400   // maximum number of products in any market

// MATRIX OF H(G)^(-(sigma-1)) FOR \alpha(\sigma-1)=-2.69
mat htable = J(`max',2,.)
mat colnames htable = gterm caphsig
mat roweq htable = goods
forvalues g = 1/`max' {
  matname htable `g', rows(`g') explicit
  mat htable[`g',1] = `g'^(-2.69)
  }
forvalues g = 1/`max' {
  local rowbefr = `g'-1
  if `g'==1  mat htable[`g',2] = htable[`g',1]
  else       mat htable[`g',2] = htable[`rowbefr',2] + htable[`g',1]
  }


// EXPORTER SCOPE AND TOTAL EXPORTS DISTRIBUTION BY COUNTRY

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {

local cntrylst ""

* Country list
use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms
drop if wtfkey==0
keep wtfkey
sort wtfkey
by wtfkey: keep if _n==1
sort wtfkey
qui count
local totcntry = `r(N)'
forvalues i = 1/`totcntry' {
  local wtfadd = wtfkey[`i']
  local cntrylst "`cntrylst' `wtfadd'"
  }
disp "`cntrylst'"


* Data preparation and scale-scope graphs by country

* foreach cntry in 168960 167060 443680 552460 586420 365900 368960 457020 336040 532500 218400 { // Afr.Other NS, Somalia, Iraq, Finland, Romania, Panama, US NES, Singapore, Peru, France/Monac, USA
foreach cntry in `cntrylst' {
tempfile c`cntry'

use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0
keep if wtfkey==`cntry'

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

collapse (sum) value, by(firmid cnae hs6dgt) fast  // collapse over destinations
sort firmid hs6dgt
gsort firmid -value
by firmid: gen gndidx = _n
egen goods = max(gndidx), by(firmid)
label var gndidx "Product rank (HS 6-digit)"
label var goods  "Exporter scope (HS 6-digit)"
collapse (sum) sumsales=value (count) goods=value, by(firmid cnae) fast  // collapse over goods
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per product (US$ mill fob)"

gen lngoods=ln(goods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(sumsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(gsales)
label var lngsales "Log exports/product (US$ mill fob)"

gen lncaphsig = .
label var lncaphsig "Log H(goods)^(-(sigma-1))"
forvalues g = 1/`max' {
  qui replace lncaphsig = log(htable[`g',2]) if int(goods+.5)==`g'   // rounding to closest integer number of goods
  qui replace lncaphsig = log(htable[`max',2]) if int(goods+.5)>`max'   // no machine-size difference above `max'
  }
sort goods

egen ranksales=rank(sumsales), unique
label var ranksales "Rank of total exports"
egen rankgoods=rank(goods), unique
label var rankgoods "Rank of number of products"
egen rankgsales=rank(gsales), unique
label var rankgsales "Rank of mean exports per product"

sort firmid
count if firmid~=firmid[_n-1]
local firms = `r(N)'
gen pcsales=ranksales/`firms'
label var pcsales  "Firm percentile: Tot. exports"
gen pcgoods=rankgoods/`firms'
label var pcgoods  "Firm percentile: No. of products"
gen pcgsales=rankgsales/`firms'
label var pcgsales "Firm percentile: Exports/product"
* egen mdgsales=median(gsales), by(goods)
* label var mdgsales "Median of mean exports per product"
sort firmid

gen _pctlval = int(pcsales*100+1)
replace _pctlval = 100 if _pctlval==101
gen byte _dummy = 1
preserve
  tabl2tex firmid, type(count) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_`cntry') fancy replace over nolog
  mat rename histT_`cntry'_tbl _hist`cntry'_tbl
  local rows = rowsof(_hist`cntry'_tbl)
  local tot = _hist`cntry'_tbl[`rows',2]
  mat _hist`cntry'_tbl = _hist`cntry'_tbl[1...,1] , _hist`cntry'_tbl[1...,2]/`tot'
restore, preserve
  tabl2tex sumsales, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_`cntry') fancy replace over nolog
  local rows = rowsof(histT_`cntry'_tbl)
  mat _hist`cntry'_tbl = _hist`cntry'_tbl[1..`rows',1...] , histT_`cntry'_tbl
restore, preserve
  tabl2tex gsales, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_`cntry') fancy replace over nolog
  local rows = rowsof(histT_`cntry'_tbl)
  mat _hist`cntry'_tbl = _hist`cntry'_tbl[1..`rows',1...] , histT_`cntry'_tbl
restore, preserve
  tabl2tex goods, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_`cntry') fancy replace over nolog
  local rows = rowsof(histT_`cntry'_tbl)
  mat _hist`cntry'_tbl = _hist`cntry'_tbl[1..`rows',1...] , histT_`cntry'_tbl
restore, preserve
  tabl2tex lnsumsales, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_`cntry') fancy replace over nolog
  local rows = rowsof(histT_`cntry'_tbl)
  mat _hist`cntry'_tbl = _hist`cntry'_tbl[1..`rows',1...] , histT_`cntry'_tbl
restore, preserve
  tabl2tex lncaphsig, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_`cntry') fancy replace over nolog
  local rows = rowsof(histT_`cntry'_tbl)
  mat histT_`cntry'_tbl = _hist`cntry'_tbl[1..`rows',1...] , histT_`cntry'_tbl
  mat drop _hist`cntry'_tbl
restore
  mat colnames histT_`cntry'_tbl = count freq mean_sumsales mean_gsales mean_goods mean_lnsumsales mean_lncaphsig
  est2tex histT_`cntry', ready fancy p(braxpmkt/tex/`sec') replace dropall
  mat cumT_`cntry'_tbl = J(`rows',7,.)
  local rownames : rowfullnames histT_`cntry'_tbl
  mat colnames cumT_`cntry'_tbl = count freq mean_sumsales mean_gsales mean_goods mean_lnsumsales mean_lncaphsig
  mat rownames cumT_`cntry'_tbl = or_higher
  mat roweq cumT_`cntry'_tbl = `rownames'
  forvalues i = 1/`rows' {
    qui summ count if _n>=`i', meanonly
    mat cumT_`cntry'_tbl[`i',1] = `r(sum)'
    qui summ freq if _n>=`i', meanonly
    mat cumT_`cntry'_tbl[`i',2] = `r(sum)'
    qui summ mean_sumsales if _n>=`i' [fw=count], meanonly
    mat cumT_`cntry'_tbl[`i',3] = `r(mean)'
    qui summ mean_gsales if _n>=`i' [fw=count], meanonly
    mat cumT_`cntry'_tbl[`i',4] = `r(mean)'
    qui summ mean_goods if _n>=`i' [fw=count], meanonly
    mat cumT_`cntry'_tbl[`i',5] = `r(mean)'
    qui summ mean_lnsumsales if _n>=`i' [fw=count], meanonly
    mat cumT_`cntry'_tbl[`i',6] = `r(mean)'
    qui summ mean_lncaphsig if _n>=`i' [fw=count], meanonly
    mat cumT_`cntry'_tbl[`i',7] = `r(mean)'
    }
  est2tex cumT_`cntry', ready fancy p(braxpmkt/tex/`sec') replace dropall
  gen wmean_gsales = mean_sumsales/mean_goods
  gen pctl = freq*100
  replace mean_gsales = mean_gsales*1000
  replace wmean_gsales = wmean_gsales*1000
  order _rowname mean_goods count freq mean_sumsales
  label var mean_goods "Mean Exporter Scope"
  label var count "# of Firms with min. sales"
  label var freq "Share of Firms with min. sales"
  label var mean_sumsales "Firms' Mean Total Exports"
  label var mean_gsales "Firms' Mean Product Scale" // (US$ thsd fob)
  label var wmean_gsales "Firms' Mean Product Scale" // (US$ thsd fob)
  label var mean_lnsumsales "Firms' Mean Log Total Exports"
  label var mean_lncaphsig "Firms' Mean Log H(G)^(-(sigma-1))"
  label var pctl "Cumulative Percentile of Firms"
  graph twoway scatter mean_goods pctl, yaxis(1) yscale(log axis(1)) ylabel(1 2 4 16 64 256 1024, nogrid axis(1)) yline(1 4 16 256, lcolor(gs13) axis(1)) ytitle("Mean Number of Products", axis(1)) msymbol(smcircle_hollow) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter mean_sumsales pctl, yaxis(2) yscale(log axis(2)) ylabel(1 10 100 1000, nogrid axis(2)) yline(10 100 1000, lcolor(gs14) axis(2)) ytitle("Mean Total Exports (US$ million fob)", axis(2)) msymbol(smsquare_hollow)
  graph export "braxpmkt/eps/`sec'/avgscope-totexp-pcsales-`cntry'.eps", replace
  graph twoway scatter mean_goods pctl, yaxis(1) yscale(log axis(1) range(1 10000)) ylabel(1 2 4 16 64 256 1024, nogrid axis(1)) yline(1 4 16 256, lcolor(gs13) axis(1)) ytitle("Mean Number of Products", axis(1)) msymbol(smcircle_hollow) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter wmean_gsales pctl, yaxis(2) yscale(log axis(2) range(1 10000)) ylabel(1 10 100 1000 10000, nogrid axis(2)) yline(1 100 1000 10000, lcolor(gs14) axis(2)) ytitle("Mean Exports/Product (US$ thsd fob)", axis(2)) msymbol(smsquare_hollow)
  graph export "braxpmkt/eps/`sec'/avgscope-wgsales-pcsales-`cntry'.eps", replace
  erase "braxpmkt/tex/`sec'/histT_`cntry'.tex"
  erase "braxpmkt/tex/`sec'/histT_`cntry'_tbl.dta"
  erase "braxpmkt/tex/`sec'/cumT_`cntry'.tex"
  erase "braxpmkt/tex/`sec'/cumT_`cntry'_tbl.dta"

gen long wtfkey = `cntry'
label var wtfkey "Six-digit WTF code"
keep wtfkey pctl mean_sumsales mean_goods mean_gsales wmean_gsales mean_lnsumsales mean_lncaphsig freq
order wtfkey pctl mean_sumsales mean_goods mean_gsales wmean_gsales mean_lnsumsales mean_lncaphsig freq
sort wtfkey
compress
save `c`cntry''

}  // close `cntry' loop


* Data collection after avgscope-wgsales graphs by country

tempfile allwtf
local j -1
* foreach cntry in 168960 167060 443680 552460 586420 365900 368960 457020 336040 532500 218400 { // Afr.Other NS, Somalia, Iraq, Finland, Romania, Panama, US NES, Singapore, Peru, France/Monac, USA
foreach cntry in `cntrylst' {
  local j = `j' + 1
  if `j'==0  use `c`cntry'', clear
  else       append using `c`cntry''
  }  // close `cntry' loop
save `allwtf'


* Data addition for four aggregate regions  // graphs produced in %03/prodsales-stats.do

local j -1
foreach region in "world" "mercosur" "oecd90" "nonoecd90" {
local j = `j' + 1

tempfile reg`j'

use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members

collapse (sum) value, by(firmid cnae hs6dgt) fast  // collapse over destinations
sort firmid hs6dgt
gsort firmid -value
by firmid: gen gndidx = _n
egen goods = max(gndidx), by(firmid)
label var gndidx "Product rank (HS 6-digit)"
label var goods  "Exporter scope (HS 6-digit)"
collapse (sum) sumsales=value (count) goods=value, by(firmid cnae) fast  // collapse over goods
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per product (US$ mill fob)"

gen lngoods=ln(goods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(sumsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(gsales)
label var lngsales "Log exports/product (US$ mill fob)"

gen lncaphsig = .
label var lncaphsig "Log H(goods)^(-(sigma-1))"
forvalues g = 1/`max' {
  qui replace lncaphsig = log(htable[`g',2]) if int(goods+.5)==`g'   // rounding to closest integer number of goods
  qui replace lncaphsig = log(htable[`max',2]) if int(goods+.5)>`max'   // no machine-size difference above `max'
  }
sort goods

egen ranksales=rank(sumsales), unique
label var ranksales "Rank of total exports"
egen rankgoods=rank(goods), unique
label var rankgoods "Rank of number of products"
egen rankgsales=rank(gsales), unique
label var rankgsales "Rank of mean exports per product"

sort firmid
count if firmid~=firmid[_n-1]
local firms = `r(N)'
gen pcsales=ranksales/`firms'
label var pcsales  "Firm percentile: Tot. exports"
gen pcgoods=rankgoods/`firms'
label var pcgoods  "Firm percentile: No. of products"
gen pcgsales=rankgsales/`firms'
label var pcgsales "Firm percentile: Exports/product"
* egen mdgsales=median(gsales), by(goods)
* label var mdgsales "Median of mean exports per product"
sort firmid

gen _pctlval = int(pcsales*100+1)
replace _pctlval = 100 if _pctlval==101
gen byte _dummy = 1
preserve
  tabl2tex firmid, type(count) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_) fancy replace over nolog
  mat rename histT__tbl _hist`region'_tbl
  local rows = rowsof(_hist`region'_tbl)
  local tot = _hist`region'_tbl[`rows',2]
  mat _hist`region'_tbl = _hist`region'_tbl[1...,1] , _hist`region'_tbl[1...,2]/`tot'
restore, preserve
  tabl2tex sumsales, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_) fancy replace over nolog
  local rows = rowsof(histT__tbl)
  mat _hist`region'_tbl = _hist`region'_tbl[1..`rows',1...] , histT__tbl
restore, preserve
  tabl2tex gsales, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_) fancy replace over nolog
  local rows = rowsof(histT__tbl)
  mat _hist`region'_tbl = _hist`region'_tbl[1..`rows',1...] , histT__tbl
restore, preserve
  tabl2tex goods, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_) fancy replace over nolog
  local rows = rowsof(histT__tbl)
  mat _hist`region'_tbl = _hist`region'_tbl[1..`rows',1...] , histT__tbl
restore, preserve
  tabl2tex lnsumsales, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_) fancy replace over nolog
  local rows = rowsof(histT__tbl)
  mat _hist`region'_tbl = _hist`region'_tbl[1..`rows',1...] , histT__tbl
restore, preserve
  tabl2tex lncaphsig, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec') name(histT_) fancy replace over nolog
  local rows = rowsof(histT__tbl)
  mat histT__tbl = _hist`region'_tbl[1..`rows',1...] , histT__tbl
  mat drop _hist`region'_tbl
restore
  mat colnames histT__tbl = count freq mean_sumsales mean_gsales mean_goods mean_lnsumsales mean_lncaphsig
  est2tex histT_, ready fancy p(braxpmkt/tex/`sec') replace dropall
  mat cumT__tbl = J(`rows',7,.)
  local rownames : rowfullnames histT__tbl
  mat colnames cumT__tbl = count freq mean_sumsales mean_gsales mean_goods mean_lnsumsales mean_lncaphsig
  mat rownames cumT__tbl = or_higher
  mat roweq cumT__tbl = `rownames'
  forvalues i = 1/`rows' {
    qui summ count if _n>=`i', meanonly
    mat cumT__tbl[`i',1] = `r(sum)'
    qui summ freq if _n>=`i', meanonly
    mat cumT__tbl[`i',2] = `r(sum)'
    qui summ mean_sumsales if _n>=`i' [fw=count], meanonly
    mat cumT__tbl[`i',3] = `r(mean)'
    qui summ mean_gsales if _n>=`i' [fw=count], meanonly
    mat cumT__tbl[`i',4] = `r(mean)'
    qui summ mean_goods if _n>=`i' [fw=count], meanonly
    mat cumT__tbl[`i',5] = `r(mean)'
    qui summ mean_lnsumsales if _n>=`i' [fw=count], meanonly
    mat cumT__tbl[`i',6] = `r(mean)'
    qui summ mean_lncaphsig if _n>=`i' [fw=count], meanonly
    mat cumT__tbl[`i',7] = `r(mean)'
    }
  est2tex cumT_, ready fancy p(braxpmkt/tex/`sec') replace dropall
  gen wmean_gsales = mean_sumsales/mean_goods
  gen pctl = freq*100
  replace mean_gsales = mean_gsales*1000
  replace wmean_gsales = wmean_gsales*1000
  order _rowname mean_goods count freq mean_sumsales
  label var mean_goods "Mean Exporter Scope"
  label var count "# of Firms with min. sales"
  label var freq "Share of Firms with min. sales"
  label var mean_sumsales "Firms' Mean Total Exports"
  label var mean_gsales "Firms' Mean Product Scale" // (US$ thsd fob)
  label var wmean_gsales "Firms' Mean Product Scale" // (US$ thsd fob)
  label var mean_lnsumsales "Firms' Mean Log Total Exports"
  label var mean_lncaphsig "Firms' Mean Log H(G)^(-(sigma-1))"
  label var pctl "Cumulative Percentile of Firms"
  erase "braxpmkt/tex/`sec'/histT_.tex"
  erase "braxpmkt/tex/`sec'/histT__tbl.dta"
  erase "braxpmkt/tex/`sec'/cumT_.tex"
  erase "braxpmkt/tex/`sec'/cumT__tbl.dta"

gen long wtfkey = `j'
label var wtfkey "Six-digit WTF code"
keep wtfkey pctl mean_sumsales mean_goods mean_gsales wmean_gsales mean_lnsumsales mean_lncaphsig freq
order wtfkey pctl mean_sumsales mean_goods mean_gsales wmean_gsales mean_lnsumsales mean_lncaphsig freq
sort wtfkey
compress
save `reg`j''

}  // close `region' loop

use `allwtf', clear
qui do "braxpmkt/conc/wtfkey.do"
label values wtfkey wtfkey
local j -1
foreach region in "world" "mercosur" "oecd90" "nonoecd90" {
  local j = `j' + 1
  append using `reg`j''
  label define wtfkey `j' "`region'", modify
  }  // close `region' loop
save "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'", replace

}  // close `sec' loop


// PARETO SHAPE AND DELTA ESTIMATES

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {
local cntrylst ""
use "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'", clear
keep wtfkey
sort wtfkey
by wtfkey: keep if _n==1
sort wtfkey
qui count
local totcntry = `r(N)'
forvalues i = 1/`totcntry' {
  local wtfadd = wtfkey[`i']
  local cntrylst "`cntrylst' `wtfadd'"
  }
disp "`cntrylst'"

use "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'", clear
gen totexp = .
label var totexp "Tot. Dest. Exp. (US$ mill fob)"
gen totnum = .
label var totnum "# of Exporters at Dest."
gen ascope = .
label var ascope "a: lngoods = a + b*ln(1-Pr)"
gen bscope = .
label var bscope "b: lngoods = a + b*ln(1-Pr)"
gen r2scope = .
label var r2scope "r2: lngoods = a + b*ln(1-Pr)"

gen ascale = .
label var ascale "a: lngoods = a + b*ln(1-Pr)"
gen bscale = .
label var bscale "b: lngoods = a + b*ln(1-Pr)"
gen r2scale = .
label var r2scale "r2: lngoods = a + b*ln(1-Pr)"
preserve

foreach cntry in `cntrylst' {
local totexp = "."
local bscope = "."
local ascope = "."
local r2scope = "."
local bscale = "."
local ascale = "."
local r2scale = "."

restore, preserve
keep if wtfkey==`cntry'

gen x_axis = log(100-pctl)
gen rev_x_axis = log(pctl)
gen ln_mean_goods = log(mean_goods)
gen ln_wmean_gsales = log(wmean_gsales)
label var x_axis "Log Percentile (1-Pr on x-axis)"
label var rev_x_axis "Log Percentile (as if Pr on x-axis)"
label var ln_mean_goods "Log Mean Exporter Scope"
label var ln_wmean_gsales "Log Mean Product Scale"
capture noi regress ln_mean_goods rev_x_axis
capture local bscope = _b[rev_x_axis]
capture local ascope = _b[_cons]
capture local r2scope = `e(r2)'
capture noi regress ln_wmean_gsales rev_x_axis
capture local bscale = _b[rev_x_axis]
capture local ascale = _b[_cons]
capture local r2scale = `e(r2)'

restore, preserve
use firmid wtfkey value cnae isic2 hs6dgt indoecd90 using "braxpmkt/secex/prodsales-data-2000", clear
drop if value==0
* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms
* select destinations
if `cntry'==0  keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if `cntry'==1  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if `cntry'==2  keep if indoecd90==1  // exports to group of 1990-OECD members
if `cntry'==3  keep if indoecd90==0  // exports to group of 1990-OECD non-members
if `cntry'>9   keep if wtfkey==`cntry'
collapse (sum) value, by(firmid cnae hs6dgt) fast  // collapse over destinations
collapse (sum) sumsales=value (count) goods=value, by(firmid cnae) fast  // collapse over goods
replace sumsales = sumsales/1000000
label var sumsales "Exports (US$ mill fob)"
qui summ sumsales
local totnum = `r(N)'
local totexp = `r(sum)'

restore
replace totexp  = `totexp'  if wtfkey==`cntry'
replace totnum  = `totnum'  if wtfkey==`cntry'
replace bscope  = `bscope'  if wtfkey==`cntry'
replace ascope  = `ascope'  if wtfkey==`cntry'
replace r2scope = `r2scope' if wtfkey==`cntry'
replace bscale  = `bscale'  if wtfkey==`cntry'
replace ascale  = `ascale'  if wtfkey==`cntry'
replace r2scale = `r2scale' if wtfkey==`cntry'
preserve

}  // close `cntry' loop

restore
gen delta = 1 + bscale/bscope
label var delta "delta: 1 + bscale/bscope"
sort wtfkey pctl
compress
save "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'", replace

}  // close `sec' loop


log close
set more off
