*! version 1.1  01may2011  by Marc Muendler  muendler@ucsd.edu
*! version 1.3  20jul2011  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 650m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/srvc-firms"
capture mkdir "braxpmkt/eps/comrc-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/srvc-firms"
capture mkdir "braxpmkt/estmat/comrc-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-desc-reg.log", replace


// PRODUCT SALES BY SECTOR AND REGION
* as in %03desc-stats/prodsales-stats.do

foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" {

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {

// Product rankings

use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina
if "`region'"=="top20th" & "`sec'"=="allsec"      keep if wtfkey==557560 // exports to Switz.Liecht
if "`region'"=="top20th" & "`sec'"=="manf-goods"  keep if wtfkey==586430 // exports to Russian Fed
if "`region'"=="top20th" & "`sec'"=="manf-firms"  keep if wtfkey==481560 // exports to China
if "`region'"=="top20th" & "`sec'"=="srvc-firms"  keep if wtfkey==368960 // exports to US NES
if "`region'"=="top20th" & "`sec'"=="comrc-firms" keep if wtfkey==211240 // exports to Canada
if "`region'"=="top20th" & "`sec'"=="manf-ekk"    keep if wtfkey==454100 // exports to Korea Rep.
if "`region'"=="top25th" & "`sec'"=="allsec"      keep if wtfkey==330680 // exports to Bolivia
if "`region'"=="top25th" & "`sec'"=="manf-goods"  keep if wtfkey==710360 // exports to Australia
if "`region'"=="top25th" & "`sec'"=="manf-firms"  keep if wtfkey==586430 // exports to Russian Fed
if "`region'"=="top25th" & "`sec'"=="srvc-firms"  keep if wtfkey==453440 // exports to China HK SAR
if "`region'"=="top25th" & "`sec'"=="comrc-firms" keep if wtfkey==352140 // exports to Dominican Rp
if "`region'"=="top25th" & "`sec'"=="manf-ekk"    keep if wtfkey==446820 // exports to Saudi Arabia

collapse (sum) value, by(firmid cnae hs6dgt)
label var value "Exports (US$ fob)"
egen goods = count(hs6dgt), by(firmid)
label var goods "Exporter scope (HS 6-digit)"
gsort firmid -value
by firmid: gen currnum=_n
label var currnum "Product rank within firm (HS 6-digit)"
gen lnvalue = log(value)
label var lnvalue "Log Exports (US$ fob)"
gen lncurrnum = log(currnum)
label var lncurrnum "Log Product rank within firm (HS 6)"
gen lngoods=ln(goods)
label var lngoods "Log number of products (HS 6)"
compress

* mark least selling product by firm and destination
egen _maxcurrnum = max(currnum), by(firmid cnae)
gen byte indminval = (currnum==_maxcurrnum)
label var indminval "Indic.: Least selling product"
drop _maxcurrnum

reg lnvalue lngoods if indminval==1
  est2vec expminval_`region', vars(lngoods _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(rawdata:ols) replace

est2tex expminval_`region', p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop
}  // close `region' loop


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" "chile-manffrms" {

use "braxpmkt/secex/expprod-`sec'", clear
gen lngoods=ln(goods)
label var lngoods "Log number of products (HS 6)"
qui tab wtfkey, gen(indwtf)
drop indwtf1

* mark least selling product by firm and destination
egen _maxcurrnum = max(currnum), by(wtfkey firmid)
gen byte indminval = (currnum==_maxcurrnum)
label var indminval "Indic.: Least selling product"
drop _maxcurrnum

unab vars : lngoods indwtf*
reg lnvalue lngoods if indminval==1
  est2vec expminval, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(rawdata:ols) replace
reg lnvalue lngoods indwtf* if indminval==1
  est2vec expminval, addto(expminval) name(rawdata:fe_wtf) replace
xtreg lnvalue lngoods if indminval==1, i(firm) fe
  est2vec expminval, addto(expminval) name(rawdata:fe_firm) replace
xtreg lnvalue lngoods indwtf* if indminval==1, i(firm) fe
  est2vec expminval, addto(expminval) name(rawdata:fe_wtffirm) replace

est2tex expminval, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop

log close
set more off
