*! version 1.0.2  19oct2007  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.3  11apr2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.4  25jan2012  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 100m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/eps/allsec/bycntry"
capture mkdir "braxpmkt/eps/manf-goods/bycntry"
capture mkdir "braxpmkt/eps/manf-firms/bycntry"
capture mkdir "braxpmkt/eps/manf-ekk/bycntry"

capture mkdir "braxpmkt/tex/allsec"
capture mkdir "braxpmkt/tex/manf-goods"
capture mkdir "braxpmkt/tex/manf-firms"
capture mkdir "braxpmkt/tex/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-goods-pcsales-bycountry.log", replace

// EXPORTER SCOPE AND TOTAL EXPORTS DISTRIBUTION BY COUNTRY

foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {

local cntrylst ""

* Country list
use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms
drop if wtfkey==0 | wtfkey==356580  // remove St. Kitts and Nevis
keep wtfkey
sort wtfkey
by wtfkey: keep if _n==1
sort wtfkey
qui count
local totcntry = `r(N)'
forvalues i = 1/`totcntry' {
  local wtfadd = wtfkey[`i']
  local cntrylst "`cntrylst' `wtfadd'"
  }
disp "`cntrylst'"


* Data preparation and scale-scope graphs by country

* foreach cntry in 168960 167060 443680 552460 586420 365900 368960 457020 336040 532500 218400 { // Afr.Other NS, Somalia, Iraq, Finland, Romania, Panama, US NES, Singapore, Peru, France/Monac, USA
foreach cntry in `cntrylst' {
tempfile c`cntry'

use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0
keep if wtfkey==`cntry'

merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
keep firmid cnae hs6dgt isic2 wtfkey value indoecd90 n_pis

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

collapse (sum) value, by(firmid n_pis cnae hs6dgt) fast  // collapse over destinations
collapse (sum) sumsales=value (count) goods=value, by(firmid n_pis cnae) fast  // collapse over goods
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per product (US$ mill fob)"

gen lngoods=ln(goods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(sumsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(gsales)
label var lngsales "Log exports/product (US$ mill fob)"
sort goods

egen ranksales=rank(sumsales), unique
label var ranksales "Rank of total exports"
egen rankgoods=rank(goods), unique
label var rankgoods "Rank of number of products"
egen rankgsales=rank(gsales), unique
label var rankgsales "Rank of mean exports per product"
egen ranknpis=rank(n_pis), unique
label var ranknpis "Rank of employment"

sort firmid
count if firmid~=firmid[_n-1]
local firms = `r(N)'
gen pcsales=ranksales/`firms'
label var pcsales  "Firm percentile: Tot. exports"
gen pcgoods=rankgoods/`firms'
label var pcgoods  "Firm percentile: No. of products"
gen pcgsales=rankgsales/`firms'
label var pcgsales "Firm percentile: Exports/product"
* egen mdgsales=median(gsales), by(goods)
* label var mdgsales "Median of mean exports per product"
sort firmid
count if firmid~=firmid[_n-1] & ranknpis~=.
local raisfirms = `r(N)'
gen pcnpis=ranknpis/`raisfirms'
label var pcnpis "Firm percentile: Employment"

* twoway scatter (mean) goods pcsales
order pcsales goods firmid
keep firmid goods lngoods pcsales
sort pcsales goods
gen byte pctl = int(pcsales*100)
label var pctl "Firm Percentile in Total Exports"
gen long wtfkey = `cntry'
label var wtfkey "Six-digit WTF code"
order wtfkey firmid pctl pcsales goods lngoods
sort wtfkey firmid
compress
save `c`cntry''
collapse (mean) goods (sd) sd_goods=goods (count) no_obs=goods, by(pctl) fast
replace pctl=pctl/100
gen lngoods = ln(goods)
* reg lngoods pctl if pctl<=.98
gen lnserr_goods_up = log(goods + sd_goods/sqrt(no_obs))
gen lnserr_goods_dn = log(goods - sd_goods/sqrt(no_obs))
graph twoway lfitci lngoods pctl if pctl<=.98, clpattern(solid) || scatter lngoods pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") ylabel(0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1000") ytick(0 2.3025851 4.6051702 6.9077553) yline(0 2.3025851 4.6051702 6.9077553, lcolor(gs13)) ytitle("Log Mean Number of Products (HS 6-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle) legend(order(3 2) label(3 "Mean Exp. Scope (HS 6-digit)") label(2 "Predicted Mean Exp. Scope")) || scatter lnserr_goods_up lnserr_goods_dn pctl, msymbol(point point)
graph export "braxpmkt/eps/`sec'/bycntry/goods-pcsales-`cntry'-mean.eps", replace

}  // close `cntry' loop


* Data collection after scale-scope graphs by country

tempfile allwtf
local j -1
* foreach cntry in 168960 167060 443680 552460 586420 365900 368960 457020 336040 532500 218400 { // Afr.Other NS, Somalia, Iraq, Finland, Romania, Panama, US NES, Singapore, Peru, France/Monac, USA
foreach cntry in `cntrylst' {
  local j = `j' + 1
  if `j'==0  use `c`cntry'', clear
  else       append using `c`cntry''
  }  // close `cntry' loop
save `allwtf'


* Data addition for four aggregate regions  // graphs produced in %03/prodsales-stats.do

local j -1
foreach region in "world" "mercosur" "oecd90" "nonoecd90" {
local j = `j' + 1

tempfile reg`j'
use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0
merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
keep firmid cnae hs6dgt isic2 wtfkey value indoecd90 n_pis

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members

collapse (sum) value, by(firmid n_pis cnae hs6dgt) fast  // collapse over destinations
collapse (sum) sumsales=value (count) goods=value, by(firmid n_pis cnae) fast  // collapse over goods
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per product (US$ mill fob)"

gen lngoods=ln(goods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(sumsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(gsales)
label var lngsales "Log exports/product (US$ mill fob)"
sort goods

egen ranksales=rank(sumsales), unique
label var ranksales "Rank of total exports"
egen rankgoods=rank(goods), unique
label var rankgoods "Rank of number of products"
egen rankgsales=rank(gsales), unique
label var rankgsales "Rank of mean exports per product"
egen ranknpis=rank(n_pis), unique
label var ranknpis "Rank of employment"

sort firmid
count if firmid~=firmid[_n-1]
local firms = `r(N)'
gen pcsales=ranksales/`firms'
label var pcsales  "Firm percentile: Tot. exports"
gen pcgoods=rankgoods/`firms'
label var pcgoods  "Firm percentile: No. of products"
gen pcgsales=rankgsales/`firms'
label var pcgsales "Firm percentile: Exports/product"
* egen mdgsales=median(gsales), by(goods)
* label var mdgsales "Median of mean exports per product"
sort firmid
count if firmid~=firmid[_n-1] & ranknpis~=.
local raisfirms = `r(N)'
gen pcnpis=ranknpis/`raisfirms'
label var pcnpis "Firm percentile: Employment"

order pcsales goods firmid
keep firmid goods lngoods pcsales
sort pcsales goods
gen byte pctl = int(pcsales*100)
label var pctl "Firm Percentile in Total Exports"
gen long wtfkey = `j'
label var wtfkey "Six-digit WTF code"
order wtfkey firmid pctl pcsales goods lngoods
sort wtfkey firmid
compress
save `reg`j''

}  // close `region' loop

use `allwtf', clear
qui do "braxpmkt/conc/wtfkey.do"
label values wtfkey wtfkey
local j -1
foreach region in "world" "mercosur" "oecd90" "nonoecd90" {
  local j = `j' + 1
  append using `reg`j''
  label define wtfkey `j' "`region'", modify
  }  // close `region' loop
save "braxpmkt/secex/scope-pctl-`sec'", replace

}  // close `sec' loop


// EXPORTER SCOPE AND TOTAL EXPORTS REGRESSIONS BY COUNTRY

foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {
local cntrylst ""
use "braxpmkt/secex/scope-pctl-`sec'", clear
keep wtfkey
sort wtfkey
by wtfkey: keep if _n==1
sort wtfkey
qui count
local totcntry = `r(N)'
forvalues i = 1/`totcntry' {
  local wtfadd = wtfkey[`i']
  local cntrylst "`cntrylst' `wtfadd'"
  }
disp "`cntrylst'"

use "braxpmkt/secex/scope-pctl-`sec'", clear
gen totexp = .
label var totexp "Tot. Dest. Exp. (US$ mill fob)"
gen bcoeff = .
label var bcoeff "beta: lngoods = beta*pctl + cons"
gen ccoeff = .
label var ccoeff "cons: lngoods = beta*pctl + cons"
preserve

foreach cntry in `cntrylst' {
local bcoeff = "."
local ccoeff = "."
local totexp = "."

restore, preserve
keep if wtfkey==`cntry'
replace pctl=pctl/100
qui capture reg lngoods pctl if pctl<=.98
capture local bcoeff = _b[pctl]
capture local ccoeff = _b[_cons]

restore, preserve
use wtfkey value cnae isic2 indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0
* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms
* select destinations
if `cntry'==0  keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if `cntry'==1  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if `cntry'==2  keep if indoecd90==1  // exports to group of 1990-OECD members
if `cntry'==3  keep if indoecd90==0  // exports to group of 1990-OECD non-members
if `cntry'>9   keep if wtfkey==`cntry'
replace value = value/1000000
label var value "Exports (US$ mill fob)"
qui summ value
local totexp = `r(sum)'

restore
replace totexp = `totexp' if wtfkey==`cntry'
replace bcoeff = `bcoeff' if wtfkey==`cntry'
replace ccoeff = `ccoeff' if wtfkey==`cntry'
preserve

}  // close `cntry' loop

restore
sort wtfkey firmid
save "braxpmkt/secex/scope-pctl-`sec'", replace

}  // close `sec' loop


log close
set more off
