*! version 1.0.3  09jan2009  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.4  19feb2009  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.4  19feb2009  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.6  11apr2010  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 650m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/chile-manffrms"
capture mkdir "braxpmkt/tex/chile-manffrms"

capture log close
log using "braxpmkt/logs/prodsales-graphs-chile.log", replace

capture program drop uicorr
program define uicorr
  if "`e(cmd)'"=="xtreg" qui predict ui, u
  else qui gen ui = .
  capture corr ui lncurrnum
  drop ui
end


// PRODUCT SALES BY SECTOR AND REGION
* as in %03desc-stats/prodsales-stats.do

foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" {

// Product rankings

use firmid hs6dgt isic* wtfkey value indoecd90 using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina

collapse (sum) value, by(firmid hs6dgt)
label var value "Exports (US$ fob)"
egen goods = count(hs6dgt), by(firmid)
label var goods "Exporter scope (HS 6-digit)"
gsort firmid -value
by firmid: gen currnum=_n
label var currnum "Product rank within firm (HS 6-digit)"
gen lnvalue = log(value)
label var lnvalue "Log Exports (US$ fob)"
gen lncurrnum = log(currnum)
label var lncurrnum "Log Product rank within firm (HS 6)"
compress

reg lnvalue lncurrnum
  est2vec expprod_`region', vars(lngoods lncurrnum _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(rawdata:ols) replace
  uicorr
  est2vec expprod_`region', r(rho) name(rawdata:ols) replace
xtreg lnvalue lncurrnum, i(goods) fe
  est2vec expprod_`region', addto(expprod_`region') name(rawdata:fe_goods) replace
  uicorr
  est2vec expprod_`region', raddto(expprod_`region') name(rawdata:fe_goods) replace
xtreg lnvalue lncurrnum, i(firm) fe
  est2vec expprod_`region', addto(expprod_`region') name(rawdata:fe_firm) replace
  uicorr
  est2vec expprod_`region', raddto(expprod_`region') name(rawdata:fe_firm) replace
graph twoway scatter lnvalue lncurrnum if goods==16, ytitle("Log Exports (US$ fob)") xtitle("Log Product Rank within Firm (HS 6-digit)") xlabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16") graphregion(color(white)) scheme(sj) || scatter lnvalue lncurrnum if goods==8 || scatter lnvalue lncurrnum if goods==4 || lfitci lnvalue lncurrnum if goods==16 || lfitci lnvalue lncurrnum if goods==8 || lfitci lnvalue lncurrnum if goods==4

replace value = value/1000
collapse (mean) value (sd) sd_value=value (count) count_value=value, by(goods currnum) fast
gen lnvalue = log(value)
gen lncurrnum = log(currnum)
label var value "Exports (US$ thsd fob)"
label var sd_value "Std. dev. Exports (US$ thsd fob)"
label var count "# of Firms with identical Scope"
label var lnvalue "Log Exports (US$ thsd fob)"
label var lncurrnum "Log Product rank within firm (HS 6)"

reg lnvalue lncurrnum
  est2vec expprod_`region', addto(expprod_`region') name(meandata:ols) replace
  uicorr
  est2vec expprod_`region', raddto(expprod_`region') name(meandata:ols) replace
xtreg lnvalue lncurrnum, i(goods) fe
  est2vec expprod_`region', addto(expprod_`region') name(meandata:fe_goods) replace
  uicorr
  est2vec expprod_`region', raddto(expprod_`region') name(meandata:fe_goods) replace
local i 0
foreach goods in 32 16 8 4 {
  local i = `i' + 1
  local gds `goods'
  if "`region'"=="usa" & `gds'==32        local gds 31
  if "`region'"=="argentina" & `gds'==32  local gds 33
  qui summ count_value if goods==`gds'
  local lbl`i' = `r(mean)'
  }
local maxgds 32
if "`region'"=="usa"        local maxgds 31
if "`region'"=="argentina"  local maxgds 33
graph twoway scatter value currnum if goods==`maxgds', yscale(log) ytitle("Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Product Rank within Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==16 || scatter value currnum if goods==8 || scatter value currnum if goods==4, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')"))
graph export "braxpmkt/eps/chile-manffrms/expprod_`region'-4-32.eps", replace
local i 0
foreach goods in 16 8 4 2 {
  local i = `i' + 1
  qui summ count_value if goods==`goods'
  local lbl`i' = `r(mean)'
  }
graph twoway scatter value currnum if goods==16, yscale(log) ytitle("Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Product Rank within Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==8 || scatter value currnum if goods==4 || scatter value currnum if goods==2, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')"))
graph export "braxpmkt/eps/chile-manffrms/expprod_`region'-2-16.eps", replace

est2tex expprod_`region', p(braxpmkt/estmat/chile-manffrms) replace level(90 95 99) mark(starse) dropall

}  // close `region' loop


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

local cntrylst ""

* Country list
use firmid hs6dgt isic* wtfkey value indoecd90 using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
keep if isic2>=300 & isic2<=399    // manufacturing products
drop if wtfkey==0
keep wtfkey
sort wtfkey
by wtfkey: keep if _n==1
sort wtfkey
qui count
local totcntry = `r(N)'
forvalues i = 1/`totcntry' {
  local wtfadd = wtfkey[`i']
  local cntrylst "`cntrylst' `wtfadd'"
  }
disp "`cntrylst'"

* Data preparation and within-firm product sales by firm and country

foreach cntry in `cntrylst' {
tempfile c`cntry'
use firmid hs6dgt isic* wtfkey value indoecd90 using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0
keep if wtfkey==`cntry'

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

collapse (sum) value, by(wtfkey firmid hs6dgt)
label var value "Exports (US$ fob)"
egen goods = count(hs6dgt), by(firmid)
label var goods "Exporter scope (HS 6-digit)"
gsort firmid -value
by firmid: gen currnum=_n
label var currnum "Product rank within firm (HS 6-digit)"
gen lnvalue = log(value)
label var lnvalue "Log Exports (US$ fob)"
gen lncurrnum = log(currnum)
label var lncurrnum "Log Product rank within firm (HS 6)"
sort wtfkey firmid
compress
save `c`cntry''

}  // close `cntry' loop

local j -1
* foreach cntry in 168960 167060 443680 552460 586420 365900 368960 457020 336040 532500 218400 { // Afr.Other NS, Somalia, Iraq, Finland, Romania, Panama, US NES, Singapore, Peru, France/Monac, USA
foreach cntry in `cntrylst' {
  local j = `j' + 1
  if `j'==0  use `c`cntry'', clear
  else       append using `c`cntry''
  }  // close `cntry' loop
qui do "braxpmkt/conc/wtfkey.do"
label values wtfkey wtfkey
save "braxpmkt/secex/expprod-chile-manffrms", replace

qui tab goods, gen(indgoods)
drop indgoods1
qui tab wtfkey, gen(indwtf)
drop indwtf1
gen lngoods=ln(goods)
label var lngoods "Log number of products (HS 6)"

unab vars : lngoods lncurrnum indwtf* indgoods*
reg lnvalue lncurrnum
  est2vec expprod, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(rawdata:ols) replace
  uicorr
  est2vec expprod, r(rho) name(rawdata:ols) replace
xtreg lnvalue lncurrnum, i(goods) fe
  est2vec expprod, addto(expprod) name(rawdata:fe_goods) replace
  uicorr
  est2vec expprod, raddto(expprod) name(rawdata:fe_goods) replace
xtreg lnvalue lncurrnum, i(firm) fe
  est2vec expprod, addto(expprod) name(rawdata:fe_firm) replace
  uicorr
  est2vec expprod, raddto(expprod) name(rawdata:fe_firm) replace
xtreg lnvalue lncurrnum indgoods*, i(firm) fe
  est2vec expprod, addto(expprod) name(rawdata:fe_goodsfirm) replace
  uicorr
  est2vec expprod, raddto(expprod) name(rawdata:fe_goodsfirm) replace
xtreg lnvalue lncurrnum indgoods* indwtf*, i(firm) fe
  est2vec expprod, addto(expprod) name(rawdata:fe_wtfgoodsfirm) replace
  uicorr
  est2vec expprod, raddto(expprod) name(rawdata:fe_wtfgoodsfirm) replace
foreach goods in 16 8 4 {
  local i = `i' + 1
  qui summ value if goods==`goods'
  local lbl`i' = `r(N)'
  }
graph twoway scatter lnvalue lncurrnum if goods==16, ytitle("Log Exports (US$ fob)") xtitle("Log Product Rank within Firm (HS 6-digit)") xlabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16") graphregion(color(white)) scheme(sj) || scatter lnvalue lncurrnum if goods==8 || scatter lnvalue lncurrnum if goods==4 || lfitci lnvalue lncurrnum if goods==16 || lfitci lnvalue lncurrnum if goods==8 || lfitci lnvalue lncurrnum if goods==4, legend(order(3 2 1) label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')"))

reg lnvalue lngoods lncurrnum
  est2vec expprod, addto(expprod) name(rawdata:ols_long) replace
  uicorr
  est2vec expprod, raddto(expprod) name(rawdata:ols_long) replace
reg lnvalue lngoods lncurrnum indwtf*
  est2vec expprod, addto(expprod) name(rawdata:fewtf_long) replace
  uicorr
  est2vec expprod, raddto(expprod) name(rawdata:fewtf_long) replace
* xtreg lnvalue lngoods lncurrnum indwtf*, i(cnae) fe
*   est2vec expprod, addto(expprod) name(rawdata:fewtfcnae_long) replace
*   uicorr
*   est2vec expprod, raddto(expprod) name(rawdata:fewtfcnae_long) replace
xtreg lnvalue lngoods lncurrnum indwtf*, i(firm) fe
  est2vec expprod, addto(expprod) name(rawdata:fewtffirm_goods) replace
  uicorr
  est2vec expprod, raddto(expprod) name(rawdata:fewtffirm_goods) replace

replace value = value/1000
collapse (mean) value (sd) sd_value=value (count) count_value=value, by(wtfkey goods currnum) fast
gen lnvalue = log(value)
gen lncurrnum = log(currnum)
egen mean_value = mean(value), by(goods currnum)
label var value "Exports (US$ thsd fob)"
label var sd_value "Std. dev. Exports (US$ thsd fob)"
label var count "# of Firms with identical Scope"
label var lnvalue "Log Exports (US$ thsd fob)"
label var lncurrnum "Log Product rank within firm (HS 6)"
label var mean_value "Mean Exports (US$ thsd fob)"

reg lnvalue lncurrnum
  est2vec expprod, addto(expprod) name(meandata:ols) replace
  uicorr
  est2vec expprod, raddto(expprod) name(meandata:ols) replace
xtreg lnvalue lncurrnum, i(goods) fe
  est2vec expprod, addto(expprod) name(meandata:fe_goods) replace
  uicorr
  est2vec expprod, raddto(expprod) name(meandata:fe_goods) replace
local i 0
foreach goods in 32 16 8 4 {
  local i = `i' + 1
  qui summ mean_value if goods==`goods'
  local lbl`i' = `r(N)'
  }
graph twoway scatter mean_value currnum if goods==32, yscale(log) ytitle("Mean Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Product Rank within Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter mean_value currnum if goods==16 || scatter mean_value currnum if goods==8 || scatter mean_value currnum if goods==4, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')"))
graph export "braxpmkt/eps/chile-manffrms/expprod-4-32.eps", replace
local i 0
foreach goods in 16 8 4 2 {
  local i = `i' + 1
  qui summ mean_value if goods==`goods'
  local lbl`i' = `r(N)'
  }
graph twoway scatter mean_value currnum if goods==16, yscale(log) ytitle("Mean Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Product Rank within Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter mean_value currnum if goods==8 || scatter mean_value currnum if goods==4 || scatter mean_value currnum if goods==2, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')"))
graph export "braxpmkt/eps/chile-manffrms/expprod-2-16.eps", replace

est2tex expprod, p(braxpmkt/estmat/chile-manffrms) replace level(90 95 99) mark(starse) dropall


log close
set more off
