*! version 1.0.1  24nov2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.2  09mar2008  by Oana Hirakawa     otocoian@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 100m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/chile-manffrms"
capture mkdir "braxpmkt/tex/chile-manffrms"

capture log close
log using "braxpmkt/logs/prodsales-prelim-chile.log", replace


// FIND MEDIAN COUNTRY BY SECTOR TYPE

* loop over different sector definitions has been eliminated (manf-firms only)

use firmid hs6dgt isic* wtfkey indoecd90 value using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

keep if wtfkey~=0
collapse (sum) value, by(wtfkey indoecd90) fast
label var value "Value (current US$ fob)"
sort wtfkey

qui count
local countries = `r(N)'
egen rankvalue=rank(value), unique
gen pcvalue=rankvalue/`countries'
label var rankvalue "Unique rank of Tot. exports"
label var pcvalue  "Country percentile: Tot. exports"

* identify median country (two countries if even number of countries)
qui summ value, meanonly
sort rankvalue
if int(`countries'/2)~=`countries'/2 {
  local medobs = int(`countries'/2)+1
  local wtfkey = wtfkey[`medobs']
  local wtfname : label wtfkey `wtfkey'
  local wtfshare = (value[`medobs']/`r(sum)')*100
  disp in gr "Median country for sector " in ye "chile-manffrms" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"
  }
else {
  local medobs = int(`countries'/2)
  local wtfkey = wtfkey[`medobs']
  local wtfname : label wtfkey `wtfkey'
  local wtfshare = (value[`medobs']/`r(sum)')*100
  disp in gr "Just-below median country for sector " in ye "chile-manffrms" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"
  local medobs = int(`countries'/2)+1
  local wtfkey = wtfkey[`medobs']
  local wtfname : label wtfkey `wtfkey'
  local wtfshare = (value[`medobs']/`r(sum)')*100
  disp in gr "Just-above median country for sector " in ye "chile-manffrms" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"
  }
gsort -rankvalue
local wtfkey = wtfkey[20]
local wtfname : label wtfkey `wtfkey'
local wtfshare = (value[20]/`r(sum)')*100
disp in gr "Top 20th country for sector " in ye "chile-manffrms" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"
gsort -rankvalue
local wtfkey = wtfkey[25]
local wtfname : label wtfkey `wtfkey'
local wtfshare = (value[25]/`r(sum)')*100
disp in gr "Top 25th country for sector " in ye "chile-manffrms" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"

* calculate regional shares in total exports
mat relstats_prelim_tbl = J(1,8,.)
mat colnames relstats_prelim_tbl = world mercosur oecd90 nonoecd90 usa argentina top20th top25th
mat rownames relstats_prelim_tbl = totexpsh
qui summ value, meanonly
local totexp = `r(sum)'
foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top20th" "top25th" {
  if "`region'"=="world"     summ value, meanonly, if wtfkey~=0     // worldwide exports (keep individual destinations)
  if "`region'"=="mercosur"  summ value, meanonly, if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
  if "`region'"=="oecd90"    summ value, meanonly, if indoecd90==1  // exports to group of 1990-OECD members
  if "`region'"=="nonoecd90" summ value, meanonly, if indoecd90==0  // exports to group of 1990-OECD non-members
  if "`region'"=="usa"       summ value, meanonly, if wtfkey==218400  // exports to USA
  if "`region'"=="argentina" summ value, meanonly, if wtfkey==330320  // exports to Argentina
  if "`region'"=="top20th"   summ value, meanonly, if wtfkey==211240  // exports to Canada
  if "`region'"=="top25th"   summ value, meanonly, if wtfkey==341880  // exports to Costa Rica
  mat relstats_prelim_tbl[1,colnumb(relstats_prelim_tbl,"`region'")] = `r(sum)'/`totexp'
}  // close `region' loop
est2tex relstats_prelim, ready fancy p(braxpmkt/tex/chile-manffrms) replace dropall

log close
set more off
