*! version 1.1.2  06jul2011  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 100m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/manf-firms-ncm8"
capture mkdir "braxpmkt/eps/comrc-firms-ncm8"
capture mkdir "braxpmkt/tex/manf-firms-ncm8"
capture mkdir "braxpmkt/tex/comrc-firms-ncm8"

capture log close
log using "braxpmkt/logs/prodsales-prelim-ncm8.log", replace


// FIND MEDIAN COUNTRY BY SECTOR TYPE

foreach sec in "manf-firms" "comrc-firms" {

use firmid cnae ncm8dgt isic2 wtfkey indoecd90 value using "braxpmkt/secex/prodsales-data-2000-ncm8.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms
keep if wtfkey~=0
collapse (sum) value, by(wtfkey indoecd90) fast
label var value "Value (current US$ fob)"
sort wtfkey

qui count
local countries = `r(N)'
egen rankvalue=rank(value), unique
gen pcvalue=rankvalue/`countries'
label var rankvalue "Unique rank of Tot. exports"
label var pcvalue  "Country percentile: Tot. exports"

* identify median country (two countries if even number of countries)
qui summ value, meanonly
sort rankvalue
if int(`countries'/2)~=`countries'/2 {
  local medobs = int(`countries'/2)+1
  local wtfkey = wtfkey[`medobs']
  local wtfname : label wtfkey `wtfkey'
  local wtfshare = (value[`medobs']/`r(sum)')*100
  disp in gr "Median country for sector " in ye "`sec'" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"
  }
else {
  local medobs = int(`countries'/2)
  local wtfkey = wtfkey[`medobs']
  local wtfname : label wtfkey `wtfkey'
  local wtfshare = (value[`medobs']/`r(sum)')*100
  disp in gr "Just-below median country for sector " in ye "`sec'" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"
  local medobs = int(`countries'/2)+1
  local wtfkey = wtfkey[`medobs']
  local wtfname : label wtfkey `wtfkey'
  local wtfshare = (value[`medobs']/`r(sum)')*100
  disp in gr "Just-above median country for sector " in ye "`sec'" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"
  }
gsort -rankvalue
local wtfkey = wtfkey[20]
local wtfname : label wtfkey `wtfkey'
local wtfshare = (value[20]/`r(sum)')*100
disp in gr "Top 20th country for sector " in ye "`sec'" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"
gsort -rankvalue
local wtfkey = wtfkey[25]
local wtfname : label wtfkey `wtfkey'
local wtfshare = (value[25]/`r(sum)')*100
disp in gr "Top 25th country for sector " in ye "`sec'" in gr ": " in ye "`wtfname' " in gr "(" in ye "`wtfkey'" in gr "), w/ " in ye %9.1g `wtfshare' in gr " percent of total exports"

* calculate regional shares in total exports
mat relstats_prelim_tbl = J(1,8,.)
mat colnames relstats_prelim_tbl = world mercosur oecd90 nonoecd90 usa argentina top20th top25th
mat rownames relstats_prelim_tbl = totexpsh
qui summ value, meanonly
local totexp = `r(sum)'
foreach region in "world" "usa" "argentina" {
  if "`region'"=="world"     summ value, meanonly, if wtfkey~=0     // worldwide exports (keep individual destinations)
  if "`region'"=="mercosur"  summ value, meanonly, if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
  if "`region'"=="oecd90"    summ value, meanonly, if indoecd90==1  // exports to group of 1990-OECD members
  if "`region'"=="nonoecd90" summ value, meanonly, if indoecd90==0  // exports to group of 1990-OECD non-members
  if "`region'"=="usa"       summ value, meanonly, if wtfkey==218400  // exports to USA
  if "`region'"=="argentina" summ value, meanonly, if wtfkey==330320  // exports to Argentina
  if "`region'"=="top20th" & "`sec'"=="allsec"      summ value, meanonly, if wtfkey==557560 // exports to Switz.Liecht
  if "`region'"=="top20th" & "`sec'"=="manf-goods"  summ value, meanonly, if wtfkey==586430 // exports to Russian Fed
  if "`region'"=="top20th" & "`sec'"=="manf-firms"  summ value, meanonly, if wtfkey==481560 // exports to China
  if "`region'"=="top20th" & "`sec'"=="srvc-firms"  summ value, meanonly, if wtfkey==368960 // exports to US NES
  if "`region'"=="top20th" & "`sec'"=="comrc-firms" summ value, meanonly, if wtfkey==211240 // exports to Canada
  if "`region'"=="top20th" & "`sec'"=="manf-ekk"    summ value, meanonly, if wtfkey==454100 // exports to Korea Rep.
  if "`region'"=="top25th" & "`sec'"=="allsec"      summ value, meanonly, if wtfkey==330680 // exports to Bolivia
  if "`region'"=="top25th" & "`sec'"=="manf-goods"  summ value, meanonly, if wtfkey==710360 // exports to Australia
  if "`region'"=="top25th" & "`sec'"=="manf-firms"  summ value, meanonly, if wtfkey==586430 // exports to Russian Fed
  if "`region'"=="top25th" & "`sec'"=="srvc-firms"  summ value, meanonly, if wtfkey==453440 // exports to China HK SAR
  if "`region'"=="top25th" & "`sec'"=="comrc-firms" summ value, meanonly, if wtfkey==352140 // exports to Dominican Rp
  if "`region'"=="top25th" & "`sec'"=="manf-ekk"    summ value, meanonly, if wtfkey==446820 // exports to Saudi Arabia
  mat relstats_prelim_tbl[1,colnumb(relstats_prelim_tbl,"`region'")] = `r(sum)'/`totexp'
}  // close `region' loop
est2tex relstats_prelim, ready fancy p(braxpmkt/tex/`sec'-ncm8) replace dropall

}  // close `sec' loop


log close
set more off
