*! version 1.0.1  01apr2009  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.1  09aug2010  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 500m
set trace off
set matsize 300

cd "$root"

capture mkdir "braxpmkt/tex/allsec"
capture mkdir "braxpmkt/tex/manf-goods"
capture mkdir "braxpmkt/tex/manf-firms"
capture mkdir "braxpmkt/tex/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-product-dispersion.log", replace


// CNAE 2-DIGIT SECTORS
capture program drop mklbl
program define mklbl
  local var = "`1'"
  local lblname = "`2'"
  * qui replace `var' = lower(`var')
  local num = _N
  * Shorten label names
  local lblname = substr("`lblname'",1,8)
  * English labels
  forvalues i = 1/`num' {
    local lblnum = `2'[`i']
    local lblstr = `1'[`i']
    label define `lblname' `lblnum' "`lblstr'", modify
    }
  label values `2' `lblname'
  label list `lblname'
  label save `lblname' using "braxpmkt/conc/`lblname'", replace
end
insheet using "brazaux/conc/sec/cnae2dgt-subsibge-manual.csv", comma clear
keep cnae2dgt_num cnae2dgt
rename cnae2dgt cnae2dgtdesc
rename cnae2dgt_num cnae2dgt
mklbl cnae2dgtdesc cnae2dgt


foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {

foreach lvl in 2 4 {

clear
est2extlbl, addto(dispers_hs`lvl') intex(braxpmkt/%stata/rowlbl-braxpmkt) p(braxpmkt/tex/`sec') replace
est2extlbl, addto(lnhs`lvl'grps_lngoods) retain p(braxpmkt/tex/`sec') replace


// 1. CONCENTRATION TABLE OF HS6-DIGIT PRODUCTS IN HS2/HS4-CATEGORIES, WORLDWIDE

use firmid cnae hs6dgt isic2 cnae wtfkey value using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

gen hs2dgt = int(hs6dgt/10000)
label var hs2dgt "Harmonized System 2-digit code"
drop if hs2dgt==.
gen hs4dgt = int(hs6dgt/100)
label var hs4dgt "Harmonized System 4-digit code"
drop if hs4dgt==.
compress hs2dgt hs4dgt

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* drop world
keep if wtfkey~=0

collapse (sum) hs`lvl'sales=value (count) hs`lvl'goods=value, by(firmid cnae hs`lvl'dgt)
drop if hs`lvl'sales==0
replace hs`lvl'sales = hs`lvl'sales/1000000
label var hs`lvl'goods "No. products (HS 6-dgt w/in `lvl'-dgt)"
label var hs`lvl'sales "Exports (US$ mill w/in `lvl'-dgt)"
gen hs`lvl'gsales=hs`lvl'sales/hs`lvl'goods
label var hs`lvl'gsales "Exp/product (US$ mill w/in `lvl'-dgt)"
order firmid cnae hs`lvl'dgt hs`lvl'sales hs`lvl'goods hs`lvl'gsales
sort firmid
preserve
  tempfile hs`lvl'lvl
  collapse (sum) sales=hs`lvl'sales goods=hs`lvl'goods (count) hs`lvl'grps=hs`lvl'sales, by(firmid cnae)
  label var goods "No. products (HS 6-dgt)"
  label var sales "Total exports (US$ mill)"
  label var hs`lvl'grps "No. product groups (HS `lvl'-dgt)"
  gen gsales=sales/goods
  label var gsales "Exports/product (US$ mill)"
  order firmid cnae sales goods gsales hs`lvl'grps
  sort firmid 
  save `hs`lvl'lvl'
restore
merge firmid using `hs`lvl'lvl'
tab _m
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete match
drop _m
egen hs`lvl'rank = rank(-hs`lvl'sales), by(firmid) unique  // rank 1 is top rank, 2 is second to top, ... R is lowest-sales rank
label var hs`lvl'rank "Rank of product group (HS `lvl'-dgt)"
gen hs`lvl'ranksh = hs`lvl'sales/sales
label var hs`lvl'ranksh "Sales share prd. grp. (HS `lvl'-dgt)"
order firmid cnae goods hs`lvl'grps hs`lvl'rank hs`lvl'ranksh
sort firmid hs`lvl'rank
compress

mat dispers_hs`lvl'_tbl = J(9,7,.)
mat rownames dispers_hs`lvl'_tbl = N shareN_1grp mean_hs`lvl'grps median_hs`lvl'grps hs`lvl'ranksh_1 hs`lvl'ranksh_2 hs`lvl'ranksh_3 hs`lvl'ranksh_4 hs`lvl'ranksh_5
mat colnames dispers_hs`lvl'_tbl = goods2 goods4 goods8 goods16 goods32 goods64 goods128
foreach no in 2 4 8 16 32 64 128 {
  sort firmid
  qui count if firmid~=firmid[_n-1] & goods>=`no'
  mat dispers_hs`lvl'_tbl[rownumb(dispers_hs`lvl'_tbl,"N"),colnumb(dispers_hs`lvl'_tbl,"goods`no'")] = `r(N)'
  qui count if firmid~=firmid[_n-1] & hs`lvl'grps==1 & goods>=`no'
  mat dispers_hs`lvl'_tbl[rownumb(dispers_hs`lvl'_tbl,"shareN_1grp"),colnumb(dispers_hs`lvl'_tbl,"goods`no'")] = `r(N)' / dispers_hs`lvl'_tbl[rownumb(dispers_hs`lvl'_tbl,"N"),colnumb(dispers_hs`lvl'_tbl,"goods`no'")]
  qui summ hs`lvl'grps if goods>=`no', detail
  mat dispers_hs`lvl'_tbl[rownumb(dispers_hs`lvl'_tbl,"mean_hs`lvl'grps"),colnumb(dispers_hs`lvl'_tbl,"goods`no'")] = `r(mean)'
  mat dispers_hs`lvl'_tbl[rownumb(dispers_hs`lvl'_tbl,"median_hs`lvl'grps"),colnumb(dispers_hs`lvl'_tbl,"goods`no'")] = `r(p50)'
  forvalues rnk=1/5 {
    qui summ hs`lvl'ranksh if hs`lvl'rank==`rnk' & goods>=`no'
    capture mat dispers_hs`lvl'_tbl[rownumb(dispers_hs`lvl'_tbl,"hs`lvl'ranksh_`rnk'"),colnumb(dispers_hs`lvl'_tbl,"goods`no'")] = `r(mean)'
    }
  }
est2tex dispers_hs`lvl', ready fancy p(braxpmkt/tex/`sec') replace dropall digits(3) preserve


// 2. CONCENTRATION TABLE OF HS6-DIGIT PRODUCTS IN HS2/HS4-CATEGORIES, WORLDWIDE

gen lngoods=ln(goods)
label var lngoods "Log No. products (HS 6-dgt)"
gen lnhs`lvl'grps=ln(hs`lvl'grps)
label var lnhs`lvl'grps "Log No. prod. groups (HS `lvl'-dgt)"
gen cnae2dgt = int(cnae/1000)
label var cnae2dgt "CNAE sector (2-digit level)"
qui do "braxpmkt/conc/cnae2dgt.do"
qui label save cnae2dgt using "braxpmkt/tex/`sec'/cnae2dgt", replace
label values cnae2dgt cnae2dgt
compress

keep firmid cnae2dgt hs`lvl'grps goods lnhs`lvl'grps lngoods
duplicates drop

graph twoway scatter hs`lvl'grps goods, ytitle("No. prod. groups (HS `lvl'-digit)") xtitle("No. products (HS 6-digit)") graphregion(color(white)) scheme(sj) || lfit hs`lvl'grps goods
reg hs`lvl'grps goods

graph twoway scatter lnhs`lvl'grps lngoods, ytitle("Log No. prod. groups (HS `lvl'-digit)") xtitle("Log No. products (HS 6-digit)") xlabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16" 3.4657359 "32" 4.1588831 "64" 4.8520303 "128" 5.5451774 "256" 6.2383246 "512" 6.9314718 "1,024" 7.624619 "2,048" 8.3177662 "4,096") ylabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16" 3.4657359 "32" 4.1588831 "64" 4.8520303 "128" 5.5451774 "256") graphregion(color(white)) scheme(sj) || lfit lnhs`lvl'grps lngoods
graph export "braxpmkt/eps/`sec'/lnhs`lvl'grps-lngoods.eps", replace

reg lnhs`lvl'grps lngoods
est2vec lnhs`lvl'grps_lngoods, name(cnae2dgt:0) e(N r2) replace
qui tab cnae2dgt, matrow(cnae2dgt)
local cnaecnt = rowsof(cnae2dgt)
forvalues i = 1/`cnaecnt' {
  local cnae = cnae2dgt[`i',1]
  capture qui reg lnhs`lvl'grps lngoods if cnae2dgt==`cnae'
  if _rc==0  est2vec lnhs`lvl'grps_lngoods, addto(lnhs`lvl'grps_lngoods) name(cnae2dgt:`cnae')
  }
mat lnhs`lvl'grps_lngoods_tbl = lnhs`lvl'grps_lngoods_b[1,1...]' , lnhs`lvl'grps_lngoods_se[1,1...]' , lnhs`lvl'grps_lngoods_e[1..2,1...]'
mat colnames lnhs`lvl'grps_lngoods_tbl = lngoods lngoods_se e(N) e(r2)
mat roweq lnhs`lvl'grps_lngoods_tbl = :
preserve
foreach type in b se e {
  matsave lnhs`lvl'grps_lngoods_`type', p(braxpmkt/tex/`sec') replace dropall
  }
restore 
est2tex lnhs`lvl'grps_lngoods, ready fancy p(braxpmkt/tex/`sec') vallabel(cnae2dgt) replace dropall digits(3) preserve


}  // close `lvl' loop

}  // close `sec' loop


log close
cd "$home"
