*! version 1.0.1  16sep2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.2  11apr2010  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.3  17jul2010  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 100m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/tex/allsec"
capture mkdir "braxpmkt/tex/manf-goods"
capture mkdir "braxpmkt/tex/manf-firms"
capture mkdir "braxpmkt/tex/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-stats-bycountry.log", replace


// PRODUCT SALES STATISTICS FOR ALL COUNTRIES, BY SECTOR

foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {

* Country list
use firmid wtfkey value isic2 cnae using "braxpmkt/secex/prodsales-data-2000.dta", clear
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms
drop if value==0
drop if wtfkey==0
collapse (sum) value, by(firmid wtfkey) fast
collapse (sum) sumsales=value (count) no_firms=firmid, by(wtfkey) fast
label var no_firms "Number of Exporters to dest."
label var sumsales "Total Exports (current US$ fob)"
summ no_firms
summ no_firms, detail
keep if no_firms>1   // drop destinations with less than one firm
sort sumsales
gen wtfidx=_n
label var wtfidx "Destination rank by tot. exports"
drop if wtfidx <= _N-100  // drop bottom destinations, keep only top 100 destinations
replace wtfidx=_n
gen byte pctl = int((wtfidx/_N)*100)
label var pctl "Destination perct'l in tot. exp."
keep sumsales pctl wtfkey
order pctl sumsales wtfkey
sort pctl sumsales wtfkey
by pctl: keep if _n==1
drop if int(pctl/10)~=pctl/10 & pctl~=1 // keep only 11 percentiles: 0, 10, 20, ..., 100
replace pctl=pctl/100
sort sumsales
qui count
local fstcntry = wtfkey[1]
local cntrylst ""
local cntrystr ""
local num = `r(N)'
forvalues i = 1/`num' {
  local addcntry = wtfkey[`i']
  local cntrylst "`cntrylst' `addcntry'"
  local addstr : label wtfkey `addcntry'
  local addstr = subinstr("`addstr'",",","/",.)
  if `i'==1 local cntrystr "`addstr'"
  else      local cntrystr "`cntrystr', `addstr'"
  }
disp in green "WTF keys for " in yellow "`sec'" in green ":" in yellow "`cntrylst'"
disp in green "Country names for " in yellow "`sec'" in green ": " in yellow "`cntrystr'"


* Data preparation and scale-scope graphs

foreach cntry in `cntrylst' {

use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

keep if wtfkey==`cntry'

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

collapse (sum) value, by(firmid cnae hs6dgt) fast  // collapse over destinations
collapse (sum) sumsales=value (count) goods=value, by(firmid cnae) fast  // collapse over goods
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per product (US$ mill fob)"

// Cumulative Histograms

* tab goods
gen byte _dummy = 1
preserve
  tabl2tex firmid, type(count) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_`cntry') fancy replace over nolog
  mat rename hist_`cntry'_tbl _hist`cntry'_tbl
  local rows = rowsof(_hist`cntry'_tbl)
  local tot = _hist`cntry'_tbl[`rows',2]
  mat _hist`cntry'_tbl = _hist`cntry'_tbl[1...,1] , _hist`cntry'_tbl[1...,2]/`tot'
restore, preserve
  tabl2tex sumsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_`cntry') fancy replace over nolog
  local rows = rowsof(hist_`cntry'_tbl)
  mat _hist`cntry'_tbl = _hist`cntry'_tbl[1..`rows',1...] , hist_`cntry'_tbl
restore, preserve
  tabl2tex gsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_`cntry') fancy replace over nolog
  mat hist_`cntry'_tbl = _hist`cntry'_tbl[1..`rows',1...] , hist_`cntry'_tbl
  mat drop _hist`cntry'_tbl
restore, preserve
  mat colnames hist_`cntry'_tbl = count freq mean_sumsales mean_gsales
  est2tex hist_`cntry', ready fancy p(braxpmkt/tex) replace dropall
  gen goods_pls = int(real(_rowname))
  mat cum_`cntry'_tbl = J(`rows',5,.)
  local rownames : rowfullnames hist_`cntry'_tbl
  mat colnames cum_`cntry'_tbl = count freq mean_sumsales mean_gsales mean_goods_pls
  mat rownames cum_`cntry'_tbl = or_more
  mat roweq cum_`cntry'_tbl = `rownames'
  forvalues i = 1/`rows' {
    qui summ count if _n>=`i', meanonly
    mat cum_`cntry'_tbl[`i',1] = `r(sum)'
    qui summ freq if _n>=`i', meanonly
    mat cum_`cntry'_tbl[`i',2] = `r(sum)'
    qui summ mean_sumsales if _n>=`i' [fw=count], meanonly
    mat cum_`cntry'_tbl[`i',3] = `r(mean)'
    qui summ mean_gsales if _n>=`i' [fw=count], meanonly
    mat cum_`cntry'_tbl[`i',4] = `r(mean)'
    qui summ goods_pls if _n>=`i' [fw=count], meanonly
    mat cum_`cntry'_tbl[`i',5] = `r(mean)'
    }
  est2tex cum_`cntry', ready fancy p(braxpmkt/tex) replace dropall
restore
drop _dummy

}  // close `cntry' loop

foreach cntry in `cntrylst' {
  if "`cntry'"=="`fstcntry'"  {
    use "braxpmkt/tex/cum_`cntry'_tbl.dta", clear
    gen long wtfkey = `cntry'
    erase "braxpmkt/tex/hist_`cntry'_tbl.dta"
    erase "braxpmkt/tex/cum_`cntry'_tbl.dta"
    erase "braxpmkt/tex/hist_`cntry'.tex"
    erase "braxpmkt/tex/cum_`cntry'.tex"
    }
  else {
    append using "braxpmkt/tex/cum_`cntry'_tbl.dta"
    replace wtfkey = `cntry' if wtfkey==.
    erase "braxpmkt/tex/hist_`cntry'_tbl.dta"
    erase "braxpmkt/tex/cum_`cntry'_tbl.dta"
    erase "braxpmkt/tex/hist_`cntry'.tex"
    erase "braxpmkt/tex/cum_`cntry'.tex"
    }
  }
gen goods_pls = int(real(substr(_rowname,1,index(_rowname,":")-1)))
gen wmean_gsales = mean_sumsales/mean_goods_pls
gen pctl = freq*100
label var goods_pls "Minimum Exporter Scope"
label var count "# of Firms with min. scope"
label var freq "Share of Firms with min. scope"
label var mean_sumsales "Firms' Avg. Total Exports"
label var mean_gsales "Firms' Avg. Product Scale"
label var wmean_gsales "Firms' Avg. Product Scale"
label var mean_goods_pls "Firms' Avg. Exporter Scope"
label var pctl "Percentile of Firm with min. scope"
order wtfkey goods_pls _rowname count freq mean_sumsales
graph twoway scatter mean_goods_pls pctl, yaxis(1) yscale(log axis(1)) ylabel(1 2 4 16 64 256 1024, nogrid axis(1)) yline(1 4 16 256, lcolor(gs13) axis(1)) ytitle("Mean Number of Products Shipped", axis(1)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter mean_sumsales pctl, yaxis(2) yscale(log axis(2)) ylabel(.1 1 10 100 1000, nogrid axis(2)) yline(.1 10 100 1000, lcolor(gs14) axis(2)) ytitle("Mean Total Exports (US$ million fob)", axis(2)) msymbol(smdiamond)
graph export "braxpmkt/eps/`sec'/avgscope-totexp-pcscope-allcountries.eps", replace
graph twoway scatter mean_goods_pls pctl, yaxis(1) yscale(log axis(1)) ylabel(1 2 4 16 64 256 1024, nogrid axis(1)) yline(1 4 16 256, lcolor(gs13) axis(1)) ytitle("Mean Number of Products Shipped", axis(1)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter wmean_gsales pctl, yaxis(2) yscale(log axis(2) range(.01 .1 1 10)) ylabel(.01 .1 1 10, nogrid axis(2)) yline(.01 .25 1, lcolor(gs14) axis(2)) ytitle("Mean Exports/Product (US$ million fob)", axis(2)) msymbol(smdiamond)
graph export "braxpmkt/eps/`sec'/avgscope-wgsales-pcscope-allcountries.eps", replace

}  // close `sec' loop

log close
set more off
