*! version 1.0.4  080ct2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.5  11apr2010  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 500m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/tex/allsec"
capture mkdir "braxpmkt/tex/manf-goods"
capture mkdir "braxpmkt/tex/manf-firms"
capture mkdir "braxpmkt/tex/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-stats-byfirmtype.log", replace


* workforce information by firm
tempfile rais
use firmid n_pis n_cnpj_estbl n_municipio ind* using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", clear
foreach var in n_pis n_cnpj_estbl n_municipio {
  gen ln_`var' = ln(`var')
  local lbl : variable label `var'
  label var ln_`var' "Log `lbl'"
  }
order firmid ln* ind*
sort firmid
compress
save `rais'


// 1. PRODUCT SALES STATISTICS FOR ALL COUNTRIES, BY FIRM'S DESTINATION COUNT TERCILE

foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {

foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" {

* Firm Types

use firmid cnae hs6dgt isic2 cnae wtfkey indoecd90 value wtf_exports wtf_imports wtf_brazexp wtf_output population gdp_cap_usd lndist contig comlang_off using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* worldwide export activity by firm
tempfile ww
preserve
  tempfile wwgoods
  collapse (sum) value, by(firmid hs6dgt) fast
  collapse (sum) gwwsales=value (count) wwgoods=value, by(firmid) fast
  replace gwwsales = gwwsales/1000000
  label var wwgoods "Worldwide No. of prod. (HS 6)"
  label var gwwsales "Worldwide exports (US$ mill)"
  sort firmid
  save `wwgoods'
restore, preserve
  tempfile wwdest
  gen byte indmerc = ( wtfkey==330320 | wtfkey==336000 | wtfkey==338580 )
  label var indmerc "Indic.: Mercosur member"
  collapse (sum) value (count) wwgoods=value, by(firmid wtfkey indoecd90 indmerc) fast
  replace value = value/1000000
  gen oecdsales = indoecd90*value
  gen mercsales = indmerc*value
  collapse (sum) wwsales=value oecdsales mercsales (count) wwdest=wtfkey, by(firmid) fast
  gen byte ind0oecd = (oecdsales==0)
  gen byte ind0merc = (mercsales==0)
  label var wwsales "Worldwide exports (US$ mill)"
  label var oecdsales "OECD exports (US$ mill)"
  label var mercsales "Mercosur exports (US$ mill)"
  label var wwdest "Worldwide No. of Destinations"
  label var ind0oecd "Indic.: Zero OECD exports"
  label var ind0merc "Indic.: Zero Mercosur exports"
  sort firmid
  save `wwdest'
restore, preserve
  use `wwgoods', clear
  merge firmid using `wwdest'
  qui count if _m~=3
  if `r(N)'>0  STOP
  gen _chk = wwsales - gwwsales
  qui summ _chk
  if abs(`r(sum)')>1e-10  STOP
  drop _m _chk gwwsales
  gen wwgsales=wwsales/wwgoods
  label var wwgsales "Wrldw. exp./prod. (US$ mill)"
  gen lnwwgoods = ln(wwgoods)
  label var lnwwgoods "Log Wrldw. No. of prod. (HS 6)"
  gen lnwwsales = ln(wwsales)
  label var lnwwsales "Log Wrldw. Exp. (US$ mill)"
  gen lnoecdsales = ln(oecdsales)
  replace lnoecdsales = 0 if ind0oecd==1
  label var lnoecdsales "Log nonzero OECD Exp. (US$ mill)"
  gen lnmercsales = ln(mercsales)
  replace lnmercsales = 0 if ind0merc==1
  label var lnmercsales "Log nonz. Mrcos. Exp. (US$ mill)"
  gen lnwwdest = ln(wwdest)
  label var lnwwdest "Log Wrldw. No. of Destinations"
  gen lnwwgsales = ln(wwgsales)
  label var lnwwgsales "Log Wrldw. Exp./prod. (US$ mill)"
  compress
  sort firmid
  save `ww'
restore

sort firmid
merge firmid using `ww'
tab _m
drop _m

sort firmid
merge firmid using `rais', nokeep
tab _m
drop _m

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina

collapse (sum) value, by(firmid cnae hs6dgt wwdest indcoll n_pis) fast  // collapse over destinations
collapse (sum) sumsales=value (count) goods=value, by(firmid cnae wwdest indcoll n_pis) fast  // collapse over goods
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per product (US$ mill fob)"

gen lngoods=ln(goods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(sumsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(gsales)
label var lngsales "Log exports/product (US$ mill fob)"
sort goods

// Cumulative Histograms by WW Destination Count Tercile and College-ducated Workers Tercile

sort wwdest firmid
gen _quantile = _n/_N
gen tercl_wwdest = 1 if _quantile <= 1/3
replace tercl_wwdest = 2 if tercl_wwdest==. & _quantile <= 2/3
replace tercl_wwdest = 3 if tercl_wwdest==. & _quantile <= 1
drop _quantile
label var tercl_wwdest "Tercile: Ww. No. of Dest."

sort indcoll firmid
gen _quantile = _n/_N
gen tercl_indcoll = 1 if _quantile <= 1/3
replace tercl_indcoll = 2 if tercl_indcoll==. & _quantile <= 2/3
replace tercl_indcoll = 3 if tercl_indcoll==. & _quantile <= 1
drop _quantile
label var tercl_indcoll "Tercile: College educ. wf. sh."

sort n_pis firmid
gen _quantile = _n/_N
gen tercl_n_pis = 1 if _quantile <= 1/3
replace tercl_n_pis = 2 if tercl_n_pis==. & _quantile <= 2/3
replace tercl_n_pis = 3 if tercl_n_pis==. & _quantile <= 1
drop _quantile
label var tercl_n_pis "Tercile: Employment"

forvalues tercl = 1/3 {

* tab goods
gen byte _dummy = 1

preserve
  keep if tercl_wwdest==`tercl'
  tabl2tex firmid, type(count) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_wwdest`tercl') fancy replace over nolog
  mat rename hist_wwdest`tercl'_tbl _hist`tercl'_tbl
  local rows = rowsof(_hist`tercl'_tbl)
  local tot = _hist`tercl'_tbl[`rows',2]
  mat _hist`tercl'_tbl = _hist`tercl'_tbl[1...,1] , _hist`tercl'_tbl[1...,2]/`tot'
restore, preserve
  keep if tercl_wwdest==`tercl'
  tabl2tex sumsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_wwdest`tercl') fancy replace over nolog
  local rows = rowsof(hist_wwdest`tercl'_tbl)
  mat _hist`tercl'_tbl = _hist`tercl'_tbl[1..`rows',1...] , hist_wwdest`tercl'_tbl
restore, preserve
  keep if tercl_wwdest==`tercl'
  tabl2tex gsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_wwdest`tercl') fancy replace over nolog
  mat hist_wwdest`tercl'_tbl = _hist`tercl'_tbl[1..`rows',1...] , hist_wwdest`tercl'_tbl
  mat drop _hist`tercl'_tbl
restore, preserve
  mat colnames hist_wwdest`tercl'_tbl = count freq mean_sumsales mean_gsales
  est2tex hist_wwdest`tercl', ready fancy p(braxpmkt/tex) replace dropall
  gen goods_pls = int(real(_rowname))
  mat cum_wwdest`tercl'_tbl = J(`rows',5,.)
  local rownames : rowfullnames hist_wwdest`tercl'_tbl
  mat colnames cum_wwdest`tercl'_tbl = count freq mean_sumsales mean_gsales mean_goods_pls
  mat rownames cum_wwdest`tercl'_tbl = or_more
  mat roweq cum_wwdest`tercl'_tbl = `rownames'
  forvalues i = 1/`rows' {
    qui summ count if _n>=`i', meanonly
    mat cum_wwdest`tercl'_tbl[`i',1] = `r(sum)'
    qui summ freq if _n>=`i', meanonly
    mat cum_wwdest`tercl'_tbl[`i',2] = `r(sum)'
    qui summ mean_sumsales if _n>=`i' [fw=count], meanonly
    mat cum_wwdest`tercl'_tbl[`i',3] = `r(mean)'
    qui summ mean_gsales if _n>=`i' [fw=count], meanonly
    mat cum_wwdest`tercl'_tbl[`i',4] = `r(mean)'
    qui summ goods_pls if _n>=`i' [fw=count], meanonly
    mat cum_wwdest`tercl'_tbl[`i',5] = `r(mean)'
    }
  est2tex cum_wwdest`tercl', ready fancy p(braxpmkt/tex) replace dropall

restore, preserve
  keep if tercl_indcoll==`tercl'
  tabl2tex firmid, type(count) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_indcoll`tercl') fancy replace over nolog
  mat rename hist_indcoll`tercl'_tbl _hist`tercl'_tbl
  local rows = rowsof(_hist`tercl'_tbl)
  local tot = _hist`tercl'_tbl[`rows',2]
  mat _hist`tercl'_tbl = _hist`tercl'_tbl[1...,1] , _hist`tercl'_tbl[1...,2]/`tot'
restore, preserve
  keep if tercl_indcoll==`tercl'
  tabl2tex sumsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_indcoll`tercl') fancy replace over nolog
  local rows = rowsof(hist_indcoll`tercl'_tbl)
  mat _hist`tercl'_tbl = _hist`tercl'_tbl[1..`rows',1...] , hist_indcoll`tercl'_tbl
restore, preserve
  keep if tercl_indcoll==`tercl'
  tabl2tex gsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_indcoll`tercl') fancy replace over nolog
  mat hist_indcoll`tercl'_tbl = _hist`tercl'_tbl[1..`rows',1...] , hist_indcoll`tercl'_tbl
  mat drop _hist`tercl'_tbl
restore, preserve
  mat colnames hist_indcoll`tercl'_tbl = count freq mean_sumsales mean_gsales
  est2tex hist_indcoll`tercl', ready fancy p(braxpmkt/tex) replace dropall
  gen goods_pls = int(real(_rowname))
  mat cum_indcoll`tercl'_tbl = J(`rows',5,.)
  local rownames : rowfullnames hist_indcoll`tercl'_tbl
  mat colnames cum_indcoll`tercl'_tbl = count freq mean_sumsales mean_gsales mean_goods_pls
  mat rownames cum_indcoll`tercl'_tbl = or_more
  mat roweq cum_indcoll`tercl'_tbl = `rownames'
  forvalues i = 1/`rows' {
    qui summ count if _n>=`i', meanonly
    mat cum_indcoll`tercl'_tbl[`i',1] = `r(sum)'
    qui summ freq if _n>=`i', meanonly
    mat cum_indcoll`tercl'_tbl[`i',2] = `r(sum)'
    qui summ mean_sumsales if _n>=`i' [fw=count], meanonly
    mat cum_indcoll`tercl'_tbl[`i',3] = `r(mean)'
    qui summ mean_gsales if _n>=`i' [fw=count], meanonly
    mat cum_indcoll`tercl'_tbl[`i',4] = `r(mean)'
    qui summ goods_pls if _n>=`i' [fw=count], meanonly
    mat cum_indcoll`tercl'_tbl[`i',5] = `r(mean)'
    }
  est2tex cum_indcoll`tercl', ready fancy p(braxpmkt/tex) replace dropall

restore, preserve
  keep if tercl_n_pis==`tercl'
  tabl2tex firmid, type(count) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_n_pis`tercl') fancy replace over nolog
  mat rename hist_n_pis`tercl'_tbl _hist`tercl'_tbl
  local rows = rowsof(_hist`tercl'_tbl)
  local tot = _hist`tercl'_tbl[`rows',2]
  mat _hist`tercl'_tbl = _hist`tercl'_tbl[1...,1] , _hist`tercl'_tbl[1...,2]/`tot'
restore, preserve
  keep if tercl_n_pis==`tercl'
  tabl2tex sumsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_n_pis`tercl') fancy replace over nolog
  local rows = rowsof(hist_n_pis`tercl'_tbl)
  mat _hist`tercl'_tbl = _hist`tercl'_tbl[1..`rows',1...] , hist_n_pis`tercl'_tbl
restore, preserve
  keep if tercl_n_pis==`tercl'
  tabl2tex gsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex) name(hist_n_pis`tercl') fancy replace over nolog
  mat hist_n_pis`tercl'_tbl = _hist`tercl'_tbl[1..`rows',1...] , hist_n_pis`tercl'_tbl
  mat drop _hist`tercl'_tbl
restore, preserve
  mat colnames hist_n_pis`tercl'_tbl = count freq mean_sumsales mean_gsales
  est2tex hist_n_pis`tercl', ready fancy p(braxpmkt/tex) replace dropall
  gen goods_pls = int(real(_rowname))
  mat cum_n_pis`tercl'_tbl = J(`rows',5,.)
  local rownames : rowfullnames hist_n_pis`tercl'_tbl
  mat colnames cum_n_pis`tercl'_tbl = count freq mean_sumsales mean_gsales mean_goods_pls
  mat rownames cum_n_pis`tercl'_tbl = or_more
  mat roweq cum_n_pis`tercl'_tbl = `rownames'
  forvalues i = 1/`rows' {
    qui summ count if _n>=`i', meanonly
    mat cum_n_pis`tercl'_tbl[`i',1] = `r(sum)'
    qui summ freq if _n>=`i', meanonly
    mat cum_n_pis`tercl'_tbl[`i',2] = `r(sum)'
    qui summ mean_sumsales if _n>=`i' [fw=count], meanonly
    mat cum_n_pis`tercl'_tbl[`i',3] = `r(mean)'
    qui summ mean_gsales if _n>=`i' [fw=count], meanonly
    mat cum_n_pis`tercl'_tbl[`i',4] = `r(mean)'
    qui summ goods_pls if _n>=`i' [fw=count], meanonly
    mat cum_n_pis`tercl'_tbl[`i',5] = `r(mean)'
    }
  est2tex cum_n_pis`tercl', ready fancy p(braxpmkt/tex) replace dropall
restore

drop _dummy

}  // close `tercl' loop

* Cumulative Histograms by WW Destination Count Tercile
forvalues tercl = 1/3 {
  if `tercl'==1  {
    use "braxpmkt/tex/cum_wwdest`tercl'_tbl.dta", clear
    gen long tercl = `tercl'
    erase "braxpmkt/tex/hist_wwdest`tercl'_tbl.dta"
    erase "braxpmkt/tex/cum_wwdest`tercl'_tbl.dta"
    erase "braxpmkt/tex/hist_wwdest`tercl'.tex"
    erase "braxpmkt/tex/cum_wwdest`tercl'.tex"
    }
  else {
    append using "braxpmkt/tex/cum_wwdest`tercl'_tbl.dta"
    replace tercl = `tercl' if tercl==.
    erase "braxpmkt/tex/hist_wwdest`tercl'_tbl.dta"
    erase "braxpmkt/tex/cum_wwdest`tercl'_tbl.dta"
    erase "braxpmkt/tex/hist_wwdest`tercl'.tex"
    erase "braxpmkt/tex/cum_wwdest`tercl'.tex"
    }
  }
gen goods_pls = int(real(substr(_rowname,1,index(_rowname,":")-1)))
gen wmean_gsales = mean_sumsales/mean_goods_pls
gen pctl = freq*100
order tercl goods_pls _rowname count freq mean_sumsales
reshape wide count freq mean_sumsales mean_gsales wmean_gsales mean_goods_pls pctl, i(goods_pls _rowname) j(tercl)
forvalues tercl = 1/3 {
  if `tercl'==1  local tercstr "1st"
  if `tercl'==2  local tercstr "2nd"
  if `tercl'==3  local tercstr "3rd"
  label var count`tercl' "`tercstr' Tercl.: # of Firms with min. scope"
  label var freq`tercl' "`tercstr' Tercl.: Share of Firms with min. scope"
  label var mean_sumsales`tercl' "`tercstr' Tercl.: Firms' Avg. Tot. Exports"
  label var mean_gsales`tercl' "`tercstr' Tercl.: Firms' Avg. Prod. Scale"
  label var wmean_gsales`tercl' "`tercstr' Tercl.: Firms' Avg. Prod. Scale"
  label var mean_goods_pls`tercl' "`tercstr' Tercl.: Firms' Avg. Exp. Scope"
  label var pctl`tercl' "`tercstr' Tercl.: Percentile of Firm with min. scope"
  }
graph twoway scatter mean_goods_pls1 pctl1, yaxis(1) yscale(log axis(1)) ylabel(1 2 4 16 64 256 1024, nogrid axis(1)) yline(1 4 16 256, lcolor(gs13) axis(1)) ytitle("Mean Number of Products Shipped", axis(1)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter mean_goods_pls2 pctl2, msymbol(smcircle_hollow) mcolor(black) || scatter mean_goods_pls3 pctl3, msymbol(smcircle)
graph export "braxpmkt/eps/`sec'/bywwdest-avgscope-pcscope-`region'.eps", replace
graph twoway scatter mean_sumsales1 pctl1, yaxis(2) yscale(log axis(2)) ylabel(1 10 100 1000, nogrid axis(2)) yline(10 100 1000, lcolor(gs14) axis(2)) ytitle("Mean Total Exports (US$ million fob)", axis(2)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter mean_sumsales2 pctl2, yaxis(2) msymbol(smcircle) || scatter mean_sumsales3 pctl3, yaxis(2) msymbol(smcircle_hollow) mcolor(black)
graph export "braxpmkt/eps/`sec'/bywwdest-totexp-pcscope-`region'.eps", replace
graph twoway scatter wmean_gsales1 pctl1, yaxis(2) yscale(log axis(2) range(.01 .1 1 10)) ylabel(.01 .1 1 10, nogrid axis(2)) yline(.01 .25 1, lcolor(gs14) axis(2)) ytitle("Mean Exports/Product (US$ million fob)", axis(2)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter wmean_gsales2 pctl2, yaxis(2) msymbol(smcircle) || scatter wmean_gsales3 pctl3, yaxis(2) msymbol(smcircle_hollow) mcolor(black)
graph export "braxpmkt/eps/`sec'/bywwdest-wgsales-pcscope-`region'.eps", replace

* Cumulative Histograms by College-ducated Workers Tercile
forvalues tercl = 1/3 {
  if `tercl'==1  {
    use "braxpmkt/tex/cum_indcoll`tercl'_tbl.dta", clear
    gen long tercl = `tercl'
    erase "braxpmkt/tex/hist_indcoll`tercl'_tbl.dta"
    erase "braxpmkt/tex/cum_indcoll`tercl'_tbl.dta"
    erase "braxpmkt/tex/hist_indcoll`tercl'.tex"
    erase "braxpmkt/tex/cum_indcoll`tercl'.tex"
    }
  else {
    append using "braxpmkt/tex/cum_indcoll`tercl'_tbl.dta"
    replace tercl = `tercl' if tercl==.
    erase "braxpmkt/tex/hist_indcoll`tercl'_tbl.dta"
    erase "braxpmkt/tex/cum_indcoll`tercl'_tbl.dta"
    erase "braxpmkt/tex/hist_indcoll`tercl'.tex"
    erase "braxpmkt/tex/cum_indcoll`tercl'.tex"
    }
  }
gen goods_pls = int(real(substr(_rowname,1,index(_rowname,":")-1)))
gen wmean_gsales = mean_sumsales/mean_goods_pls
gen pctl = freq*100
order tercl goods_pls _rowname count freq mean_sumsales
reshape wide count freq mean_sumsales mean_gsales wmean_gsales mean_goods_pls pctl, i(goods_pls _rowname) j(tercl)
forvalues tercl = 1/3 {
  if `tercl'==1  local tercstr "1st"
  if `tercl'==2  local tercstr "2nd"
  if `tercl'==3  local tercstr "3rd"
  label var count`tercl' "`tercstr' Tercl.: # of Firms with min. scope"
  label var freq`tercl' "`tercstr' Tercl.: Share of Firms with min. scope"
  label var mean_sumsales`tercl' "`tercstr' Tercl.: Firms' Avg. Tot. Exports"
  label var mean_gsales`tercl' "`tercstr' Tercl.: Firms' Avg. Prod. Scale"
  label var wmean_gsales`tercl' "`tercstr' Tercl.: Firms' Avg. Prod. Scale"
  label var mean_goods_pls`tercl' "`tercstr' Tercl.: Firms' Avg. Exp. Scope"
  label var pctl`tercl' "`tercstr' Tercl.: Percentile of Firm with min. scope"
  }
graph twoway scatter mean_goods_pls1 pctl1, yaxis(1) yscale(log axis(1)) ylabel(1 2 4 16 64 256 1024, nogrid axis(1)) yline(1 4 16 256, lcolor(gs13) axis(1)) ytitle("Mean Number of Products Shipped", axis(1)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter mean_goods_pls2 pctl2, msymbol(smcircle) || scatter mean_goods_pls3 pctl3, msymbol(smcircle_hollow) mcolor(black)
graph export "braxpmkt/eps/`sec'/byindcoll-avgscope-pcscope-`region'.eps", replace
graph twoway scatter mean_sumsales1 pctl1, yaxis(2) yscale(log axis(2)) ylabel(1 10 100 1000, nogrid axis(2)) yline(10 100 1000, lcolor(gs14) axis(2)) ytitle("Mean Total Exports (US$ million fob)", axis(2)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter mean_sumsales2 pctl2, yaxis(2) msymbol(smcircle) || scatter mean_sumsales3 pctl3, yaxis(2) msymbol(smcircle_hollow) mcolor(black)
graph export "braxpmkt/eps/`sec'/byindcoll-totexp-pcscope-`region'.eps", replace
graph twoway scatter wmean_gsales1 pctl1, yaxis(2) yscale(log axis(2) range(.01 .1 1 10)) ylabel(.01 .1 1 10, nogrid axis(2)) yline(.01 .25 1, lcolor(gs14) axis(2)) ytitle("Mean Exports/Product (US$ million fob)", axis(2)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter wmean_gsales2 pctl2, yaxis(2) msymbol(smcircle) || scatter wmean_gsales3 pctl3, yaxis(2) msymbol(smcircle_hollow) mcolor(black)
graph export "braxpmkt/eps/`sec'/byindcoll-wgsales-pcscope-`region'.eps", replace

* Cumulative Histograms by Employment Tercile
forvalues tercl = 1/3 {
  if `tercl'==1  {
    use "braxpmkt/tex/cum_n_pis`tercl'_tbl.dta", clear
    gen long tercl = `tercl'
    erase "braxpmkt/tex/hist_n_pis`tercl'_tbl.dta"
    erase "braxpmkt/tex/cum_n_pis`tercl'_tbl.dta"
    erase "braxpmkt/tex/hist_n_pis`tercl'.tex"
    erase "braxpmkt/tex/cum_n_pis`tercl'.tex"
    }
  else {
    append using "braxpmkt/tex/cum_n_pis`tercl'_tbl.dta"
    replace tercl = `tercl' if tercl==.
    erase "braxpmkt/tex/hist_n_pis`tercl'_tbl.dta"
    erase "braxpmkt/tex/cum_n_pis`tercl'_tbl.dta"
    erase "braxpmkt/tex/hist_n_pis`tercl'.tex"
    erase "braxpmkt/tex/cum_n_pis`tercl'.tex"
    }
  }
gen goods_pls = int(real(substr(_rowname,1,index(_rowname,":")-1)))
gen wmean_gsales = mean_sumsales/mean_goods_pls
gen pctl = freq*100
order tercl goods_pls _rowname count freq mean_sumsales
reshape wide count freq mean_sumsales mean_gsales wmean_gsales mean_goods_pls pctl, i(goods_pls _rowname) j(tercl)
forvalues tercl = 1/3 {
  if `tercl'==1  local tercstr "1st"
  if `tercl'==2  local tercstr "2nd"
  if `tercl'==3  local tercstr "3rd"
  label var count`tercl' "`tercstr' Tercl.: # of Firms with min. scope"
  label var freq`tercl' "`tercstr' Tercl.: Share of Firms with min. scope"
  label var mean_sumsales`tercl' "`tercstr' Tercl.: Firms' Avg. Tot. Exports"
  label var mean_gsales`tercl' "`tercstr' Tercl.: Firms' Avg. Prod. Scale"
  label var wmean_gsales`tercl' "`tercstr' Tercl.: Firms' Avg. Prod. Scale"
  label var mean_goods_pls`tercl' "`tercstr' Tercl.: Firms' Avg. Exp. Scope"
  label var pctl`tercl' "`tercstr' Tercl.: Percentile of Firm with min. scope"
  }
graph twoway scatter mean_goods_pls1 pctl1, yaxis(1) yscale(log axis(1)) ylabel(1 2 4 16 64 256 1024, nogrid axis(1)) yline(1 4 16 256, lcolor(gs13) axis(1)) ytitle("Mean Number of Products Shipped", axis(1)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter mean_goods_pls2 pctl2, msymbol(smcircle) || scatter mean_goods_pls3 pctl3, msymbol(smcircle_hollow) mcolor(black)
graph export "braxpmkt/eps/`sec'/bynpis-avgscope-pcscope-`region'.eps", replace
graph twoway scatter mean_sumsales1 pctl1, yaxis(2) yscale(log axis(2)) ylabel(1 10 100 1000, nogrid axis(2)) yline(10 100 1000, lcolor(gs14) axis(2)) ytitle("Mean Total Exports (US$ million fob)", axis(2)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter mean_sumsales2 pctl2, yaxis(2) msymbol(smcircle) || scatter mean_sumsales3 pctl3, yaxis(2) msymbol(smcircle_hollow) mcolor(black)
graph export "braxpmkt/eps/`sec'/bynpis-totexp-pcscope-`region'.eps", replace
graph twoway scatter wmean_gsales1 pctl1, yaxis(2) yscale(log axis(2) range(.01 .1 1 10)) ylabel(.01 .1 1 10, nogrid axis(2)) yline(.01 .25 1, lcolor(gs14) axis(2)) ytitle("Mean Exports/Product (US$ million fob)", axis(2)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter wmean_gsales2 pctl2, yaxis(2) msymbol(smcircle) || scatter wmean_gsales3 pctl3, yaxis(2) msymbol(smcircle_hollow) mcolor(black)
graph export "braxpmkt/eps/`sec'/bynpis-wgsales-pcscope-`region'.eps", replace

}  // close `region' loop

}  // close `sec' loop

log close
set more off
