*! version 1.3.3  05jul2011  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 100m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/manf-firms-ncm8"
capture mkdir "braxpmkt/eps/comrc-firms-ncm8"
capture mkdir "braxpmkt/tex/manf-firms-ncm8"
capture mkdir "braxpmkt/tex/comrc-firms-ncm8"

capture log close
log using "braxpmkt/logs/prodsales-stats-ncm8.log", replace


// OVERVIEW STATISTICS BY SECTOR

foreach sec in "manf-firms" "comrc-firms" {

// Major export destinations in 2000

use firmid cnae ncm8dgt isic2 wtfkey value using "braxpmkt/secex/prodsales-data-2000-ncm8.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms
keep if wtfkey~=0
collapse (sum) value, by(wtfkey ncm8dgt)
collapse (sum) value (count) goods=ncm8dgt, by(wtfkey)
replace value = value/1000000
qui summ value, meanonly
gen percsh = value/`r(sum)'
label var value "Exports (US$ mill fob)"
label var goods "Exporter scope (NCM 8-digit)"
label var percsh "Share in total exports (%)"
order wtfkey value percsh goods
gsort -value
list in 1/25

// Major export products in 2000

use firmid cnae ncm8dgt isic2 wtfkey value using "braxpmkt/secex/prodsales-data-2000-ncm8.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms
keep if wtfkey~=0
collapse (sum) value, by(wtfkey ncm8dgt)
collapse (sum) value (count) dests=wtfkey, by(ncm8dgt)
replace value = value/1000000
qui summ value, meanonly
gen percsh = value/`r(sum)'
label var value "Exports (US$ mill fob)"
label var dests "Number of destinations"
label var percsh "Share in total exports (%)"
order ncm8dgt value percsh dests
gsort -value
list in 1/25

} // close `sec' loop


// PRODUCT SALES STATISTICS BY SECTOR AND REGION

foreach region in "world" "usa" "argentina" {

foreach sec in "manf-firms" "comrc-firms" {


// Product rankings

use firmid cnae ncm8dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000-ncm8.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina
if "`region'"=="top20th" & "`sec'"=="allsec"      keep if wtfkey==557560 // exports to Switz.Liecht
if "`region'"=="top20th" & "`sec'"=="manf-goods"  keep if wtfkey==586430 // exports to Russian Fed
if "`region'"=="top20th" & "`sec'"=="manf-firms"  keep if wtfkey==481560 // exports to China
if "`region'"=="top20th" & "`sec'"=="srvc-firms"  keep if wtfkey==368960 // exports to US NES
if "`region'"=="top20th" & "`sec'"=="comrc-firms" keep if wtfkey==211240 // exports to Canada
if "`region'"=="top20th" & "`sec'"=="manf-ekk"    keep if wtfkey==454100 // exports to Korea Rep.
if "`region'"=="top25th" & "`sec'"=="allsec"      keep if wtfkey==330680 // exports to Bolivia
if "`region'"=="top25th" & "`sec'"=="manf-goods"  keep if wtfkey==710360 // exports to Australia
if "`region'"=="top25th" & "`sec'"=="manf-firms"  keep if wtfkey==586430 // exports to Russian Fed
if "`region'"=="top25th" & "`sec'"=="srvc-firms"  keep if wtfkey==453440 // exports to China HK SAR
if "`region'"=="top25th" & "`sec'"=="comrc-firms" keep if wtfkey==352140 // exports to Dominican Rp
if "`region'"=="top25th" & "`sec'"=="manf-ekk"    keep if wtfkey==446820 // exports to Saudi Arabia

collapse (sum) value, by(firmid cnae ncm8dgt)
replace value = value/1000000
label var value "Exports (US$ mill fob)"
egen goods = count(ncm8dgt), by(firmid)
label var goods "Exporter scope (NCM 8-digit)"
gsort firmid -value
by firmid: gen currnum=_n
label var currnum "Current product rank (NCM 8-digit)"
compress
preserve
  tabl2tex value if goods<=10 & currnum<=10, type(mean) r(goods) c(currnum) p(braxpmkt/tex/`sec'-ncm8) name(meanexp_`region') fancy replace over nolog digits(3)
restore, preserve
  tabl2tex value if goods<=10 & currnum<=10, type(sd) r(goods) c(currnum) p(braxpmkt/tex/`sec'-ncm8) name(sdexp_`region') fancy replace over nolog digits(3)
restore, preserve
  tabl2tex value if goods<=10 & currnum<=10, type(count) r(goods) c(currnum) p(braxpmkt/tex/`sec'-ncm8) name(countexp_`region') fancy replace over nolog digits(3)
restore
* reshape wide value, i(firmid cnae goods) j(currnum)
* graph bar (mean) value1-value10 if value10~=., ytitle("Exports (US$ mill fob)") graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs9)) bar(6, bcolor(gs14)) bar(7, bcolor(gs12)) bar(8, bcolor(gs10)) bar(9, bcolor(gs9)) bar(10, bcolor(gs14)) bar(11, bcolor(gs12)) bar(12, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
* graph bar (mean) value1-value10, ytitle("Exports (US$ mill fob)") graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs9)) bar(6, bcolor(gs14)) bar(7, bcolor(gs12)) bar(8, bcolor(gs10)) bar(9, bcolor(gs9)) bar(10, bcolor(gs14)) bar(11, bcolor(gs12)) bar(12, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */


// Data preparation for scale-scope statistics

use firmid cnae ncm8dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000-ncm8.dta", clear
drop if value==0
merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
keep firmid cnae ncm8dgt isic2 wtfkey value indoecd90 n_pis

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina
if "`region'"=="top20th" & "`sec'"=="allsec"      keep if wtfkey==557560 // exports to Switz.Liecht
if "`region'"=="top20th" & "`sec'"=="manf-goods"  keep if wtfkey==586430 // exports to Russian Fed
if "`region'"=="top20th" & "`sec'"=="manf-firms"  keep if wtfkey==481560 // exports to China
if "`region'"=="top20th" & "`sec'"=="srvc-firms"  keep if wtfkey==368960 // exports to US NES
if "`region'"=="top20th" & "`sec'"=="comrc-firms" keep if wtfkey==211240 // exports to Canada
if "`region'"=="top20th" & "`sec'"=="manf-ekk"    keep if wtfkey==454100 // exports to Korea Rep.
if "`region'"=="top25th" & "`sec'"=="allsec"      keep if wtfkey==330680 // exports to Bolivia
if "`region'"=="top25th" & "`sec'"=="manf-goods"  keep if wtfkey==710360 // exports to Australia
if "`region'"=="top25th" & "`sec'"=="manf-firms"  keep if wtfkey==586430 // exports to Russian Fed
if "`region'"=="top25th" & "`sec'"=="srvc-firms"  keep if wtfkey==453440 // exports to China HK SAR
if "`region'"=="top25th" & "`sec'"=="comrc-firms" keep if wtfkey==352140 // exports to Dominican Rp
if "`region'"=="top25th" & "`sec'"=="manf-ekk"    keep if wtfkey==446820 // exports to Saudi Arabia

* Relevance Statistics (on the go)
mat relstats = J(16,1,.)
mat rownames relstats = no_obs no_dest no_firms no_varieties median_vartyvalue mean_vartyvalue median_scope median_sumsales median_gsales mean_scope mean_sumsales mean_gsales wmean_gsales pcsumsal_singlgood pcsumsal_multgood_1 pcsumsal_multgood_2plus
mat colnames relstats = `region'

qui count  // number of observations: `no_obs'
mat relstats[rownumb(relstats,"no_obs"),1] = `r(N)'
sort wtfkey
qui count if wtfkey~=wtfkey[_n-1]  // number of countries: `no_dest'
mat relstats[rownumb(relstats,"no_dest"),1] = `r(N)'
sort firmid
qui count if firmid~=firmid[_n-1]  // number of firms: `no_firms'
mat relstats[rownumb(relstats,"no_firms"),1] = `r(N)'

collapse (sum) value, by(firmid n_pis cnae ncm8dgt) fast  // collapse over destinations
sort firmid ncm8dgt
qui count  // number of varieties: `no_varieties'
mat relstats[rownumb(relstats,"no_varieties"),1] = `r(N)'
qui summ value, detail  // median and mean sales value of variety: `median_vartyvalue', `mean_vartyvalue'
mat relstats[rownumb(relstats,"median_vartyvalue"),1] = `r(p50)'/1000000
mat relstats[rownumb(relstats,"mean_vartyvalue"),1] = `r(mean)'/1000000

disp in green "Total sales T: " in yellow %9.2f `r(sum)'/1000000
disp in green "Decomposed as M x tbar = T:" in yellow %9.0f relstats[rownumb(relstats,"no_varieties"),1] in green " x" in yellow %9.2f relstats[rownumb(relstats,"mean_vartyvalue"),1] in green " = " in yellow %9.2f relstats[rownumb(relstats,"no_varieties"),1]*relstats[rownumb(relstats,"mean_vartyvalue"),1]
disp in green "       (where N x Gbar = M:" in yellow %9.0f relstats[rownumb(relstats,"no_firms"),1] in green " x" in yellow %9.2f relstats[rownumb(relstats,"no_varieties"),1]/relstats[rownumb(relstats,"no_firms"),1] in green " = " in yellow %9.0f relstats[rownumb(relstats,"no_varieties"),1] in green ")"

gsort firmid -value
by firmid: gen gndidx = _n
egen goods = max(gndidx), by(firmid)
label var gndidx "Product rank (NCM 8-digit)"
label var goods  "Exporter scope (NCM 8-digit)"
qui summ value, meanonly
local totsum = `r(sum)'
qui summ value if goods==1, meanonly  // pcsumsal_singlgood: share of total exports from single-product firms
mat relstats[rownumb(relstats,"pcsumsal_singlgood"),1] = `r(sum)'/`totsum'
qui summ value if goods>1 & gndidx==1, meanonly  // pcsumsal_multgood_1: share of total exports from first products of multi-product firms
mat relstats[rownumb(relstats,"pcsumsal_multgood_1"),1] = `r(sum)'/`totsum'
qui summ value if goods>1 & gndidx>1, meanonly  // pcsumsal_multgood_2plus: share of total exports from second to Gth product of multi-product firms
mat relstats[rownumb(relstats,"pcsumsal_multgood_2plus"),1] = `r(sum)'/`totsum'

collapse (sum) sumsales=value (count) goods=value, by(firmid n_pis cnae) fast  // collapse over goods
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (NCM 8-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per product (US$ mill fob)"

qui summ goods, detail
mat relstats[rownumb(relstats,"median_scope"),1] = `r(p50)'
mat relstats[rownumb(relstats,"mean_scope"),1] = `r(mean)'

qui summ gsales [fw=goods], meanonly
mat relstats[rownumb(relstats,"wmean_gsales"),1] = `r(mean)'

qui summ gsales, detail
mat relstats[rownumb(relstats,"median_gsales"),1] = `r(p50)'
mat relstats[rownumb(relstats,"mean_gsales"),1] = `r(mean)'

qui summ sumsales, detail
mat relstats[rownumb(relstats,"median_sumsales"),1] = `r(p50)'
mat relstats[rownumb(relstats,"mean_sumsales"),1] = `r(mean)'

disp in green "Total sales T: " in yellow %9.2f `r(sum)'
disp in green "Decomposed as N x Tbar = T:" in yellow %9.0f relstats[rownumb(relstats,"no_firms"),1] in green " x" in yellow %9.2f relstats[rownumb(relstats,"mean_sumsales"),1] in green " = " in yellow %9.2f relstats[rownumb(relstats,"no_firms"),1]*relstats[rownumb(relstats,"mean_sumsales"),1]
disp in green "Decomposed as N x Gbar x tbar = T:" in yellow %9.0f relstats[rownumb(relstats,"no_firms"),1] in green " x" in yellow %9.2f relstats[rownumb(relstats,"mean_scope"),1] in green " x" in yellow %9.2f relstats[rownumb(relstats,"wmean_gsales"),1]  in green " = " in yellow %9.2f relstats[rownumb(relstats,"no_firms"),1]*relstats[rownumb(relstats,"mean_scope"),1]*relstats[rownumb(relstats,"wmean_gsales"),1]
if int(`r(sum)')~=int(relstats[rownumb(relstats,"no_firms"),1]*relstats[rownumb(relstats,"mean_scope"),1]*relstats[rownumb(relstats,"wmean_gsales"),1])  STOP

preserve
  mat rename relstats relstats_`region'_tbl
  est2tex relstats_`region', ready fancy p(braxpmkt/tex/`sec'-ncm8) replace dropall
  mat drop relstats_`region'_tbl
restore 

gen lngoods=ln(goods)
label var lngoods "Log number of products (NCM 8)"
gen lnsumsales=ln(sumsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(gsales)
label var lngsales "Log exports/product (US$ mill fob)"
sort goods

egen ranksales=rank(sumsales), unique
label var ranksales "Rank of total exports"
egen rankgoods=rank(goods), unique
label var rankgoods "Rank of number of products"
egen rankgsales=rank(gsales), unique
label var rankgsales "Rank of mean exports per product"
egen ranknpis=rank(n_pis), unique
label var ranknpis "Rank of employment"

sort firmid
count if firmid~=firmid[_n-1]
local firms = `r(N)'
gen pcsales=ranksales/`firms'
label var pcsales  "Firm percentile: Tot. exports"
gen pcgoods=rankgoods/`firms'
label var pcgoods  "Firm percentile: No. of products"
gen pcgsales=rankgsales/`firms'
label var pcgsales "Firm percentile: Exports/product"
* egen mdgsales=median(gsales), by(goods)
* label var mdgsales "Median of mean exports per product"
sort firmid
count if firmid~=firmid[_n-1] & ranknpis~=.
local raisfirms = `r(N)'
gen pcnpis=ranknpis/`raisfirms'
label var pcnpis "Firm percentile: Employment"


// Cumulative Histograms for Total-exports percentiles

gen _pctlval = int(pcsales*100+1)
replace _pctlval = 100 if _pctlval==101
gen byte _dummy = 1
preserve
  tabl2tex firmid, type(count) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec'-ncm8) name(histT_`region') fancy replace over nolog
  mat rename histT_`region'_tbl _hist`region'_tbl
  local rows = rowsof(_hist`region'_tbl)
  local tot = _hist`region'_tbl[`rows',2]
  mat _hist`region'_tbl = _hist`region'_tbl[1...,1] , _hist`region'_tbl[1...,2]/`tot'
restore, preserve
  tabl2tex sumsales, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec'-ncm8) name(histT_`region') fancy replace over nolog
  local rows = rowsof(histT_`region'_tbl)
  mat _hist`region'_tbl = _hist`region'_tbl[1..`rows',1...] , histT_`region'_tbl
restore, preserve
  tabl2tex gsales, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec'-ncm8) name(histT_`region') fancy replace over nolog
  local rows = rowsof(histT_`region'_tbl)
  mat _hist`region'_tbl = _hist`region'_tbl[1..`rows',1...] , histT_`region'_tbl
restore, preserve
  tabl2tex goods, type(mean) r(_pctlval) c(_dummy) p(braxpmkt/tex/`sec'-ncm8) name(histT_`region') fancy replace over nolog
  local rows = rowsof(histT_`region'_tbl)
  mat histT_`region'_tbl = _hist`region'_tbl[1..`rows',1...] , histT_`region'_tbl
  mat drop _hist`region'_tbl
restore, preserve
  mat colnames histT_`region'_tbl = count freq mean_sumsales mean_gsales mean_goods
  est2tex histT_`region', ready fancy p(braxpmkt/tex/`sec'-ncm8) replace dropall
  mat cumT_`region'_tbl = J(`rows',5,.)
  local rownames : rowfullnames histT_`region'_tbl
  mat colnames cumT_`region'_tbl = count freq mean_sumsales mean_gsales mean_goods
  mat rownames cumT_`region'_tbl = or_higher
  mat roweq cumT_`region'_tbl = `rownames'
  forvalues i = 1/`rows' {
    qui summ count if _n>=`i', meanonly
    mat cumT_`region'_tbl[`i',1] = `r(sum)'
    qui summ freq if _n>=`i', meanonly
    mat cumT_`region'_tbl[`i',2] = `r(sum)'
    qui summ mean_sumsales if _n>=`i' [fw=count], meanonly
    mat cumT_`region'_tbl[`i',3] = `r(mean)'
    qui summ mean_gsales if _n>=`i' [fw=count], meanonly
    mat cumT_`region'_tbl[`i',4] = `r(mean)'
    qui summ mean_goods if _n>=`i' [fw=count], meanonly
    mat cumT_`region'_tbl[`i',5] = `r(mean)'
    }
  est2tex cumT_`region', ready fancy p(braxpmkt/tex/`sec'-ncm8) replace dropall
  gen wmean_gsales = mean_sumsales/mean_goods
  gen pctl = freq*100
  replace mean_gsales = mean_gsales*1000
  replace wmean_gsales = wmean_gsales*1000
  order _rowname mean_goods count freq mean_sumsales
  label var mean_goods "Mean Exporter Scope"
  label var count "# of Firms with min. sales"
  label var freq "Share of Firms with min. sales"
  label var mean_sumsales "Firms' Mean Total Exports"
  label var mean_gsales "Firms' Mean Product Scale" // (US$ thsd fob)
  label var wmean_gsales "Firms' Mean Product Scale" // (US$ thsd fob)
  label var pctl "Cumulative Percentile of Firms"
  graph twoway scatter mean_sumsales pctl, yaxis(1) yscale(log axis(1) range(1 1000)) ylabel(1 10 100 1000, nogrid axis(1)) yline(1 10 100 1000, lcolor(gs14) axis(1)) ytitle("Mean Exports (US$ million fob)", axis(1)) msymbol(smsquare_hollow) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj)
  graph export "braxpmkt/eps/`sec'-ncm8/avgsumsales-pcsales-`region'.eps", replace
  if "`sec'"=="manf-firms" & ( "`region'"=="usa" | "`region'"=="argentina" ) save "braxpmkt/eps/`sec'-ncm8/avgsumsales-pcsales-`region'", replace
  foreach i in 1 50 90 95 {
    local ypos`i' = mean_goods[`i']*1.1
    local xpos`i' = pctl[`i']
    if `ypos`i''==.  local ypos`i'=0
    if `xpos`i''==.  local xpos`i'=0
    }
  graph twoway scatter mean_goods pctl, yaxis(1) yscale(log axis(1)) ylabel(1 2 4 16 64, nogrid axis(1)) yline(1 2 4 16 64, lcolor(gs13) axis(1)) ytitle("Mean Number of Products", axis(1)) msymbol(smcircle_hollow) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter mean_sumsales pctl, yaxis(2) yscale(log axis(2)) ylabel(1 10 100 1000, nogrid axis(2)) yline(10 100 1000, lcolor(gs14) axis(2)) ytitle("Mean Total Exports (US$ million fob)", axis(2)) msymbol(smsquare_hollow) text(`ypos1' `xpos1' "p>=1" `ypos50' `xpos50' "p>=50" `ypos90' `xpos90' "p>=90" `ypos95' `xpos95' "p>=95", placement(top) size(vsmall))
  graph export "braxpmkt/eps/`sec'-ncm8/avgscope-totexp-pcsales-`region'.eps", replace
  if "`sec'"=="manf-firms" & ( "`region'"=="usa" | "`region'"=="argentina" ) save "braxpmkt/eps/`sec'-ncm8/avgscope-totexp-pcsales-`region'", replace
  foreach i in 1 50 90 95 {
    local ypos`i' = mean_goods[`i']*.9
    local xpos`i' = pctl[`i']
    if `ypos`i''==.  local ypos`i'=0
    if `xpos`i''==.  local xpos`i'=0
    }
  graph twoway scatter mean_goods pctl, yaxis(1) yscale(log axis(1) range(1 10000)) ylabel(1 2 4 16 64, nogrid axis(1)) yline(1 2 4 16 64, lcolor(gs13) axis(1)) ytitle("Mean Number of Products", axis(1)) msymbol(smcircle_hollow) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter wmean_gsales pctl, yaxis(2) yscale(log axis(2) range(1 10000)) ylabel(100 1000 10000, nogrid axis(2)) yline(1 100 1000 10000, lcolor(gs14) axis(2)) ytitle("Mean Exports/Product (US$ thsd fob)", axis(2)) msymbol(smsquare_hollow) text(`ypos1' `xpos1' "p>=1" `ypos50' `xpos50' "p>=50" `ypos90' `xpos90' "p>=90" `ypos95' `xpos95' "p>=95", placement(bottom) size(vsmall))
  graph export "braxpmkt/eps/`sec'-ncm8/avgscope-wgsales-pcsales-`region'.eps", replace
  if "`sec'"=="manf-firms" & ( "`region'"=="usa" | "`region'"=="argentina" ) save "braxpmkt/eps/`sec'-ncm8/avgscope-wgsales-pcsales-`region'", replace
  graph twoway scatter mean_goods pctl, yaxis(1) yscale(log axis(1) range(1 10000)) ylabel(1 2 4 16 64, nogrid axis(1)) yline(1 2 4 16 64, lcolor(gs13) axis(1)) ytitle("Mean Number of Products", axis(1)) msymbol(smcircle_hollow) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter mean_gsales pctl, yaxis(2) yscale(log axis(2) range(1 10000)) ylabel(100 1000 10000, nogrid axis(2)) yline(1 100 1000 10000, lcolor(gs14) axis(2)) ytitle("Mean Exports/Product (US$ thsd fob)", axis(2)) msymbol(smsquare_hollow) text(`ypos1' `xpos1' "p>=1" `ypos50' `xpos50' "p>=50" `ypos90' `xpos90' "p>=90" `ypos95' `xpos95' "p>=95", placement(bottom) size(vsmall))
  graph export "braxpmkt/eps/`sec'-ncm8/avgscope-gsales-pcsales-`region'.eps", replace
restore
drop _dummy


// Cumulative Histograms for Scope percentiles

tab goods
gen byte _dummy = 1
preserve
  tabl2tex firmid, type(count) r(goods) c(_dummy) p(braxpmkt/tex/`sec'-ncm8) name(hist_`region') fancy replace over nolog
  mat rename hist_`region'_tbl _hist`region'_tbl
  local rows = rowsof(_hist`region'_tbl)
  local tot = _hist`region'_tbl[`rows',2]
  mat _hist`region'_tbl = _hist`region'_tbl[1...,1] , _hist`region'_tbl[1...,2]/`tot'
restore, preserve
  tabl2tex sumsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex/`sec'-ncm8) name(hist_`region') fancy replace over nolog
  local rows = rowsof(hist_`region'_tbl)
  mat _hist`region'_tbl = _hist`region'_tbl[1..`rows',1...] , hist_`region'_tbl
restore, preserve
  tabl2tex gsales, type(mean) r(goods) c(_dummy) p(braxpmkt/tex/`sec'-ncm8) name(hist_`region') fancy replace over nolog
  mat hist_`region'_tbl = _hist`region'_tbl[1..`rows',1...] , hist_`region'_tbl
  mat drop _hist`region'_tbl
restore, preserve
  mat colnames hist_`region'_tbl = count freq mean_sumsales mean_gsales
  est2tex hist_`region', ready fancy p(braxpmkt/tex/`sec'-ncm8) replace dropall
  gen goods_pls = int(real(_rowname))
  mat cum_`region'_tbl = J(`rows',5,.)
  local rownames : rowfullnames hist_`region'_tbl
  mat colnames cum_`region'_tbl = count freq mean_sumsales mean_gsales mean_goods_pls
  mat rownames cum_`region'_tbl = or_more
  mat roweq cum_`region'_tbl = `rownames'
  forvalues i = 1/`rows' {
    qui summ count if _n>=`i', meanonly
    mat cum_`region'_tbl[`i',1] = `r(sum)'
    qui summ freq if _n>=`i', meanonly
    mat cum_`region'_tbl[`i',2] = `r(sum)'
    qui summ mean_sumsales if _n>=`i' [fw=count], meanonly
    mat cum_`region'_tbl[`i',3] = `r(mean)'
    qui summ mean_gsales if _n>=`i' [fw=count], meanonly
    mat cum_`region'_tbl[`i',4] = `r(mean)'
    qui summ goods_pls if _n>=`i' [fw=count], meanonly
    mat cum_`region'_tbl[`i',5] = `r(mean)'
    }
  est2tex cum_`region', ready fancy p(braxpmkt/tex/`sec'-ncm8) replace dropall
  gen goods_pls = int(real(substr(_rowname,1,index(_rowname,":")-1)))
  gen wmean_gsales = mean_sumsales/mean_goods_pls
  gen pctl = freq*100
  order _rowname goods_pls count freq mean_sumsales
  label var goods_pls "Minimum Exporter Scope"
  label var count "# of Firms with min. sales"
  label var freq "Share of Firms with min. sales"
  label var mean_sumsales "Firms' Avg. Total Exports"
  label var mean_gsales "Firms' Avg. Product Scale"
  label var wmean_gsales "Firms' Avg. Product Scale"
  label var mean_goods_pls "Firms' Avg. Exporter Scope"
  label var pctl "Percentile of Firm with min. scope"
  forvalues i = 1/4 {
    local ypos`i' = mean_goods_pls[`i']*1.1
    local xpos`i' = pctl[`i']
    if `ypos`i''==.  local ypos`i'=0
    if `xpos`i''==.  local xpos`i'=0
    }
  graph twoway scatter mean_goods_pls pctl, yaxis(1) yscale(log axis(1)) ylabel(1 2 4 16 64 256 1024, nogrid axis(1)) yline(1 4 16 256, lcolor(gs13) axis(1)) ytitle("Mean Number of Products Shipped", axis(1)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter mean_sumsales pctl, yaxis(2) yscale(log axis(2)) ylabel(1 10 100 1000, nogrid axis(2)) yline(10 100 1000, lcolor(gs14) axis(2)) ytitle("Mean Total Exports (US$ million fob)", axis(2)) msymbol(smdiamond) text(`ypos1' `xpos1' "#>=1" `ypos2' `xpos2' "#>=2" `ypos3' `xpos3' "#>=3" `ypos4' `xpos4' "#>=4", placement(top) size(vsmall))
  graph export "braxpmkt/eps/`sec'-ncm8/avgscope-totexp-pcscope-`region'.eps", replace
  if "`sec'"=="manf-firms" & ("`region'"=="usa" | "`region'"=="argentina")  save "braxpmkt/eps/`sec'-ncm8/avgscope-totexp-pcscope-`region'", replace
  forvalues i = 1/4 {
    local ypos`i' = mean_goods_pls[`i']*.9
    local xpos`i' = pctl[`i']
    if `ypos`i''==.  local ypos`i'=0
    if `xpos`i''==.  local xpos`i'=0
    }
  graph twoway scatter mean_goods_pls pctl, yaxis(1) yscale(log axis(1)) ylabel(1 2 4 16 64 256 1024, nogrid axis(1)) yline(1 4 16 256, lcolor(gs13) axis(1)) ytitle("Mean Number of Products Shipped", axis(1)) msymbol(smcircle) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentile in Minimum Number of Products Shipped") graphregion(color(white)) scheme(sj) || scatter wmean_gsales pctl, yaxis(2) yscale(log axis(2)) ylabel(.01 .25 1, nogrid axis(2)) yline(.01 .25 1, lcolor(gs14) axis(2)) ytitle("Mean Exports/Product (US$ million fob)", axis(2)) msymbol(smdiamond) text(`ypos1' `xpos1' "#>=1" `ypos2' `xpos2' "#>=2" `ypos3' `xpos3' "#>=3" `ypos4' `xpos4' "#>=4", placement(bottom) size(vsmall))
  graph export "braxpmkt/eps/`sec'-ncm8/avgscope-wgsales-pcscope-`region'.eps", replace
restore
drop _dummy


// Histograms

histogram goods if goods<=25, discrete xtitle("Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj)
graph export "braxpmkt/eps/`sec'-ncm8/histogram-goods-25-`region'.eps", replace

histogram goods if goods>=10 & goods<=25, discrete xtitle("Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj)
graph export "braxpmkt/eps/`sec'-ncm8/histogram-goods-10to25-`region'.eps", replace

capture histogram goods if goods>=25 & goods<=100, discrete xtitle("Number of Products (NCM 8-digit)") xlab(25(15)100) graphregion(color(white)) scheme(sj)
if _rc==0  graph export "braxpmkt/eps/`sec'-ncm8/histogram-goods-25to100-`region'.eps", replace


// Graphs (and accompanying tables)

* twoway scatter sumsales pcsales
preserve
  order pcsales sumsales firmid
  keep firmid sumsales pcsales
  sort pcsales sumsales
  * graph twoway scatter sumsales pcsales, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Total Exports (US$ million fob)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  gen byte pctl = int(pcsales*100)
  keep sumsales pctl
  sort pctl sumsales
  by pctl: keep if _n==1
  replace pctl=pctl/100
  graph twoway scatter sumsales pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Total Exports (US$ million fob)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  graph export "braxpmkt/eps/`sec'-ncm8/sumsales-pcsales-`region'.eps", replace
  if "`sec'"=="manf-firms" & "`region'"=="usa"  save "braxpmkt/eps/`sec'-ncm8/sumsales-pcsales-`region'", replace
  more
restore

* twoway scatter goods pcsales
preserve
  order pcsales goods firmid
  keep firmid goods pcsales
  sort pcsales goods
  * graph twoway scatter goods pcsales, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") yscale(log) ylabel(1 10 100 1000) ytick(1 10 100 1000) yline(1 10 100 1000, lcolor(gs13)) ytitle("Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  gen byte pctl = int(pcsales*100)
  keep goods pctl
  sort pctl goods
  by pctl: keep if _n==1
  replace pctl=pctl/100
  graph twoway scatter goods pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") yscale(log) ylabel(1 10 100 1000) ytick(1 10 100 1000) yline(1 10 100 1000, lcolor(gs13)) ytitle("Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  graph export "braxpmkt/eps/`sec'-ncm8/goods-pcsales-`region'.eps", replace
  more
restore

* twoway scatter gsales pcsales
preserve
  order pcsales gsales firmid
  keep firmid gsales pcsales
  sort pcsales gsales
  * graph twoway scatter gsales pcsales, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Exports per Product (US$ million fob)")  graphregion(color(white)) scheme(sj) msymbol(smcircle)
  gen byte pctl = int(pcsales*100)
  keep gsales pctl
  sort pctl gsales
  by pctl: keep if _n==1
  replace pctl=pctl/100
  graph twoway scatter gsales pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Exports per Product (US$ million fob)")  graphregion(color(white)) scheme(sj) msymbol(smcircle)
  graph export "braxpmkt/eps/`sec'-ncm8/gsales-pcsales-`region'.eps", replace
  more
restore

* twoway scatter goods pcgoods
preserve
  order pcgoods goods firmid
  keep firmid goods pcgoods
  sort pcgoods goods
  * graph twoway scatter goods pcgoods, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Number of Products Shipped") yscale(log) ylabel(1 10 100 1000) ytick(1 10 100 1000) yline(1 10 100 1000, lcolor(gs13)) ytitle("Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  gen byte pctl = int(pcgoods*100)
  keep goods pctl
  sort pctl goods
  by pctl: keep if _n==1
  replace pctl=pctl/100
  graph twoway scatter goods pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Number of Products Shipped") yscale(log) ylabel(1 10 100 1000) ytick(1 10 100 1000) yline(1 10 100 1000, lcolor(gs13)) ytitle("Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  graph export "braxpmkt/eps/`sec'-ncm8/goods-pcgoods-`region'.eps", replace
  if "`sec'"=="manf-firms" & "`region'"=="usa"  save "braxpmkt/eps/`sec'-ncm8/goods-pcgoods-`region'", replace
  more
  gen _rowname = "pctl_0" + string(_n-1) if _n-1<10
  replace _rowname = "pctl_" + string(_n-1) if _n-1>=10 & _n-1<100
  replace _rowname = "pctl" + string(_n-1) if _n-1==100
  drop pctl
  order _rowname
  save "braxpmkt/tex/`sec'-ncm8/goods_pcgoods_`region'_tbl.dta", replace  // proper table for matload
  matload goods_pcgoods_`region'_tbl, p(braxpmkt/tex/`sec'-ncm8) over dropall missing(.)
  est2tex goods_pcgoods_`region', ready fancy p(braxpmkt/tex/`sec'-ncm8) replace dropall
restore

* graph cwhiskers goods pcsales
preserve
  order pcsales goods firmid
  keep firmid goods lngoods pcsales
  sort pcsales goods
  gen byte pctl = int(pcsales*100)/100
  gen byte pctl100 = int(pcsales*100)
  keep goods lngoods pctl pctl100 firmid
  order goods lngoods pctl pctl100 firmid
  keep if int(pctl100/5)==pctl100/5 & pctl100>0 & pctl100<100
  graph box goods, over(pctl100) yscale(log) ylabel(1 10 100 1000) ytick(1 10 100 1000) yline(1 10 100 1000, lcolor(gs13)) ytitle("Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj) cwhiskers intensity(25) medtype(cline) medline(lcolor(black)) marker(1, msymbol(smcircle_hollow)) 
  graph export "braxpmkt/eps/`sec'-ncm8/goods-pcsales-`region'-cwhiskers.eps", replace
  more
  gen _rowname = "pctl_0" + string(_n-1) if _n-1<10
  replace _rowname = "pctl_" + string(_n-1) if _n-1>=10 & _n-1<100
  replace _rowname = "pctl" + string(_n-1) if _n-1==100
  drop pctl* lngoods firmid
  order _rowname
  save "braxpmkt/tex/`sec'-ncm8/goods_pcsales_`region'_tbl.dta", replace  // proper table for matload
  * matload goods_pcsales_`region'_tbl, p(braxpmkt/tex/`sec'-ncm8) over dropall missing(.)
  * est2tex goods_pcsales_`region', ready fancy p(braxpmkt/tex/`sec'-ncm8) replace dropall
restore

* twoway scatter (mean) goods pcsales
preserve
  order pcsales goods firmid
  keep firmid goods lngoods pcsales
  sort pcsales goods
  gen byte pctl = int(pcsales*100)
  collapse (mean) goods (sd) sd_goods=goods (count) no_obs=goods, by(pctl) fast
  replace pctl=pctl/100
  gen lngoods = ln(goods)
  reg lngoods pctl if pctl<=.98
  gen lnserr_goods_up = log(goods + sd_goods/sqrt(no_obs))
  gen lnserr_goods_dn = log(goods - sd_goods/sqrt(no_obs))
  graph twoway lfitci lngoods pctl if pctl<=.98, clpattern(solid) || scatter lngoods pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") ylabel(0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1000") ytick(0 2.3025851 4.6051702 6.9077553) yline(0 2.3025851 4.6051702 6.9077553, lcolor(gs13)) ytitle("Mean Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle) legend(order(3 2) label(3 "Mean Exp. Scope (NCM 8-digit)") label(2 "Predicted Mean Exp. Scope")) || scatter lnserr_goods_up lnserr_goods_dn pctl, msymbol(point point)
  graph export "braxpmkt/eps/`sec'-ncm8/goods-pcsales-`region'-mean.eps", replace
  more
restore

* twoway scatter (mean) goods pcnpis
preserve
  order pcnpis goods firmid
  keep firmid goods lngoods pcnpis
  sort pcnpis goods
  gen byte pctl = int(pcnpis*100)
  collapse (mean) goods (sd) sd_goods=goods (count) no_obs=goods, by(pctl) fast
  replace pctl=pctl/100
  gen lngoods = ln(goods)
  reg lngoods pctl if pctl<=.98
  gen lnserr_goods_up = log(goods + sd_goods/sqrt(no_obs))
  gen lnserr_goods_dn = log(goods - sd_goods/sqrt(no_obs))
  graph twoway lfitci lngoods pctl if pctl<=.98, clpattern(solid) || scatter lngoods pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Employment") ylabel(0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1000") ytick(0 2.3025851 4.6051702 6.9077553) yline(0 2.3025851 4.6051702 6.9077553, lcolor(gs13)) ytitle("Mean Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle) legend(order(3 2) label(3 "Mean Exp. Scope (NCM 8-digit)") label(2 "Predicted Mean Exp. Scope")) || scatter lnserr_goods_up lnserr_goods_dn pctl, msymbol(point point)
  graph export "braxpmkt/eps/`sec'-ncm8/goods-pcnpis-`region'-mean.eps", replace
  more
restore

* twoway scatter gsales pcgsales
preserve
  order pcgsales gsales firmid
  keep firmid gsales pcgsales
  sort pcgsales gsales
  * graph twoway scatter gsales pcgsales, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Exports per Product") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Exports per Product (US$ million fob)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  gen byte pctl = int(pcgsales*100)
  keep gsales pctl
  sort pctl gsales
  by pctl: keep if _n==1
  replace pctl=pctl/100
  graph twoway scatter gsales pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Exports per Product") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Exports per Product (US$ million fob)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
  graph export "braxpmkt/eps/`sec'-ncm8/gsales-pcgsales-`region'.eps", replace
  more
restore

* twoway scatter goods sumsales
graph twoway scatter goods sumsales, xscale(log) xlabel(.00001 .001 .01 .1 1 10 100 1000) xtitle("Total Exports (US$ million fob)") yscale(log) ylabel(1 10 100 1000) ytick(1 10 100 1000) yline(1 10 100 1000, lcolor(gs13)) ytitle("Number of Products (NCM 8-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
graph export "braxpmkt/eps/`sec'-ncm8/goods-sumsales-`region'.eps", replace
more

* twoway scatter gsales sumsales
graph twoway scatter gsales sumsales, xscale(log) xlabel(.00001 .001 .01 .1 1 10 100 1000) xtitle("Total Exports (US$ million fob)") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Exports per Product (US$ million fob)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
graph export "braxpmkt/eps/`sec'-ncm8/gsales-sumsales-`region'.eps", replace
more

* twoway scatter gsales goods
graph twoway scatter gsales goods, xscale(log) xlabel(.00001 .001 .01 .1 1 10 100 1000) xtitle("Number of Products (NCM 8-digit)") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Exports per Product (US$ million fob)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
graph export "braxpmkt/eps/`sec'-ncm8/gsales-goods-`region'.eps", replace
more


// Regressions

reg lngoods lnsumsales
est2vec `region', e(N p df_m r2) name(lngoods) replace
more

capture reg lngsales lnsumsales
if _rc==0  est2vec `region', addto(`region') name(lngsales)
more

capture reg lngsales lnsumsales if goods>=2
if _rc==0  est2vec `region', addto(`region') name(lngsales_2ormore)
more

capture reg lngsales lnsumsales if goods>=3
if _rc==0  est2vec `region', addto(`region') name(lngsales_3ormore)
more

capture reg lngsales lnsumsales if goods>=10
if _rc==0  est2vec `region', addto(`region') name(lngsales_10ormore)
more

capture reg lngsales lnsumsales if goods>=25
if _rc==0  est2vec `region', addto(`region') name(lngsales_25ormore)
more

capture reg lngsales lnsumsales if goods>=100
if _rc==0  est2vec `region', addto(`region') name(lngsales_100ormore)
more

est2tex `region', p(braxpmkt/tex/`sec'-ncm8) extracols(1) dropall replace

}  // close `sec' loop

}  // close `region' loop


log close
set more off
