*! version 1.0.1  11apr2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.2  27apr2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.1.1  18may2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.2.1  09aug2010  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 650m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/chile-manffrms"
capture mkdir "braxpmkt/tex/chile-manffrms"

capture log close
log using "braxpmkt/logs/prodsales-tables-chile.log", replace


// PRODUCT RANK BY FIRM AND COUNTRY

*foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {
local sec "chile-manffrms"

est2extlbl, addto(expprodcnt) intex(braxpmkt/%stata/rowlbl-braxpmkt) p(braxpmkt/tex/`sec') replace dropall
est2extlbl, addto(expprodsel_usa) retain p(braxpmkt/tex/`sec') replace
est2extlbl, addto(expprodsel_argentina) retain p(braxpmkt/tex/`sec') replace

foreach region in "usa" "argentina" {

* matrix for overall statistics (goodscnt)
mat goodscnt_`region'_tbl = J(12,2,.)
if "`region'"=="usa"       mat colnames goodscnt_`region'_tbl = usa:world usa:oecd                 // exports to USA
if "`region'"=="argentina" mat colnames goodscnt_`region'_tbl = argentina:world argentina:nonoecd  // exports to Argentina
mat rownames goodscnt_`region'_tbl = firmgoods:r(N) firmgoods:sh_refonly firmgoods:sh_elsewhonly firmgoods:sh_both firms:r(N) firms:sh_if1both corr:r(rho) corr:r(p) corr:r(N) spearman:r(rho) spearman:r(p) spearman:r(N)

* select reference country
tempfile rankfile
use firmid hs6dgt wtfkey currnum using "braxpmkt/secex/expprod-`sec'", clear
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina
drop wtfkey
rename currnum currnum_`region'
sort firmid hs6dgt
save `rankfile'

// elsewhere: rest of world

* overall statistics (goodscnt)
use firmid hs6dgt wtfkey currnum using "braxpmkt/secex/expprod-`sec'", clear
if "`region'"=="usa"       drop if wtfkey==218400  // exports to USA
if "`region'"=="argentina" drop if wtfkey==330320  // exports to Argentina
sort firmid hs6dgt
merge firmid hs6dgt using `rankfile'
tab _m
qui count
local tot = `r(N)'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firmgoods:r(N)"),1] = `tot'
qui count if _m==2
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firmgoods:sh_refonly"),1] = `r(N)'/`tot'
qui count if _m==1
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firmgoods:sh_elsewhonly"),1] = `r(N)'/`tot'
qui count if _m==3
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firmgoods:sh_both"),1] = `r(N)'/`tot'
preserve
  keep firmid _m
  gen byte if1both = (_m==3)
  collapse (max) if1both, by(firmid) fast
  bysort firmid if1both: keep if _n==1
  label var if1both "Indic.: At least 1 prod. both in ref. cntry and elsewhere"
  qui count
  local tot = `r(N)'
  mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firms:r(N)"),1] = `tot'
  qui count if if1both==1
  mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firms:sh_if1both"),1] = `r(N)'/`tot'
restore
corr currnum currnum_`region'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"corr:r(rho)"),1] = `r(rho)'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"corr:r(p)"),1] = 2 * ttail( `r(N)'-2, `r(rho)'*sqrt(`r(N)'-2)/sqrt(1-`r(rho)'^2) )
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"corr:r(N)"),1] = `r(N)'
spearman currnum currnum_`region'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"spearman:r(rho)"),1] = `r(rho)'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"spearman:r(p)"),1] = `r(p)'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"spearman:r(N)"),1] = `r(N)'

* extensive margins
keep if _m==3
drop _m
preserve
  tempfile dstnofrm
  keep firmid wtfkey
  bysort firmid wtfkey: keep if _n==1
  collapse (count) destnum_firm=wtfkey, by(firmid) fast
  label var destnum_firm "# Dest./firm"
  sort firmid
  save `dstnofrm'
restore, preserve
  tempfile dstnotp1
  keep if currnum_`region'==1
  keep firmid wtfkey
  bysort firmid wtfkey: keep if _n==1
  collapse (count) destnum_top1=wtfkey, by(firmid) fast
  label var destnum_top1 "# Dest./top prod."
  sort firmid
  save `dstnotp1'
restore, preserve
  tempfile frmnornk
  keep firmid currnum_`region'
  bysort firmid currnum_`region': keep if _n==1
  collapse (count) firmnum_currnum=firmid, by(currnum_`region') fast
  label var firmnum_currnum "# Firms at rank"
  sort currnum_`region'
  save `frmnornk'
restore
sort firmid
merge firmid using `dstnofrm'
drop _m
sort firmid
merge firmid using `dstnotp1'
drop _m
sort currnum_`region'
merge currnum_`region' using `frmnornk'
collapse (count) destnum=wtfkey, by(firmid destnum_firm destnum_top1 hs6dgt currnum_`region' firmnum_currnum) fast
label var destnum "# Dest. at rank"
collapse (mean) destnum destnum_firm destnum_top1, by(currnum_`region' firmnum_currnum) fast
label var destnum "Mean # Dest."
label var destnum_firm "Mean # Dest./firm"
label var destnum_top1 "Mean # Dest./top prod."
keep if currnum_`region'==1 | currnum_`region'==2 | currnum_`region'==4 | currnum_`region'==8 | currnum_`region'==16 | currnum_`region'==32 | currnum_`region'==64 | currnum_`region'==128
rename currnum_`region' _rowname
order _rowname destnum firmnum_currnum destnum_firm destnum_top1
save "braxpmkt/tex/`sec'/expprodsel_`region'_tbl.dta", replace  // proper table for matload
matload expprodsel_`region'_tbl, p(braxpmkt/tex/`sec') over dropall missing(.)
est2tex expprodsel_`region', ready fancy p(braxpmkt/tex/`sec') replace dropall
mat rename expprodsel_`region'_tbl expprodsel_`region'_wrld_tbl
mat coleq expprodsel_`region'_wrld_tbl = world world world

// elsewhere: OECD or non-OECD

* overall statistics (goodscnt)
use firmid hs6dgt wtfkey currnum using "braxpmkt/secex/expprod-`sec'", clear
* OECD dummy
gen byte indoecd90=0
label var indoecd90 "Indic.: OECD member 1990"
replace indoecd90=1 if wtfkey==710360 // Australia 7 June 1971
replace indoecd90=1 if wtfkey==550400 // Austria 29 September 1961 
replace indoecd90=1 if wtfkey==530560 // Belgium-Lux 13 September 1961, 7 December 1961
replace indoecd90=1 if wtfkey==211240 // Canada 10 April 1961
replace indoecd90=1 if wtfkey==532080 // Denmark 30 May 1961
replace indoecd90=1 if wtfkey==552460 // Finland 28 January 1969
replace indoecd90=1 if wtfkey==532500 // France,Monac 7 August 1961
replace indoecd90=1 if wtfkey==532760 // Germany 27 September 1961
replace indoecd90=1 if wtfkey==533000 // Greece 27 September 1961
replace indoecd90=1 if wtfkey==553520 // Iceland 5 June 1961
replace indoecd90=1 if wtfkey==533720 // Ireland 7 August 1961
replace indoecd90=1 if wtfkey==533800 // Italy 29 March 1962
replace indoecd90=1 if wtfkey==413920 // Japan 28 April 1964
replace indoecd90=1 if wtfkey==535280 // Netherlands 13 November 1961
replace indoecd90=1 if wtfkey==715540 // New Zealand 29 May 1973
replace indoecd90=1 if wtfkey==555780 // Norway 4 July 1961
replace indoecd90=1 if wtfkey==536200 // Portugal 4 August 1961
replace indoecd90=1 if wtfkey==537240 // Spain 3 August 1961
replace indoecd90=1 if wtfkey==557520 // Sweden 28 September 1961
replace indoecd90=1 if wtfkey==557560 // Switz.Liecht 28 September 1961
replace indoecd90=1 if wtfkey==447920 // Turkey 2 August 1961
replace indoecd90=1 if wtfkey==538260 // UK 2 May 1961
replace indoecd90=1 if wtfkey==218400 // USA 12 April 1961
if "`region'"=="usa"       keep if indoecd90==1  // exports to USA and OECD
if "`region'"=="argentina" keep if indoecd90~=1  // exports to Argentina and non-OECD
if "`region'"=="usa"       drop if wtfkey==218400  // exports to USA
if "`region'"=="argentina" drop if wtfkey==330320  // exports to Argentina
sort firmid hs6dgt
merge firmid hs6dgt using `rankfile'
tab _m
qui count
local tot = `r(N)'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firmgoods:r(N)"),2] = `tot'
qui count if _m==2
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firmgoods:sh_refonly"),2] = `r(N)'/`tot'
qui count if _m==1
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firmgoods:sh_elsewhonly"),2] = `r(N)'/`tot'
qui count if _m==3
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firmgoods:sh_both"),2] = `r(N)'/`tot'
preserve
  keep firmid _m
  gen byte if1both = (_m==3)
  collapse (max) if1both, by(firmid) fast
  bysort firmid if1both: keep if _n==1
  label var if1both "Indic.: Active ref. cntry and elsewh."
  qui count
  local tot = `r(N)'
  mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firms:r(N)"),2] = `tot'
  qui count if if1both==1
  mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"firms:sh_if1both"),2] = `r(N)'/`tot'
restore
corr currnum currnum_`region'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"corr:r(rho)"),2] = `r(rho)'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"corr:r(p)"),2] = 2 * ttail( `r(N)'-2, `r(rho)'*sqrt(`r(N)'-2)/sqrt(1-`r(rho)'^2) )
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"corr:r(N)"),2] = `r(N)'
spearman currnum currnum_`region'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"spearman:r(rho)"),2] = `r(rho)'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"spearman:r(p)"),2] = `r(p)'
mat goodscnt_`region'_tbl[rownumb(goodscnt_`region'_tbl,"spearman:r(N)"),2] = `r(N)'

* extensive margins
keep if _m==3
drop _m
preserve
  tempfile dstnofrm
  keep firmid wtfkey
  bysort firmid wtfkey: keep if _n==1
  collapse (count) destnum_firm=wtfkey, by(firmid) fast
  label var destnum_firm "# Dest./firm"
  sort firmid
  save `dstnofrm'
restore, preserve
  tempfile dstnotp1
  keep if currnum_`region'==1
  keep firmid wtfkey
  bysort firmid wtfkey: keep if _n==1
  collapse (count) destnum_top1=wtfkey, by(firmid) fast
  label var destnum_top1 "# Dest./top prod."
  sort firmid
  save `dstnotp1'
restore, preserve
  tempfile frmnornk
  keep firmid currnum_`region'
  bysort firmid currnum_`region': keep if _n==1
  collapse (count) firmnum_currnum=firmid, by(currnum_`region') fast
  label var firmnum_currnum "# Firms at rank"
  sort currnum_`region'
  save `frmnornk'
restore
sort firmid
merge firmid using `dstnofrm'
drop _m
sort firmid
merge firmid using `dstnotp1'
drop _m
sort currnum_`region'
merge currnum_`region' using `frmnornk'
collapse (count) destnum=wtfkey, by(firmid destnum_firm destnum_top1 hs6dgt currnum_`region' firmnum_currnum) fast
label var destnum "# Dest. at rank"
collapse (mean) destnum destnum_firm destnum_top1, by(currnum_`region' firmnum_currnum) fast
label var destnum "Mean # Dest."
label var destnum_firm "Mean # Dest./firm"
label var destnum_top1 "Mean # Dest./top prod."
keep if currnum_`region'==1 | currnum_`region'==2 | currnum_`region'==4 | currnum_`region'==8 | currnum_`region'==16 | currnum_`region'==32 | currnum_`region'==64 | currnum_`region'==128
rename currnum_`region' _rowname
order _rowname destnum firmnum_currnum destnum_firm destnum_top1
save "braxpmkt/tex/`sec'/expprodsel_`region'_tbl.dta", replace  // proper table for matload
matload expprodsel_`region'_tbl, p(braxpmkt/tex/`sec') over dropall missing(.)
est2tex expprodsel_`region', ready fancy p(braxpmkt/tex/`sec') replace dropall
if "`region'"=="usa"       mat coleq expprodsel_`region'_tbl = oecd oecd oecd // exports to USA
if "`region'"=="argentina" mat coleq expprodsel_argentina_tbl = nonoecd nonoecd nonoecd // exports to Argentina
mat expprodsel_`region'_tbl = expprodsel_`region'_wrld_tbl , expprodsel_`region'_tbl
mat drop expprodsel_`region'_wrld_tbl
if "`region'"=="usa"       matorder expprodsel_`region'_tbl, m(expprodsel_`region'_tbl) ifc(world:destnum world:destnum_top1 world:destnum_firm world:firmnum_currnum oecd:destnum oecd:destnum_top1 oecd:destnum_firm oecd:firmnum_currnum) over
if "`region'"=="argentina" matorder expprodsel_`region'_tbl, m(expprodsel_`region'_tbl) ifc(world:destnum world:destnum_top1 world:destnum_firm world:firmnum_currnum nonoecd:destnum nonoecd:destnum_top1 nonoecd:destnum_firm nonoecd:firmnum_currnum) over
local rowmax = rowsof(expprodsel_`region'_tbl)
forvalues row = 1/`rowmax' {
  mat expprodsel_`region'_tbl[`row',1] = expprodsel_`region'_tbl[`row',1]/expprodsel_`region'_tbl[`row',3]
  mat expprodsel_`region'_tbl[`row',2] = expprodsel_`region'_tbl[`row',2]/expprodsel_`region'_tbl[`row',3]
  mat expprodsel_`region'_tbl[`row',5] = expprodsel_`region'_tbl[`row',5]/expprodsel_`region'_tbl[`row',7]
  mat expprodsel_`region'_tbl[`row',6] = expprodsel_`region'_tbl[`row',6]/expprodsel_`region'_tbl[`row',7]
  }
est2tex expprodsel_`region', ready fancy p(braxpmkt/tex/`sec') replace dropall extracols(4) digits(2)

}  // close `region' loop

mat expprodcnt_tbl = goodscnt_usa_tbl, goodscnt_argentina_tbl
mat drop goodscnt_usa_tbl goodscnt_argentina_tbl
est2tex expprodcnt, ready fancy p(braxpmkt/tex/`sec') replace dropall extracols(2)

*}  // close `sec' loop


// CONCENTRATION OF PRODUCT SALES IN TOP PRODUCTS BY FIRMS OF GIVEN SCOPE

*foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {
local sec "chile-manffrms"
foreach region in "usa" "argentina" "world" {

use firmid hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina

collapse (sum) value, by(firmid hs6dgt)
label var value "Product exports (US$ fob)"
egen goods = count(hs6dgt), by(firmid)
label var goods "Exporter scope (HS 6-digit)"
gsort firmid -value
by firmid: gen currnum=_n
label var currnum "Product rank within firm (HS 6-digit)"
gen lnvalue = log(value)
label var lnvalue "Log Exports (US$ fob)"
gen lncurrnum = log(currnum)
label var lncurrnum "Log Product rank within firm (HS 6)"
compress

egen sumvalue = sum(value), by(firmid)
label var sumvalue "Firm exports (US$ fob)"
gen top1value = value if currnum==1 & goods>=1
gen top2value = value if (currnum==1 | currnum==2) & goods>=2
gen top3value = value if (currnum==1 | currnum==2 | currnum==3) & goods>=3
egen top1sh = sum(top1value) if goods>=1, by(firmid)
egen top2sh = sum(top2value) if goods>=2, by(firmid)
egen top3sh = sum(top3value) if goods>=3, by(firmid)
replace top1sh = top1sh/sumvalue
replace top2sh = top2sh/sumvalue
replace top3sh = top3sh/sumvalue
label var top1sh "Top-1 Product Share in Exports"
label var top2sh "Top-2 Products Share in Exports"
label var top3sh "Top-3 Products Share in Exports"
drop top?value sumvalue
gen byte _dummyc = 1
gen byte _dummyr = 1
* summ top1sh top2sh top3sh
preserve
tabl2tex top1sh top2sh top3sh, type(mean) r(_dummyr) c(_dummyc) p(braxpmkt/tex/`sec') name(topsh_`region') fancy replace over nolog keepmiss
restore
mat topsh_`region'_marg = topsh_`region'_tbl
mat rownames topsh_`region'_marg = r(mean)
* table goods if goods==1 | goods==2 | goods==3 | goods==4 | goods==8 | goods==16 | goods==32 | goods==64 | goods==128, contents(mean top1sh mean top2sh mean top3sh)
tabl2tex top1sh top2sh top3sh if goods==1 | goods==2 | goods==3 | goods==4 | goods==8 | goods==16 | goods==32 | goods==64 | goods==128, type(mean) r(goods) c(_dummyc) p(braxpmkt/tex/`sec') name(topsh_`region') fancy replace over nolog keepmiss
mat topsh_`region'_tbl = topsh_`region'_tbl \ topsh_`region'_marg
est2tex topsh_`region', ready fancy p(braxpmkt/tex/`sec') replace dropall

}  // close `region' loop
*}  // close `sec' loop

log close
set more off
