*! version 1.0.2  22aug2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.1  01may2011  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.2  10jan2012  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.3  17jan2013  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.4  28jan2012  by Marc Muendler     muendler@ucsd.edu
*! version 1.2.1  03feb2012  by Marc Muendler     muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture mkdir "braxpmkt/estmat/manf-ekk"
capture mkdir "braxpmkt/tex/manf-ekk"

capture log close
log using "braxpmkt/logs/replication-stats-expitems.log", replace

// ISO 3166-1 country codes (3 letters)
tempfile cntrymap
use wtfkey wtfcountry iso3code indold using "brazaux/conc/countries/country-table.dta", clear
drop if indold==1
drop indold
duplicates drop
drop if wtfkey==.
compress
order wtfkey
drop wtfcountry
sort wtfkey
count if wtfkey==wtfkey[_n-1]
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] 
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1], nolab
replace iso3code="AFR" if wtfkey==168960 // Afr.Other NS
replace iso3code="ANT" if wtfkey==355320 // Aruba; backward compatibility with 2007-04-13
replace iso3code="CAR" if wtfkey==358960 // Carib. NES
replace iso3code="USO" if wtfkey==368960 // US NES
replace iso3code="ASI" if wtfkey==450000 // Asia NES
replace iso3code="BLX" if wtfkey==530560 // Belgium-Lux
replace iso3code="FRA" if wtfkey==532500 // France,Monac 
replace iso3code="EEC" if wtfkey==538960 // EEC NES
replace iso3code="CHE" if wtfkey==557560 // Switz.Liecht
replace iso3code="EUR" if wtfkey==578960 // Eur.Other NE
replace iso3code="OCE" if wtfkey==728960 // Oth.Oceania
duplicates drop
sort wtfkey
count if wtfkey==wtfkey[_n-1]
if `r(N)'>0  STOP
save `cntrymap'


// Extension to TABLE 2: Penetration of export markets by Brazilian export items in 2000

* Brazil 2000, export items
use firmid hs6dgt sicekk wtfkey itvfte using "braxpmkt/secex/replication-data-2000-expitems.dta", clear
drop if sicekk==.
collapse (sum) itvfte (count) ncntry=wtfkey, by(firmid hs6dgt sicekk)
label var itvfte "Item exports (US$ mill fob)"
label var ncntry "Export markets"
drop if sicekk==1 | sicekk==18
preserve  // produce manufacturing aggregate, excepting petroleum refinery
  tempfile manfagg
  collapse (count) nitems=hs6dgt (sum) itvfte, by(ncntry)
  label var nitems "No. of Exp. Items"
  label var itvfte "Item exports (US$ mill fob)"
  gen byte sicekk=18  // manufacturing aggregate
  compress
  order sicekk
  sort sicekk
  save `manfagg'
  qui summ nitems
  local chk = int(`r(sum)')
restore
collapse (count) nitems=hs6dgt (sum) itvfte, by(sicekk ncntry)
label var nitems "No. of Exp. Items"
label var itvfte "Item exports (US$ mill fob)"
compress
qui summ nitems
if `chk' ~= int(`r(sum)')  STOP
append using `manfagg'
preserve
  foreach trf in col1 col2 col3 tot {
    restore, preserve
    tempfile `trf'
    if "`trf'"=="col1"  collapse (sum) `trf'_nitems=nitems `trf'_itvfte=itvfte if ncntry== 1, by(sicekk)
    if "`trf'"=="col2"  collapse (sum) `trf'_nitems=nitems `trf'_itvfte=itvfte if ncntry>=10, by(sicekk)
    if "`trf'"=="col3"  collapse (sum) `trf'_nitems=nitems `trf'_itvfte=itvfte if ncntry>=50, by(sicekk)
    if "`trf'"=="tot"   collapse (sum) `trf'_nitems=nitems `trf'_itvfte=itvfte              , by(sicekk)
    label var `trf'_nitems "No. of exporters"
    label var `trf'_itvfte "Exports (US$ mill fob)"
    compress
    sort sicekk
    save ``trf''
    }
restore
use `col1', clear
foreach trf in col2 col3 tot {
  sort sicekk
  merge sicekk using ``trf''
  drop _m
  }
egen _totcol1 = sum(col1_nitems)
replace _totcol1 = _totcol1/2
if _totcol1[17]~=col1_nitems[17]  STOP
drop _totcol1
foreach trf in col1 col2 col3 {
  replace `trf'_nitems = int((`trf'_nitems/tot_nitems)*1000)/10
  replace `trf'_itvfte = int((`trf'_itvfte/tot_itvfte)*1000)/10
  gen str _`trf'_nitems = string(`trf'_nitems)
  replace _`trf'_nitems = _`trf'_nitems + ".0" if index(_`trf'_nitems,".")==0
  replace _`trf'_nitems = "0" + _`trf'_nitems if index(_`trf'_nitems,".")==1
  replace _`trf'_nitems = "0.0" if _`trf'_nitems=="0."
  gen str _`trf'_itvfte = string(`trf'_itvfte)
  replace _`trf'_itvfte = _`trf'_itvfte + ".0" if index(_`trf'_itvfte,".")==0
  replace _`trf'_itvfte = "0" + _`trf'_itvfte if index(_`trf'_itvfte,".")==1
  replace _`trf'_itvfte = "0.0" if _`trf'_itvfte=="0."
  replace _`trf'_itvfte = "(" + _`trf'_itvfte + ")"
  }
drop tot_nitems tot_itvfte
format col* %9.1f
drop col*
decode sicekk, generate(_sicekk)
drop sicekk
rename _sicekk sicekk
order sicekk
rename _col1_nitems itm_market1_a
rename _col2_nitems itm_market10_a
rename _col3_nitems itm_market50_a
rename _col1_itvfte itm_market1_b
rename _col2_itvfte itm_market10_b
rename _col3_itvfte itm_market50_b
label var itm_market1_a  "Single market: Perc. items"
label var itm_market1_b  "Single market: Perc. exports"
label var itm_market10_a "Ten+ markets: Perc. items"
label var itm_market10_b "Ten+ markets: Perc. exports"
label var itm_market50_a "Fifty+ markets: Perc. items"
label var itm_market50_b "Fifty+ markets: Perc. exports"
sort sicekk
merge using "braxpmkt/tex/manf-ekk/ekk_tab2_tbl.dta"
drop fr_market1_a fr_market1_b fr_market10_a fr_market10_b fr_market50_a fr_market50_b
count if _m~=3
if `r(N)'>0  STOP  // non-matching tables
list _rowname sicekk
drop _*
rename sicekk _rowname
save "braxpmkt/tex/manf-ekk/expitem_tab2_tbl.dta", replace
foreach var in _rowname itm_market1_a itm_market1_b itm_market10_a itm_market10_b itm_market50_a itm_market50_b br_market1_a br_market1_b br_market10_a br_market10_b br_market50_a {
  replace `var' = `var' + " &"
  }
foreach var in itm_market1_b itm_market10_b itm_market50_b br_market1_b br_market10_b {
  replace `var' = `var' + "&"
  }
replace br_market50_b = br_market50_b + " \" + "\"
outsheet using "braxpmkt/tex/manf-ekk/expitem_tab2.tex", noquote nonames replace


// Extension to Figure 1a: Presence of Brazilian export items

* Item count by number of markets
use firmid hs6dgt sicekk wtfkey itvfte using "braxpmkt/secex/replication-data-2000-expitems.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
collapse (count) ncntry=wtfkey, by(firmid hs6dgt)
collapse (count) nitems=hs6dgt, by(ncntry)
replace ncntry = ncntry+1
label var ncntry "Number of markets per export item"
label var nitems "Number of Brazilian export items"
sort ncntry
count if ncntry<2
if `r(N)'>0  STOP
graph twoway scatter nitems ncntry, ysca(log) ylab(1 10 100 1000 "1,000" 10000 "10,000" 100000 "100,000" 1000000 "1,000,000", angle(horizontal))  xsca(log) xlab(1 2 4 8 16 32 64 128) graphregion(color(white)) scheme(sj)
graph export "braxpmkt/eps/manf-ekk/expitem-fig1.eps", replace

gen lnncntry = ln(ncntry)
gen lnnitems = ln(nitems)
label var lnncntry "Log No. of Markets per Item"
label var lnnitems "Log No. of Brazilian Exp. Items"
reg lnnitems lnncntry if ncntry>1
disp in gr "Elasticity of number of items with respect to number of markets: " in yellow _b[lnncntry] in green " (standard error " in yellow _se[lnncntry] in green ")"


// Extension to Figure 2: Entry and market size

* Brazil
use firmid hs6dgt wtfkey sicekk itsunb ittfshare tabsorp using "braxpmkt/secex/replication-data-2000-expitems.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmid hs6dgt sicekk
sort wtfkey
by wtfkey: keep if _n==1
order wtfkey
sort wtfkey
joinby wtfkey using `cntrymap', unmatched(both) _merge(_merge)
tab _m
count if wtfkey==wtfkey[_n-1]
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] 
if `r(N)'>0  STOP
drop if _m~=3
drop _m
gen yvar = (itsunb/ittfshare)/1000
replace tabsorp=tabsorp/1000000000
label var yvar "Thousands of Brazilian export items/Brazilian mkt. share"
label var tabsorp "Destination market size (US$ billion)"
graph twoway scatter yvar tabsorp, ysca(log) ylab(1 10 100 1000 "1,000" 10000 "10,000", angle(horizontal)) xsca(log range(.1 10000)) xlab(.1 1 10 100 1000 "1,000" 10000 "10,000") graphregion(color(white)) scheme(sj) ytitle("Thousands of Brazilian" "export items/Brazilian mkt. share") mlabel(iso3code) mlabposition(0) msymbol(i)
graph export "braxpmkt/eps/manf-ekk/expitem-fig3.eps", replace
gen ln_yvar = log(yvar)
local lbl : variable label yvar
label var ln_yvar "`lbl'"
gen ln_tabsorp = log(tabsorp)
local lbl : variable label tabsorp
label var ln_tabsorp "`lbl'"
graph twoway lfit ln_yvar ln_tabsorp, clpattern(solid) || scatter ln_yvar ln_tabsorp, ylab(0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000", angle(horizontal)) xsca(range(0 9.2103404)) xlab(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000") graphregion(color(white)) scheme(sj) ytitle("Thousands of Brazilian export items" "per Brazilian market share") mlabel(iso3code) mlabposition(0) msymbol(i) legend(off)
graph export "braxpmkt/eps/manf-ekk/expitem-fig3-lfit.eps", replace
reg ln_yvar ln_tabsorp

* Chile
use firmid hs6dgt wtfkey sicekk itsunb ittfshare tabsorp using "braxpmkt/chile/replication-data-2000-expitems-chile.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmid hs6dgt sicekk
sort wtfkey
by wtfkey: keep if _n==1
order wtfkey
sort wtfkey
joinby wtfkey using `cntrymap', unmatched(both) _merge(_merge)
tab _m
count if wtfkey==wtfkey[_n-1]
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] 
if `r(N)'>0  STOP
drop if _m~=3
drop _m
gen yvar = (itsunb/ittfshare)/1000
replace tabsorp=tabsorp/1000000000
label var yvar "Thousands of Chilean export items/Chilean mkt. share"
label var tabsorp "Destination market size (US$ billion)"
graph twoway scatter yvar tabsorp, ysca(log) ylab(1 10 100 1000 "1,000" 10000 "10,000", angle(horizontal)) xsca(log range(.1 10000)) xlab(.1 1 10 100 1000 "1,000" 10000 "10,000") graphregion(color(white)) scheme(sj) ytitle("Thousands of Chilean" "export items/Chilean mkt. share") mlabel(iso3code) mlabposition(0) msymbol(i)
graph export "braxpmkt/eps/manf-ekk-chile/expitem-fig3.eps", replace
gen ln_yvar = log(yvar)
local lbl : variable label yvar
label var ln_yvar "`lbl'"
gen ln_tabsorp = log(tabsorp)
local lbl : variable label tabsorp
label var ln_tabsorp "`lbl'"
graph twoway lfit ln_yvar ln_tabsorp, clpattern(solid) || scatter ln_yvar ln_tabsorp, ylab(0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000", angle(horizontal)) xsca(range(0 9.2103404)) xlab(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000") graphregion(color(white)) scheme(sj) ytitle("Thousands of Chilean export items" "per Chilean market share") mlabel(iso3code) mlabposition(0) msymbol(i) legend(off)
graph export "braxpmkt/eps/manf-ekk-chile/expitem-fig3-lfit.eps", replace
reg ln_yvar ln_tabsorp


// Extensions to Regression 1: Elasticity of number of Brazilian export items per Brazilian items' market share with respect to market size

tempfile frmlvldta
use firmid wtfkey svftesic svfte sunb sunbsic using "braxpmkt/secex/replication-data-2000.dta", clear
rename svftesic _svftesic
rename svfte _svfte
sort firmid wtfkey
save `frmlvldta'

use firmid hs6dgt wtfkey sicekk itsunb ittfshare tabsorp itsunbsic svftesic svfte itvftebav itvftebavsic using "braxpmkt/secex/replication-data-2000-expitems.dta", clear
sort firmid wtfkey sicekk
merge firmid wtfkey using `frmlvldta'
count if _m~=3
if `r(N)'>0  STOP
drop _m
compare svftesic _svftesic
compare svfte _svfte
drop _*

drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmid hs6dgt
sort wtfkey sicekk
by wtfkey sicekk: keep if _n==1
order wtfkey sicekk
sort wtfkey sicekk

gen goods = svfte/(itvftebav*sunb)
gen goodssic = svftesic/(itvftebavsic*sunbsic)
label var goods "Exporter scope (HS) by dest."
label var goodssic "Exporter scope (HS) by dst. ind."
* list wtfkey sicekk sunbsic goodssic itvftebavsic svftesic if wtfkey==553520 & sicekk==4
* list wtfkey sicekk sunbsic goodssic itvftebavsic svftesic if wtfkey==555780 & sicekk==17

gen _chk = itsunb/sunb
compare _chk goods
drop _chk
compress

gen ln_n_sd = ln(sunb)  // sunb = count(firmid), by(wtfkey) at destination level
label var ln_n_sd "Log No. SCX exp'rs to dest."
gen ln_m_sd = ln(itsunb)  // itsunb = count(firmid hs6dgt), by(wtfkey) at destination level
label var ln_m_sd "Log No. SCX items to dest."
gen ln_lambda_sd = ln(ittfshare)  // ittfshare = svfte/tabsorp at destination level
label var ln_lambda_sd "Log SCX market share at dest."
gen ln_x_d = ln(tabsorp)  // tabsorp = wtf_output + wtf_imports - wtf_exports at destination level
label var ln_x_d "Log Absorption at dest."
gen ln_p_sd = ln(goods)   // goods = svfte/(itvftebav*sunb)
label var ln_p_sd "Log Exp. scope (HS) at dest."

gen ln_n_isd = ln(sunbsic)  // sunbsic = count(firmid), by(wtfkey sicekk) at destination-industry level
label var ln_n_isd "Log No. SCX exp'rs to dest. ind."
gen ln_m_isd = ln(itsunbsic)  // itsunbsic = count(firmid hs6dgt), by(wtfkey sicekk) at destination-industry level
label var ln_m_isd "Log No. SCX items to dest. ind."
gen ln_b_isd = ln(svftesic/svfte)  // svftesic = sum(itvfte), by(wtfkey sicekk) at destination-industry level; svfte = sum(itvfte), by(wtfkey) at destination level
label var ln_b_isd "Log Industry bias of SCX sales"
gen ln_p_isd = ln(goodssic)   // goods = svfte/(itvftebav*sunb)
label var ln_p_isd "Exporter scope (HS) by dst. ind."

preserve
keep sicekk wtfkey ln_n_sd ln_m_sd ln_lambda_sd ln_x_d ln_p_sd
sort wtfkey
by wtfkey: keep if _n==1   // removes industry variation
sort wtfkey sicekk   // no industry variation
qui duplicates report wtfkey
if `r(unique_value)'~=`r(N)'  STOP  // break if erroneous variation within country
drop sicekk
reg ln_n_sd ln_lambda_sd ln_x_d
est2vec expitem_reg, vars(ln_lambda_sd ln_x_d ln_b_isd ln_p_sd ln_p_isd ln_n_sd ln_n_isd _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho) name(reg1) replace
reg ln_m_sd ln_lambda_sd ln_x_d
est2vec expitem_reg, addto(expitem_reg) name(reg1_lnm)
reg ln_n_sd ln_lambda_sd ln_x_d ln_p_sd
est2vec expitem_reg, addto(expitem_reg) name(reg1_scop)
reg ln_p_sd ln_lambda_sd ln_x_d ln_n_sd
est2vec expitem_reg, addto(expitem_reg) name(scop_reg1)
reg ln_p_sd ln_lambda_sd ln_x_d
est2vec expitem_reg, addto(expitem_reg) name(scop_reg1_non)

gen ln_t_sd = ln_lambda_sd + ln_x_d - ln(1000000)
label var ln_t_sd "Log SCX Exp. to dest. (US$ mill)"
gen ln_x_d_bill = ln_x_d - ln(1000000000)
label var ln_x_d_bill "Log Absorpt. at dest. (US$ bill)"
gen p_sd = exp(ln_p_sd)
label var p_sd "Mean Exporter scope (HS-6)"
gen lambda_sd = exp(ln_lambda_sd)
label var lambda_sd "Brazil's Market share"
gen x_d = exp(ln_x_d) / 1000000000
label var x_d "Absorption (US$ billion)"  // x_d is tabsorp "Destination market size (US$)"
gen t_sd = lambda_sd * x_d * 1000
label var t_sd "Brazil's Exports (US$ million)"

reg ln_p_sd ln_t_sd
est2vec expitem_reg, addto(expitem_reg) name(scop_reg1_tsd)
graph twoway scatter ln_p_sd ln_lambda_sd, ytitle("Mean Exporter Scope") ylabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16", nogrid) xtitle("Market Share") xlabel(-9.2103404 ".0001" -6.9077553 ".001" -4.6051702 ".01" -2.3025851 ".1", nogrid) graphregion(color(white)) scheme(sj) || lfit ln_p_sd ln_lambda_sd
graph export "braxpmkt/eps/manf-ekk/expitem-scope-lambda.eps", replace
graph twoway scatter ln_p_sd ln_t_sd, ytitle("Mean Exporter Scope") ylabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16", nogrid) xtitle("Total Brazilian Exports (US$ million)") xlabel(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000", nogrid) graphregion(color(white)) scheme(sj) || lfit ln_p_sd ln_t_sd
graph export "braxpmkt/eps/manf-ekk/expitem-scope-totexports.eps", replace
reg ln_p_sd ln_x_d_bill
est2vec expitem_reg, addto(expitem_reg) name(scop_reg1_xdbill)
graph twoway scatter ln_p_sd ln_x_d_bill, ytitle("Mean Exporter Scope") ylabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16", nogrid) xtitle("Absorption (US$ billion)") xlabel(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000", nogrid) graphregion(color(white)) scheme(sj) || lfit ln_p_sd ln_x_d_bill
graph export "braxpmkt/eps/manf-ekk/expitem-scope-absorpt.eps", replace

restore
reg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd, cluster(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(reg2)
reg ln_m_isd ln_lambda_sd ln_x_d ln_b_isd, cluster(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(reg2_lnm)
reg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd ln_p_isd, cluster(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(reg2_scop)
reg ln_p_isd ln_lambda_sd ln_x_d ln_b_isd ln_n_isd, cluster(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(scop_reg2)

xtreg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd, fe i(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(xtreg2)
xtreg ln_m_isd ln_lambda_sd ln_x_d ln_b_isd, fe i(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(xtreg2_lnm)
xtreg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd ln_p_isd, fe i(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(xtreg2_scop)
xtreg ln_p_isd ln_lambda_sd ln_x_d ln_b_isd ln_n_isd, fe i(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(scop_xtreg2)

est2tex expitem_reg, fancy p(braxpmkt/estmat/manf-ekk) replace level(90 95 99) mark(starse) dropall
mat drop expitem_reg_b expitem_reg_se expitem_reg_e
mat coleq expitem_reg_tbl = itm
matload ekk_reg_tbl, p(braxpmkt/tex/manf-ekk) missing(.) dropall over
matorder ekk_reg_tbl, m(ekk_reg_tbl) over ifc(br_reg1 br_reg2 br_xtreg2)
local rownames : rowfullnames expitem_reg_tbl
matins ekk_reg_tbl, m(ekk_reg_tbl) over ifr(`rownames')
mat colnames ekk_reg_tbl = reg1 reg2 xtreg2
mat coleq ekk_reg_tbl = frm
mat expitem_reg_tbl = expitem_reg_tbl , ekk_reg_tbl
mat drop ekk_reg_tbl
est2tex expitem_reg, ready fancy p(braxpmkt/tex/manf-ekk) replace level(90 95 99) mark(starse) dropall extracols(3)


// Extensions to Regression 1: Elasticity of number of Chilean export items per Chilean items' market share with respect to market size

tempfile frmlvldta
use firmid wtfkey svftesic svfte sunb sunbsic using "braxpmkt/chile/replication-data-2000-chile.dta", clear
rename svftesic _svftesic
rename svfte _svfte
sort firmid wtfkey
save `frmlvldta'

use firmid hs6dgt wtfkey sicekk itsunb ittfshare tabsorp itsunbsic svftesic svfte itvftebav itvftebavsic using "braxpmkt/chile/replication-data-2000-expitems-chile.dta", clear
sort firmid wtfkey sicekk
merge firmid wtfkey using `frmlvldta'
count if _m~=3
if `r(N)'>0  STOP
drop _m
compare svftesic _svftesic
compare svfte _svfte
drop _*

drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmid hs6dgt
sort wtfkey sicekk
by wtfkey sicekk: keep if _n==1
order wtfkey sicekk
sort wtfkey sicekk

gen goods = svfte/(itvftebav*sunb)
gen goodssic = svftesic/(itvftebavsic*sunbsic)
label var goods "Exporter scope (HS) by dest."
label var goodssic "Exporter scope (HS) by dst. ind."
* list wtfkey sicekk sunbsic goodssic itvftebavsic svftesic if wtfkey==553520 & sicekk==4
* list wtfkey sicekk sunbsic goodssic itvftebavsic svftesic if wtfkey==555780 & sicekk==17

gen _chk = itsunb/sunb
compare _chk goods
drop _chk
compress

gen ln_n_sd = ln(sunb)  // sunb = count(firmid), by(wtfkey) at destination level
label var ln_n_sd "Log No. CHL exp'rs to dest."
gen ln_m_sd = ln(itsunb)  // itsunb = count(firmid hs6dgt), by(wtfkey) at destination level
label var ln_m_sd "Log No. CHL items to dest."
gen ln_lambda_sd = ln(ittfshare)  // ittfshare = svfte/tabsorp at destination level
label var ln_lambda_sd "Log CHL market share at dest."
gen ln_x_d = ln(tabsorp)  // tabsorp = wtf_output + wtf_imports - wtf_exports at destination level
label var ln_x_d "Log Absorption at dest."
gen ln_p_sd = ln(goods)   // goods = svfte/(itvftebav*sunb)
label var ln_p_sd "Log Exp. scope (HS) at dest."

gen ln_n_isd = ln(sunbsic)  // sunbsic = count(firmid), by(wtfkey sicekk) at destination-industry level
label var ln_n_isd "Log No. CHL exp'rs to dest. ind."
gen ln_m_isd = ln(itsunbsic)  // itsunbsic = count(firmid hs6dgt), by(wtfkey sicekk) at destination-industry level
label var ln_m_isd "Log No. CHL items to dest. ind."
gen ln_b_isd = ln(svftesic/svfte)  // svftesic = sum(itvfte), by(wtfkey sicekk) at destination-industry level; svfte = sum(itvfte), by(wtfkey) at destination level
label var ln_b_isd "Log Industry bias of CHL sales"
gen ln_p_isd = ln(goodssic)   // goods = svfte/(itvftebav*sunb)
label var ln_p_isd "Exporter scope (HS) by dst. ind."

preserve
keep sicekk wtfkey ln_n_sd ln_m_sd ln_lambda_sd ln_x_d ln_p_sd
sort wtfkey
by wtfkey: keep if _n==1   // removes industry variation
sort wtfkey sicekk   // no industry variation
qui duplicates report wtfkey
if `r(unique_value)'~=`r(N)'  STOP  // break if erroneous variation within country
drop sicekk
reg ln_n_sd ln_lambda_sd ln_x_d
est2vec expitem_reg, vars(ln_lambda_sd ln_x_d ln_b_isd ln_p_sd ln_p_isd ln_n_sd ln_n_isd _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho) name(reg1) replace
reg ln_m_sd ln_lambda_sd ln_x_d
est2vec expitem_reg, addto(expitem_reg) name(reg1_lnm)
reg ln_n_sd ln_lambda_sd ln_x_d ln_p_sd
est2vec expitem_reg, addto(expitem_reg) name(reg1_scop)
reg ln_p_sd ln_lambda_sd ln_x_d ln_n_sd
est2vec expitem_reg, addto(expitem_reg) name(scop_reg1)
reg ln_p_sd ln_lambda_sd ln_x_d
est2vec expitem_reg, addto(expitem_reg) name(scop_reg1_non)

gen ln_t_sd = ln_lambda_sd + ln_x_d - ln(1000000)
label var ln_t_sd "Log CHL Exp. to dest. (US$ mill)"
gen ln_x_d_bill = ln_x_d - ln(1000000000)
label var ln_x_d_bill "Log Absorpt. at dest. (US$ bill)"
gen p_sd = exp(ln_p_sd)
label var p_sd "Mean Exporter scope (HS-6)"
gen lambda_sd = exp(ln_lambda_sd)
label var lambda_sd "Chile's Market share"
gen x_d = exp(ln_x_d) / 1000000000
label var x_d "Absorption (US$ billion)"  // x_d is tabsorp "Destination market size (US$)"
gen t_sd = lambda_sd * x_d * 1000
label var t_sd "Chile's Exports (US$ million)"

reg ln_p_sd ln_t_sd
est2vec expitem_reg, addto(expitem_reg) name(scop_reg1_tsd)
graph twoway scatter ln_p_sd ln_lambda_sd, ytitle("Mean Exporter Scope") ylabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16", nogrid) xtitle("Market Share") xlabel(-9.2103404 ".0001" -6.9077553 ".001" -4.6051702 ".01" -2.3025851 ".1", nogrid) graphregion(color(white)) scheme(sj) || lfit ln_p_sd ln_lambda_sd
graph export "braxpmkt/eps/manf-ekk-chile/expitem-scope-lambda.eps", replace
graph twoway scatter ln_p_sd ln_t_sd, ytitle("Mean Exporter Scope") ylabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16", nogrid) xtitle("Total Chilean Exports (US$ million)") xlabel(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000", nogrid) graphregion(color(white)) scheme(sj) || lfit ln_p_sd ln_t_sd
graph export "braxpmkt/eps/manf-ekk-chile/expitem-scope-totexports.eps", replace
reg ln_p_sd ln_x_d_bill
est2vec expitem_reg, addto(expitem_reg) name(scop_reg1_xdbill)
graph twoway scatter ln_p_sd ln_x_d_bill, ytitle("Mean Exporter Scope") ylabel(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16", nogrid) xtitle("Absorption (US$ billion)") xlabel(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000", nogrid) graphregion(color(white)) scheme(sj) || lfit ln_p_sd ln_x_d_bill
graph export "braxpmkt/eps/manf-ekk-chile/expitem-scope-absorpt.eps", replace

restore
reg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd, cluster(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(reg2)
reg ln_m_isd ln_lambda_sd ln_x_d ln_b_isd, cluster(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(reg2_lnm)
reg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd ln_p_isd, cluster(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(reg2_scop)
reg ln_p_isd ln_lambda_sd ln_x_d ln_b_isd ln_n_isd, cluster(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(scop_reg2)

xtreg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd, fe i(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(xtreg2)
xtreg ln_m_isd ln_lambda_sd ln_x_d ln_b_isd, fe i(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(xtreg2_lnm)
xtreg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd ln_p_isd, fe i(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(xtreg2_scop)
xtreg ln_p_isd ln_lambda_sd ln_x_d ln_b_isd ln_n_isd, fe i(sicekk)
est2vec expitem_reg, addto(expitem_reg) name(scop_xtreg2)

est2tex expitem_reg, fancy p(braxpmkt/estmat/manf-ekk-chile) replace level(90 95 99) mark(starse) dropall


log close
set more off
