*! version 1.0.4  08oct2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.6  15jun2008  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.8  12apr2010  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.9  17jul2010  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.1  10jan2011  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.2  17jan2012  by Marc Muendler     muendler@ucsd.edu
*! version 1.2.1  03feb2012  by Marc Muendler     muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture mkdir "braxpmkt/estmat/manf-ekk"
capture mkdir "braxpmkt/tex/manf-ekk"
capture mkdir "braxpmkt/estmat/manf-bjrs"
capture mkdir "braxpmkt/tex/manf-bjrs"
capture mkdir "braxpmkt/estmat/manf-bjrs-chile"
capture mkdir "braxpmkt/estmat/manf-ekk-chile"
capture mkdir "braxpmkt/eps/manf-ekk-chile"

capture log close
log using "braxpmkt/logs/replication-stats.log", replace


capture program drop mklbl
program define mklbl
  local var = "`1'"
  local lblname = "`2'"
  * qui replace `var' = lower(`var')
  local num = _N
  * Shorten label names
  local lblname = substr("`lblname'",1,8)
  * English labels
  forvalues i = 1/`num' {
    local lblnum = `2'[`i']
    local lblstr = `1'[`i']
    label define `lblname' `lblnum' "`lblstr'", modify
    }
  label values `2' `lblname'
  label list `lblname'
  * label save `lblname' using "braxpmkt/conc/`lblname'", replace
end

// ISO 3166-1 country codes (3 letters)
tempfile cntrymap
use wtfkey wtfcountry iso3code indold using "brazaux/conc/countries/country-table.dta", clear
drop if indold==1
drop indold
duplicates drop
drop if wtfkey==.
compress
order wtfkey
drop wtfcountry
sort wtfkey
count if wtfkey==wtfkey[_n-1]
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] 
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1], nolab
replace iso3code="AFR" if wtfkey==168960 // Afr.Other NS
replace iso3code="ANT" if wtfkey==355320 // Aruba; backward compatibility with 2007-04-13
replace iso3code="CAR" if wtfkey==358960 // Carib. NES
replace iso3code="USO" if wtfkey==368960 // US NES
replace iso3code="ASI" if wtfkey==450000 // Asia NES
replace iso3code="BLX" if wtfkey==530560 // Belgium-Lux
replace iso3code="FRA" if wtfkey==532500 // France,Monac 
replace iso3code="EEC" if wtfkey==538960 // EEC NES
replace iso3code="CHE" if wtfkey==557560 // Switz.Liecht
replace iso3code="EUR" if wtfkey==578960 // Eur.Other NE
replace iso3code="OCE" if wtfkey==728960 // Oth.Oceania
duplicates drop
sort wtfkey
count if wtfkey==wtfkey[_n-1]
if `r(N)'>0  STOP
save `cntrymap'

// Mapping from ISIC rev. 2 to SIC (as in EKK 2004)

tempfile isic2ekk
insheet using "braxpmkt/ekk/ekk-sic-isic2-conc.csv", comma clear names
qui count if index(isic2,",") > 0
local chk = `r(N)'
while `chk'>0 {
  sort sic
  qui gen byte _exp_cnt = ( index(isic2,",") > 0 ) + 1
  qui expand _exp_cnt if index(isic2,",") > 0
  sort sic isic2
  by sic isic2: gen byte _cnt = _n
  qui replace isic2 = trim(substr(isic2,1,index(isic2,",")-1)) if _exp_cnt>1 & _cnt==1
  qui replace isic2 = trim(substr(isic2,index(isic2,",")+1,.)) if _exp_cnt>1 & _cnt>1
  qui drop _*
  qui count if index(isic2,",") > 0
  local chk = `r(N)'
  }
gen isic2num = int(real(isic2))
compress
drop isic2
rename isic2num isic2
order isic2
sort isic2
qui do "braxpmkt/conc/unido-isic2.do"
label values isic2 isic2
replace sic = "99" if sic=="0"
gen _sicind = "[" + sic + "] " + industry
encode _sicind, generate(sicekk) label(sicekk)
drop _sicind
keep isic2 sicekk
tab sicekk
label var isic2 "ISIC 2.0 (3-digit)"
label var sicekk "EKK (SIC) industries"
compress
sort isic2
save `isic2ekk'

// Mapping from CNAE to NAICS (as in BJRS 2007)

tempfile naics
use "brazcomp/filters/cnae2naic-loose.dta", clear
gen str naicstr = string(naic)
drop if substr(naicstr,1,1)~="3"
replace naicstr = "332" if naicstr=="3" // cnae 2899 (Other Metal Product Manufacturing)
qui count if length(naicstr)<3
if `r(N)'>0  STOP
replace naicstr = substr(naicstr,1,3)
drop naic naicdesc cnaedesc
gen int naic = int(real(naicstr))
label var naic "NAICS industry (3-digit)"
keep cnae naic
order cnae naic
sort cnae naic
save `naics'


// EKK TABLE 1a (upper panel): Number of producers by manufacturing industry in 2000

* France 1986, US 1987
tempfile fr_us_nfirms
insheet using "braxpmkt/ekk/ekk04-tab1a.tex", clear delimit("&")
replace v1="99" if v2=="Manufacturing (ex. petroleum refining)"
drop if v1=="" | v1=="SIC"
rename v1 _sicekk
replace v4 = trim(subinstr(v4,"\\","",.))
gen france86 = int(real(subinstr(v3,",","",.)))
gen us87 = int(real(subinstr(v4,",","",.)))
drop v2-v4
sort _sicekk
save `fr_us_nfirms'

* Brazil 2000
tempfile nfirms
insheet using "rais/base-agg/cnae/aggsec.csv", comma clear
keep if ano==2000
keep clas_cnae_95 n_cnpj_radic
gen cnae = string(int(clas_cnae_95/10))
replace cnae = "0" + cnae if length(cnae)<4
drop clas_cnae_95
label var cnae "CNAE sector (annual mode)"
rename n_cnpj_radic nfirms
label var nfirms "Number of firms"
order cnae
sort cnae
merge cnae using "brazcomp/filters/cnae-isic2"
tab _m
list cnae nfirms if _m==1
list cnae isic2 if _m==2
drop if _m~=3
drop _m cnae_desc
collapse (sum) nfirms, by(isic2dgt3)
label var nfirms "Number of producers"
rename isic2dgt3 isic2
qui do "braxpmkt/conc/unido-isic2.do"
label values isic2 isic2
sort isic2
merge isic2 using `isic2ekk'
tab _m
drop if _m==1  // EKK manufacturing firms only
collapse (sum) nfirms, by(sicekk)
label var nfirms "Number of producers"
drop if sicekk==1 // drop excluded category: petroleum refining [ISIC: 353, Petroleum refineries]
order sicekk
sort sicekk
egen _totfirms = sum(nfirms)
replace nfirms = _totfirms if sicekk==18 & nfirms==0  // [99] Manufacturing (ex. petroleum refining)
drop _totfirms
sort sicekk
save `nfirms'
merge using `fr_us_nfirms'
count if _m~=3
if `r(N)'>0  STOP  // non-matching tables
list _sicekk sicekk
drop _*
rename nfirms brazil00
label var brazil00 "Brazil 2000: No. of Producers"
label var france86 "France 1986: No. of Producers"
label var us87 "U.S. 1987: No. of Producers"
qui label save sicekk using "braxpmkt/tex/manf-ekk/sicekk", replace
gen str _rowname = string(sicekk)
drop sicekk
save "braxpmkt/tex/manf-ekk/ekk_tab1a_tbl.dta", replace
matload ekk_tab1a_tbl, dropall p(braxpmkt/tex/manf-ekk) over
est2tex ekk_tab1a, replace dropall preserve ready vallabel(sicekk) p(braxpmkt/tex/manf-ekk) fancy thousep


// EKK TABLE 1b (lower panel): Share of exporters by manufacturing industry in 2000

* France 1986, US 1987
tempfile fr_us_shexp
insheet using "braxpmkt/ekk/ekk04-tab1b.tex", clear delimit("&")
replace v1="99" if v1=="0" & _n==_N
drop if v1=="" | v1=="SIC"
rename v1 _sicekk
replace v3 = trim(subinstr(v3,"\\","",.))
gen france86 = real(subinstr(v2,",","",.))
gen us87 = real(subinstr(v3,",","",.))
drop v2-v3
sort _sicekk
save `fr_us_shexp'

* Brazil 2000
use firmid sicekk wtfkey vfte using "braxpmkt/secex/replication-data-2000.dta", clear
drop if sicekk==.
collapse (sum) vfte, by(firmid sicekk)  // sicekk is defined at firm level, and only assigned for SECEX exporters with RAIS entry
collapse (count) nexp=firmid, by(sicekk)
label var nexp "No. of Exporters (w/ RAIS entry)"
drop if sicekk==1 // drop excluded category: petroleum refining [ISIC: 353, Petroleum refineries]
order sicekk
sort sicekk
preserve // [99] Manufacturing (ex. petroleum refining)
  tempfile aggsic
  collapse (sum) nexp
  gen byte sicekk = 18
  order sicekk
  save `aggsic'
restore
append using `aggsic'
compress
rename sicekk _sicekk
sort _sicekk
merge using `nfirms'
count if _m~=3
if `r(N)'>0  STOP  // non-matching tables
list _sicekk sicekk
drop _*
label var nexp "No. of Producers (w/ RAIS entry)"
order sicekk nexp nfirms
compress
gen shexp = (nexp/nfirms)*100
label var shexp "Percentage of exporters"
keep sicekk shexp

merge using `fr_us_shexp'
count if _m~=3
if `r(N)'>0  STOP  // non-matching tables
list _sicekk sicekk
drop _*
rename shexp brazil00
label var brazil00 "Brazil 2000: Perc. exporters"
label var france86 "France 1986: Perc. exporters"
label var us87 "U.S. 1987: Perc. exporters"
qui label save sicekk using "braxpmkt/tex/manf-ekk/sicekk", replace
gen str _rowname = string(sicekk)
drop sicekk
save "braxpmkt/tex/manf-ekk/ekk_tab1b_tbl.dta", replace
matload ekk_tab1b_tbl, dropall p(braxpmkt/tex/manf-ekk) over
est2tex ekk_tab1b, replace dropall preserve ready vallabel(sicekk) p(braxpmkt/tex/manf-ekk) fancy digits(1)


// EKK TABLE 2: Penetration of export markets by Brazilian exporters in 2000

* France 1986
tempfile fr_us_penet
insheet using "braxpmkt/ekk/ekk04-tab2.tex", clear delimit("&") names
replace sic="99" if sic=="0" & _n==_N
rename sic _sicekk
replace v7 = trim(subinstr(v7,"\\","",.))
rename market fr_market1_a
rename v3 fr_market1_b
rename tenormore fr_market10_a
rename v5 fr_market10_b
rename fiftyormore fr_market50_a
rename v7 fr_market50_b
label var fr_market1_a  "Single market: Perc. firms"
label var fr_market1_b  "Single market: Perc. exports"
label var fr_market10_a "Ten+ markets: Perc. firms"
label var fr_market10_b "Ten+ markets: Perc. exports"
label var fr_market50_a "Fifty+ markets: Perc. firms"
label var fr_market50_b "Fifty+ markets: Perc. exports"
foreach var in fr_market1_a fr_market10_a fr_market50_a {
  rename `var' _`var'
  gen str `var' = string(_`var')
  replace `var' = `var' + ".0" if index(`var',".")==0
  replace `var' = "0" + `var' if index(`var',".")==1
  replace `var' = "0.0" if `var'=="0."
  drop _`var'
  }
order _sicekk fr_market1_a fr_market1_b fr_market10_a fr_market10_b fr_market50_a fr_market50_b
sort _sicekk
compress
save `fr_us_penet'

* Brazil 2000
use firmid sicekk wtfkey vfte using "braxpmkt/secex/replication-data-2000.dta", clear
drop if sicekk==.
collapse (sum) vfte (count) ncntry=wtfkey, by(firmid sicekk)
label var vfte "Exports (US$ mill fob)"
label var ncntry "Export markets"
drop if sicekk==1 | sicekk==18
preserve  // produce manufacturing aggregate, excepting petroleum refinery
  tempfile manfagg
  collapse (count) nfirms=firmid (sum) vfte, by(ncntry)
  label var nfirms "No. of Exporters"
  label var vfte "Exports (US$ mill fob)"
  gen byte sicekk=18  // manufacturing aggregate
  compress
  order sicekk
  sort sicekk
  save `manfagg'
  qui summ nfirms
  local chk = `r(N)'*`r(mean)'
restore
collapse (count) nfirms=firmid (sum) vfte, by(sicekk ncntry)
label var nfirms "No. of Exporters"
label var vfte "Exports (US$ mill fob)"
compress
qui summ nfirms
if `chk' ~= `r(N)'*`r(mean)'  STOP
append using `manfagg'
preserve
  foreach trf in col1 col2 col3 tot {
    restore, preserve
    tempfile `trf'
    if "`trf'"=="col1"  collapse (sum) `trf'_nfirms=nfirms `trf'_vfte=vfte if ncntry== 1, by(sicekk)
    if "`trf'"=="col2"  collapse (sum) `trf'_nfirms=nfirms `trf'_vfte=vfte if ncntry>=10, by(sicekk)
    if "`trf'"=="col3"  collapse (sum) `trf'_nfirms=nfirms `trf'_vfte=vfte if ncntry>=50, by(sicekk)
    if "`trf'"=="tot"   collapse (sum) `trf'_nfirms=nfirms `trf'_vfte=vfte              , by(sicekk)
    label var `trf'_nfirms "No. of Exporters"
    label var `trf'_vfte "Exports (US$ mill fob)"
    compress
    sort sicekk
    save ``trf''
    }
restore
use `col1', clear
foreach trf in col2 col3 tot {
  sort sicekk
  merge sicekk using ``trf''
  drop _m
  }
egen _totcol1 = sum(col1_nfirms)
replace _totcol1 = _totcol1/2
if _totcol1[17]~=col1_nfirms[17]  STOP
drop _totcol1
foreach trf in col1 col2 col3 {
  replace `trf'_nfirms = int((`trf'_nfirms/tot_nfirms)*1000)/10
  replace `trf'_vfte = int((`trf'_vfte/tot_vfte)*1000)/10
  gen str _`trf'_nfirms = string(`trf'_nfirms)
  replace _`trf'_nfirms = _`trf'_nfirms + ".0" if index(_`trf'_nfirms,".")==0
  replace _`trf'_nfirms = "0" + _`trf'_nfirms if index(_`trf'_nfirms,".")==1
  replace _`trf'_nfirms = "0.0" if _`trf'_nfirms=="0."
  gen str _`trf'_vfte = string(`trf'_vfte)
  replace _`trf'_vfte = _`trf'_vfte + ".0" if index(_`trf'_vfte,".")==0
  replace _`trf'_vfte = "0" + _`trf'_vfte if index(_`trf'_vfte,".")==1
  replace _`trf'_vfte = "0.0" if _`trf'_vfte=="0."
  replace _`trf'_vfte = "(" + _`trf'_vfte + ")"
  }
drop tot_nfirms tot_vfte
format col* %9.1f
drop col*
decode sicekk, generate(_sicekk)
drop sicekk
rename _sicekk sicekk
order sicekk
rename _col1_nfirms br_market1_a
rename _col2_nfirms br_market10_a
rename _col3_nfirms br_market50_a
rename _col1_vfte br_market1_b
rename _col2_vfte br_market10_b
rename _col3_vfte br_market50_b
label var br_market1_a  "Single market: Perc. firms"
label var br_market1_b  "Single market: Perc. exports"
label var br_market10_a "Ten+ markets: Perc. firms"
label var br_market10_b "Ten+ markets: Perc. exports"
label var br_market50_a "Fifty+ markets: Perc. firms"
label var br_market50_b "Fifty+ markets: Perc. exports"
sort sicekk
merge using `fr_us_penet'
count if _m~=3
if `r(N)'>0  STOP  // non-matching tables
list _sicekk sicekk
drop _*
rename sicekk _rowname
save "braxpmkt/tex/manf-ekk/ekk_tab2_tbl.dta", replace
foreach var in _rowname br_market1_a br_market1_b br_market10_a br_market10_b br_market50_a br_market50_b fr_market1_a fr_market1_b fr_market10_a fr_market10_b fr_market50_a {
  replace `var' = `var' + " &"
  }
foreach var in br_market1_b br_market10_b br_market50_b fr_market1_b fr_market10_b {
  replace `var' = `var' + "&"
  }
replace fr_market50_b = fr_market50_b + " \" + "\"
outsheet using "braxpmkt/tex/manf-ekk/ekk_tab2.tex", noquote nonames replace


// BJRS TABLE 2: Exporting by Manufacturing Firms

* U.S. 2002
tempfile us_nfirms
insheet using "braxpmkt/bjrs/bjrs07-tab2.tex", clear delimit("&") nonames
replace v1="99" if v2=="Aggregate Manufacturing"
drop if v1=="" | v1=="NAICS"
rename v1 naic
replace v5 = trim(subinstr(v5,"\\","",.))
gen us02nperc = int(real(subinstr(v3,",","",.)))
gen us02expperc = int(real(subinstr(v4,",","",.)))
rename v2 sector
drop v3-v5
gen _naic = int(real(naic))
drop naic
rename _naic naic
order naic
replace naic=999 if naic==99
compress
sort naic
save `us_nfirms'

* Brazil RAIS 2000
tempfile br_nfirms
insheet using "rais/base-agg/cnae/aggsec.csv", comma clear
keep if ano==2000
keep clas_cnae_95 n_cnpj_radic
gen cnaestr = string(int(clas_cnae_95/10))
replace cnaestr = "0" + cnae if length(cnae)<4
drop clas_cnae_95
label var cnae "CNAE sector (annual mode)"
rename n_cnpj_radic nfirms
label var nfirms "Number of firms"
gen cnae = int(real(cnaestr))
order cnae cnaestr
sort cnae
merge cnae using `naics'
tab _m
list cnae nfirms if _m==1
list cnae naic if _m==2
drop if _m~=3
collapse (sum) nfirms, by(naic) fast
label var nfirms "Number of producers"
expand 2 if naic==339
replace naic=999 if _n==_N
qui summ nfirms if naic~=999
replace nfirms = `r(sum)' if naic==999
sort naic
save `br_nfirms'

* Brazil SECEX 2000
tempfile scx_nfirms
use firmid using "braxpmkt/secex/firms-2000.dta", clear
sort firmid
by firmid: keep if _n==1
merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
drop _m n_pis rem_dezembro n_cnpj_estbl n_municipio ind*
rename mod_clas_cnae_95 cnae
drop if cnae==.
collapse (count) scxfirms=firmid, by(cnae) fast
label var scxfirms "Number of exporters"
gen cnaestr = string(int(cnae/10))
replace cnaestr = "0" + cnaestr if length(cnaestr)<4
drop cnae
label var cnaestr "CNAE sector (annual mode)"
gen cnae = int(real(cnaestr))
order cnae cnaestr
sort cnae
merge cnae using `naics'
tab _m
list cnae scxfirms if _m==1
list cnae naic if _m==2
drop if _m~=3
collapse (sum) scxfirms, by(naic)
label var scxfirms "Number of exporters"
expand 2 if naic==339
replace naic=999 if _n==_N
qui summ scxfirms if naic~=999
replace scxfirms = `r(sum)' if naic==999
sort naic
save `scx_nfirms'

* Put together BJRS Table 2
use `br_nfirms'
merge naic using `scx_nfirms'
drop _m
replace scxfirms = 0 if scxfirms==.
qui summ nfirms if naic~=999
gen nperc = int((nfirms/`r(sum)')*100+.5)
gen scxperc = int((scxfirms/nfirms)*1000+.5)/10
keep naic nperc scxperc
order naic nperc scxperc
sort naic
merge naic using `us_nfirms'
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
order naic sector us02nperc us02expperc  nperc scxperc
rename naic naicbjrs
mklbl sector naicbjrs
drop sector
label var nperc "Brazil 2000: Perc. of Producers"
label var scxperc "Brazil 2000: Share of Exporters"
label var us02nperc "U.S. 2002: Perc. of Producers"
label var us02expperc "U.S. 2002: Share of Exporters"
qui label save naicbjrs using "braxpmkt/tex/manf-bjrs/naicbjrs", replace
gen str _rowname = string(naicbjrs)
sort naicbjrs
drop naicbjrs
save "braxpmkt/tex/manf-bjrs/bjrs_tab2_tbl.dta", replace
matload bjrs_tab2_tbl, dropall p(braxpmkt/tex/manf-bjrs) over
est2tex bjrs_tab2, replace dropall preserve ready vallabel(naicbjrs) p(braxpmkt/tex/manf-bjrs) fancy thousep extracols(2)


// BJRS TABLE 4: Distributions by Number of Products and Destinations

* U.S. 2002
foreach tab in 4a 4b 4c {
  insheet using "braxpmkt/bjrs/bjrs07-tab`tab'.tex", clear delimit("&") names
  gen _dall = real(trim(subinstr(dall,"\\","",.)))
  drop dall
  rename _dall dall
  rename v1 _rowname
  compress
  sort _rowname
  save "braxpmkt/tex/manf-bjrs/bjrs_tab`tab'_tbl.dta", replace
  matload bjrs_tab`tab'_tbl, dropall p(braxpmkt/tex/manf-bjrs) over
  mat rename bjrs_tab`tab'_tbl us_tab`tab'_tbl
  local rownames : rownames us_tab`tab'_tbl
  mat roweq us_tab`tab'_tbl = us
  }

* Brazil 2000
tempfile scx_dnfirms
use firmid wtfkey hs6dgt value using "braxpmkt/secex/firms-2000.dta", clear
merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
drop _m rem_dezembro n_cnpj_estbl n_municipio ind*
rename mod_clas_cnae_95 cnae
drop if cnae==.
gen cnaestr = string(int(cnae/10))
replace cnaestr = "0" + cnaestr if length(cnaestr)<4
drop cnae
label var cnaestr "CNAE sector (annual mode)"
gen cnae = int(real(cnaestr))
order cnae cnaestr
sort cnae
merge cnae using `naics'
tab _m
drop if _m~=3  // keep manufacturing firms only, as in BJRS 2007
* worldwide export activity by firm (as in %04/prodsales-firm-cntry-correlates.do)
preserve
  tempfile wwgoods
  collapse (sum) value, by(firmid n_pis hs6dgt) fast
  collapse (sum) wwsales=value (count) wwgoods=value, by(firmid n_pis) fast
  replace wwsales = wwsales/1000000
  label var wwgoods "Worldwide No. of prod. (HS 6)"
  label var wwsales "Worldwide exports (US$ mill)"
  sort firmid
  save `wwgoods'
restore, preserve
  tempfile wwdest
  collapse (sum) value, by(firmid n_pis wtfkey) fast
  collapse (sum) dwwsales=value (count) wwdest=value, by(firmid n_pis) fast
  replace dwwsales = dwwsales/1000000
  label var wwdest "Worldwide No. of Destinations"
  label var dwwsales "Worldwide exports (US$ mill)"
  compress
  sort firmid
  save `wwdest'
restore
use `wwgoods', clear
merge firmid using `wwdest'
qui count if _m~=3
if `r(N)'>0  STOP
gen _chk = wwsales - dwwsales
qui summ _chk
if `r(sum)'>0  STOP
drop _m _chk dwwsales
replace wwgoods = 5 if wwgoods>=5
replace wwdest = 5 if wwdest>=5
drop if wwgoods==0 | wwdest==0
order firmid wwgoods wwdest
preserve
tabl2tex firmid, type(count) r(wwgoods) c(wwdest) p(braxpmkt/tex/manf-bjrs) name(bjrs_tab4a) fancy replace over nolog
restore, preserve
tabl2tex wwsales, type(sum) r(wwgoods) c(wwdest) p(braxpmkt/tex/manf-bjrs) name(bjrs_tab4b) fancy replace over nolog
restore, preserve
tabl2tex n_pis, type(sum) r(wwgoods) c(wwdest) p(braxpmkt/tex/manf-bjrs) name(bjrs_tab4c) fancy replace over nolog
restore
foreach tab in 4a 4b 4c {
  mat rename bjrs_tab`tab'_tbl hs6dgt_tab`tab'_tbl
  }

* Brazil 2000, 8-digit product level
tempfile scx_dnfirms
use firmid wtfkey prodctid value using "braxpmkt/secex/firms-2000-ncm8dgt.dta", clear
merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
drop _m rem_dezembro n_cnpj_estbl n_municipio ind*
rename mod_clas_cnae_95 cnae
drop if cnae==.
gen cnaestr = string(int(cnae/10))
replace cnaestr = "0" + cnaestr if length(cnaestr)<4
drop cnae
label var cnaestr "CNAE sector (annual mode)"
gen cnae = int(real(cnaestr))
order cnae cnaestr
sort cnae
merge cnae using `naics'
tab _m
drop if _m~=3  // keep manufacturing firms only, as in BJRS 2007
* worldwide export activity by firm (as in %04/prodsales-firm-cntry-correlates.do)
preserve
  tempfile wwgoods
  collapse (sum) value, by(firmid n_pis prodctid) fast
  collapse (sum) wwsales=value (count) wwgoods=value, by(firmid n_pis) fast
  replace wwsales = wwsales/1000000
  label var wwgoods "Worldwide No. of prod. (NCM 8)"
  label var wwsales "Worldwide exports (US$ mill)"
  sort firmid
  save `wwgoods'
restore, preserve
  tempfile wwdest
  collapse (sum) value, by(firmid n_pis wtfkey) fast
  collapse (sum) dwwsales=value (count) wwdest=value, by(firmid n_pis) fast
  replace dwwsales = dwwsales/1000000
  label var wwdest "Worldwide No. of Destinations"
  label var dwwsales "Worldwide exports (US$ mill)"
  compress
  sort firmid
  save `wwdest'
restore
use `wwgoods', clear
merge firmid using `wwdest'
qui count if _m~=3
if `r(N)'>0  STOP
gen _chk = wwsales - dwwsales
qui summ _chk
if `r(sum)'>0  STOP
drop _m _chk dwwsales
replace wwgoods = 5 if wwgoods>=5
replace wwdest = 5 if wwdest>=5
drop if wwgoods==0 | wwdest==0
order firmid wwgoods wwdest
preserve
tabl2tex firmid, type(count) r(wwgoods) c(wwdest) p(braxpmkt/tex/manf-bjrs) name(bjrs_tab4a) fancy replace over nolog
restore, preserve
tabl2tex wwsales, type(sum) r(wwgoods) c(wwdest) p(braxpmkt/tex/manf-bjrs) name(bjrs_tab4b) fancy replace over nolog
restore, preserve
tabl2tex n_pis, type(sum) r(wwgoods) c(wwdest) p(braxpmkt/tex/manf-bjrs) name(bjrs_tab4c) fancy replace over nolog
restore
foreach tab in 4a 4b 4c {
  mat rename bjrs_tab`tab'_tbl ncm8dgt_tab`tab'_tbl
  }

* Put table together
foreach tab in 4a 4b 4c {
  local tot = hs6dgt_tab`tab'_tbl[6,6]
  mat hs6dgt_tab`tab'_tbl = (hs6dgt_tab`tab'_tbl/`tot')*100
  mat rownames hs6dgt_tab`tab'_tbl = `rownames'
  mat roweq hs6dgt_tab`tab'_tbl = br_hs6
  local tot = ncm8dgt_tab`tab'_tbl[6,6]
  mat ncm8dgt_tab`tab'_tbl = (ncm8dgt_tab`tab'_tbl/`tot')*100
  mat rownames ncm8dgt_tab`tab'_tbl = `rownames'
  mat roweq ncm8dgt_tab`tab'_tbl = br_ncm8
  mat bjrs_tab`tab'_tbl = us_tab`tab'_tbl \ hs6dgt_tab`tab'_tbl \ ncm8dgt_tab`tab'_tbl
  mat drop us_tab`tab'_tbl
  }
est2tex bjrs_tab4a, digits(1) replace dropall ready p(braxpmkt/tex/manf-bjrs) fancy
est2tex bjrs_tab4b, digits(2) replace dropall ready p(braxpmkt/tex/manf-bjrs) fancy
est2tex bjrs_tab4c, digits(1) replace dropall ready p(braxpmkt/tex/manf-bjrs) fancy


// EKK FIGURE 1a: Presence of Brazilian firms

* Count RAIS manufacturers
tempfile raistot
insheet using "rais/base-agg/cnae/aggsec.csv", comma clear
keep if ano==2000
keep clas_cnae_95 n_cnpj_radic
gen cnae = string(int(clas_cnae_95/10))
replace cnae = "0" + cnae if length(cnae)<4
drop clas_cnae_95
label var cnae "CNAE sector (annual mode)"
rename n_cnpj_radic nfirms
label var nfirms "Number of firms"
order cnae
sort cnae
merge cnae using "brazcomp/filters/cnae-isic2"
tab _m
list cnae nfirms if _m==1
list cnae isic2 if _m==2
drop if _m~=3
drop _m cnae_desc
collapse (sum) nfirms, by(isic2dgt3)
label var nfirms "Number of producers"
rename isic2dgt3 isic2
qui do "braxpmkt/conc/unido-isic2.do"
label values isic2 isic2
sort isic2
merge isic2 using `isic2ekk'
tab _m
drop if _m==1  // EKK manufacturing firms only
collapse (sum) nfirms, by(sicekk)
label var nfirms "Number of producers"
drop if sicekk==1 // drop excluded category: petroleum refining [ISIC: 353, Petroleum refineries]
order sicekk
sort sicekk
qui summ nfirms
local totfirms = `r(N)'*`r(mean)'
disp in green "RAIS manufacturers: " in yellow `totfirms'
collapse (sum) nfirms
gen byte ncntry = 1
compress
order ncntry
sort ncntry
save `raistot'

* Brazil: Firm count by number of markets
use firmid sicekk wtfkey vfte using "braxpmkt/secex/replication-data-2000.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
collapse (count) ncntry=wtfkey, by(firmid)
collapse (count) nfirms=firmid, by(ncntry)
replace ncntry = ncntry+1
qui summ nfirms
local totexp = `r(N)'*`r(mean)'
append using `raistot'
replace nfirms = nfirms - `totexp' if ncntry==1
label var ncntry "Number of markets per firm"
label var nfirms "Number of Brazilian firms"
sort ncntry
graph twoway scatter nfirms ncntry, ysca(log) ylab(1 10 100 1000 "1,000" 10000 "10,000" 100000 "100,000" 1000000 "1,000,000", angle(horizontal))  xsca(log) xlab(1 2 4 8 16 32 64 128) graphregion(color(white)) scheme(sj)
graph export "braxpmkt/eps/manf-ekk/ekk-fig1.eps", replace

gen lnncntry = ln(ncntry)
gen lnnfirms = ln(nfirms)
label var lnncntry "Log No. of Markets per firm"
label var lnnfirms "Log No. of Brazilian firms"
reg lnnfirms lnncntry
disp in gr "Brazil. Elasticity of number of firms with respect to number of markets: " in yellow _b[lnncntry] in green " (standard error " in yellow _se[lnncntry] in green ")"
reg lnnfirms lnncntry if ncntry>1  // only exporters, omitting domestic market
disp in gr "Brazil. Elasticity of number of exporters with respect to number of export destinations: " in yellow _b[lnncntry] in green " (standard error " in yellow _se[lnncntry] in green ")"

* Chile: Firm count by number of markets
use firmnum sicekk wtfkey vfte using "braxpmkt/chile/replication-data-2000-chile.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
collapse (count) ncntry=wtfkey, by(firmnum)
collapse (count) nfirms=firmnum, by(ncntry)
replace ncntry = ncntry+1
expand 2 in 1  // add observation
replace ncntry=1 in 1
local totperexp = 4693/936  // from BergoMiccoRepet11, Table 5 (for 2000)
qui summ nfirms, meanonly
replace nfirms = `r(sum)'*`totperexp' if ncntry==1
label var ncntry "Number of markets per firm"
label var nfirms "Number of Chilean firms"
sort ncntry
graph twoway scatter nfirms ncntry, ysca(log) ylab(1 10 100 1000 "1,000" 10000 "10,000" 100000 "100,000" 1000000 "1,000,000", angle(horizontal))  xsca(log) xlab(1 2 4 8 16 32 64 128) graphregion(color(white)) scheme(sj)
graph export "braxpmkt/eps/manf-ekk-chile/ekk-fig1.eps", replace

gen lnncntry = ln(ncntry)
gen lnnfirms = ln(nfirms)
label var lnncntry "Log No. of Markets per firm"
label var lnnfirms "Log No. of Chilean firms"
reg lnnfirms lnncntry
disp in gr "Chile. Elasticity of number of firms with respect to number of markets: " in yellow _b[lnncntry] in green " (standard error " in yellow _se[lnncntry] in green ")"
reg lnnfirms lnncntry if ncntry>1  // only exporters, omitting domestic market
disp in gr "Chile. Elasticity of number of exporters with respect to number of export destinations: " in yellow _b[lnncntry] in green " (standard error " in yellow _se[lnncntry] in green ")"

// EKK FIGURE 3: Entry and market size

* Brazil
use firmid wtfkey sicekk sunb tfshare tabsorp using "braxpmkt/secex/replication-data-2000.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmid sicekk
sort wtfkey
by wtfkey: keep if _n==1
order wtfkey
sort wtfkey
joinby wtfkey using `cntrymap', unmatched(both) _merge(_merge)
tab _m
count if wtfkey==wtfkey[_n-1]
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] 
if `r(N)'>0  STOP
drop if _m~=3
drop _m
gen yvar = (sunb/tfshare)/1000
replace tabsorp=tabsorp/1000000000
label var yvar "Thousands of Brazilian exporters/Brazilian mkt. share"
label var tabsorp "Destination market size (US$ billion)"
graph twoway scatter yvar tabsorp, ysca(log) ylab(1 10 100 1000 "1,000" 10000 "10,000", angle(horizontal)) xsca(log range(.1 10000)) xlab(.1 1 10 100 1000 "1,000" 10000 "10,000") graphregion(color(white)) scheme(sj) ytitle("Thousands of Brazilian" "exporters/Brazilian mkt. share") mlabel(iso3code) mlabposition(0) msymbol(i)
graph export "braxpmkt/eps/manf-ekk/ekk-fig3.eps", replace
gen ln_yvar = log(yvar)
local lbl : variable label yvar
label var ln_yvar "`lbl'"
gen ln_tabsorp = log(tabsorp)
local lbl : variable label tabsorp
label var ln_tabsorp "`lbl'"
graph twoway lfit ln_yvar ln_tabsorp, clpattern(solid) || scatter ln_yvar ln_tabsorp, ylab(0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000", angle(horizontal)) xsca(range(0 9.2103404)) xlab(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000") graphregion(color(white)) scheme(sj) ytitle("Thousands of Brazilian exporters" "per Brazilian market share") mlabel(iso3code) mlabposition(0) msymbol(i) legend(off)
graph export "braxpmkt/eps/manf-ekk/ekk-fig3-lfit.eps", replace
reg ln_yvar ln_tabsorp

* Chile
use firmnum wtfkey sicekk sunb tfshare tabsorp using "braxpmkt/chile/replication-data-2000-chile.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmnum sicekk
sort wtfkey
by wtfkey: keep if _n==1
order wtfkey
sort wtfkey
joinby wtfkey using `cntrymap', unmatched(both) _merge(_merge)
tab _m
count if wtfkey==wtfkey[_n-1]
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] 
if `r(N)'>0  STOP
drop if _m~=3
drop _m
gen yvar = (sunb/tfshare)/1000
replace tabsorp=tabsorp/1000000000
label var yvar "Thousands of Chilean exporters/Chilean mkt. share"
label var tabsorp "Destination market size (US$ billion)"
graph twoway scatter yvar tabsorp, ysca(log) ylab(1 10 100 1000 "1,000" 10000 "10,000", angle(horizontal)) xsca(log range(.1 10000)) xlab(.1 1 10 100 1000 "1,000" 10000 "10,000") graphregion(color(white)) scheme(sj) ytitle("Thousands of Brazilian" "exporters/Brazilian mkt. share") mlabel(iso3code) mlabposition(0) msymbol(i)
graph export "braxpmkt/eps/manf-ekk-chile/ekk-fig3.eps", replace
gen ln_yvar = log(yvar)
local lbl : variable label yvar
label var ln_yvar "`lbl'"
gen ln_tabsorp = log(tabsorp)
local lbl : variable label tabsorp
label var ln_tabsorp "`lbl'"
graph twoway lfit ln_yvar ln_tabsorp, clpattern(solid) || scatter ln_yvar ln_tabsorp, ylab(0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000", angle(horizontal)) xsca(range(0 9.2103404)) xlab(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000") graphregion(color(white)) scheme(sj) ytitle("Thousands of Brazilian exporters" "per Brazilian market share") mlabel(iso3code) mlabposition(0) msymbol(i) legend(off)
graph export "braxpmkt/eps/manf-ekk-chile/ekk-fig3-lfit.eps", replace
reg ln_yvar ln_tabsorp

// VARIATION ON EKK FIGURE 3: Firm-product entry and market size

* Brazil
tempfile prodscx
use firmid wtfkey hs6dgt value using "braxpmkt/secex/prodsales-data-2000.dta", clear
collapse (sum) value (count) goods=value, by(firmid wtfkey) fast  // collapse over goods
drop if value==0
replace value = value/1000000
label var goods "Exporter scope (HS 6-digit)"
label var value "Total exports (US$ mill fob)"
gen gsales=value/goods
label var gsales "Exports per product (US$ mill fob)"
collapse (sum) totsales=value totgoods=goods (count) nfirms=firmid (mean) goods sumsales=value, by(wtfkey) fast
gen double wgsales = sumsales/goods
gen double brsdens = totsales/(nfirms*totgoods*wgsales) // see BRS "Multi-Product Firms and Trade Liberalization" (Dec 2008), section 5.3. Margins of Trade and Trade Costs
gen double brjssales = totsales/(nfirms*totgoods)
gen _chk = totsales - (nfirms * goods * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
replace _chk = totsales - (nfirms * totgoods * brsdens * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
drop _chk
label var totsales  "Total Exports (US$ mill fob)"
label var totgoods  "Total Number of Products"
label var nfirms    "Number of Exporters"
label var sumsales  "Mean Exports (US$ mill fob)"
label var goods     "Mean Scope (HS 6-digit)"
label var wgsales   "Mean Scale (US$ mill fob)"
label var brsdens   "Density of trade (BRS 2008)"
label var brjssales "Exp/prod.&firm (US$ mil fob)"
order wtfkey totsales nfirms sumsales goods wgsales totgoods brsdens brjssales
sort wtfkey
save `prodscx' 
use firmid wtfkey sicekk sunb tfshare tabsorp using "braxpmkt/secex/replication-data-2000.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmid sicekk
sort wtfkey
by wtfkey: keep if _n==1
order wtfkey
sort wtfkey
joinby wtfkey using `cntrymap', unmatched(both) _merge(_merge)
tab _m
count if wtfkey==wtfkey[_n-1]
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] 
if `r(N)'>0  STOP
drop if _m~=3
drop _m
sort wtfkey
merge wtfkey using `prodscx'
tab _m
tab wtfkey if _m==2
keep if _m==3
drop _m
gen yvar = goods
replace tabsorp=tabsorp/1000000000
label var yvar "Mean Brazilian exporter scope (HS 6-digit)"
label var tabsorp "Destination market size (US$ billion)"
gen ln_yvar = log(yvar)
local lbl : variable label yvar
label var ln_yvar "`lbl'"
gen ln_tabsorp = log(tabsorp)
local lbl : variable label tabsorp
label var ln_tabsorp "`lbl'"
graph twoway lfit ln_yvar ln_tabsorp, clpattern(solid) || scatter ln_yvar ln_tabsorp, ylab(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16", angle(horizontal)) xsca(range(0 9.2103404)) xlab(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000") graphregion(color(white)) scheme(sj) ytitle("Mean Brazilian exporter scope (HS 6-dgt)") mlabel(iso3code) mlabposition(0) msymbol(i) legend(off)
graph export "braxpmkt/eps/manf-ekk/ekk-fig3-scope-lfit.eps", replace
gen ln_tfshare = ln(tfshare)
reg ln_yvar ln_tabsorp
reg ln_yvar ln_tabsorp ln_tfshare
replace yvar = (goods/tfshare)
label var yvar "Mean Brazilian exporter scope (HS 6-digit)/Brazilian mkt. share"
replace ln_yvar = log(yvar)
local lbl : variable label yvar
label var ln_yvar "`lbl'"
graph twoway lfit ln_yvar ln_tabsorp, clpattern(solid) || scatter ln_yvar ln_tabsorp, ylab(2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000" 11.512925 "100,000" 13.815511 "1,000,000", angle(horizontal)) xsca(range(0 9.2103404)) xlab(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000") graphregion(color(white)) scheme(sj) ytitle("Mean Brazilian exporter scope (HS 6-dgt)" "per Brazilian mkt. share") mlabel(iso3code) mlabposition(0) msymbol(i) legend(off)
graph export "braxpmkt/eps/manf-ekk/ekk-fig3-scope-pershare-lfit.eps", replace
reg ln_yvar ln_tabsorp

* Chile
tempfile prodchl
use firmid wtfkey hs6dgt value using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
collapse (sum) value (count) goods=value, by(firmid wtfkey) fast  // collapse over goods
drop if value==0
replace value = value/1000000
label var goods "Exporter scope (HS 6-digit)"
label var value "Total exports (US$ mill fob)"
gen gsales=value/goods
label var gsales "Exports per product (US$ mill fob)"
collapse (sum) totsales=value totgoods=goods (count) nfirms=firmid (mean) goods sumsales=value, by(wtfkey) fast
gen double wgsales = sumsales/goods
gen double brsdens = totsales/(nfirms*totgoods*wgsales) // see BRS "Multi-Product Firms and Trade Liberalization" (Dec 2008), section 5.3. Margins of Trade and Trade Costs
gen double brjssales = totsales/(nfirms*totgoods)
gen _chk = totsales - (nfirms * goods * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
replace _chk = totsales - (nfirms * totgoods * brsdens * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
drop _chk
label var totsales  "Total Exports (US$ mill fob)"
label var totgoods  "Total Number of Products"
label var nfirms    "Number of Exporters"
label var sumsales  "Mean Exports (US$ mill fob)"
label var goods     "Mean Scope (HS 6-digit)"
label var wgsales   "Mean Scale (US$ mill fob)"
label var brsdens   "Density of trade (BRS 2008)"
label var brjssales "Exp/prod.&firm (US$ mil fob)"
order wtfkey totsales nfirms sumsales goods wgsales totgoods brsdens brjssales
sort wtfkey
save `prodchl' 
use firmnum wtfkey sicekk sunb tfshare tabsorp using "braxpmkt/chile/replication-data-2000-chile.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmnum sicekk
sort wtfkey
by wtfkey: keep if _n==1
order wtfkey
sort wtfkey
joinby wtfkey using `cntrymap', unmatched(both) _merge(_merge)
tab _m
count if wtfkey==wtfkey[_n-1]
list wtfkey iso3code if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] 
if `r(N)'>0  STOP
drop if _m~=3
drop _m
sort wtfkey
merge wtfkey using `prodchl'
tab _m
tab wtfkey if _m==2
keep if _m==3
drop _m
gen yvar = goods
replace tabsorp=tabsorp/1000000000
label var yvar "Mean Chilean exporter scope (HS 6-digit)"
label var tabsorp "Destination market size (US$ billion)"
gen ln_yvar = log(yvar)
local lbl : variable label yvar
label var ln_yvar "`lbl'"
gen ln_tabsorp = log(tabsorp)
local lbl : variable label tabsorp
label var ln_tabsorp "`lbl'"
graph twoway lfit ln_yvar ln_tabsorp, clpattern(solid) || scatter ln_yvar ln_tabsorp, ylab(0 "1" .69314718 "2" 1.3862944 "4" 2.0794415 "8" 2.7725887 "16", angle(horizontal)) xsca(range(0 9.2103404)) xlab(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000") graphregion(color(white)) scheme(sj) ytitle("Mean Chilean exporter scope (HS 6-dgt)") mlabel(iso3code) mlabposition(0) msymbol(i) legend(off)
graph export "braxpmkt/eps/manf-ekk-chile/ekk-fig3-scope-lfit.eps", replace
gen ln_tfshare = ln(tfshare)
reg ln_yvar ln_tabsorp
reg ln_yvar ln_tabsorp ln_tfshare
replace yvar = (goods/tfshare)
label var yvar "Mean Chilean exporter scope (HS 6-digit)/Chilean mkt. share"
replace ln_yvar = log(yvar)
local lbl : variable label yvar
label var ln_yvar "`lbl'"
graph twoway lfit ln_yvar ln_tabsorp, clpattern(solid) || scatter ln_yvar ln_tabsorp, ylab(2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000" 11.512925 "100,000" 13.815511 "1,000,000", angle(horizontal)) xsca(range(0 9.2103404)) xlab(-2.3025851 ".1" 0 "1" 2.3025851 "10" 4.6051702 "100" 6.9077553 "1,000" 9.2103404 "10,000") graphregion(color(white)) scheme(sj) ytitle("Mean Chilean exporter scope (HS 6-dgt)" "per Chilean mkt. share") mlabel(iso3code) mlabposition(0) msymbol(i) legend(off)
graph export "braxpmkt/eps/manf-ekk-chile/ekk-fig3-scope-pershare-lfit.eps", replace
reg ln_yvar ln_tabsorp

// REGRESSION 1: Elasticity of number of Brazilian exporters per Brazilian market share with respect to market size

use firmid wtfkey sicekk sunb tfshare tabsorp sunbsic svftesic svfte gdp_cap_usd population using "braxpmkt/secex/replication-data-2000.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmid
sort wtfkey sicekk
by wtfkey sicekk: keep if _n==1
order wtfkey sicekk
sort wtfkey sicekk

gen ln_n_sd = ln(sunb)  // sunb = count(firmid), by(wtfkey) at destination level
label var ln_n_sd "Log No. SCX exp'rs to dest."
gen ln_lambda_sd = ln(tfshare)  // tfshare = svfte/tabsorp at destination level
label var ln_lambda_sd "Log SCX market share at dest."
gen ln_x_d = ln(tabsorp)  // tabsorp = wtf_output + wtf_imports - wtf_exports at destination level
label var ln_x_d "Absorption at dest."

gen ln_n_isd = ln(sunbsic)  // sunbsic = count(firmid), by(wtfkey sicekk) at destination-industry level
label var ln_n_isd "Log No. SCX exp'rs to dest. ind."
gen ln_b_isd = ln(svftesic/svfte)  // svftesic = sum(vfte), by(wtfkey sicekk) at destination-industry level; svfte = sum(vfte), by(wtfkey) at destination level
label var ln_b_isd "Log Industry bias of SCX sales"

gen ln_lambdagdp_sd = ln(svfte/(gdp_cap_usd*population))  // tfshare = svfte/gdp at destination level
label var ln_lambdagdp_sd "Log GDP share at dest."
gen ln_xgdpcap_d = ln(gdp_cap_usd)  // per-capita GDP at destination
label var ln_xgdpcap_d "GDP per cap. at dest."
gen ln_xpop_d = ln(population)  // population at destination
label var ln_xpop_d "Population at dest."

preserve
keep sicekk wtfkey ln_n_sd ln_lambda_sd ln_x_d
sort wtfkey
by wtfkey: keep if _n==1
sort wtfkey sicekk
reg ln_n_sd ln_lambda_sd ln_x_d
* est2vec ekk_reg, vars(ln_lambda_sd ln_x_d ln_b_isd ln_p_sd ln_p_isd ln_n_isd ln_lambdagdp_sd ln_xgdpcap_d ln_xpop_d _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho) name(reg1) replace
est2vec ekk_reg, vars(ln_lambda_sd ln_x_d ln_b_isd ln_p_sd ln_p_isd ln_n_isd _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho) name(reg1) replace
restore, preserve

keep sicekk wtfkey ln_n_sd ln_lambdagdp_sd ln_xgdpcap_d ln_xpop_d
sort wtfkey
by wtfkey: keep if _n==1
sort wtfkey sicekk
reg ln_n_sd ln_lambdagdp_sd ln_xgdpcap_d ln_xpop_d
* est2vec ekk_reg, addto(ekk_reg) name(reggdp)
restore

reg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd, cluster(sicekk)
est2vec ekk_reg, addto(ekk_reg) name(reg2)
xtreg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd, fe i(sicekk)
est2vec ekk_reg, addto(ekk_reg) name(xtreg2)

est2tex ekk_reg, fancy p(braxpmkt/estmat/manf-ekk) replace level(90 95 99) mark(starse) dropall
mat drop ekk_reg_b ekk_reg_se ekk_reg_e
mat rename ekk_reg_tbl br_ekk_reg_tbl
mat coleq br_ekk_reg_tbl = br
insheet using "braxpmkt/ekk/ekk04-reg.tex", clear delimit("&")
rename v1 _rowname
gen reg1   = real(v2)
gen reg2   = real(v3)
gen xtreg2 = real(subinstr(v4,"\","",.))
drop v2-v4
save "braxpmkt/tex/manf-ekk/ekk_reg_tbl", replace
matload ekk_reg_tbl, p(braxpmkt/tex/manf-ekk) missing(.) dropall
mat coleq ekk_reg_tbl = fr
mat ekk_reg_tbl = br_ekk_reg_tbl , ekk_reg_tbl
mat drop br_ekk_reg_tbl
est2tex ekk_reg, ready fancy p(braxpmkt/tex/manf-ekk) replace level(90 95 99) mark(starse) dropall extracols(3)


// REGRESSION 1: Elasticity of number of Chilean exporters per Chilean market share with respect to market size

use firmid wtfkey sicekk sunb tfshare tabsorp sunbsic svftesic svfte gdp_cap_usd population using "braxpmkt/chile/replication-data-2000-chile.dta", clear
drop if sicekk==.
drop if sicekk==1 | sicekk==18
drop firmid
sort wtfkey sicekk
by wtfkey sicekk: keep if _n==1
order wtfkey sicekk
sort wtfkey sicekk

gen ln_n_sd = ln(sunb)  // sunb = count(firmid), by(wtfkey) at destination level
label var ln_n_sd "Log No. CHL exp'rs to dest."
gen ln_lambda_sd = ln(tfshare)  // tfshare = svfte/tabsorp at destination level
label var ln_lambda_sd "Log CHL market share at dest."
gen ln_x_d = ln(tabsorp)  // tabsorp = wtf_output + wtf_imports - wtf_exports at destination level
label var ln_x_d "Absorption at dest."

gen ln_n_isd = ln(sunbsic)  // sunbsic = count(firmid), by(wtfkey sicekk) at destination-industry level
label var ln_n_isd "Log No. CHL exp'rs to dest. ind."
gen ln_b_isd = ln(svftesic/svfte)  // svftesic = sum(vfte), by(wtfkey sicekk) at destination-industry level; svfte = sum(vfte), by(wtfkey) at destination level
label var ln_b_isd "Log Industry bias of CHL sales"

gen ln_lambdagdp_sd = ln(svfte/(gdp_cap_usd*population))  // tfshare = svfte/gdp at destination level
label var ln_lambdagdp_sd "Log GDP share at dest."
gen ln_xgdpcap_d = ln(gdp_cap_usd)  // per-capita GDP at destination
label var ln_xgdpcap_d "GDP per cap. at dest."
gen ln_xpop_d = ln(population)  // population at destination
label var ln_xpop_d "Population at dest."

preserve
keep sicekk wtfkey ln_n_sd ln_lambda_sd ln_x_d
sort wtfkey
by wtfkey: keep if _n==1
sort wtfkey sicekk
reg ln_n_sd ln_lambda_sd ln_x_d
* est2vec ekk_reg, vars(ln_lambda_sd ln_x_d ln_b_isd ln_p_sd ln_p_isd ln_n_isd ln_lambdagdp_sd ln_xgdpcap_d ln_xpop_d _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho) name(reg1) replace
est2vec ekk_reg, vars(ln_lambda_sd ln_x_d ln_b_isd ln_p_sd ln_p_isd ln_n_isd _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho) name(reg1) replace
restore, preserve

keep sicekk wtfkey ln_n_sd ln_lambdagdp_sd ln_xgdpcap_d ln_xpop_d
sort wtfkey
by wtfkey: keep if _n==1
sort wtfkey sicekk
reg ln_n_sd ln_lambdagdp_sd ln_xgdpcap_d ln_xpop_d
* est2vec ekk_reg, addto(ekk_reg) name(reggdp)
restore

reg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd, cluster(sicekk)
est2vec ekk_reg, addto(ekk_reg) name(reg2)
xtreg ln_n_isd ln_lambda_sd ln_x_d ln_b_isd, fe i(sicekk)
est2vec ekk_reg, addto(ekk_reg) name(xtreg2)

est2tex ekk_reg, fancy p(braxpmkt/estmat/manf-ekk-chile) replace level(90 95 99) mark(starse) dropall
mat drop ekk_reg_b ekk_reg_se ekk_reg_e
mat rename ekk_reg_tbl br_ekk_reg_tbl
mat coleq br_ekk_reg_tbl = br
insheet using "braxpmkt/ekk/ekk04-reg.tex", clear delimit("&")
rename v1 _rowname
gen reg1   = real(v2)
gen reg2   = real(v3)
gen xtreg2 = real(subinstr(v4,"\","",.))
drop v2-v4
save "braxpmkt/tex/manf-ekk/ekk_reg_chl_tbl", replace
matload ekk_reg_chl_tbl, p(braxpmkt/tex/manf-ekk) missing(.) dropall
mat coleq ekk_reg_chl_tbl = fr
mat ekk_reg_chl_tbl = br_ekk_reg_tbl , ekk_reg_chl_tbl
mat drop br_ekk_reg_tbl
est2tex ekk_reg_chl, ready fancy p(braxpmkt/tex/manf-ekk) replace level(90 95 99) mark(starse) dropall extracols(3)


// REGRESSION 2: Gravity and Decomposed U.S. Exports, 2000 (BJRS TABLE 6 and BRS08 TABLE 3)

* Brazil 2000
use firmid wtfkey hs6dgt value using "braxpmkt/secex/firms-2000.dta", clear
merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
drop _m n_pis rem_dezembro n_cnpj_estbl n_municipio ind*
rename mod_clas_cnae_95 cnae
drop if cnae==.
gen cnaestr = string(int(cnae/10))
replace cnaestr = "0" + cnaestr if length(cnaestr)<4
drop cnae
label var cnaestr "CNAE sector (annual mode)"
gen cnae = int(real(cnaestr))
order cnae cnaestr
sort cnae
merge cnae using `naics'
tab _m
drop if _m~=3  // keep manufacturing firms only, as in BJRS 2007

collapse (sum) value (count) goods=value, by(firmid wtfkey) fast  // collapse over goods
drop if value==0
replace value = value/1000000
label var goods "Exporter scope (HS 6-digit)"
label var value "Total exports (US$ mill fob)"
gen gsales=value/goods
label var gsales "Exports per product (US$ mill fob)"

collapse (sum) totsales=value totgoods=goods (count) nfirms=firmid (mean) goods sumsales=value, by(wtfkey) fast
gen double wgsales = sumsales/goods
gen double brsdens = totsales/(nfirms*totgoods*wgsales) // see BRS "Multi-Product Firms and Trade Liberalization" (Dec 2008), section 5.3. Margins of Trade and Trade Costs
gen double brjssales = totsales/(nfirms*totgoods)
gen _chk = totsales - (nfirms * goods * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
replace _chk = totsales - (nfirms * totgoods * brsdens * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
drop _chk
label var totsales  "Total Exports (US$ mill fob)"
label var totgoods  "Total Number of Products"
label var nfirms    "Number of Exporters"
label var sumsales  "Mean Exports (US$ mill fob)"
label var goods     "Mean Scope (HS 6-digit)"
label var wgsales   "Mean Scale (US$ mill fob)"
label var brsdens   "Density of trade (BRS 2008)"
label var brjssales "Exp/prod.&firm (US$ mil fob)"
order wtfkey totsales nfirms sumsales goods wgsales totgoods brsdens brjssales

* merge country data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/country-data-2000.dta"
replace indoecd90=0 if indoecd90==.
replace indoecd00=0 if indoecd00==.
tab wtfkey if _m==2
tab wtfkey if _m==1
drop _m
* merge destination data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/distance-data.dta"
tab wtfkey if _m==2
tab wtfkey if _m==1
drop _m
* take logs
keep wtfkey indoecd90 totsales nfirms sumsales goods wgsales totgoods brsdens brjssales gdp_usd lndist population
rename gdp_usd gdp
foreach var in totsales nfirms sumsales goods wgsales totgoods brsdens brjssales gdp population {
  gen ln_`var' = ln(`var')
  local label : variable label `var'
  drop `var'
  label var ln_`var' "Log `label'"
  }
gen ln_gdp_cap = ln_gdp - ln_population
label var ln_gdp_cap "Log GDP per capita [curr. USD]"

reg ln_totsales ln_gdp lndist
est2vec bjrshs6_regam, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec bjrshs6_regam, addto(bjrshs6_regam) name(nfirms)
reg ln_goods ln_gdp lndist
est2vec bjrshs6_regam, addto(bjrshs6_regam) name(goods)
reg ln_wgsales ln_gdp lndist
est2vec bjrshs6_regam, addto(bjrshs6_regam) name(wgsales)
reg ln_totsales ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_regam, addto(bjrshs6_regam) name(totsales_nonoecd)
reg ln_nfirms ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_regam, addto(bjrshs6_regam) name(nfirms_nonoecd)
reg ln_goods ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_regam, addto(bjrshs6_regam) name(goods_nonoecd)
reg ln_wgsales ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_regam, addto(bjrshs6_regam) name(wgsales_nonoecd)
est2tex bjrshs6_regam, fancy p(braxpmkt/estmat/manf-bjrs) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp_cap ln_pop lndist
est2vec bjrshs6_regam_pop, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp_cap ln_pop lndist
est2vec bjrshs6_regam_pop, addto(bjrshs6_regam_pop) name(nfirms)
reg ln_goods ln_gdp_cap ln_pop lndist
est2vec bjrshs6_regam_pop, addto(bjrshs6_regam_pop) name(goods)
reg ln_wgsales ln_gdp_cap ln_pop lndist
est2vec bjrshs6_regam_pop, addto(bjrshs6_regam_pop) name(wgsales)
est2tex bjrshs6_regam_pop, fancy p(braxpmkt/estmat/manf-bjrs) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp lndist
est2vec bjrshs6_reg, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec bjrshs6_reg, addto(bjrshs6_reg) name(nfirms)
reg ln_totgoods ln_gdp lndist
est2vec bjrshs6_reg, addto(bjrshs6_reg) name(totgoods)
reg ln_brjssales ln_gdp lndist
est2vec bjrshs6_reg, addto(bjrshs6_reg) name(brjssales)
reg ln_totsales ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_reg, addto(bjrshs6_reg) name(totsales_nonoecd)
reg ln_nfirms ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_reg, addto(bjrshs6_reg) name(nfirms_nonoecd)
reg ln_totgoods ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_reg, addto(bjrshs6_reg) name(totgoods_nonoecd)
reg ln_brjssales ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_reg, addto(bjrshs6_reg) name(brjssales_nonoecd)
est2tex bjrshs6_reg, fancy p(braxpmkt/estmat/manf-bjrs) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp lndist
est2vec brshs6_regrev, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec brshs6_regrev, addto(brshs6_regrev) name(nfirms)
reg ln_totgoods ln_gdp lndist
est2vec brshs6_regrev, addto(brshs6_regrev) name(totgoods)
reg ln_brsdens ln_gdp lndist
est2vec brshs6_regrev, addto(brshs6_regrev) name(brsdens)
reg ln_wgsales ln_gdp lndist
est2vec brshs6_regrev, addto(brshs6_regrev) name(wgsales)
est2tex brshs6_regrev, fancy p(braxpmkt/estmat/manf-bjrs) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp_cap ln_pop lndist
est2vec brshs6_regrev_pop, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp_cap ln_pop lndist
est2vec brshs6_regrev_pop, addto(brshs6_regrev_pop) name(nfirms)
reg ln_totgoods ln_gdp_cap ln_pop lndist
est2vec brshs6_regrev_pop, addto(brshs6_regrev_pop) name(totgoods)
reg ln_brsdens ln_gdp_cap ln_pop lndist
est2vec brshs6_regrev_pop, addto(brshs6_regrev_pop) name(brsdens)
reg ln_wgsales ln_gdp_cap ln_pop lndist
est2vec brshs6_regrev_pop, addto(brshs6_regrev_pop) name(wgsales)
est2tex brshs6_regrev_pop, fancy p(braxpmkt/estmat/manf-bjrs) replace level(90 95 99) mark(starse) dropall digits(2) preserve

* Brazil 2000, 8-digit product level
use firmid wtfkey prodctid value using "braxpmkt/secex/firms-2000-ncm8dgt.dta", clear
merge firmid using "braxpmkt/secex/rais-cnpj-cnae-2000.dta", nokeep
tab _m
drop _m n_pis rem_dezembro n_cnpj_estbl n_municipio ind*
rename mod_clas_cnae_95 cnae
drop if cnae==.
gen cnaestr = string(int(cnae/10))
replace cnaestr = "0" + cnaestr if length(cnaestr)<4
drop cnae
label var cnaestr "CNAE sector (annual mode)"
gen cnae = int(real(cnaestr))
order cnae cnaestr
sort cnae
merge cnae using `naics'
tab _m
drop if _m~=3  // keep manufacturing firms only, as in BJRS 2007

collapse (sum) value (count) goods=value, by(firmid wtfkey) fast  // collapse over goods
drop if value==0
replace value = value/1000000
label var goods "Exporter scope (NCM 8-digit)"
label var value "Total exports (US$ mill fob)"
gen gsales=value/goods
label var gsales "Exports per product (US$ mill fob)"

collapse (sum) totsales=value totgoods=goods (count) nfirms=firmid (mean) goods sumsales=value, by(wtfkey) fast
gen double wgsales = sumsales/goods
gen double brsdens = totsales/(nfirms*totgoods*wgsales) // see BRS "Multi-Product Firms and Trade Liberalization" (Dec 2008), section 5.3. Margins of Trade and Trade Costs
gen double brjssales = totsales/(nfirms*totgoods)
gen _chk = totsales - (nfirms * goods * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
replace _chk = totsales - (nfirms * totgoods * brsdens * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
drop _chk
label var totsales  "Total Exports (US$ mill fob)"
label var totgoods  "Total Number of Products"
label var nfirms    "Number of Exporters"
label var sumsales  "Mean Exports (US$ mill fob)"
label var goods     "Mean Scope (HS 6-digit)"
label var wgsales   "Mean Scale (US$ mill fob)"
label var brsdens   "Density of trade (BRS 2008)"
label var brjssales "Avg Exp./prd.&firm (US$ mil fob)"
order wtfkey totsales nfirms sumsales goods wgsales totgoods brsdens brjssales

* merge country data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/country-data-2000.dta"
tab wtfkey if _m==2
tab wtfkey if _m==1
drop _m
* merge destination data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/distance-data.dta"
tab wtfkey if _m==2
tab wtfkey if _m==1
drop _m
* take logs
keep wtfkey indoecd90 totsales nfirms sumsales goods wgsales totgoods brsdens brjssales gdp_usd lndist
rename gdp_usd gdp
foreach var in totsales nfirms sumsales goods wgsales totgoods brsdens brjssales gdp {
  gen ln_`var' = ln(`var')
  local label : variable label `var'
  drop `var'
  label var ln_`var' "Log `label'"
  }

reg ln_totsales ln_gdp lndist
est2vec bjrsncm8_regam, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec bjrsncm8_regam, addto(bjrsncm8_regam) name(nfirms)
reg ln_goods ln_gdp lndist
est2vec bjrsncm8_regam, addto(bjrsncm8_regam) name(goods)
reg ln_wgsales ln_gdp lndist
est2vec bjrsncm8_regam, addto(bjrsncm8_regam) name(wgsales)
reg ln_totsales ln_gdp lndist if indoecd90==0
* est2vec bjrsncm8_regam, addto(bjrsncm8_regam) name(totsales_nonoecd)
reg ln_nfirms ln_gdp lndist if indoecd90==0
* est2vec bjrsncm8_regam, addto(bjrsncm8_regam) name(nfirms_nonoecd)
reg ln_goods ln_gdp lndist if indoecd90==0
* est2vec bjrsncm8_regam, addto(bjrsncm8_regam) name(goods_nonoecd)
reg ln_wgsales ln_gdp lndist if indoecd90==0
* est2vec bjrsncm8_regam, addto(bjrsncm8_regam) name(wgsales_nonoecd)
est2tex bjrsncm8_regam, fancy p(braxpmkt/estmat/manf-bjrs) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp lndist
est2vec bjrsncm8_reg, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec bjrsncm8_reg, addto(bjrsncm8_reg) name(nfirms)
reg ln_totgoods ln_gdp lndist
est2vec bjrsncm8_reg, addto(bjrsncm8_reg) name(totgoods)
reg ln_brjssales ln_gdp lndist
est2vec bjrsncm8_reg, addto(bjrsncm8_reg) name(brjssales)
reg ln_totsales ln_gdp lndist if indoecd90==0
* est2vec bjrsncm8_reg, addto(bjrsncm8_reg) name(totsales_nonoecd)
reg ln_nfirms ln_gdp lndist if indoecd90==0
* est2vec bjrsncm8_reg, addto(bjrsncm8_reg) name(nfirms_nonoecd)
reg ln_totgoods ln_gdp lndist if indoecd90==0
* est2vec bjrsncm8_reg, addto(bjrsncm8_reg) name(totgoods_nonoecd)
reg ln_brjssales ln_gdp lndist if indoecd90==0
* est2vec bjrsncm8_reg, addto(bjrsncm8_reg) name(brjssales_nonoecd)
est2tex bjrsncm8_reg, fancy p(braxpmkt/estmat/manf-bjrs) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp lndist
est2vec brsncm8_regrev, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec brsncm8_regrev, addto(brsncm8_regrev) name(nfirms)
reg ln_totgoods ln_gdp lndist
est2vec brsncm8_regrev, addto(brsncm8_regrev) name(totgoods)
reg ln_brsdens ln_gdp lndist
est2vec brsncm8_regrev, addto(brsncm8_regrev) name(brsdens)
reg ln_wgsales ln_gdp lndist
est2vec brsncm8_regrev, addto(brsncm8_regrev) name(wgsales)
est2tex brsncm8_regrev, fancy p(braxpmkt/estmat/manf-bjrs) replace level(90 95 99) mark(starse) dropall digits(2) preserve

// Chilean country concordance
tempfile wbcode
use "brazaux/conc/countries/country-table.dta", clear
qui do "braxpmkt/conc/wtfkey-chile.do"
label define wtfkey 0 `"World Total"', modify
label values wtfkey wtfkey
* Chilean concordance
rename wdikey wbcode
replace wbcode="AND" if isoname=="Andorra"
replace wbcode="ARB" if isoname=="Aruba"
replace wbcode="ASM" if isoname=="American Samoa"
replace wbcode="GER" if wtfcountry=="Germany"
replace wbcode="MCO" if isoname=="Monaco"
replace wbcode="YSR" if isoname=="Yugoslavia"
keep wbcode wtfkey
duplicates drop
drop if wbcode==""
** note that the matching is not unique by wbcode; in the case of USA, this was creating problems later on
duplicates list wbcode
** manual fix for all wbcodes with multiple wtfkeys: USA, CHN, CZE, MAR, NCL, NOR, YEM, YSR
drop if wbcode=="USA" & wtfkey~=218400
drop if wbcode=="CHN" & wtfkey~=481560
drop if wbcode=="CZE" & wtfkey~=582030
drop if wbcode=="MAR" & wtfkey~=135040
drop if wbcode=="NCL" & wtfkey~=725400
drop if wbcode=="NOR" & wtfkey~=555780
drop if wbcode=="YEM" & wtfkey~=448870
drop if wbcode=="YSR" & wtfkey~=598910
duplicates list wbcode
sort wbcode
save `wbcode'

* Chile 2000
use rut wbcode pr8 exp using "braxpmkt/chile/exports-2000.dta", clear
gen double firmid = real(subinstr(rut,"K","9",.))
sort firmid rut
qui count if firmid==firmid[_n-1] & rut~=rut[_n-1]
if `r(N)'>0  STOP  // replacement of "K" in RUT with 9 results in duplicates
drop rut
rename pr8 hs8dgt
rename exp value
sort wbcode firmid hs8dgt
label var firmid "Firm Number (RUT, but 9 where K)"
label var hs8dgt "Harmonized System 8-digit code"
label var value "Value (current US$ fob)"
merge wbcode using `wbcode'
tab _merge
keep if _m==3
drop _m wbcode
gen hs6dgt = int(hs8dgt/100)
collapse (sum) value, by(wtfkey firmid hs6dgt)
label var hs6dgt "Harmonized System 6-digit code"

collapse (sum) value (count) goods=value, by(firmid wtfkey) fast  // collapse over goods
drop if value==0
replace value = value/1000000
label var goods "Exporter scope (HS 6-digit)"
label var value "Total exports (US$ mill fob)"
gen gsales=value/goods
label var gsales "Exports per product (US$ mill fob)"

collapse (sum) totsales=value totgoods=goods (count) nfirms=firmid (mean) goods sumsales=value, by(wtfkey) fast
gen double wgsales = sumsales/goods
gen double brsdens = totsales/(nfirms*totgoods*wgsales) // see BRS "Multi-Product Firms and Trade Liberalization" (Dec 2008), section 5.3. Margins of Trade and Trade Costs
gen double brjssales = totsales/(nfirms*totgoods)
gen _chk = totsales - (nfirms * goods * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
replace _chk = totsales - (nfirms * totgoods * brsdens * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
drop _chk
label var totsales  "Total Exports (US$ mill fob)"
label var totgoods  "Total Number of Products"
label var nfirms    "Number of Exporters"
label var sumsales  "Mean Exports (US$ mill fob)"
label var goods     "Mean Scope (HS 6-digit)"
label var wgsales   "Mean Scale (US$ mill fob)"
label var brsdens   "Density of trade (BRS 2008)"
label var brjssales "Exp/prod.&firm (US$ mil fob)"
order wtfkey totsales nfirms sumsales goods wgsales totgoods brsdens brjssales

* merge country data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/country-data-2000.dta"
tab wtfkey if _m==2
tab wtfkey if _m==1
drop _m
* merge destination data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/distance-data.dta"
tab wtfkey if _m==2
tab wtfkey if _m==1
drop _m
* take logs
keep wtfkey indoecd90 totsales nfirms sumsales goods wgsales totgoods brsdens brjssales gdp_usd lndist
rename gdp_usd gdp
foreach var in totsales nfirms sumsales goods wgsales totgoods brsdens brjssales gdp {
  gen ln_`var' = ln(`var')
  local label : variable label `var'
  drop `var'
  label var ln_`var' "Log `label'"
  }

reg ln_totsales ln_gdp lndist
est2vec bjrshs6_regam, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec bjrshs6_regam, addto(bjrshs6_regam) name(nfirms)
reg ln_goods ln_gdp lndist
est2vec bjrshs6_regam, addto(bjrshs6_regam) name(goods)
reg ln_wgsales ln_gdp lndist
est2vec bjrshs6_regam, addto(bjrshs6_regam) name(wgsales)
reg ln_totsales ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_regam, addto(bjrshs6_regam) name(totsales_nonoecd)
reg ln_nfirms ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_regam, addto(bjrshs6_regam) name(nfirms_nonoecd)
reg ln_goods ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_regam, addto(bjrshs6_regam) name(goods_nonoecd)
reg ln_wgsales ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_regam, addto(bjrshs6_regam) name(wgsales_nonoecd)
est2tex bjrshs6_regam, fancy p(braxpmkt/estmat/manf-bjrs-chile) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp lndist
est2vec bjrshs6_reg, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec bjrshs6_reg, addto(bjrshs6_reg) name(nfirms)
reg ln_totgoods ln_gdp lndist
est2vec bjrshs6_reg, addto(bjrshs6_reg) name(totgoods)
reg ln_brjssales ln_gdp lndist
est2vec bjrshs6_reg, addto(bjrshs6_reg) name(brjssales)
reg ln_totsales ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_reg, addto(bjrshs6_reg) name(totsales_nonoecd)
reg ln_nfirms ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_reg, addto(bjrshs6_reg) name(nfirms_nonoecd)
reg ln_totgoods ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_reg, addto(bjrshs6_reg) name(totgoods_nonoecd)
reg ln_brjssales ln_gdp lndist if indoecd90==0
* est2vec bjrshs6_reg, addto(bjrshs6_reg) name(brjssales_nonoecd)
est2tex bjrshs6_reg, fancy p(braxpmkt/estmat/manf-bjrs-chile) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp lndist
est2vec brshs6_regrev, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec brshs6_regrev, addto(brshs6_regrev) name(nfirms)
reg ln_totgoods ln_gdp lndist
est2vec brshs6_regrev, addto(brshs6_regrev) name(totgoods)
reg ln_brsdens ln_gdp lndist
est2vec brshs6_regrev, addto(brshs6_regrev) name(brsdens)
reg ln_wgsales ln_gdp lndist
est2vec brshs6_regrev, addto(brshs6_regrev) name(wgsales)
est2tex brshs6_regrev, fancy p(braxpmkt/estmat/manf-bjrs-chile) replace level(90 95 99) mark(starse) dropall digits(2) preserve

* Chile 2000, 8-digit product level
use rut wbcode pr8 exp using "braxpmkt/chile/exports-2000.dta", clear
gen double firmid = real(subinstr(rut,"K","9",.))
sort firmid rut
qui count if firmid==firmid[_n-1] & rut~=rut[_n-1]
if `r(N)'>0  STOP  // replacement of "K" in RUT with 9 results in duplicates
drop rut
rename pr8 hs8dgt
rename exp value
sort wbcode firmid hs8dgt
label var firmid "Firm Number (RUT, but 9 where K)"
label var hs8dgt "Harmonized System 8-digit code"
label var value "Value (current US$ fob)"
merge wbcode using `wbcode'
tab _merge
keep if _m==3
drop _m wbcode

count
local cnt = `r(N)'
collapse (sum) value, by(firmid wtfkey hs8dgt) fast  // collapse over goods
count
if `cnt'~=`r(N)'  disp in yellow `cnt'-`r(N)' in red " non-unique firm-destination-product obs. out of " in yellow `r(N)' in red " original obs. at HS 8-digit level"
collapse (sum) value (count) goods=value, by(firmid wtfkey) fast  // collapse over goods
drop if value==0
replace value = value/1000000
label var goods "Exporter scope (HS 8-digit)"
label var value "Total exports (US$ mill fob)"
gen gsales=value/goods
label var gsales "Exports per product (US$ mill fob)"

collapse (sum) totsales=value totgoods=goods (count) nfirms=firmid (mean) goods sumsales=value, by(wtfkey) fast
gen double wgsales = sumsales/goods
gen double brsdens = totsales/(nfirms*totgoods*wgsales) // see BRS "Multi-Product Firms and Trade Liberalization" (Dec 2008), section 5.3. Margins of Trade and Trade Costs
gen double brjssales = totsales/(nfirms*totgoods)
gen _chk = totsales - (nfirms * goods * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
replace _chk = totsales - (nfirms * totgoods * brsdens * wgsales)
qui summ _chk
if abs(`r(sum)')>1e-10  STOP
drop _chk
label var totsales  "Total Exports (US$ mill fob)"
label var totgoods  "Total Number of Products"
label var nfirms    "Number of Exporters"
label var sumsales  "Mean Exports (US$ mill fob)"
label var goods     "Mean Scope (HS 6-digit)"
label var wgsales   "Mean Scale (US$ mill fob)"
label var brsdens   "Density of trade (BRS 2008)"
label var brjssales "Exp/prod.&firm (US$ mil fob)"
order wtfkey totsales nfirms sumsales goods wgsales totgoods brsdens brjssales

* merge country data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/country-data-2000.dta"
tab wtfkey if _m==2
tab wtfkey if _m==1
drop _m
* merge destination data
sort wtfkey 
merge wtfkey using "braxpmkt/ext/distance-data.dta"
tab wtfkey if _m==2
tab wtfkey if _m==1
drop _m
* take logs
keep wtfkey indoecd90 totsales nfirms sumsales goods wgsales totgoods brsdens brjssales gdp_usd lndist
rename gdp_usd gdp
foreach var in totsales nfirms sumsales goods wgsales totgoods brsdens brjssales gdp {
  gen ln_`var' = ln(`var')
  local label : variable label `var'
  drop `var'
  label var ln_`var' "Log `label'"
  }

reg ln_totsales ln_gdp lndist
est2vec bjrshs8_regam, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec bjrshs8_regam, addto(bjrshs8_regam) name(nfirms)
reg ln_goods ln_gdp lndist
est2vec bjrshs8_regam, addto(bjrshs8_regam) name(goods)
reg ln_wgsales ln_gdp lndist
est2vec bjrshs8_regam, addto(bjrshs8_regam) name(wgsales)
reg ln_totsales ln_gdp lndist if indoecd90==0
* est2vec bjrshs8_regam, addto(bjrshs8_regam) name(totsales_nonoecd)
reg ln_nfirms ln_gdp lndist if indoecd90==0
* est2vec bjrshs8_regam, addto(bjrshs8_regam) name(nfirms_nonoecd)
reg ln_goods ln_gdp lndist if indoecd90==0
* est2vec bjrshs8_regam, addto(bjrshs8_regam) name(goods_nonoecd)
reg ln_wgsales ln_gdp lndist if indoecd90==0
* est2vec bjrshs8_regam, addto(bjrshs8_regam) name(wgsales_nonoecd)
est2tex bjrshs8_regam, fancy p(braxpmkt/estmat/manf-bjrs-chile) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp lndist
est2vec bjrshs8_reg, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec bjrshs8_reg, addto(bjrshs8_reg) name(nfirms)
reg ln_totgoods ln_gdp lndist
est2vec bjrshs8_reg, addto(bjrshs8_reg) name(totgoods)
reg ln_brjssales ln_gdp lndist
est2vec bjrshs8_reg, addto(bjrshs8_reg) name(brjssales)
reg ln_totsales ln_gdp lndist if indoecd90==0
* est2vec bjrshs8_reg, addto(bjrshs8_reg) name(totsales_nonoecd)
reg ln_nfirms ln_gdp lndist if indoecd90==0
* est2vec bjrshs8_reg, addto(bjrshs8_reg) name(nfirms_nonoecd)
reg ln_totgoods ln_gdp lndist if indoecd90==0
* est2vec bjrshs8_reg, addto(bjrshs8_reg) name(totgoods_nonoecd)
reg ln_brjssales ln_gdp lndist if indoecd90==0
* est2vec bjrshs8_reg, addto(bjrshs8_reg) name(brjssales_nonoecd)
est2tex bjrshs8_reg, fancy p(braxpmkt/estmat/manf-bjrs-chile) replace level(90 95 99) mark(starse) dropall digits(2) preserve

reg ln_totsales ln_gdp lndist
est2vec brshs8_regrev, e(N r2) name(totsales) replace
reg ln_nfirms ln_gdp lndist
est2vec brshs8_regrev, addto(brshs8_regrev) name(nfirms)
reg ln_totgoods ln_gdp lndist
est2vec brshs8_regrev, addto(brshs8_regrev) name(totgoods)
reg ln_brsdens ln_gdp lndist
est2vec brshs8_regrev, addto(brshs8_regrev) name(brsdens)
reg ln_wgsales ln_gdp lndist
est2vec brshs8_regrev, addto(brshs8_regrev) name(wgsales)
est2tex brshs8_regrev, fancy p(braxpmkt/estmat/manf-bjrs-chile) replace level(90 95 99) mark(starse) dropall digits(2) preserve

log close
set more off
