*! version 1.1  03nov2014  by Marc Muendler  muendler@ucsd.edu

version 9.2
set more off
set virtual on
clear
set mem 1000m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/poolsec"
capture mkdir "braxpmkt/estmat/poolsec"

capture log close
log using "braxpmkt/logs/prep-prodlvl-2delta.log", replace

local sec "poolsec"

// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach smpl in "manf-firms" "comrc-firms" {
  if "`smpl'"=="manf-firms"     local prfx "br"
  if "`smpl'"=="comrc-firms"    local prfx "brcmrc"
  tempfile `prfx'
  use "braxpmkt/secex/expprod-`smpl'", clear
  label var lncurrnum "Log Product rank within firm-dest. (HS 6)"
  gen lngoods=ln(goods)
  label var lngoods "Log number of goods (HS 6)"
  foreach var in lngoods lncurrnum {
    rename `var' `prfx'_`var'
    }
  gen str subsmpl = "`smpl'"
  label var subsmpl "Sample"
  sort firmid subsmpl wtfkey hs6dgt
  save ``prfx''
  }
use `br'
append using `brcmrc'
sort subsmpl firmid wtfkey hs6dgt
foreach smpl in "manf-firms" "comrc-firms" {
  if "`smpl'"=="manf-firms"     local prfx "br" 
  if "`smpl'"=="comrc-firms"    local prfx "brcmrc"
  replace `prfx'_lngoods = 0 if `prfx'_lngoods==.
  replace `prfx'_lncurrnum = 0 if  `prfx'_lncurrnum==.
  }
sort firmid

* global product rank
preserve
  tempfile globnum
  collapse (sum) value, by(firmid hs6dgt subsmpl) fast
  gsort firmid hs6dgt -value
  by firmid: gen globnum = _n
  label var globnum "Global product rank by firm (HS 6-digit)"
  keep firmid hs6dgt globnum subsmpl
  gen lnglobnum = log(globnum)
  label var globnum "Log Global product rank by firm (HS 6-digit)"
  gen br_lnglobnum = log(globnum) if subsmpl=="manf-firms"
  replace br_lnglobnum = 0 if globnum~=. & subsmpl~="manf-firms"
  label var br_lnglobnum "Log Global product rank by firm (HS 6-digit)"
  gen brcmrc_lnglobnum = log(globnum) if subsmpl=="comrc-firms"
  replace brcmrc_lnglobnum = 0 if globnum~=. & subsmpl~="comrc-firms"
  label var brcmrc_lnglobnum "Log Global product rank by firm (HS 6-digit)"
  drop subsmpl
  sort firmid hs6dgt
  compress
  save `globnum'
restore
merge n:1 firmid hs6dgt using `globnum'
drop _merge

* log vars
gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"
gen lncurrnum=ln(currnum)
label var lncurrnum "Log Product rank within firm-dest. (HS 6)"

* indicator for dual Delta estimates
gen byte indlac = (int(wtfkey/100000)==3)  //  LAC: >=Argentina & <=U.S. NES (assuming U.S. NES is dominated by Puerto Rico and U.S. Virgin Islands; Guam, Northern Mariana Islands and American Samoa are unimportant)
label var indlac "Indic.: Destination in LAC"
foreach prfx in "" "br_" "brcmrc_" {
  gen `prfx'lngoods_lac = `prfx'lngoods * indlac
  label var `prfx'lngoods_lac "Log number of goods (HS 6) at LAC dest."
  gen `prfx'lngoods_row = `prfx'lngoods * (1-indlac)
  label var `prfx'lngoods_row "Log number of goods (HS 6) at ROW dest."
  }

* use [(\sigma-1)/\theta]\ln(1-\Pr) as proxy to (\sigma-1)\ln(\phi/\phi^*G)
tempfile pctls
preserve
  collapse (sum) value, by(firmid subsmpl wtfkey goods) fast
  label var value "Destination exports (US$ fob)"
  duplicates drop
  gen lnglblphi_pctl = .
  label var lnglblphi_pctl "Productivity ratio (global pctl rank)"
  qui tab goods, matrow(gdslst)
  local rows = rowsof(gdslst)
  local gdslst ""
  forvalues i = 1/`rows' {
    local `i' = gdslst[`i',1]
    local gdslst "`gdslst' ``i''"
    }
  * disp "`gdslst'"
  egen totexp = sum(value), by(firmid)  // global exports (crucial difference to braxpmkt/%stata/%04regress/prep-prodlvl-struct.do)
  foreach i in `gdslst' {
    qui egen rank`i'=rank(totexp) if goods>=`i', by(subsmpl wtfkey) unique
    label var rank`i' "Sales rank in scope-`i' grp."
    * gsort subsmpl wtfkey goods -rank`i' firmid hs6dgt
    qui egen _firms = max(rank`i'), by(subsmpl wtfkey)
    qui gen pcsal`i'=rank`i'/_firms
    label var pcsal`i' "Firm pctl: Sales in scope-`i' grp."
    qui gen _pctlval = int(pcsal`i'*100)
    qui count if _pctlval>100 & _pctlval~=.
    if `r(N)' > 0  STOP  // bad percentile definition
    replace lnglblphi_pctl = ln(1-pcsal`i') if goods==`i'
    qui drop rank`i' _firms pcsal`i' _pctlval
    }
  keep firmid wtfkey lnglblphi_pctl
  qui duplicates report
  if `r(unique_value)'~=`r(N)'  STOP  // duplicates
  duplicates drop
  sort firmid wtfkey
  save `pctls'
restore
sort firmid wtfkey
merge firmid wtfkey using `pctls'
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete rematch
drop _m
sort firmid wtfkey hs6dgt

* use log employment and log global exports, relative to log min empl and global exports, as (\phi/\phi^*G) proxies
merge firmid using "braxpmkt/secex/prodsales-rais-2000-addons.dta", nokeep keep(n_pis wagebill avgpsihat indfdicc)
qui count if _m~=3
if `r(N)'>0  STOP  // unexpected data discrepancy
drop _m
egen totexp = sum(exp(lnvalue)), by(firmid)
egen minphi_exp = min(totexp), by(subsmpl goods wtfkey)
gen lnphiratio_exp = ln(totexp/minphi_exp)
label var lnphiratio_exp "Productivity ratio (Tot exports)"
egen minphi_empl = min(n_pis), by(subsmpl goods wtfkey)
gen lnphiratio_empl = ln(n_pis/minphi_empl)
label var lnphiratio_empl "Productivity ratio (Employment)"
* gen _wagebill = n_pis * exp(avgpsihat)
* egen minphi_wageb = min(_wagebill), by(subsmpl goods wtfkey)
* gen lnphiratio_wageb = ln(_wagebill/minphi_wageb)
* label var lnphiratio_wageb "Productivity ratio (FE wage bill)"
* egen minphi_psi = min(avgpsihat), by(subsmpl goods wtfkey)
* gen lnphiratio_psi = avgpsihat-minphi_psi  // psihat is log-wage effect (already in logs)
* label var lnphiratio_psi "Productivity ratio (Avg Plant FE)"
* egen minphi_wbill = min(wagebill), by(subsmpl goods wtfkey)
* gen lnphiratio_wbill = ln(wagebill/minphi_wbill)
* label var lnphiratio_wbill "Productivity ratio (Wage bill)"
drop n_pis avgpsihat wagebill min*

order firmid cnae wtfkey hs6dgt value goods currnum lnvalue lngoods* lncurrnum
sort firmid wtfkey hs6dgt
compress
saveold "braxpmkt/secex/prodsales-rais-2000-2delta.dta", replace v(11)

log close
set more off
