*! version 1.0.2  05jul2011  by Marc Muendler  muendler@ucsd.edu

version 9.2
set more off
set virtual on
clear
set mem 1000m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/poolsec-ncm8"
capture mkdir "braxpmkt/estmat/poolsec-ncm8"

capture log close
log using "braxpmkt/logs/prep-prodlvl-struct-ncm8.log", replace

local sec "poolsec"

// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach smpl in "manf-firms" "comrc-firms" {
  if "`smpl'"=="manf-firms"     local prfx "br"
  if "`smpl'"=="comrc-firms"    local prfx "brcmrc"
  tempfile `prfx'
  use "braxpmkt/secex/expprod-`smpl'-ncm8", clear
  gen lngoods=ln(goods)
  label var lngoods "Log number of goods (NCM 8)"
  foreach var in lngoods lncurrnum {
    rename `var' `prfx'_`var'
    }
  gen str subsmpl = "`smpl'"
  label var subsmpl "Sample"
  sort firmid subsmpl wtfkey ncm8dgt
  save ``prfx''
  }
use `br'
append using `brcmrc'
sort subsmpl firmid wtfkey ncm8dgt
foreach smpl in "manf-firms" "comrc-firms" {
  if "`smpl'"=="manf-firms"     local prfx "br" 
  if "`smpl'"=="comrc-firms"    local prfx "brcmrc"
  replace `prfx'_lngoods = 0 if `prfx'_lngoods==.
  replace `prfx'_lncurrnum = 0 if  `prfx'_lncurrnum==.
  }
sort firmid

* use [(\sigma-1)/\theta]\ln(1-\Pr) as proxy to (\sigma-1)\ln(\phi/\phi^*G)
tempfile pctls
preserve
  collapse (sum) value, by(firmid subsmpl wtfkey goods) fast
  label var value "Destination exports (US$ fob)"
  duplicates drop
  gen lnphiratio_pctl = .
  label var lnphiratio_pctl "Productivity ratio (pctl rank)"
  qui tab goods, matrow(gdslst)
  local rows = rowsof(gdslst)
  local gdslst ""
  forvalues i = 1/`rows' {
    local `i' = gdslst[`i',1]
    local gdslst "`gdslst' ``i''"
    }
  * disp "`gdslst'"
  foreach i in `gdslst' {
    qui egen rank`i'=rank(value) if goods>=`i', by(subsmpl wtfkey) unique
    label var rank`i' "Sales rank in scope-`i' grp."
    * gsort subsmpl wtfkey goods -rank`i' firmid ncm8dgt
    qui egen _firms = max(rank`i'), by(subsmpl wtfkey)
    qui gen pcsal`i'=rank`i'/_firms
    label var pcsal`i' "Firm pctl: Sales in scope-`i' grp."
    qui gen _pctlval = int(pcsal`i'*100)
    qui count if _pctlval>100 & _pctlval~=.
    if `r(N)' > 0  STOP  // bad percentile definition
    replace lnphiratio_pctl = ln(1-pcsal`i') if goods==`i'
    qui drop rank`i' _firms pcsal`i' _pctlval
    }
  keep firmid wtfkey lnphiratio_pctl
  qui duplicates report
  if `r(unique_value)'~=`r(N)'  STOP  // duplicates
  duplicates drop
  sort firmid wtfkey
  save `pctls'
restore
sort firmid wtfkey
merge firmid wtfkey using `pctls'
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete rematch
drop _m
sort firmid wtfkey ncm8dgt

* use log employment and log global exports, relative to log min empl and global exports, as (\phi/\phi^*G) proxies
merge firmid using "braxpmkt/secex/prodsales-rais-2000-addons.dta", nokeep keep(n_pis wagebill avgpsihat indfdicc)
qui count if _m~=3
if `r(N)'>0  STOP  // unexpected data discrepancy
drop _m
egen totexp = sum(exp(lnvalue)), by(firmid)
egen minphi_exp = min(totexp), by(subsmpl goods wtfkey)
gen lnphiratio_exp = ln(totexp/minphi_exp)
label var lnphiratio_exp "Productivity ratio (Tot exports)"
egen minphi_empl = min(n_pis), by(subsmpl goods wtfkey)
gen lnphiratio_empl = ln(n_pis/minphi_empl)
label var lnphiratio_empl "Productivity ratio (Employment)"
* gen _wagebill = n_pis * exp(avgpsihat)
* egen minphi_wageb = min(_wagebill), by(subsmpl goods wtfkey)
* gen lnphiratio_wageb = ln(_wagebill/minphi_wageb)
* label var lnphiratio_wageb "Productivity ratio (FE wage bill)"
* egen minphi_psi = min(avgpsihat), by(subsmpl goods wtfkey)
* gen lnphiratio_psi = avgpsihat-minphi_psi  // psihat is log-wage effect (already in logs)
* label var lnphiratio_psi "Productivity ratio (Avg Plant FE)"
* egen minphi_wbill = min(wagebill), by(subsmpl goods wtfkey)
* gen lnphiratio_wbill = ln(wagebill/minphi_wbill)
* label var lnphiratio_wbill "Productivity ratio (Wage bill)"
drop n_pis avgpsihat wagebill min*

sort firmid wtfkey ncm8dgt
compress
save "braxpmkt/secex/prodsales-rais-2000-struct-ncm8.dta", replace

log close
set more off
