*! version 1.0.1  02mar2010  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 650m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/srvc-firms"
capture mkdir "braxpmkt/eps/comrc-firms"
capture mkdir "braxpmkt/eps/manf-ekk"
capture mkdir "braxpmkt/eps/chile-manffrms"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/srvc-firms"
capture mkdir "braxpmkt/estmat/comrc-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"
capture mkdir "braxpmkt/estmat/chile-manffrms"

capture log close
log using "braxpmkt/logs/prodsales-corr-prodlvl-delta-byctry.log", replace


// CORRELATIONS BETWEEN COUNTRY-SPECIFIC MARKET-ENTRY ELASTICITIES

tempfile repldat
use wtfkey tfshare using "braxpmkt/secex/replication-data-2000.dta", clear
gen ln_lambda_sd = ln(tfshare)  // tfshare = svfte/tabsorp at destination level
label var ln_lambda_sd "Log SCX market share at dest."
drop tfshare
sort wtfkey
save `repldat'

tempfile cntryvars
use wtfkey gdp_usd population using "braxpmkt/secex/prodsales-data-2000.dta", clear
collapse (sum) gdp_usd population, by(wtfkey)
label var gdp_usd "GDP [curr. USD]"
label var population "Population (total)"
gen ln_gdp_usd = ln(gdp_usd)
gen ln_pop = ln(population)
gen ln_gdp_cap_usd = ln_gdp_usd - ln_pop
label var ln_gdp_usd "Log GDP [curr. USD]"
label var ln_pop "Log Population (total)"
label var ln_gdp_cap_usd "Log GDP per cap. [curr. USD]"
drop gdp_usd population
sort wtfkey
save `cntryvars'

tempfile cntryvchl
use wtfkey gdp_usd population using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
collapse (sum) gdp_usd population, by(wtfkey)
label var gdp_usd "GDP [curr. USD]"
label var population "Population (total)"
gen ln_gdp_usd = ln(gdp_usd)
gen ln_pop = ln(population)
gen ln_gdp_cap_usd = ln_gdp_usd - ln_pop
label var ln_gdp_usd "Log GDP [curr. USD]"
label var ln_pop "Log Population (total)"
label var ln_gdp_cap_usd "Log GDP per cap. [curr. USD]"
drop gdp_usd population
sort wtfkey
save `cntryvchl'

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" "chile-manffrms" {

local smpl = subinstr("`sec'","-","",.)
tempfile `smpl'

* numeric country codes (running country numbers)
tempfile cntrylnk
use "braxpmkt/secex/expprod-`sec'", clear
qui tab wtfkey, gen(indwtf)
unab wtfvarlst : indwtf*
local i 0
foreach var of varlist `wtfvarlst' {
  local i = `i'+1
  local wtf`i' : variable label `var'
  local wtf`i' = subinstr("`wtf`i''","wtfkey==","",.)
  label define wtfnum `i' "`wtf`i''", modify
  * disp "`wtf`i'' " _continue
  } 
* label list wtfnum
* label list wtfkey
egen wtfnum = group(wtfkey)
label values wtfnum wtfnum
decode wtfkey, generate(_wtfkey)
decode wtfnum, generate(_wtfnum)
qui count if _wtfkey~=_wtfnum
if `r(N)'>0  STOP   // numeric country codes do not coincide
drop _*
keep wtfkey wtfnum
duplicates drop
sort wtfkey
if substr("`sec'",1,5)~="chile"  merge wtfkey using `cntryvars', nokeep
else                             merge wtfkey using `cntryvchl', nokeep
qui count if _m~=3
if `r(N)'  STOP  // incomplete country information
drop _m
order wtfnum wtfkey
sort wtfnum
save `cntrylnk'

* delta (matload expprodctry_tbl, p(braxpmkt/estmat/`sec') over dropall missing(.))
use "braxpmkt/estmat/`sec'/expprodctry_tbl.dta", clear
drop if _rowname=="_se"
capture rename rawdata_fewtfhssec_long_ge100 rawdata_fewtfcnae_long_ge100
keep _rowname rawdata_fewtfcnae_long_ge100
gen int wtfnum = int(real(subinstr(_rowname,"lngoods","",.))) if index(_rowname,"lngoods")>0
label var wtfnum "group(wtfkey)"
label values wtfnum wtfnum
qui summ rawdata_fewtfcnae_long_ge100 if _rowname=="lncurrnum"
local alphabar = - (1 + `r(mean)')
gen delta = rawdata_fewtfcnae_long_ge100 - `alphabar' - 1 if index(_rowname,"lngoods")>0  // delta_new = delta_old - 1
label var delta "Country-specific Delta"
sort wtfnum
merge wtfnum using `cntrylnk', nokeep
tab _m
drop _m
order wtfkey wtfnum
drop if wtfkey==.
drop _rowname
rename rawdata_fewtfcnae_long_ge100 coeff_lngoods
label var coeff_lngoods "Country-spec. Coeff. on lngoods"
rename delta delta_`smpl'
rename coeff_lngoods coeff_lngoods_`smpl'
sort wtfkey

save ``smpl''

}  // close `sec' loop

use `allsec'
foreach sec in "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" "chile-manffrms" {
  local smpl = subinstr("`sec'","-","",.)
  sort wtfkey
  merge wtfkey using ``smpl''
  drop _m
  }  // close `sec' loop
order wtfkey wtfnum delta_allsec delta_manfgoods delta_manffirms delta_srvcfirms delta_comrcfirms delta_manfekk delta_chilemanffrms coeff_lngoods_allsec coeff_lngoods_manfgoods coeff_lngoods_manffirms coeff_lngoods_srvcfirms coeff_lngoods_comrcfirms coeff_lngoods_manfekk coeff_lngoods_chilemanffrms ln_gdp_usd ln_pop ln_gdp_cap_usd
sort wtfkey
merge wtfkey using `repldat', nokeep
drop _m

corr delta_allsec delta_manfgoods delta_manffirms delta_srvcfirms delta_comrcfirms delta_manfekk delta_chilemanffrms ln_gdp_usd ln_pop ln_gdp_cap_usd ln_lambda_sd

log close
set more off
