*! version 1.0.8  08oct2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.9  09mar2008  by Oana Hirakawa     otocoian@ucsd.edu
*! version 1.1.1  29may2008  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 500m
set trace off
set matsize 300

cd "$root"

capture mkdir "braxpmkt/estmat/chile-manffrms"

capture log close
log using "braxpmkt/logs/prodsales-firm-cntry-correlates-chile.log", replace


// 1. CORRELATES OF COUNTRY EFFECTS IN FIRM-DESTINATION DATA AND SCALE REGRESSIONS, WORLDWIDE

* loop over different sector definitions has been eliminated (manf-firms only)
local sec="manf-firms"

use firmid hs6dgt isic2 wtfkey value wtf_exports wtf_imports wtf_chilexp wtf_output population gdp_cap_usd lndist contig comlang_off using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

gen wtf_absorpt = wtf_output + wtf_imports - wtf_exports
label var wtf_absorpt "ISIC2 absorption at dest."

replace wtf_exports = ln(wtf_exports)
rename wtf_exports lnexp
label var lnexp "Log ISIC2 exports from dest."
replace wtf_imports = ln(wtf_imports)
rename wtf_imports lnimp
label var lnimp "Log ISIC2 imports to dest."
replace wtf_chilexp = ln(wtf_chilexp)
rename wtf_chilexp lnbrexp
label var lnbrexp "Chile's Log ISIC2 exp. to dst."
replace wtf_output = ln(wtf_output)
rename wtf_output lnoutp
label var lnoutp "Log ISIC2 output at dest."
replace wtf_absorpt = ln(wtf_absorpt)
rename wtf_absorpt lnabso
label var lnabso "Log ISIC2 absorption at dest."

replace population=ln(population)
rename population lnpop
label var lnpop "Log Population (total)"
replace gdp_cap_usd=ln(gdp_cap_usd)
rename gdp_cap_usd lngdpcap
label var lngdpcap "Log GDP per cap. [curr. USD]"

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

* select destinations
keep if wtfkey~=0     // worldwide exports (keep individual destinations)

collapse (sum) wtfsales=value (count) wtfgoods=value (mean) lnexp lnimp lnbrexp lnoutp lnabso, by(firmid wtfkey lnpop lngdpcap lndist contig comlang_off)
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
gen wtfgsales=wtfsales/wtfgoods
label var wtfgoods "Number of products (HS 6-digit)"
label var wtfsales "Total exports (US$ mill)"
label var wtfgsales "Exports per product (US$ mill)"
label var lnexp "Log ISIC2 exports from dest."
label var lnimp "Log ISIC2 imports to dest."
label var lnbrexp "Chile's Log ISIC2 exp. to dst."
label var lnoutp "Log ISIC2 output at dest."
label var lnabso "Log ISIC2 absorption at dest."

gen lngoods=ln(wtfgoods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/product (US$ mill)"
drop wtfsales wtfgoods wtfgsales

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country in general: either USA or Argentina (depending on country group); here: USA
// drop dummy for USA (wtfkey==USA)
sort wtfkey
qui count if wtfkey~=wtfkey[_n-1]
local maxcntry = `r(N)'
forvalues i = 1/`maxcntry' {
  local lblname :  variable label wtfkey_`i'
  if "`lblname'"=="wtfkey==USA" {
    local droppedi `i'
    drop wtfkey_`i'
    }
  }

qui reg lngsales wtfkey_*
preserve
  forvalues i = 1/`maxcntry' {
    if `i'~=`droppedi'  qui replace wtfkey_`i' = wtfkey_`i' * ( _b[wtfkey_`i'] + _b[_cons] )
    }
  egen xtwtf = rsum(wtfkey_*)
  keep wtfkey xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  sort wtfkey
  by wtfkey: keep if _n==1
  reg xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_world, name(long:ols) e(N r2) replace
  reg xtwtf lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_world, addto(xtwtf_frmdst_world) name(short:ols) replace
restore

qui reg lngsales lngoods wtfkey_*
preserve
  forvalues i = 1/`maxcntry' {
    if `i'~=`droppedi'  qui replace wtfkey_`i' = wtfkey_`i' * ( _b[wtfkey_`i'] + _b[_cons] )
    }
  egen xtwtf = rsum(wtfkey_*)
  keep wtfkey xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  sort wtfkey
  by wtfkey: keep if _n==1
  reg xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_world, addto(xtwtf_frmdst_world) name(long:ols_condl_lngoods)
  reg xtwtf lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_world, addto(xtwtf_frmdst_world) name(short:ols_condl_lngoods)
restore

qui xtreg lngsales wtfkey_*, fe i(firmid)
preserve
  forvalues i = 1/`maxcntry' {
    if `i'~=`droppedi'  qui replace wtfkey_`i' = wtfkey_`i' * ( _b[wtfkey_`i'] + _b[_cons] )
    }
  egen xtwtf = rsum(wtfkey_*)
  keep wtfkey xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  sort wtfkey
  by wtfkey: keep if _n==1
  reg xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_world, addto(xtwtf_frmdst_world) name(long:xtfirm)
  reg xtwtf lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_world, addto(xtwtf_frmdst_world) name(short:xtfirm)
restore

qui xtreg lngsales lngoods wtfkey_*, fe i(firmid)
preserve
  forvalues i = 1/`maxcntry' {
    if `i'~=`droppedi'  qui replace wtfkey_`i' = wtfkey_`i' * ( _b[wtfkey_`i'] + _b[_cons] )
    }
  egen xtwtf = rsum(wtfkey_*)
  keep wtfkey xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  sort wtfkey
  by wtfkey: keep if _n==1
  reg xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_world, addto(xtwtf_frmdst_world) name(long:xtfrm_condl_lngoods)
  reg xtwtf lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_world, addto(xtwtf_frmdst_world) name(short:xtfrm_condl_lngoods)
restore

est2tex xtwtf_frmdst_world, fancy p(braxpmkt/estmat/chile-manffrms) replace level(90 95 99) mark(starse) dropall

*}  // close chile-manffrms loop


// 2. CORRELATES OF FIRM EFFECTS IN FIRM-DESTINATION DATA AND SCALE REGRESSIONS, WORLDWIDE

* loop over different sector definitions has been eliminated (manf-firms only)
local sec="manf-firms"
/*
    * workforce information by firm
    tempfile rais
    use firmid n_pis n_cnpj_estbl n_municipio ind* using "braxpmkt/chile/rais-cnpj-cnae-2000.dta", clear
    foreach var in n_pis n_cnpj_estbl n_municipio {
      gen ln_`var' = ln(`var')
      local lbl : variable label `var'
      label var ln_`var' "Log `lbl'"
      drop `var'
      }
    order firmid ln* ind*
    sort firmid
    compress
    save `rais'
*/
use firmid hs6dgt isic2 wtfkey indoecd90 value wtf_exports wtf_imports wtf_chilexp wtf_output population gdp_cap_usd lndist contig comlang_off using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

* select destinations
keep if wtfkey~=0     // worldwide exports (keep individual destinations)

* worldwide export activity by firm
tempfile ww
preserve
  tempfile wwgoods
  collapse (sum) value, by(firmid hs6dgt) fast
  collapse (sum) gwwsales=value (count) wwgoods=value, by(firmid) fast
  replace gwwsales = gwwsales/1000000
  label var wwgoods "Worldwide No. of prod. (HS 6)"
  label var gwwsales "Worldwide exports (US$ mill)"
  sort firmid
  save `wwgoods'
restore, preserve
  tempfile wwdest
  gen byte indmerc = ( wtfkey==330320 | wtfkey==336000 | wtfkey==338580 )
  label var indmerc "Indic.: Mercosur member"
  collapse (sum) value (count) wwgoods=value, by(firmid wtfkey indoecd90 indmerc) fast
  replace value = value/1000000
  gen oecdsales = indoecd90*value
  gen mercsales = indmerc*value
  collapse (sum) wwsales=value oecdsales mercsales (count) wwdest=wtfkey, by(firmid) fast
  gen byte ind0oecd = (oecdsales==0)
  gen byte ind0merc = (mercsales==0)
  label var wwsales "Worldwide exports (US$ mill)"
  label var oecdsales "OECD exports (US$ mill)"
  label var mercsales "Mercosur exports (US$ mill)"
  label var wwdest "Worldwide No. of Destinations"
  label var ind0oecd "Indic.: Zero OECD exports"
  label var ind0merc "Indic.: Zero Mercosur exports"
  sort firmid
  save `wwdest'
restore, preserve
  use `wwgoods', clear
  merge firmid using `wwdest'
  assert _m==3
  gen _chk = wwsales - gwwsales
  qui summ _chk
  if abs(`r(sum)')>1e-10  STOP
  drop _m _chk gwwsales
  gen wwgsales=wwsales/wwgoods
  label var wwgsales "Wrldw. exp./prod. (US$ mill)"
  gen lnwwgoods = ln(wwgoods)
  label var lnwwgoods "Log Wrldw. No. of prod. (HS 6)"
  gen lnwwsales = ln(wwsales)
  label var lnwwsales "Log Wrldw. Exp. (US$ mill)"
  gen lnoecdsales = ln(oecdsales)
  replace lnoecdsales = 0 if ind0oecd==1
  label var lnoecdsales "Log nonzero OECD Exp. (US$ mill)"
  gen lnmercsales = ln(mercsales)
  replace lnmercsales = 0 if ind0merc==1
  label var lnmercsales "Log nonz. Mrcos. Exp. (US$ mill)"
  gen lnwwdest = ln(wwdest)
  label var lnwwdest "Log Wrldw. No. of Destinations"
  gen lnwwgsales = ln(wwgsales)
  label var lnwwgsales "Log Wrldw. Exp./prod. (US$ mill)"
  compress
  sort firmid
  save `ww'
restore

sort firmid
merge firmid using `ww'
tab _m
drop _m

/*  sort firmid
    merge firmid using `rais', nokeep
    tab _m
    drop _m
*/
collapse (sum) wtfsales=value (count) wtfgoods=value, by(firmid wtfkey ind* lnww* lnoecd* lnmerc*) fast
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
gen wtfgsales=wtfsales/wtfgoods
label var wtfgoods "Number of products (HS 6-digit)"
label var wtfsales "Total exports (US$ mill)"
label var wtfgsales "Exports per product (US$ mill)"

gen lngoods=ln(wtfgoods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/product (US$ mill)"
drop wtfsales wtfgoods wtfgsales

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
// drop dummy for USA (wtfkey==USA)
sort wtfkey
qui count if wtfkey~=wtfkey[_n-1]
local maxcntry = `r(N)'
forvalues i = 1/`maxcntry' {
  local lblname :  variable label wtfkey_`i'
  if "`lblname'"=="wtfkey==USA" {
    local droppedi `i'
    drop wtfkey_`i'
    }
  }

qui xtreg lngsales, fe i(firmid)
preserve
  predict xtfrm, u
  keep firmid xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  sort firmid
  by firmid: keep if _n==1
  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  est2vec xtfrm_frmdst_world, name(long:xtreg) e(N r2) replace
/*  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_world, addto(xtfrm_frmdst_world) name(short:xtreg) replace
*/
restore

qui xtreg lngsales lngoods, fe i(firmid)
preserve
  predict xtfrm, u
  keep firmid xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  sort firmid
  by firmid: keep if _n==1
  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  est2vec xtfrm_frmdst_world, addto(xtfrm_frmdst_world) name(long:xtreg_condl_lngoods)
/*  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_world, addto(xtfrm_frmdst_world) name(short:xtreg_condl_lngoods)
*/
restore

qui xtreg lngsales wtfkey_*, fe i(firmid)
preserve
  predict xtfrm, u
  keep firmid xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  sort firmid
  by firmid: keep if _n==1
  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  est2vec xtfrm_frmdst_world, addto(xtfrm_frmdst_world) name(long:xtwtffirm)
/*  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_world, addto(xtfrm_frmdst_world) name(short:xtwtffirm)
*/
restore

qui xtreg lngsales lngoods wtfkey_*, fe i(firmid)
preserve
  predict xtfrm, u
  keep firmid xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  sort firmid
  by firmid: keep if _n==1
  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  est2vec xtfrm_frmdst_world, addto(xtfrm_frmdst_world) name(long:xtwtffirm_condl_lngoods)
/*  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_world, addto(xtfrm_frmdst_world) name(short:xtwtffirm_condl_lngoods)
*/
restore

est2tex xtfrm_frmdst_world, fancy p(braxpmkt/estmat/chile-manffrms) replace level(90 95 99) mark(starse) dropall

*}  // close chile-manffrms loop


// 3. CORRELATES OF COUNTRY EFFECTS IN FIRM-DESTINATION DATA AND SCOPE REGRESSIONS, WORLDWIDE

* loop over different sector definitions has been eliminated (manf-firms only)
local sec="manf-firms"

use firmid hs6dgt isic2 wtfkey value wtf_exports wtf_imports wtf_chilexp wtf_output population gdp_cap_usd lndist contig comlang_off using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

gen wtf_absorpt = wtf_output + wtf_imports - wtf_exports
label var wtf_absorpt "ISIC2 absorption at dest."

replace wtf_exports = ln(wtf_exports)
rename wtf_exports lnexp
label var lnexp "Log ISIC2 exports from dest."
replace wtf_imports = ln(wtf_imports)
rename wtf_imports lnimp
label var lnimp "Log ISIC2 imports to dest."
replace wtf_chilexp = ln(wtf_chilexp)
rename wtf_chilexp lnbrexp
label var lnbrexp "Chile's Log ISIC2 exp. to dst."
replace wtf_output = ln(wtf_output)
rename wtf_output lnoutp
label var lnoutp "Log ISIC2 output at dest."
replace wtf_absorpt = ln(wtf_absorpt)
rename wtf_absorpt lnabso
label var lnabso "Log ISIC2 absorption at dest."

replace population=ln(population)
rename population lnpop
label var lnpop "Log Population (total)"
replace gdp_cap_usd=ln(gdp_cap_usd)
rename gdp_cap_usd lngdpcap
label var lngdpcap "Log GDP per cap. [curr. USD]"

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

* select destinations
keep if wtfkey~=0     // worldwide exports (keep individual destinations)

collapse (sum) wtfsales=value (count) wtfgoods=value (mean) lnexp lnimp lnbrexp lnoutp lnabso, by(firmid wtfkey lnpop lngdpcap lndist contig comlang_off)
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
gen wtfgsales=wtfsales/wtfgoods
label var wtfgoods "Number of products (HS 6-digit)"
label var wtfsales "Total exports (US$ mill)"
label var wtfgsales "Exports per product (US$ mill)"
label var lnexp "Log ISIC2 exports from dest."
label var lnimp "Log ISIC2 imports to dest."
label var lnbrexp "Chile's Log ISIC2 exp. to dst."
label var lnoutp "Log ISIC2 output at dest."
label var lnabso "Log ISIC2 absorption at dest."

gen lngoods=ln(wtfgoods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/product (US$ mill)"
drop wtfsales wtfgoods wtfgsales

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
// drop dummy for USA (wtfkey==USA)
sort wtfkey
qui count if wtfkey~=wtfkey[_n-1]
local maxcntry = `r(N)'
forvalues i = 1/`maxcntry' {
  local lblname :  variable label wtfkey_`i'
  if "`lblname'"=="wtfkey==USA" {
    local droppedi `i'
    drop wtfkey_`i'
    }
  }

qui reg lngoods wtfkey_*
preserve
  forvalues i = 1/`maxcntry' {
    if `i'~=`droppedi'  qui replace wtfkey_`i' = wtfkey_`i' * ( _b[wtfkey_`i'] + _b[_cons] )
    }
  egen xtwtf = rsum(wtfkey_*)
  keep wtfkey xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  sort wtfkey
  by wtfkey: keep if _n==1
  reg xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_scop_world, name(long:ols) e(N r2) replace
  reg xtwtf lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_scop_world, addto(xtwtf_frmdst_scop_world) name(short:ols) replace
restore

qui reg lngoods lngsales wtfkey_*
preserve
  forvalues i = 1/`maxcntry' {
    if `i'~=`droppedi'  qui replace wtfkey_`i' = wtfkey_`i' * ( _b[wtfkey_`i'] + _b[_cons] )
    }
  egen xtwtf = rsum(wtfkey_*)
  keep wtfkey xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  sort wtfkey
  by wtfkey: keep if _n==1
  reg xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_scop_world, addto(xtwtf_frmdst_scop_world) name(long:ols_condl_lngsales)
  reg xtwtf lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_scop_world, addto(xtwtf_frmdst_scop_world) name(short:ols_condl_lngsales)
restore

qui xtreg lngoods wtfkey_*, fe i(firmid)
preserve
  forvalues i = 1/`maxcntry' {
    if `i'~=`droppedi'  qui replace wtfkey_`i' = wtfkey_`i' * ( _b[wtfkey_`i'] + _b[_cons] )
    }
  egen xtwtf = rsum(wtfkey_*)
  keep wtfkey xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  sort wtfkey
  by wtfkey: keep if _n==1
  reg xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_scop_world, addto(xtwtf_frmdst_scop_world) name(long:xtfirm)
  reg xtwtf lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_scop_world, addto(xtwtf_frmdst_scop_world) name(short:xtfirm)
restore

qui xtreg lngoods lngsales wtfkey_*, fe i(firmid)
preserve
  forvalues i = 1/`maxcntry' {
    if `i'~=`droppedi'  qui replace wtfkey_`i' = wtfkey_`i' * ( _b[wtfkey_`i'] + _b[_cons] )
    }
  egen xtwtf = rsum(wtfkey_*)
  keep wtfkey xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  sort wtfkey
  by wtfkey: keep if _n==1
  reg xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_scop_world, addto(xtwtf_frmdst_scop_world) name(long:xtfrm_condl_lngsales)
  reg xtwtf lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_frmdst_scop_world, addto(xtwtf_frmdst_scop_world) name(short:xtfrm_condl_lngsales)
restore

est2tex xtwtf_frmdst_scop_world, fancy p(braxpmkt/estmat/chile-manffrms) replace level(90 95 99) mark(starse) dropall

*}  // close chile-manffrms loop


// 4. CORRELATES OF FIRM EFFECTS IN FIRM-DESTINATION DATA AND SCOPE REGRESSIONS, WORLDWIDE

* loop over different sector definitions has been eliminated (manf-firms only)
local sec="manf-firms"

/*  * workforce information by firm
    tempfile rais
    use firmid n_pis n_cnpj_estbl n_municipio ind* using "braxpmkt/chile/rais-cnpj-cnae-2000.dta", clear
    foreach var in n_pis n_cnpj_estbl n_municipio {
      gen ln_`var' = ln(`var')
      local lbl : variable label `var'
      label var ln_`var' "Log `lbl'"
      drop `var'
      }
    order firmid ln* ind*
    sort firmid
    compress
    save `rais'
*/
use firmid hs6dgt isic2 wtfkey indoecd90 value wtf_exports wtf_imports wtf_chilexp wtf_output population gdp_cap_usd lndist contig comlang_off using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

* select destinations
keep if wtfkey~=0     // worldwide exports (keep individual destinations)

* worldwide export activity by firm
tempfile ww
preserve
  tempfile wwgoods
  collapse (sum) value, by(firmid hs6dgt) fast
  collapse (sum) gwwsales=value (count) wwgoods=value, by(firmid) fast
  replace gwwsales = gwwsales/1000000
  label var wwgoods "Worldwide No. of prod. (HS 6)"
  label var gwwsales "Worldwide exports (US$ mill)"
  sort firmid
  save `wwgoods'
restore, preserve
  tempfile wwdest
  gen byte indmerc = ( wtfkey==330320 | wtfkey==336000 | wtfkey==338580 )
  label var indmerc "Indic.: Mercosur member"
  collapse (sum) value (count) wwgoods=value, by(firmid wtfkey indoecd90 indmerc) fast
  replace value = value/1000000
  gen oecdsales = indoecd90*value
  gen mercsales = indmerc*value
  collapse (sum) wwsales=value oecdsales mercsales (count) wwdest=wtfkey, by(firmid) fast
  gen byte ind0oecd = (oecdsales==0)
  gen byte ind0merc = (mercsales==0)
  label var wwsales "Worldwide exports (US$ mill)"
  label var oecdsales "OECD exports (US$ mill)"
  label var mercsales "Mercosur exports (US$ mill)"
  label var wwdest "Worldwide No. of Destinations"
  label var ind0oecd "Indic.: Zero OECD exports"
  label var ind0merc "Indic.: Zero Mercosur exports"
  sort firmid
  save `wwdest'
restore, preserve
  use `wwgoods', clear
  merge firmid using `wwdest'
  qui count if _m~=3
  if `r(N)'>0  STOP
  gen _chk = wwsales - gwwsales
  qui summ _chk
  if abs(`r(sum)')>1e-10  STOP
  drop _m _chk gwwsales
  gen wwgsales=wwsales/wwgoods
  label var wwgsales "Wrldw. exp./prod. (US$ mill)"
  gen lnwwgoods = ln(wwgoods)
  label var lnwwgoods "Log Wrldw. No. of prod. (HS 6)"
  gen lnwwsales = ln(wwsales)
  label var lnwwsales "Log Wrldw. Exp. (US$ mill)"
  gen lnoecdsales = ln(oecdsales)
  replace lnoecdsales = 0 if ind0oecd==1
  label var lnoecdsales "Log nonzero OECD Exp. (US$ mill)"
  gen lnmercsales = ln(mercsales)
  replace lnmercsales = 0 if ind0merc==1
  label var lnmercsales "Log nonz. Mrcos. Exp. (US$ mill)"
  gen lnwwdest = ln(wwdest)
  label var lnwwdest "Log Wrldw. No. of Destinations"
  gen lnwwgsales = ln(wwgsales)
  label var lnwwgsales "Log Wrldw. Exp./prod. (US$ mill)"
  compress
  sort firmid
  save `ww'
restore

sort firmid
merge firmid using `ww'
tab _m
drop _m

/*  sort firmid
    merge firmid using `rais', nokeep
    tab _m
    drop _m
*/
collapse (sum) wtfsales=value (count) wtfgoods=value, by(firmid wtfkey ind* lnww* lnoecd* lnmerc*) fast
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
gen wtfgsales=wtfsales/wtfgoods
label var wtfgoods "Number of products (HS 6-digit)"
label var wtfsales "Total exports (US$ mill)"
label var wtfgsales "Exports per product (US$ mill)"

gen lngoods=ln(wtfgoods)
label var lngoods "Log number of products (HS 6)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/product (US$ mill)"
drop wtfsales wtfgoods wtfgsales

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
// drop dummy for USA (wtfkey==USA)
sort wtfkey
qui count if wtfkey~=wtfkey[_n-1]
local maxcntry = `r(N)'
forvalues i = 1/`maxcntry' {
  local lblname :  variable label wtfkey_`i'
  if "`lblname'"=="wtfkey==USA" {
    local droppedi `i'
    drop wtfkey_`i'
    }
  }

qui xtreg lngoods, fe i(firmid)
preserve
  predict xtfrm, u
  keep firmid xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  sort firmid
  by firmid: keep if _n==1
  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_scop_world, name(long:xtreg) e(N r2) replace
/*  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_scop_world, addto(xtfrm_frmdst_scop_world) name(short:xtreg) replace
*/
restore

qui xtreg lngoods lngsales, fe i(firmid)
preserve
  predict xtfrm, u
  keep firmid xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  sort firmid
  by firmid: keep if _n==1
  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  est2vec xtfrm_frmdst_scop_world, addto(xtfrm_frmdst_scop_world) name(long:xtreg_condl_lngsales)
/*  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  est2vec xtfrm_frmdst_scop_world, addto(xtfrm_frmdst_scop_world) name(short:xtreg_condl_lngsales)
*/
restore

qui xtreg lngoods wtfkey_*, fe i(firmid)
preserve
  predict xtfrm, u
  keep firmid xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales 
  sort firmid
  by firmid: keep if _n==1
  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_scop_world, addto(xtfrm_frmdst_scop_world) name(long:xtwtffirm)
/*  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_scop_world, addto(xtfrm_frmdst_scop_world) name(short:xtwtffirm)
*/
restore

qui xtreg lngoods lngsales wtfkey_*, fe i(firmid)
preserve
  predict xtfrm, u
  keep firmid xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  sort firmid
  by firmid: keep if _n==1
  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_scop_world, addto(xtfrm_frmdst_scop_world) name(long:xtwtffirm_condl_lngsales)
/*  reg xtfrm lnwwgoods lnwwgsales lnwwdest ind0oecd lnoecdsales ind0merc lnmercsales
  est2vec xtfrm_frmdst_scop_world, addto(xtfrm_frmdst_scop_world) name(short:xtwtffirm_condl_lngsales)
*/
restore

est2tex xtfrm_frmdst_scop_world, fancy p(braxpmkt/estmat/chile-manffrms) replace level(90 95 99) mark(starse) dropall

*}  // close chile-manffrms loop


log close
cd "$home"
