*! version 1.0.2  12nov2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.3  11apr2010  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.4  30jan2012  by Marc Muendler     muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 500m
set trace off
set matsize 300

cd "$root"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-goods-pcsales-spearman.log", replace

foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {

tempfile destchar
use firmid cnae isic2 wtfkey indoecd90 value wtf_exports wtf_imports wtf_brazexp wtf_output population gdp_usd gdp_cap_usd lndist contig comlang_off using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0
drop if wtfkey==0  // drop world
* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms
gen wtf_absorpt = wtf_output + wtf_imports - wtf_exports
label var wtf_absorpt "ISIC2 absorption at dest."
replace wtf_absorpt = ln(wtf_absorpt)
rename wtf_absorpt lnabso
label var lnabso "Log ISIC2 absorption at dest."
replace population=ln(population)
rename population lnpop
label var lnpop "Log Population (total)"
replace gdp_cap_usd=ln(gdp_cap_usd)
rename gdp_cap_usd lngdpcap
label var lngdpcap "Log GDP per cap. [curr. USD]"
replace gdp_usd=ln(gdp_usd)
rename gdp_usd lngdpusd
label var lngdpusd "Log GDP [curr. USD]"
collapse (sum) wtfsales=value (count) wtfgoods=value, by(firmid wtfkey ind* lnabso lnpop lngdpusd lngdpcap lndist contig comlang_off) fast
drop if wtfkey==356580  // drop St. Kitts and Nevis
drop wtfsales wtfgoods
sort firmid wtfkey
compress
save `destchar'

tempfile world
use firmid wtfkey pctl pcsales using "braxpmkt/secex/scope-pctl-`sec'.dta", clear
keep if wtfkey==0  // worldwide
drop wtfkey
rename pcsales wrld_pcsales
rename pctl wrld_pctl
sort firmid
save `world'

use firmid wtfkey lngoods pctl pcsales using "braxpmkt/secex/scope-pctl-`sec'.dta", clear
drop if wtfkey<100000
sort firmid
merge firmid using `world'
tab _m
count if _m~=3
if `r(N)'>0  STOP // incomplete merge
drop _m
sort firmid wtfkey
merge firmid wtfkey using `destchar'
tab _m
count if _m~=3
if `r(N)'>0  STOP // incomplete merge
drop _m

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country in general: either USA or Argentina (depending on country group); here: USA
// drop dummy for USA (wtfkey==USA)
sort wtfkey
qui count if wtfkey~=wtfkey[_n-1]
local maxcntry = `r(N)'
forvalues i = 1/`maxcntry' {
  local lblname :  variable label wtfkey_`i'
  if "`lblname'"=="wtfkey==USA" {
    local droppedi `i'
    drop wtfkey_`i'
    }
  }

* table for correlations
mat pcsales_corr_tbl = J(8,7,.)
mat colnames pcsales_corr_tbl = corr spearman ktau kwallis reg xtwtf xtwtffrm
mat rownames pcsales_corr_tbl = r(rho) r(chi2_adj) r(p) r(N) e(N_g) e(corr) e(T) e(Tbar)


// pctl correlations

corr pctl wrld_pctl
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(rho)"),colnumb(pcsales_corr_tbl,"corr")] = `r(rho)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(p)"),colnumb(pcsales_corr_tbl,"corr")] = 2 * ttail( `r(N)'-2, `r(rho)'*sqrt(`r(N)'-2)/sqrt(1-`r(rho)'^2) )
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(N)"),colnumb(pcsales_corr_tbl,"corr")] = `r(N)'

spearman pctl wrld_pctl
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(rho)"),colnumb(pcsales_corr_tbl,"spearman")] = `r(rho)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(p)"),colnumb(pcsales_corr_tbl,"spearman")] = `r(p)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(N)"),colnumb(pcsales_corr_tbl,"spearman")] = `r(N)'

ktau pctl wrld_pctl
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(rho)"),colnumb(pcsales_corr_tbl,"ktau")] = `r(tau_a)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(p)"),colnumb(pcsales_corr_tbl,"ktau")] = `r(p)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(N)"),colnumb(pcsales_corr_tbl,"ktau")] = `r(N)'

kwallis pctl, by(wtfkey)
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(chi2_adj)"),colnumb(pcsales_corr_tbl,"kwallis")] = `r(chi2_adj)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(p)"),colnumb(pcsales_corr_tbl,"kwallis")] = 1 - chi2(`r(df)',`r(chi2_adj)')
qui summ, meanonly
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(N)"),colnumb(pcsales_corr_tbl,"kwallis")] = `r(N)'


// pctl regressions with firm and destination fixed effects

reg pctl wrld_pctl
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(rho)"),colnumb(pcsales_corr_tbl,"reg")] = _coef[wrld_pctl]
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(p)"),colnumb(pcsales_corr_tbl,"reg")] = 2*ttail( `e(df_r)' , _coef[wrld_pctl]/_se[wrld_pctl] )
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(N)"),colnumb(pcsales_corr_tbl,"reg")] = `e(N)'

xtreg pctl wrld_pctl, fe i(wtfkey)
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(rho)"),colnumb(pcsales_corr_tbl,"xtwtf")] = _coef[wrld_pctl]
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(p)"),colnumb(pcsales_corr_tbl,"xtwtf")] = 2*ttail( `e(df_r)' , _coef[wrld_pctl]/_se[wrld_pctl] )
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(N)"),colnumb(pcsales_corr_tbl,"xtwtf")] = `e(N)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"e(T)"),colnumb(pcsales_corr_tbl,"xtwtf")] = `e(N_g)'

xtreg pctl wtfkey_*, fe i(firmid)
predict ui, u
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"e(N_g)"),colnumb(pcsales_corr_tbl,"xtwtffrm")] = `e(N_g)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"e(corr)"),colnumb(pcsales_corr_tbl,"xtwtffrm")] = `e(rho)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"e(T)"),colnumb(pcsales_corr_tbl,"xtwtffrm")] = `e(df_b)' + 1
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"e(Tbar)"),colnumb(pcsales_corr_tbl,"xtwtffrm")] = `e(Tbar)'
corr pctl ui
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(rho)"),colnumb(pcsales_corr_tbl,"xtwtffrm")] = `r(rho)'
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(p)"),colnumb(pcsales_corr_tbl,"xtwtffrm")] = 2 * ttail( `r(N)'-2, `r(rho)'*sqrt(`r(N)'-2)/sqrt(1-`r(rho)'^2) )
mat pcsales_corr_tbl[rownumb(pcsales_corr_tbl,"r(N)"),colnumb(pcsales_corr_tbl,"xtwtffrm")] = `r(N)'
drop ui

preserve
est2tex pcsales_corr, ready fancy p(braxpmkt/estmat/`sec') replace dropall
restore


// scope-pctl regressions with firm and destination fixed effects

replace pctl=pctl/100
gen lnpctl = ln(pctl+.01)
replace lnpctl = ln(1) if lnpctl > ln(1)

reg lngoods lnpctl if pctl<=.98
est2vec lnscope_pctl, vars(lnpctl _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(ols) replace

xtreg lngoods lnpctl if pctl<=.98, fe i(firmid)
est2vec lnscope_pctl, addto(lnscope_pctl) name(xtfirm)

reg lngoods lnpctl wtfkey_* if pctl<=.98
est2vec lnscope_pctl, addto(lnscope_pctl) name(xtwtf)
preserve
  forvalues i = 1/`maxcntry' {
    if `i'~=`droppedi'  qui replace wtfkey_`i' = wtfkey_`i' * ( _b[wtfkey_`i'] + _b[_cons] )
    }
  egen xtwtf = rsum(wtfkey_*)
  keep wtfkey xtwtf lnabso lnpop lngdpcap lngdpusd lndist contig comlang_off
  sort wtfkey
  by wtfkey: keep if _n==1
  reg xtwtf lnabso lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_lnscope_pctl, name(long:ols) e(N r2) vars(lnabso lnpop lngdpcap lngdpusd lndist contig comlang_off) replace
  reg xtwtf lnpop lngdpcap lndist contig comlang_off
  est2vec xtwtf_lnscope_pctl, addto(xtwtf_lnscope_pctl) name(short:ols) replace
  reg xtwtf lngdpusd lndist contig comlang_off
  est2vec xtwtf_lnscope_pctl, addto(xtwtf_lnscope_pctl) name(vshort:ols) replace
restore, preserve
  keep lngoods lnabso lnpop lngdpcap lngdpusd lndist contig comlang_off wtfkey pctl
  reg lngoods lnabso lnpop lngdpcap lndist contig comlang_off if pctl<=.98, cluster(wtfkey)
  est2vec lnscope_wtfchar, name(long:ols) e(N r2) vars(lnabso lnpop lngdpcap lngdpusd lndist contig comlang_off) replace
  reg lngoods lnpop lngdpcap lndist contig comlang_off if pctl<=.98, cluster(wtfkey)
  est2vec lnscope_wtfchar, addto(lnscope_wtfchar) name(short:ols) replace
  reg lngoods lngdpusd lndist contig comlang_off if pctl<=.98, cluster(wtfkey)
  est2vec lnscope_wtfchar, addto(lnscope_wtfchar) name(vshort:ols) replace
restore

xtreg lngoods lnpctl wtfkey_* if pctl<=.98, fe i(firmid)
est2vec lnscope_pctl, addto(lnscope_pctl) name(xtwtffirm)

est2tex lnscope_pctl, fancy p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall
est2tex xtwtf_lnscope_pctl, fancy p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall
est2tex lnscope_wtfchar, fancy p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall


}  // close `sec' loop


log close
cd "$home"
