*! version 1.0.2  16sep2007  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 500m
set trace off
set matsize 300

cd "$root"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-product-correlates.log", replace


// AGGREGATE EXTERNAL DATA TO HS2-DIGIT LEVEL
* Rauch data mapped from SITC4 to HS6 - aggregate to HS2 by taking arithmetic mean across HS6
* Balasssa data mapped from ISCI2 to HS6 - aggregate to HS2 by taking arithmetic mean across HS6
tempfile ext
use hs6dgt balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp using "braxpmkt/ext/product-data.dta", clear
gen int hs2dgt = int(hs6dgt/10000)
label var hs2dgt "Harmonized System 2-digit code"
collapse (mean) balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp, by(hs2dgt)
label var balcadv "Balassa comp. advantage (2000)"
label var indcon1 "Share: Homogeneous goods"
label var indcon2 "Share: Reference priced"
label var indcon3 "Share: Differentiated products"
label var indi0oecd "Indic.: Zero OECD imports"
label var indi0merc "Indic.: Zero Mercosur imports"
label var lnoecdimp "Log nonzero OECD Imp. (US$ mill)"
label var lnmercimp "Log nonz. Mrcos. Imp. (US$ mill)"
label var lnwwdest  "Log Wrldw. No. of Destinations"
sort hs2dgt
save `ext'


// 1. CORRELATES OF PRODUCT EFFECTS IN PRODUCT-FIRM-DESTINATION DATA AND SCALE REGRESSIONS, WORLDWIDE

foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {

use firmid cnae hs6dgt isic2 cnae wtfkey indoecd90 value using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

gen int hs2dgt = int(hs6dgt/10000)
label var hs2dgt "Harmonized System 2-digit code"
drop if hs2dgt==.
sort hs2dgt
merge hs2dgt using `ext', nokeep
tab _m
count if _m~=3
if `r(N)'>0  STOP
drop _m

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members

collapse (sum) wtfsales=value (count) wtfgoods=value (mean) balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp, by(firmid cnae wtfkey hs2dgt)
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
label var wtfgoods "No. goods (HS 6-dgt w/in 2-dgt)"
label var wtfsales "Total exports (US$ mill fob)"
gen wtfgsales=wtfsales/wtfgoods
label var wtfgsales "Exports per good (US$ mill fob)"
gen lngoods=ln(wtfgoods)
label var lngoods "Log no. goods (HS 6 w/in HS 2)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/good (US$ mill fob)"
drop wtfsales wtfgoods wtfgsales
label var balcadv "Balassa comp. advantage (2000)"
label var indcon1 "Share: Homogeneous goods"
label var indcon2 "Share: Reference priced"
label var indcon3 "Share: Differentiated products"

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
if "`region'"=="world" | "`region'"=="oecd90" { // drop dummy for USA (wtfkey==USA)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==USA"  drop wtfkey_`i'
    }
  }
if "`region'"=="mercosur" | "`region'"=="nonoecd90" { // drop dummy for Argentina (wtfkey==Argentina)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==Argentina"  drop wtfkey_`i'
    }
  }

* product-group dummies
qui tab hs2dgt, gen(hs2dgt_)
sort hs2dgt
qui count if hs2dgt~=hs2dgt[_n-1]
local maxprod = `r(N)'
drop hs2dgt_1  // drop dummy for first product group
sort firmid wtfkey hs2dgt

// xths2 only
reg lngsales hs2dgt_*
preserve
  forvalues i = 2/`maxprod' {  // hs2dgt_1 was dropped
    qui replace hs2dgt_`i' = hs2dgt_`i' * ( _b[hs2dgt_`i'] + _b[_cons] )
    }
  egen xths2 = rsum(hs2dgt_*)
  keep hs2dgt xths2 balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  sort hs2dgt
  by hs2dgt: keep if _n==1
  reg xths2 balcadv indcon2 indcon3 lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  est2vec xths2_frmdstprd_world, name(xths2) e(N r2) replace
restore

// xths2_condl_lngoods
reg lngsales lngoods hs2dgt_*
preserve
  forvalues i = 2/`maxprod' {  // hs2dgt_1 was dropped
    qui replace hs2dgt_`i' = hs2dgt_`i' * ( _b[hs2dgt_`i'] + _b[_cons] )
    }
  egen xths2 = rsum(hs2dgt_*)
  keep hs2dgt xths2 balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  sort hs2dgt
  by hs2dgt: keep if _n==1
  reg xths2 balcadv indcon2 indcon3 lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  est2vec xths2_frmdstprd_world, addto(xths2_frmdstprd_world) name(xths2_condl_lngoods)
restore

// xths2wtffrm
xtreg lngsales hs2dgt_* wtfkey_*, fe i(firmid)
preserve
  forvalues i = 2/`maxprod' {  // hs2dgt_1 was dropped
    qui replace hs2dgt_`i' = hs2dgt_`i' * ( _b[hs2dgt_`i'] + _b[_cons] )
    }
  egen xths2 = rsum(hs2dgt_*)
  keep hs2dgt xths2 balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  sort hs2dgt
  by hs2dgt: keep if _n==1
  reg xths2 balcadv indcon2 indcon3 lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  est2vec xths2_frmdstprd_world, addto(xths2_frmdstprd_world) name(xths2wtffrm)
restore

// xths2wtffrm_condl_lngoods
xtreg lngsales lngoods hs2dgt_* wtfkey_*, fe i(firmid)
preserve
  forvalues i = 2/`maxprod' {  // hs2dgt_1 was dropped
    qui replace hs2dgt_`i' = hs2dgt_`i' * ( _b[hs2dgt_`i'] + _b[_cons] )
    }
  egen xths2 = rsum(hs2dgt_*)
  keep hs2dgt xths2 balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  sort hs2dgt
  by hs2dgt: keep if _n==1
  reg xths2 balcadv indcon2 indcon3 lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  est2vec xths2_frmdstprd_world, addto(xths2_frmdstprd_world) name(xths2wtffrm_condl_lngoods)
restore

est2tex xths2_frmdstprd_world, fancy p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop


// 2. CORRELATES OF PRODUCT EFFECTS IN PRODUCT-FIRM-DESTINATION DATA AND SCOPE REGRESSIONS, WORLDWIDE

foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {

use firmid cnae hs6dgt isic2 cnae wtfkey indoecd90 value using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

gen int hs2dgt = int(hs6dgt/10000)
label var hs2dgt "Harmonized System 2-digit code"
drop if hs2dgt==.
sort hs2dgt
merge hs2dgt using `ext', nokeep
tab _m
count if _m~=3
if `r(N)'>0  STOP
drop _m

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members

collapse (sum) wtfsales=value (count) wtfgoods=value (mean) balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp, by(firmid cnae wtfkey hs2dgt)
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
label var wtfgoods "No. goods (HS 6-dgt w/in 2-dgt)"
label var wtfsales "Total exports (US$ mill fob)"
gen wtfgsales=wtfsales/wtfgoods
label var wtfgsales "Exports per good (US$ mill fob)"
gen lngoods=ln(wtfgoods)
label var lngoods "Log no. goods (HS 6 w/in HS 2)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/good (US$ mill fob)"
drop wtfsales wtfgoods wtfgsales
label var balcadv "Balassa comp. advantage (2000)"
label var indcon1 "Share: Homogeneous goods"
label var indcon2 "Share: Reference priced"
label var indcon3 "Share: Differentiated products"

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
if "`region'"=="world" | "`region'"=="oecd90" { // drop dummy for USA (wtfkey==USA)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==USA"  drop wtfkey_`i'
    }
  }
if "`region'"=="mercosur" | "`region'"=="nonoecd90" { // drop dummy for Argentina (wtfkey==Argentina)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==Argentina"  drop wtfkey_`i'
    }
  }

* product-group dummies
qui tab hs2dgt, gen(hs2dgt_)
sort hs2dgt
qui count if hs2dgt~=hs2dgt[_n-1]
local maxprod = `r(N)'
drop hs2dgt_1  // drop dummy for first product group
sort firmid wtfkey hs2dgt

// xths2 only
reg lngoods hs2dgt_*
preserve
  forvalues i = 2/`maxprod' {  // hs2dgt_1 was dropped
    qui replace hs2dgt_`i' = hs2dgt_`i' * ( _b[hs2dgt_`i'] + _b[_cons] )
    }
  egen xths2 = rsum(hs2dgt_*)
  keep hs2dgt xths2 balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  sort hs2dgt
  by hs2dgt: keep if _n==1
  reg xths2 balcadv indcon2 indcon3 lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  est2vec xths2_frmdstprd_scop_world, name(xths2) e(N r2) replace
restore

// xths2_condl_lngsales
reg lngoods lngsales hs2dgt_*
preserve
  forvalues i = 2/`maxprod' {  // hs2dgt_1 was dropped
    qui replace hs2dgt_`i' = hs2dgt_`i' * ( _b[hs2dgt_`i'] + _b[_cons] )
    }
  egen xths2 = rsum(hs2dgt_*)
  keep hs2dgt xths2 balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  sort hs2dgt
  by hs2dgt: keep if _n==1
  reg xths2 balcadv indcon2 indcon3 lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  est2vec xths2_frmdstprd_scop_world, addto(xths2_frmdstprd_scop_world) name(xths2_condl_lngsales)
restore

// xths2wtffrm
xtreg lngoods hs2dgt_* wtfkey_*, fe i(firmid)
preserve
  forvalues i = 2/`maxprod' {  // hs2dgt_1 was dropped
    qui replace hs2dgt_`i' = hs2dgt_`i' * ( _b[hs2dgt_`i'] + _b[_cons] )
    }
  egen xths2 = rsum(hs2dgt_*)
  keep hs2dgt xths2 balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  sort hs2dgt
  by hs2dgt: keep if _n==1
  reg xths2 balcadv indcon2 indcon3 lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  est2vec xths2_frmdstprd_scop_world, addto(xths2_frmdstprd_scop_world) name(xths2wtffrm)
restore

// xths2wtffrm_condl_lngsales
xtreg lngoods lngsales hs2dgt_* wtfkey_*, fe i(firmid)
preserve
  forvalues i = 2/`maxprod' {  // hs2dgt_1 was dropped
    qui replace hs2dgt_`i' = hs2dgt_`i' * ( _b[hs2dgt_`i'] + _b[_cons] )
    }
  egen xths2 = rsum(hs2dgt_*)
  keep hs2dgt xths2 balcadv indcon* lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  sort hs2dgt
  by hs2dgt: keep if _n==1
  reg xths2 balcadv indcon2 indcon3 lnwwdest indi0oecd lnoecdimp indi0merc lnmercimp
  est2vec xths2_frmdstprd_scop_world, addto(xths2_frmdstprd_scop_world) name(xths2wtffrm_condl_lngsales)
restore

est2tex xths2_frmdstprd_scop_world, fancy p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop


log close
cd "$home"
