*! version 1.0.8  21dec2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.9  09mar2008  by Oana Hirakawa     otocoian@ucsd.edu
*! version 1.1.1  11jun2008  by Marc Muendler     muendler@ucsd.edu
*! version 1.2.1  22apr2010  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 500m
set trace off
set matsize 300

cd "$root"

capture mkdir "braxpmkt/estmat/chile-manffrms"

capture log close
log using "braxpmkt/logs/prodsales-regress-chile.log", replace

capture program drop uicorr
program define uicorr
  if "`e(cmd)'"=="xtreg" qui predict ui, u
  else qui gen ui = .
  capture corr ui lngoods
  drop ui
end


// 1. FIRM DATA

foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" {

*foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {
local sec "manf-firms"

use firmid hs6dgt isic2 wtfkey indoecd90 value using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina

collapse (sum) value, by(firmid hs6dgt isic2)
collapse (sum) sumsales=value (count) goods=value, by(firmid isic2)
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per good (US$ mill fob)"

gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"
gen lnsumsales=ln(sumsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(gsales)
label var lngsales "Log exports/good (US$ mill fob)"
drop sumsales goods gsales

reg lngsales lngoods
est2vec frm_scalscop_`region', vars(lngoods _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(ols) replace
uicorr
est2vec frm_scalscop_`region', r(rho) name(ols) replace

xtreg lngsales lngoods, fe i(isic2)
est2vec frm_scalscop_`region', addto(frm_scalscop_`region') name(xtisic2)
uicorr
est2vec frm_scalscop_`region', raddto(frm_scalscop_`region') name(xtisic2)
* note: firm-fixed effect not defined b/c single observation for every firm

est2tex frm_scalscop_`region', fancy p(braxpmkt/estmat/chile-manffrms) replace level(90 95 99) mark(starse) dropall

*}  // close chile-manffrms loop

}  // close `region' loop


// 2. FIRM-DESTINATION DATA

foreach region in "world" "mercosur" "oecd90" "nonoecd90" {

*foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {
local sec "manf-firms"

use firmid hs6dgt isic2 wtfkey indoecd90 value using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members

collapse (sum) wtfsales=value (count) wtfgoods=value, by(firmid wtfkey indoecd90 isic2)
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
gen wtfgsales=wtfsales/wtfgoods
sort firmid wtfkey
by firmid: gen wtfdest = _N
egen wtfwwsales = sum(wtfsales), by(firmid)
egen wtfwwgsales = mean(wtfgsales), by(firmid)
egen ind0oecd = max(indoecd90), by(firmid)
replace ind0oecd = 1 - ind0oecd
label var wtfgoods "Number of goods (HS 6-digit)"
label var wtfsales "Total exports (US$ mill fob)"
label var wtfgsales "Exports per good (US$ mill fob)"
label var wtfdest "Number of destinations"
label var wtfwwsales "Ww. total exports (US$ mill fob)"
label var wtfwwgsales "Ww. exports/good (US$ mill fob)"
label var ind0oecd "Indic.: Zero OECD exports"
compress

gen lngoods=ln(wtfgoods)
label var lngoods "Log number of goods (HS 6)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/good (US$ mill fob)"
gen lndest = ln(wtfdest)
label var lndest "Log number of destinations"
gen lnwwsales = ln(wtfwwsales)
label var lnwwsales "Log ww. total exports (US$ mill fob)"
gen lnwwgsales = ln(wtfwwgsales)
label var lnwwgsales "Log ww. mean exp./good (US$ mill fob)"
drop wtfsales wtfgoods wtfgsales wtfdest wtfwwsales wtfwwgsales

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
if "`region'"=="world" | "`region'"=="oecd90" { // drop dummy for USA (wtfkey==USA)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==USA"  drop wtfkey_`i'
    }
  }
if "`region'"=="mercosur" | "`region'"=="nonoecd90" { // drop dummy for Argentina (wtfkey==Argentina)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==Argentina"  drop wtfkey_`i'
    }
  }

reg lngsales lngoods
est2vec frmdst_scalscop_`region', vars(lngoods _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(ols) replace
uicorr
est2vec frmdst_scalscop_`region', r(rho) name(ols) replace

xtreg lngsales lngoods, fe i(isic2)
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtisic2)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtisic2)

xtreg lngsales lngoods, fe i(firmid)
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtfirm)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtfirm)

xtreg lngsales lngoods, be i(firmid)
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtfirmbe)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtfirmbe)

reg lngsales lngoods wtfkey_*
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtwtf)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtwtf)

reg lngsales lngoods lndest wtfkey_*
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtwtf_destnum)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtwtf_destnum)

reg lngsales lngoods lnwwgsales ind0oecd lndest wtfkey_*
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtwtf_wwgsales)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtwtf_wwgsales)

xtreg lngsales lngoods wtfkey_*, fe i(isic2)
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtwtfisic2)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtwtfisic2)

xtreg lngsales lngoods lndest wtfkey_*, fe i(isic2)
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtwtfisic2_destnum)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtwtfisic2_destnum)

xtreg lngsales lngoods lnwwgsales ind0oecd lndest wtfkey_*, fe i(isic2)
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtwtfisic2_wwgsales)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtwtfisic2_wwgsales)

xtreg lngsales lngoods wtfkey_*, fe i(firmid)
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtwtffirm)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtwtffirm)

xtreg lngsales lngoods wtfkey_*, be i(firmid)
est2vec frmdst_scalscop_`region', addto(frmdst_scalscop_`region') name(xtwtffrmbe)
uicorr
est2vec frmdst_scalscop_`region', raddto(frmdst_scalscop_`region') name(xtwtffrmbe)

est2tex frmdst_scalscop_`region', fancy p(braxpmkt/estmat/chile-manffrms) replace level(90 95 99) mark(starse) dropall

*}  // close chile-manffrms loop

}  // close `region' loop


// 3. FIRM-DESTINATION-PRODUCTGROUP DATA

foreach region in "world" "mercosur" "oecd90" "nonoecd90" {

*foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {
local sec "manf-firms"

use firmid hs6dgt isic2 wtfkey indoecd90 value using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

gen int hs2dgt = int(hs6dgt/10000)
label var hs2dgt "Harmonized System 2-digit code"

* select products and firms
keep if isic2>=300 & isic2<=399    // manufacturing products

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members

collapse (sum) wtfsales=value (count) wtfgoods=value, by(firmid wtfkey hs2dgt isic2)
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
label var wtfgoods "No. goods (HS 6-dgt w/in 2-dgt)"
label var wtfsales "Total exports (US$ mill fob)"
gen wtfgsales=wtfsales/wtfgoods
label var wtfgsales "Exports per good (US$ mill fob)"

gen lngoods=ln(wtfgoods)
label var lngoods "Log no. goods (HS 6 w/in HS 2)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/good (US$ mill fob)"
drop wtfsales wtfgoods wtfgsales

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
if "`region'"=="world" | "`region'"=="oecd90" { // drop dummy for USA (wtfkey==USA)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==USA"  drop wtfkey_`i'
    }
  }
if "`region'"=="mercosur" | "`region'"=="nonoecd90" { // drop dummy for Argentina (wtfkey==Argentina)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==Argentina"  drop wtfkey_`i'
    }
  }

* product-group dummies
qui tab hs2dgt, gen(hs2dgt_)
drop hs2dgt_1  // drop dummy for first product group

reg lngsales lngoods
est2vec frmdstprd_scalscop_`region', vars(lngoods _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(ols) replace
uicorr
est2vec frmdstprd_scalscop_`region', r(rho) name(ols) replace

xtreg lngsales lngoods, fe i(isic2)
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xtisic2)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xtisic2)

xtreg lngsales lngoods, fe i(firmid)
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xtfirm)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xtfirm)

reg lngsales lngoods wtfkey_*
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xtwtf)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xtwtf)

xtreg lngsales lngoods wtfkey_*, fe i(isic2)
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xtwtfisic2)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xtwtfisic2)

xtreg lngsales lngoods wtfkey_*, fe i(firmid)
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xtwtffirm)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xtwtffirm)

reg lngsales lngoods hs2dgt_*
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xths2)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xths2)

xtreg lngsales lngoods hs2dgt_*, fe i(isic2)
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xths2isic2)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xths2isic2)

xtreg lngsales lngoods hs2dgt_*, fe i(firmid)
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xths2firm)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xths2firm)

reg lngsales lngoods hs2dgt_* wtfkey_*
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xths2wtf)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xths2wtf)

xtreg lngsales lngoods hs2dgt_* wtfkey_*, fe i(isic2)
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xths2wtfisic2)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xths2wtfisic2)

xtreg lngsales lngoods hs2dgt_* wtfkey_*, fe i(firmid)
est2vec frmdstprd_scalscop_`region', addto(frmdstprd_scalscop_`region') name(xths2wtffirm)
uicorr
est2vec frmdstprd_scalscop_`region', raddto(frmdstprd_scalscop_`region') name(xths2wtffirm)

est2tex frmdstprd_scalscop_`region', fancy p(braxpmkt/estmat/chile-manffrms) replace level(90 95 99) mark(starse) dropall

*}  // close chile-manffrms loop

}  // close `region' loop

log close
cd "$home"
