*! version 1.0.1  12nov2008  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 500m
set trace off
set matsize 300

cd "$root"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-regress-cntry-by-cntry.log", replace


// FIRM-DESTINATION DATA

local region "world"

foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {

use firmid cnae hs6dgt isic2 cnae wtfkey indoecd90 value using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members

collapse (sum) wtfsales=value (count) wtfgoods=value, by(firmid cnae wtfkey indoecd90)
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
gen wtfgsales=wtfsales/wtfgoods
sort firmid wtfkey
by firmid: gen wtfdest = _N
egen wtfwwsales = sum(wtfsales), by(firmid)
egen wtfwwgsales = mean(wtfgsales), by(firmid)
egen ind0oecd = max(indoecd90), by(firmid)
replace ind0oecd = 1 - ind0oecd
label var wtfgoods "Number of goods (HS 6-digit)"
label var wtfsales "Total exports (US$ mill fob)"
label var wtfgsales "Exports per good (US$ mill fob)"
label var wtfdest "Number of destinations"
label var wtfwwsales "Ww. total exports (US$ mill fob)"
label var wtfwwgsales "Ww. exports/good (US$ mill fob)"
label var ind0oecd "Indic.: Zero OECD exports"
compress

gen lngoods=ln(wtfgoods)
label var lngoods "Log number of goods (HS 6)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/good (US$ mill fob)"
gen lndest = ln(wtfdest)
label var lndest "Log number of destinations"
gen lnwwsales = ln(wtfwwsales)
label var lnwwsales "Log ww. total exports (US$ mill fob)"
gen lnwwgsales = ln(wtfwwgsales)
label var lnwwgsales "Log ww. mean exp./good (US$ mill fob)"
drop wtfsales wtfgoods wtfgsales wtfdest wtfwwsales wtfwwgsales

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
if "`region'"=="world" | "`region'"=="oecd90" { // drop dummy for USA (wtfkey==USA)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==USA"  drop wtfkey_`i'
    }
  }
if "`region'"=="mercosur" | "`region'"=="nonoecd90" { // drop dummy for Argentina (wtfkey==Argentina)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==Argentina"  drop wtfkey_`i'
    }
  }

unab wtfkeys : wtfkey_*
local lbl ""
foreach var of local wtfkeys {  // "world": drop dummy for USA (wtfkey==USA)
  local wtfname : variable label `var'
  local wtfname = subinstr(subinstr(subinstr(subinstr(substr("`wtfname'",index("`wtfname'","==")+2,.)," ","",.),".","",.),"-","",.),",","",.)
  local lbl "`lbl' `wtfname'"
  local maxwtf = substr("`var'",index("`var'","_")+1,.)
  }
local maxwtf = `maxwtf'-1
disp "`maxwtf'"
local lblcnt :  word count "`lbl'"
disp "`lblcnt': `lbl'"
foreach type in b se e r {
  mat frm_scalscop_cntry_`type' = J(`maxwtf',2,.)
  matrix colnames frm_scalscop_cntry_`type' = reg:`type' xtreg:`type'
  if "`type'"=="e"  matrix rownames frm_scalscop_cntry_`type' = e(N)
  if "`type'"=="r"  matrix rownames frm_scalscop_cntry_`type' = e(r2)
  matrix roweq frm_scalscop_cntry_`type' = `lbl'
  }

local i 0
foreach var of local wtfkeys {  // "world": drop dummy for USA (wtfkey==USA)
  local i = `i' + 1
  capture reg lngsales lngoods if `var'==1
  capture mat frm_scalscop_cntry_b[`i',1] = _b[lngoods]
  capture mat frm_scalscop_cntry_se[`i',1] = _se[lngoods]
  capture mat frm_scalscop_cntry_e[`i',1] = `e(N)'
  capture mat frm_scalscop_cntry_e[`i',1] = `e(r2)'
  capture xtreg lngsales lngoods if `var'==1, fe i(cnae)
  capture mat frm_scalscop_cntry_b[`i',2] = _b[lngoods]
  capture mat frm_scalscop_cntry_se[`i',2] = _se[lngoods]
  capture mat frm_scalscop_cntry_e[`i',2] = `e(N)'
  capture mat frm_scalscop_cntry_e[`i',2] = `e(r2)'
  }

foreach type in b se e r {
  matsave frm_scalscop_cntry_`type', p(braxpmkt/estmat/`sec') replace dropall eqcol
  }
drop _all
svmat frm_scalscop_cntry_b, names(eqcol)
svmat frm_scalscop_cntry_e, names(eqcol)
summ _reg_b
summ _reg_b [w=_reg_e]
summ _xtreg_b
summ _xtreg_b [w=_xtreg_e]

}  // close `sec' loop


log close
cd "$home"
