*! version 1.0.4  24jul2009  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 4000m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/srvc-firms"
capture mkdir "braxpmkt/eps/comrc-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/srvc-firms"
capture mkdir "braxpmkt/estmat/comrc-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-regress-graphs-extd-nl.log", replace

// PREDICTED PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {

* Load results

foreach type in b {
  matload expprodextdnl_`type', p(braxpmkt/estmat/`sec') over dropall missing(.)
  }

* Data preparation and within-firm product sales by firm and country

use "braxpmkt/secex/expprod-`sec'", replace

gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"
qui tab wtfkey, gen(indwtf)
drop indwtf1
qui tab cnae, gen(indcnae)
drop indcnae1

* fe lists (bwtf bcnae)
foreach fetype in "wtf" "cnae" {
  unab ind`fetype' : ind`fetype'*
  gen double b`fetype' = .
  foreach var of varlist `ind`fetype'' {
    local num = subinstr("`var'","ind`fetype'","",.)
    qui replace b`fetype' = expprodextdnl_b[rownumb(expprodextdnl_b,"b`fetype'`num'"),colnumb(expprodextdnl_b,"rawdata_nlfewtfcnae")] if ind`fetype'`num'==1
    }
  }
foreach coeff in intcpt delta alphabar beta {
  local `coeff' = expprodextdnl_b[rownumb(expprodextdnl_b,"`coeff'"),colnumb(expprodextdnl_b,"rawdata_nlfewtfcnae")]
  }
gen double predvalue = exp( `intcpt' + (`delta'-1)*lngoods + (1+`alphabar')*log(exp(lngoods)+`beta') - (1+`alphabar')*log(exp(lncurrnum)+`beta') + bcnae + bwtf )

replace value = value/1000
replace predvalue = predvalue/1000
collapse (mean) value predvalue (sd) sd_value=value (count) count_value=value, by(wtfkey goods currnum) fast
gen lnvalue = log(value)
gen lnpredvalue = log(predvalue)
gen lncurrnum = log(currnum)
egen mean_value = mean(value), by(goods currnum)
egen mean_predvalue = mean(predvalue), by(goods currnum)
label var value "Exports (US$ thsd fob)"
label var predvalue "Predicted Exports (US$ thsd fob)"
label var sd_value "Std. dev. Exports (US$ thsd fob)"
label var count "# of Firms with identical Scope"
label var lnvalue "Log Exports (US$ thsd fob)"
label var lnpredvalue "Log Predicted Exports (US$ thsd fob)"
label var lncurrnum "Log Goods rank in firm (HS 6)"
label var mean_value "Mean Exports (US$ thsd fob)"
label var mean_predvalue "Mean Predicted Exports (US$ thsd fob)"

local i 0
foreach goods in 32 16 8 4 {
  local i = `i' + 1
  qui summ mean_predvalue if goods==`goods'
  local lbl`i' = `r(N)'
  }
graph twoway scatter mean_predvalue currnum if goods==32, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter mean_predvalue currnum if goods==16 || scatter mean_predvalue currnum if goods==8 || scatter mean_predvalue currnum if goods==4, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')"))
graph export "braxpmkt/eps/`sec'/expprod-pred-4-32.eps", replace
local i 0
foreach goods in 16 8 4 2 {
  local i = `i' + 1
  qui summ mean_predvalue if goods==`goods'
  local lbl`i' = `r(N)'
  }
graph twoway scatter mean_predvalue currnum if goods==16, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter mean_predvalue currnum if goods==8 || scatter mean_predvalue currnum if goods==4 || scatter mean_predvalue currnum if goods==2, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')"))
graph export "braxpmkt/eps/`sec'/expprod-pred-2-16.eps", replace

}  // close `sec' loop

log close
set more off
