*! version 1.0.1  19febc2009  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 500m
set trace off
set matsize 300

cd "$root"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/srvc-firms"
capture mkdir "braxpmkt/estmat/comrc-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-regress-nl.log", replace

capture program drop uicorr
program define uicorr
  if "`e(cmd)'"=="xtreg" qui predict ui, u
  else qui gen ui = .
  capture corr ui lngoods
  drop ui
end


// 1. FIRM DATA

foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" {

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {

use firmid cnae hs6dgt isic2 cnae wtfkey indoecd90 value using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina

collapse (sum) value, by(firmid cnae hs6dgt)
collapse (sum) sumsales=value (count) goods=value, by(firmid cnae)
drop if sumsales==0
replace sumsales = sumsales/1000000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ mill fob)"
gen gsales=sumsales/goods
label var gsales "Exports per good (US$ mill fob)"

gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"
gen lnsumsales=ln(sumsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(gsales)
label var lngsales "Log exports/good (US$ mill fob)"
drop sumsales

* not operative: lngsales = \gamma + \deltaalpha*lngoods + log( 1-goods^(-\alpha) )
* not operative: nl ( lngsales = {gamma} + ({delta}+{alpha}-1)*lngoods + log(1-goods^(-{alpha})) ), variables(lngsales lngoods goods) initial(gamma 0 deltaalpha 0 alpha 1)
* gsales = \gamma * goods^\deltaalpha * (1-goods^(-\alpha))

capture noi nl ( gsales = {gamma} * goods^({delta}+{alpha}-1) * (1-goods^(-{alpha})) ), variables(gsales goods) initial(gamma 0 delta -.5 alpha 1.5)
est2vec frm_scalscopnl_`region', e(N r2 r2_a convergence) name(nl) replace

capture noi nl ( gsales = {gamma} * goods^({deltaalpha}-1) ), variables(gsales goods) initial(gamma 0 deltaalpha 1.5)
est2vec frm_scalscopnl_`region', addto(frm_scalscopnl_`region') name(nlolsrepl)

est2tex frm_scalscopnl_`region', fancy p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop

}  // close `region' loop


// 2. FIRM-DESTINATION DATA

foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" {

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {

use firmid cnae hs6dgt isic2 cnae wtfkey indoecd90 value using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members

collapse (sum) wtfsales=value (count) wtfgoods=value, by(firmid cnae wtfkey indoecd90)
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
gen wtfgsales=wtfsales/wtfgoods
sort firmid wtfkey
by firmid: gen wtfdest = _N
egen wtfwwsales = sum(wtfsales), by(firmid)
egen wtfwwgsales = mean(wtfgsales), by(firmid)
egen ind0oecd = max(indoecd90), by(firmid)
replace ind0oecd = 1 - ind0oecd
label var wtfgoods "Number of goods (HS 6-digit)"
label var wtfsales "Total exports (US$ mill fob)"
label var wtfgsales "Exports per good (US$ mill fob)"
label var wtfdest "Number of destinations"
label var wtfwwsales "Ww. total exports (US$ mill fob)"
label var wtfwwgsales "Ww. exports/good (US$ mill fob)"
label var ind0oecd "Indic.: Zero OECD exports"
compress

gen lngoods=ln(wtfgoods)
label var lngoods "Log number of goods (HS 6)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/good (US$ mill fob)"
gen lndest = ln(wtfdest)
label var lndest "Log number of destinations"
gen lnwwsales = ln(wtfwwsales)
label var lnwwsales "Log ww. total exports (US$ mill fob)"
gen lnwwgsales = ln(wtfwwgsales)
label var lnwwgsales "Log ww. mean exp./good (US$ mill fob)"
drop wtfsales wtfdest wtfwwsales wtfwwgsales

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
if "`region'"=="world" | "`region'"=="oecd90" { // drop dummy for USA (wtfkey==USA)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==USA"  drop wtfkey_`i'
    }
  }
if "`region'"=="mercosur" | "`region'"=="nonoecd90" { // drop dummy for Argentina (wtfkey==Argentina)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==Argentina"  drop wtfkey_`i'
    }
  }

capture noi nl ( wtfgsales = {gamma} * wtfgoods^({delta}+{alpha}-1) * (1-wtfgoods^(-{alpha})) ), variables(wtfgsales wtfgoods) initial(gamma 0 delta -.5 alpha 1.5)
est2vec frmdst_scalscopnl_`region', e(N r2 r2_a convergence) name(nl) replace

capture noi nl ( wtfgsales = {gamma} * wtfgoods^({deltaalpha}-1) ), variables(wtfgsales wtfgoods) initial(gamma 0 deltaalpha 1.5)
est2vec frmdst_scalscopnl_`region', addto(frmdst_scalscopnl_`region') name(nlolsrepl)

est2tex frmdst_scalscopnl_`region', fancy p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop

}  // close `region' loop


log close
cd "$home"
