*! version 1.0.1  02mar2010  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 650m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/srvc-firms"
capture mkdir "braxpmkt/eps/comrc-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/srvc-firms"
capture mkdir "braxpmkt/estmat/comrc-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-byctry-chile.log", replace


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach sec in "chile-manffrms" {

use "braxpmkt/secex/expprod-`sec'", clear

* create pseudo-sector information (largest HS2-digit is firm's sector)
gen str6 hs2dgt = string(hs6dgt)
replace hs2dgt = "0" + hs2dgt if length(hs2dgt)<6
replace hs2dgt = "0" + hs2dgt if length(hs2dgt)<6
replace hs2dgt = "0" + hs2dgt if length(hs2dgt)<6
replace hs2dgt = substr(hs2dgt,1,2)
sort firmid hs6dgt wtfkey
egen _sumhssec = sum(value), by(firmid hs2dgt)
egen _maxhssec = max(_sumhssec), by(firmid)
egen _modhssec = mode(hs2dgt), by(firmid) minmode  // assign minimum hs2dgt code if tie
sort firmid hs6dgt wtfkey
gen str2 _hssec = hs2dgt if _sumhssec==_maxhssec
replace _hssec = _modhssec if _hssec==""
qui count if _hssec==""
if `r(N)'>0  STOP  // incomplete sector definition
gen hssec = int(real(_hssec))
label var hssec "Main HS 2-digit sector"
drop hs2dgt _*
compress hssec

qui tab goods, gen(indgoods)
qui tab wtfkey, gen(indwtf)
gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"
unab wtfvars : indwtf*
local ftest ""
local i 0
foreach var in `wtfvars' {
  local i = `i'+1
  local wtf = subinstr("`var'","indwtf","",.)
  gen lngoods`wtf' = `var' * lngoods
  label var lngoods`wtf' "Log # goods in country `wtf'"
  if `i'==1  local ftest "lngoods`wtf'"
  if `i'>1   local ftest "`ftest'=lngoods`wtf'"
  }
drop indgoods1
drop indwtf1
drop lngoods indgoods*

unab vars : lngoods* lncurrnum indwtf*
reg lnvalue lngoods* lncurrnum indwtf*
  est2vec expprodctry, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(rawdata:fewtf_long) replace
  test `ftest'
  est2vec expprodctry, r(drop df_r F df p) name(rawdata:fewtf_long) replace
xtreg lnvalue lngoods* lncurrnum indwtf*, i(hssec) fe
  est2vec expprodctry, addto(expprodctry) name(rawdata:fewtfhssec_long) replace
  test `ftest'
  est2vec expprodctry, raddto(expprodctry) name(rawdata:fewtfhssec_long) replace
xtreg lnvalue lngoods* lncurrnum indwtf*, i(firm) fe
  est2vec expprodctry, addto(expprodctry) name(rawdata:fewtffirm_goods) replace
  test `ftest'
  est2vec expprodctry, raddto(expprodctry) name(rawdata:fewtffirm_goods) replace

reg lnvalue lngoods* lncurrnum indwtf* if value>=100
  est2vec expprodctry, addto(expprodctry) name(rawdata:fewtf_long_ge100) replace
  test `ftest'
  est2vec expprodctry, raddto(expprodctry) name(rawdata:fewtf_long_ge100) replace
xtreg lnvalue lngoods* lncurrnum indwtf* if value>=100, i(hssec) fe
  est2vec expprodctry, addto(expprodctry) name(rawdata:fewtfhssec_long_ge100) replace
  test `ftest'
  est2vec expprodctry, raddto(expprodctry) name(rawdata:fewtfhssec_long_ge100) replace
xtreg lnvalue lngoods* lncurrnum indwtf* if value>=100, i(firm) fe
  est2vec expprodctry, addto(expprodctry) name(rawdata:fewtffirm_goods_ge100) replace
  test `ftest'
  est2vec expprodctry, raddto(expprodctry) name(rawdata:fewtffirm_goods_ge100) replace

est2tex expprodctry, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

tempfile cntryvars
use wtfkey gdp_usd population lndist using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
collapse (sum) gdp_usd population (mean) lndist, by(wtfkey)
label var gdp_usd "GDP [curr. USD]"
label var population "Population (total)"
label var lndist "Log Distance (city mean, no wt)"
gen ln_gdp_usd = ln(gdp_usd)
gen ln_pop = ln(population)
gen ln_gdp_cap_usd = ln_gdp_usd - ln_pop
label var ln_gdp_usd "Log GDP [curr. USD]"
label var ln_pop "Log Population (total)"
label var ln_gdp_cap_usd "Log GDP per cap. [curr. USD]"
drop gdp_usd population
sort wtfkey
save `cntryvars'

foreach sec in "chile-manffrms" {

* numeric country codes (running country numbers)
tempfile cntrylnk
use "braxpmkt/secex/expprod-`sec'", clear
qui tab wtfkey, gen(indwtf)
unab wtfvarlst : indwtf*
local i 0
foreach var of varlist `wtfvarlst' {
  local i = `i'+1
  local wtf`i' : variable label `var'
  local wtf`i' = subinstr("`wtf`i''","wtfkey==","",.)
  label define wtfnum `i' "`wtf`i''", modify
  * disp "`wtf`i'' " _continue
  } 
* label list wtfnum
* label list wtfkey
egen wtfnum = group(wtfkey)
label values wtfnum wtfnum
decode wtfkey, generate(_wtfkey)
decode wtfnum, generate(_wtfnum)
qui count if _wtfkey~=_wtfnum
if `r(N)'>0  STOP   // numeric country codes do not coincide
drop _*
keep wtfkey wtfnum
duplicates drop
sort wtfkey
merge wtfkey using `cntryvars', nokeep
qui count if _m~=3
if `r(N)'  STOP  // incomplete country information
drop _m
order wtfnum wtfkey
sort wtfnum
save `cntrylnk'

* delta (matload expprodctry_tbl, p(braxpmkt/estmat/`sec') over dropall missing(.))
use "braxpmkt/estmat/`sec'/expprodctry_tbl.dta", clear
drop if _rowname=="_se"
keep _rowname rawdata_fewtfhssec_long_ge100
gen int wtfnum = int(real(subinstr(_rowname,"lngoods","",.))) if index(_rowname,"lngoods")>0
label var wtfnum "group(wtfkey)"
label values wtfnum wtfnum
qui summ rawdata_fewtfhssec_long_ge100 if _rowname=="lncurrnum"
local alphabar = - (1 + `r(mean)')
gen delta = rawdata_fewtfhssec_long_ge100 - `alphabar' - 1 if index(_rowname,"lngoods")>0  // delta_new = delta_old - 1
label var delta "Country-specific Delta"
sort wtfnum
merge wtfnum using `cntrylnk', nokeep
tab _m
drop _m
order wtfkey wtfnum
sort wtfkey

reg delta lndist ln_gdp_usd
est2vec expproddelta, vars(lndist ln_gdp_usd _cons) e(N r2 df_a df_r F_f) name(delta_short) replace
reg delta lndist ln_gdp_cap_usd ln_pop
est2vec expproddelta, addto(expproddelta) name(delta_long)

est2tex expproddelta, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop

  
log close
set more off
