*! version 1.1.1  02oct2010  by Marc Muendler  muendler@ucsd.edu

version 9.2
set more off
set virtual on
clear
set mem 1000m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/poolsec"
capture mkdir "braxpmkt/estmat/poolsec"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-discrete-byisic.log", replace

local sec "poolsec"


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach smpl in "manf-firms" "chile-manffrms" "comrc-firms" {
  if "`smpl'"=="manf-firms"     local prfx "br"
  if "`smpl'"=="chile-manffrms" local prfx "cl"
  if "`smpl'"=="comrc-firms"    local prfx "brcmrc"
  tempfile `prfx'
  use "braxpmkt/secex/expprod-`smpl'", clear
  gen lngoods=ln(goods)
  label var lngoods "Log number of goods (HS 6)"
  foreach var in lngoods lncurrnum {
    rename `var' `prfx'_`var'
    }
  gen str subsmpl = "`smpl'"
  label var subsmpl "Sample"
  if "`smpl'"~="chile-manffrms"  keep subsmpl firmid wtfkey hs6dgt cnae value goods currnum lnvalue `prfx'_lngoods `prfx'_lncurrnum 
  if "`smpl'"=="chile-manffrms"  keep subsmpl firmid wtfkey hs6dgt value goods currnum lnvalue `prfx'_lngoods `prfx'_lncurrnum 
  if "`smpl'"~="chile-manffrms"  order subsmpl firmid wtfkey hs6dgt cnae value goods currnum lnvalue `prfx'_lngoods `prfx'_lncurrnum
  if "`smpl'"=="chile-manffrms"  order subsmpl firmid wtfkey hs6dgt value goods currnum lnvalue `prfx'_lngoods `prfx'_lncurrnum
  sort subsmpl firmid wtfkey hs6dgt
  save ``prfx''
  }
use `br'
append using `cl'
append using `brcmrc'
sort subsmpl firmid wtfkey hs6dgt
foreach smpl in "manf-firms" "chile-manffrms" "comrc-firms" {
  if "`smpl'"=="manf-firms"     local prfx "br" 
  if "`smpl'"=="chile-manffrms" local prfx "cl" 
  if "`smpl'"=="comrc-firms"    local prfx "brcmrc"
  replace `prfx'_lngoods = 0 if `prfx'_lngoods==.
  replace `prfx'_lncurrnum = 0 if  `prfx'_lncurrnum==.
  }
gen str firm_wtf = string(firmid) + "_" + string(wtfkey)
encode firm_wtf, generate(firmwtf)
drop firm_wtf
label var firmwtf "Firm-destination category"
qui tab subsmpl, gen(indsrc)
drop indsrc1
qui tab wtfkey, gen(indwtf)
drop indwtf1

* check for duplicate firm IDs
preserve
  keep subsmpl firmid
  duplicates drop
  duplicates tag firmid, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP  // non-unique firm IDs
  by subsmpl: summ firmid
restore

* REGRESSION SAMPLE for br only, with CNAE-fixed effects
drop if subsmpl == "chile-manffrms" | subsmpl == "comrc-firms"
drop cl_* brcmrc_*

* merge ISIC information
sort hs6dgt
merge hs6dgt using "braxpmkt/conc/hs2isic.dta", nokeep
tab _m
tab isic
drop _m
drop if isic<300 | isic>399 | isic==.
sort subsmpl firmid wtfkey hs6dgt
qui tab isic, gen(indisic)
unab vars : indisic*
local i 0
foreach var in `vars' {
  local i = `i'+1
  local code : variable label `var'
  local code = substr("`code'",9,3)
  * disp "`code'"
  rename indisic`i' indisic`code'
  local lbl : variable label indisic`code'
  local lbl = substr("`lbl'",14,.)
  label var indisic`code' "`lbl'"
  gen br`code'_lngoods = br_lngoods * indisic`code'
  local lbl : variable label br_lngoods
  label var br`code'_lngoods "Log # goods (HS 6) [ISIC `code']"
  gen br`code'_lncurrnum = br_lncurrnum * indisic`code'
  local lbl : variable label br_lncurrnum
  label var br`code'_lncurrnum "Log Prod. rank (HS 6) [ISIC `code']"
  }
drop indisic*

* REGRESSIONS for br only, with CNAE-fixed effects
unab vars : br???_lngoods br_lncurrnum br???_lncurrnum indwtf*
xtreg lnvalue br???_lngoods br_lncurrnum, i(cnae) fe
  est2vec expprodisic_dibr, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(disic:fecnae_long) replace
xtreg lnvalue br???_lngoods br_lncurrnum indwtf*, i(cnae) fe
  est2vec expprodisic_dibr, addto(expprodisic_dibr) name(disic:fewtfcnae_long) replace
xtreg lnvalue br???_lngoods br_lncurrnum indwtf*, i(firmid) fe
  est2vec expprodisic_dibr, addto(expprodisic_dibr) name(disic:fewtffirm_goods) replace
xtreg lnvalue br???_lngoods br_lncurrnum, i(firmwtf) fe
  est2vec expprodisic_dibr, addto(expprodisic_dibr) name(disic:fe2wtffirm_goods) replace

xtreg lnvalue br???_lngoods br???_lncurrnum, i(cnae) fe
  est2vec expprodisic_dibr, addto(expprodisic_dibr) name(daisic:fecnae_long) replace
xtreg lnvalue br???_lngoods br???_lncurrnum indwtf*, i(cnae) fe
  est2vec expprodisic_dibr, addto(expprodisic_dibr) name(daisic:fewtfcnae_long) replace
xtreg lnvalue br???_lngoods br???_lncurrnum indwtf*, i(firmid) fe
  est2vec expprodisic_dibr, addto(expprodisic_dibr) name(daisic:fewtffirm_goods) replace
xtreg lnvalue br???_lngoods br???_lncurrnum, i(firmwtf) fe
  est2vec expprodisic_dibr, addto(expprodisic_dibr) name(daisic:fe2wtffirm_goods) replace

est2tex expprodisic_dibr, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall preserve

log close
set more off
