*! version 1.0.5  31mar2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.6  27jul2010  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 1000m
set matsize 800
set maxiter 100
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/srvc-firms"
capture mkdir "braxpmkt/eps/comrc-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/srvc-firms"
capture mkdir "braxpmkt/estmat/comrc-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-discrete-nl.log", replace

capture program drop nlprod
program nlprod
  syntax varlist(min=3 max=3) [aw fw iw] if, at(name)
  local lnvalue: word 1 of `varlist'
  local lngoods: word 2 of `varlist'
  local lncurrnum: word 3 of `varlist'
  // retrieve parameters intcpt dplsasub asub tbysls1 from at
  tempname intcpt dplsasub asub tbysls1
  scalar `intcpt' = `at'[1,1]
  scalar `dplsasub' = `at'[1,2]
  scalar `asub' = `at'[1,3]
  scalar `tbysls1' = `at'[1,4]
  // temporary variables
  * tempvar gterm numterm denterm
  * generate double `gterm' = `dplsasub'*`lngoods' - (`asub')*`lncurrnum' `if'
  * generate double `numterm' = log( 1 - (exp(`lngoods')/(exp(`lngoods')+1))^((`tbysls1'-1)*`dplsasub') ) `if'
  * generate double `denterm' = - log( 1 - (exp(`lngoods')/(exp(`lngoods')+1))^(`tbysls1'*`dplsasub') ) `if'
  // fill in dependent variable
  * replace `lnvalue' = `intcpt'+`gterm'+`numterm'+`denterm' `if'
  replace `lnvalue' = `intcpt' + `dplsasub'*`lngoods' - (`asub')*`lncurrnum' + log( 1 - (exp(`lngoods')/(exp(`lngoods')+1))^((`tbysls1'-1)*`dplsasub') ) - log( 1 - (exp(`lngoods')/(exp(`lngoods')+1))^(`tbysls1'*`dplsasub') ) `if'
end

capture program drop nlfewtf
program nlfewtf
  syntax varlist(min=3 max=3) [aw fw iw] if, at(name)
  local lnvalue: word 1 of `varlist'
  local lngoods: word 2 of `varlist'
  local lncurrnum: word 3 of `varlist'
  // retrieve parameters intcpt dplsasub asub tbysls1 from at
  tempname intcpt dplsasub asub tbysls1
  scalar `intcpt' = `at'[1,1]
  scalar `dplsasub' = `at'[1,2]
  scalar `asub' = `at'[1,3]
  scalar `tbysls1' = `at'[1,4]
  local j 4
  // fe wtf variable
  tempvar wtfterm
  local wtfrhs 0
  foreach coeff of global bwtf {
    tempname `coeff'
    local j = `j' + 1
    scalar ``coeff'' = `at'[1,`j']
    local var = subinstr("`coeff'","bwtf","indwtf",.)
    local wtfrhs "`wtfrhs' + ``coeff''*`var'"
    }
  generate double `wtfterm' = `wtfrhs' `if'
  // temporary variables
  * tempvar gterm numterm denterm
  * generate double `gterm' = `dplsasub'*`lngoods' - (`asub')*`lncurrnum' `if'
  * generate double `numterm' = log( 1 - (exp(`lngoods')/(exp(`lngoods')+1))^((`tbysls1'-1)*`dplsasub') ) `if'
  * generate double `denterm' = - log( 1 - (exp(`lngoods')/(exp(`lngoods')+1))^(`tbysls1'*`dplsasub') ) `if'
  // fill in dependent variable
  * replace `lnvalue' = `intcpt'+`gterm'+`numterm'+`denterm'+`wtfterm' `if'
  replace `lnvalue' = `intcpt' + `dplsasub'*`lngoods' - (`asub')*`lncurrnum' + log( 1 - (exp(`lngoods')/(exp(`lngoods')+1))^((`tbysls1'-1)*`dplsasub') ) - log( 1 - (exp(`lngoods')/(exp(`lngoods')+1))^(`tbysls1'*`dplsasub') ) + `wtfterm' `if'
end

// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {

use "braxpmkt/secex/expprod-`sec'", clear
drop lnvalue lncurrnum

collapse value, by(wtfkey goods currnum) fast
label var value "Mean Exports (US$ fob)"
gen lnvalue = log(value)
label var lnvalue "Log Mean Exports (US$ fob)"
gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"
gen lncurrnum = log(currnum)
label var lncurrnum "Log Goods rank in firms (HS 6)"

qui tab wtfkey, gen(indwtf) missing
drop indwtf1
* qui tab cnae, gen(indcnae) missing
* drop indcnae1

drop if lnvalue==. | goods==. | lncurrnum==.

* fe lists (bwtf bcnae)
* foreach fetype in "wtf" "cnae" {
foreach fetype in "wtf" {
  foreach var of varlist ind`fetype'* {
    local newname = subinstr("`var'","ind`fetype'","b`fetype'",.)
    rename `var' `newname'
    }
  unab b`fetype' : b`fetype'*
  global b`fetype' "`b`fetype''"
  foreach var of varlist b`fetype'* {
    local oldname = subinstr("`var'","b`fetype'","ind`fetype'",.)
    rename `var' `oldname'
    }
  }

* nl
matrix ivals = (0, 1, 1, 8/7)
matrix colnames ivals = intcpt dplsasub asub tbysls1
matrix rownames ivals = ival
capture noi nl prod @ lnvalue lngoods lncurrnum, parameters(intcpt dplsasub asub tbysls1) initial(ivals)
est2vec expprodintgnl, vars(intcpt dplsasub asub tbysls1 `bwtf' `bcnae') e(N r2 r2_a df_m df_r F converge) name(rawdata:nl) replace

* nl fewtf
local wtfcnt : list sizeof bwtf
matrix ivals = ivals , J(1,`wtfcnt',0)
matrix colnames ivals = intcpt dplsasub asub tbysls1 `bwtf'
capture noi nl fewtf @ lnvalue lngoods lncurrnum, parameters(intcpt dplsasub asub tbysls1 `bwtf') initial(ivals)
if _rc==0  est2vec expprodintgnl, addto(expprodintgnl) name(rawdata:nlfewtf) replace

* nl if value>=100
matrix ivals = (0, 1, 1, 8/7)
matrix colnames ivals = intcpt dplsasub asub tbysls1
matrix rownames ivals = ival
capture noi nl prod @ lnvalue lngoods lncurrnum if value>=100, parameters(intcpt dplsasub asub tbysls1) initial(ivals)
if _rc==0  est2vec expprodintgnl, addto(expprodintgnl) name(rawdata:nl_ge100) replace

* nl fewtf if value>=100
local wtfcnt : list sizeof bwtf
matrix ivals = ivals , J(1,`wtfcnt',0)
matrix colnames ivals = intcpt dplsasub asub tbysls1 `bwtf'
capture noi nl fewtf @ lnvalue lngoods lncurrnum if value>=100, parameters(intcpt dplsasub asub tbysls1 `bwtf') initial(ivals)
if _rc==0  est2vec expprodintgnl, addto(expprodintgnl) name(rawdata:nlfewtf_ge100) replace
  
foreach type in b se e {
  matsave expprodintgnl_`type', p(braxpmkt/estmat/`sec') replace dropall type(double)
  if "`type'"=="b" | "`type'"=="se"  matorder expprodintgnl_`type', m(expprodintgnl_`type') over ifr(intcpt dplsasub asub tbysls1)
  }

est2tex expprodintgnl, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop

log close
set more off
