*! version 1.0.4  23mar2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.5  28mar2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.6  25apr2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.1.1  17jul2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.2.1  30apr2011  by Marc Muendler  muendler@ucsd.edu

version 9.2
set more off
set virtual on
clear
set mem 1000m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/poolsec"
capture mkdir "braxpmkt/estmat/poolsec"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-discrete.log", replace

local sec "poolsec"

capture program drop uicorrftest
program define uicorrftest, rclass
  args prfxlst
  foreach prfx in `prfxlst' {
    qui test `prfx'_lngoods = 0
    return scalar `prfx'_total_F = r(F)
    return scalar `prfx'_total_p = r(p)
    return scalar `prfx'_total = return(delta) + return(alphabar)
    qui test - `prfx'_lncurrnum - 1 = 0
    return scalar `prfx'_alphabar_F = r(F)
    return scalar `prfx'_alphabar_p = r(p)
    return scalar `prfx'_alphabar = - _b[`prfx'_lncurrnum] - 1
    qui test `prfx'_lngoods + `prfx'_lncurrnum = 0
    return scalar `prfx'_delta_F = r(F)
    return scalar `prfx'_delta_p = r(p)
    return scalar `prfx'_delta = _b[`prfx'_lngoods] + _b[`prfx'_lncurrnum]
    if "`e(cmd)'"=="xtreg"  qui predict ui, u
    else qui gen ui = .
    capture corr ui `prfx'_lncurrnum
    drop ui
    return scalar `prfx'_rho = r(rho)
  }
end


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach smpl in "manf-firms" "chile-manffrms" "comrc-firms" {
  if "`smpl'"=="manf-firms"     local prfx "br"
  if "`smpl'"=="chile-manffrms" local prfx "cl"
  if "`smpl'"=="comrc-firms"    local prfx "brcmrc"
  tempfile `prfx'
  use "braxpmkt/secex/expprod-`smpl'", clear
  gen lngoods=ln(goods)
  label var lngoods "Log number of goods (HS 6)"
  foreach var in lngoods lncurrnum {
    rename `var' `prfx'_`var'
    }
  gen str subsmpl = "`smpl'"
  label var subsmpl "Sample"
  if "`smpl'"~="chile-manffrms"  keep subsmpl firmid wtfkey hs6dgt cnae value goods currnum lnvalue `prfx'_lngoods `prfx'_lncurrnum 
  if "`smpl'"=="chile-manffrms"  keep subsmpl firmid wtfkey hs6dgt value goods currnum lnvalue `prfx'_lngoods `prfx'_lncurrnum 
  if "`smpl'"~="chile-manffrms"  order subsmpl firmid wtfkey hs6dgt cnae value goods currnum lnvalue `prfx'_lngoods `prfx'_lncurrnum
  if "`smpl'"=="chile-manffrms"  order subsmpl firmid wtfkey hs6dgt value goods currnum lnvalue `prfx'_lngoods `prfx'_lncurrnum
  sort firmid subsmpl wtfkey hs6dgt
  save ``prfx''
  }
use `br'
append using `brcmrc'
preserve
  keep firmid
  sort firmid
  merge firmid using `cl'
  qui count if _m==3
  list firmid if _m==3
  if `r(N)'>0  STOP  // Chilean and Brazilian firm IDs coincide for at least one firm
restore
append using `cl'
sort subsmpl firmid wtfkey hs6dgt
foreach smpl in "manf-firms" "chile-manffrms" "comrc-firms" {
  if "`smpl'"=="manf-firms"     local prfx "br" 
  if "`smpl'"=="chile-manffrms" local prfx "cl" 
  if "`smpl'"=="comrc-firms"    local prfx "brcmrc"
  replace `prfx'_lngoods = 0 if `prfx'_lngoods==.
  replace `prfx'_lncurrnum = 0 if  `prfx'_lncurrnum==.
  }
gen str firm_wtf = string(firmid) + "_" + substr(string(wtfkey),1,2)  // Firms and WTF regions (first two WTFkey digits)
encode firm_wtf, generate(firmwtf)
preserve
  keep firm_wtf firmwtf
  duplicates drop
  duplicates tag firmwtf, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP  //  string encoding not unique
restore 
drop firm_wtf
label var firmwtf "Firm-destination category"
qui tab subsmpl, gen(indsrc)
drop indsrc1
qui tab wtfkey, gen(indwtf)
drop indwtf1

* check for duplicate firm IDs
preserve
  keep subsmpl firmid
  duplicates drop
  duplicates tag firmid, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP  // non-unique firm IDs
  by subsmpl: summ firmid
restore


* REGRESSIONS for br cl brcmrc, no industry-fixed effects
unab vars : br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf*
reg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc*
  est2vec expprodextd_d, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(raw:ols_long) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, r(br_rho br_delta br_delta_p br_delta_F br_alphabar br_alphabar_p br_alphabar_F br_total br_total_p br_total_F cl_rho cl_delta cl_delta_p cl_delta_F cl_alphabar cl_alphabar_p cl_alphabar_F cl_total cl_total_p cl_total_F brcmrc_rho brcmrc_delta brcmrc_delta_p brcmrc_delta_F brcmrc_alphabar brcmrc_alphabar_p brcmrc_alphabar_F brcmrc_total brcmrc_total_p brcmrc_total_F) name(raw:ols) replace
reg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf*
  est2vec expprodextd_d, addto(expprodextd_d) name(raw:fewtf_long) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, raddto(expprodextd_d) name(raw:fewtf_long) replace
xtreg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf*, i(firmid) fe
  est2vec expprodextd_d, addto(expprodextd_d) name(raw:fewtffirm_goods) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, raddto(expprodextd_d) name(raw:fewtffirm_goods) replace
xtreg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc*, i(firmwtf) fe
  est2vec expprodextd_d, addto(expprodextd_d) name(raw:fe2wtffirm_goods) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, raddto(expprodextd_d) name(raw:fe2wtffirm_goods) replace
areg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* [pw=value], absorb(firmwtf)  // weighted fe regression
  est2vec expprodextd_d, addto(expprodextd_d) name(wght:fe2wtffirm_goods) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, raddto(expprodextd_d) name(wght:fe2wtffirm_goods) replace

reg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* if value>=100
  est2vec expprodextd_d, addto(expprodextd_d) name(raw:ols_long_ge100) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, raddto(expprodextd_d) name(raw:ols_long_ge100) replace
reg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf* if value>=100
  est2vec expprodextd_d, addto(expprodextd_d) name(raw:fewtf_long_ge100) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, raddto(expprodextd_d) name(raw:fewtf_long_ge100) replace
xtreg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf* if value>=100, i(firmid) fe
  est2vec expprodextd_d, addto(expprodextd_d) name(raw:fewtffirm_goods_ge100) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, raddto(expprodextd_d) name(raw:fewtffirm_goods_ge100) replace
xtreg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* if value>=100, i(firmwtf) fe
  est2vec expprodextd_d, addto(expprodextd_d) name(raw:fe2wtffirm_goods_ge100) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, raddto(expprodextd_d) name(raw:fe2wtffirm_goods_ge100) replace
areg lnvalue br_lngoods br_lncurrnum cl_lngoods cl_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* if value>=100 [pw=value], absorb(firmwtf)  // weighted fe regression
  est2vec expprodextd_d, addto(expprodextd_d) name(wght:fe2wtffirm_goods_ge100) replace
  uicorrftest "br cl brcmrc"
  est2vec expprodextd_d, raddto(expprodextd_d) name(wght:fe2wtffirm_goods_ge100) replace

est2tex expprodextd_d, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall preserve
* est2tex expprodfit_d, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall preserve


* REGRESSIONS for br brcmrc only, with CNAE-fixed effects
drop if subsmpl == "chile-manffrms"
drop cl_*
unab vars : br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf*
xtreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc*, i(cnae) fe
  est2vec expprodextd_di, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(raw:fecnae_long) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, r(br_rho br_delta br_delta_p br_delta_F br_alphabar br_alphabar_p br_alphabar_F br_total br_total_p br_total_F brcmrc_rho brcmrc_delta brcmrc_delta_p brcmrc_delta_F brcmrc_alphabar brcmrc_alphabar_p brcmrc_alphabar_F brcmrc_total brcmrc_total_p brcmrc_total_F) name(raw:fecnae_long) replace
xtreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf*, i(cnae) fe
  est2vec expprodextd_di, addto(expprodextd_di) name(raw:fewtfcnae_long) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, raddto(expprodextd_di) name(raw:fewtfcnae_long) replace
xtreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf*, i(firmid) fe
  est2vec expprodextd_di, addto(expprodextd_di) name(raw:fewtffirm_goods) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, raddto(expprodextd_di) name(raw:fewtffirm_goods) replace
xtreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc*, i(firmwtf) fe
  est2vec expprodextd_di, addto(expprodextd_di) name(raw:fe2wtffirm_goods) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, raddto(expprodextd_di) name(raw:fe2wtffirm_goods) replace
areg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* [pw=value], absorb(firmwtf)  // weighted fe regression
  est2vec expprodextd_di, addto(expprodextd_di) name(wght:fe2wtffirm_goods) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, raddto(expprodextd_di) name(wght:fe2wtffirm_goods) replace

xtreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* if value>=100, i(cnae) fe
  est2vec expprodextd_di, addto(expprodextd_di) name(raw:ols_long_ge100) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, raddto(expprodextd_di) name(raw:fecnae_long_ge100) replace
xtreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf* if value>=100, i(cnae) fe
  est2vec expprodextd_di, addto(expprodextd_di) name(raw:fewtfcnae_long_ge100) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, raddto(expprodextd_di) name(raw:fewtf_long_ge100) replace
xtreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf* if value>=100, i(firmid) fe
  est2vec expprodextd_di, addto(expprodextd_di) name(raw:fewtffirm_goods_ge100) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, raddto(expprodextd_di) name(raw:fewtffirm_goods_ge100) replace
xtreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* if value>=100, i(firmwtf) fe
  est2vec expprodextd_di, addto(expprodextd_di) name(raw:fe2wtffirm_goods_ge100) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, raddto(expprodextd_di) name(raw:fe2wtffirm_goods_ge100) replace
areg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* if value>=100 [pw=value], absorb(firmwtf)  // weighted fe regression
  est2vec expprodextd_di, addto(expprodextd_di) name(wght:fe2wtffirm_goods_ge100) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_di, raddto(expprodextd_di) name(wght:fe2wtffirm_goods_ge100) replace

est2tex expprodextd_di, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall preserve
* est2tex expprodfit_di, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall preserve


* REGRESSIONS for br only, with CNAE-fixed effects
drop if subsmpl == "chile-manffrms" | subsmpl == "comrc-firms"
drop brcmrc_*
unab vars : br_lngoods br_lncurrnum indwtf*

xtreg lnvalue br_lngoods br_lncurrnum, i(cnae) fe
  est2vec expprodextd_dibr, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(raw:fecnae_long) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, r(br_rho br_delta br_delta_p br_delta_F br_alphabar br_alphabar_p br_alphabar_F br_total br_total_p br_total_F) name(raw:fecnae_long) replace
xtreg lnvalue br_lngoods br_lncurrnum indwtf*, i(cnae) fe
  est2vec expprodextd_dibr, addto(expprodextd_dibr) name(raw:fewtfcnae_long) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, raddto(expprodextd_dibr) name(raw:fewtfcnae_long) replace
xtreg lnvalue br_lngoods br_lncurrnum indwtf*, i(firmid) fe
  est2vec expprodextd_dibr, addto(expprodextd_dibr) name(raw:fewtffirm_goods) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, raddto(expprodextd_dibr) name(raw:fewtffirm_goods) replace
xtreg lnvalue br_lngoods br_lncurrnum, i(firmwtf) fe
  est2vec expprodextd_dibr, addto(expprodextd_dibr) name(raw:fe2wtffirm_goods) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, raddto(expprodextd_dibr) name(raw:fe2wtffirm_goods) replace
areg lnvalue br_lngoods br_lncurrnum [pw=value], absorb(firmwtf)  // weighted fe regression
  est2vec expprodextd_dibr, addto(expprodextd_dibr) name(wght:fe2wtffirm_goods) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, raddto(expprodextd_dibr) name(wght:fe2wtffirm_goods) replace

xtreg lnvalue br_lngoods br_lncurrnum if value>=100, i(cnae) fe
  est2vec expprodextd_dibr, addto(expprodextd_dibr) name(raw:ols_long_ge100) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, raddto(expprodextd_dibr) name(raw:fecnae_long_ge100) replace
xtreg lnvalue br_lngoods br_lncurrnum indwtf* if value>=100, i(cnae) fe
  est2vec expprodextd_dibr, addto(expprodextd_dibr) name(raw:fewtfcnae_long_ge100) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, raddto(expprodextd_dibr) name(raw:fewtf_long_ge100) replace
xtreg lnvalue br_lngoods br_lncurrnum indwtf* if value>=100, i(firmid) fe
  est2vec expprodextd_dibr, addto(expprodextd_dibr) name(raw:fewtffirm_goods_ge100) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, raddto(expprodextd_dibr) name(raw:fewtffirm_goods_ge100) replace
xtreg lnvalue br_lngoods br_lncurrnum if value>=100, i(firmwtf) fe
  est2vec expprodextd_dibr, addto(expprodextd_dibr) name(raw:fe2wtffirm_goods_ge100) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, raddto(expprodextd_dibr) name(raw:fe2wtffirm_goods_ge100) replace
areg lnvalue br_lngoods br_lncurrnum if value>=100 [pw=value], absorb(firmwtf)  // weighted fe regression
  est2vec expprodextd_dibr, addto(expprodextd_dibr) name(wght:fe2wtffirm_goods_ge100) replace
  uicorrftest "br"
  est2vec expprodextd_dibr, raddto(expprodextd_dibr) name(wght:fe2wtffirm_goods_ge100) replace

est2tex expprodextd_dibr, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall preserve
* est2tex expprodfit_dibr, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall preserve


* if Stata 10.1: reset to Stata 9.2 format
* use "braxpmkt/estmat/`sec'/expprodextd_d_tbl.dta", clear
* saveold "braxpmkt/estmat/`sec'/expprodextd_d_tbl.dta", replace
* use "braxpmkt/estmat/`sec'/expprodfit_d_tbl.dta", clear
* saveold "braxpmkt/estmat/`sec'/expprodfit_d_tbl.dta", replace
* use "braxpmkt/estmat/`sec'/expprodextd_di_tbl.dta", clear
* saveold "braxpmkt/estmat/`sec'/expprodextd_di_tbl.dta", replace
* use "braxpmkt/estmat/`sec'/expprodfit_di_tbl.dta", clear
* saveold "braxpmkt/estmat/`sec'/expprodfit_di_tbl.dta", replace
* use "braxpmkt/estmat/`sec'/expprodextd_dibr_tbl.dta", clear
* saveold "braxpmkt/estmat/`sec'/expprodextd_dibr_tbl.dta", replace
* use "braxpmkt/estmat/`sec'/expprodfit_dibr_tbl.dta", clear
* saveold "braxpmkt/estmat/`sec'/expprodfit_dibr_tbl.dta", replace

log close
set more off
