*! version 1.0.2  24feb2009  by Marc Muendler  muendler@ucsd.edu
*! version 1.1.1  14aug2009  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 650m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/chile-manffrms"
capture mkdir "braxpmkt/estmat/chile-manffrms"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-extd-chile.log", replace

capture program drop uicorrftest
program define uicorrftest, rclass
  qui test lngoods = 0
  return scalar total_F = r(F)
  return scalar total_p = r(p)
  return scalar total = return(delta) + return(alphabar)
  qui test - lncurrnum - 1 = 0
  return scalar alphabar_F = r(F)
  return scalar alphabar_p = r(p)
  return scalar alphabar = - _b[lncurrnum] - 1
  qui test lngoods + lncurrnum = 0
  return scalar delta_F = r(F)
  return scalar delta_p = r(p)
  return scalar delta = _b[lngoods] + _b[lncurrnum]
  if "`e(cmd)'"=="xtreg" qui predict ui, u
  else qui gen ui = .
  capture corr ui lncurrnum
  drop ui
  return scalar rho = r(rho)
end


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

*foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {
local sec "chile-manffrms"

use "braxpmkt/secex/expprod-chile-manffrms", clear

* create pseudo-sector information (largest HS2-digit is firm's sector)
gen str6 hs2dgt = string(hs6dgt)
replace hs2dgt = "0" + hs2dgt if length(hs2dgt)<6
replace hs2dgt = "0" + hs2dgt if length(hs2dgt)<6
replace hs2dgt = "0" + hs2dgt if length(hs2dgt)<6
replace hs2dgt = substr(hs2dgt,1,2)
sort firmid hs6dgt wtfkey
egen _sumhssec = sum(value), by(firmid hs2dgt)
egen _maxhssec = max(_sumhssec), by(firmid)
egen _modhssec = mode(hs2dgt), by(firmid) minmode  // assign minimum hs2dgt code if tie
sort firmid hs6dgt wtfkey
gen str2 _hssec = hs2dgt if _sumhssec==_maxhssec
replace _hssec = _modhssec if _hssec==""
qui count if _hssec==""
if `r(N)'>0  STOP  // incomplete sector definition
gen hssec = int(real(_hssec))
label var hssec "Main HS 2-digit sector"
drop hs2dgt _*
compress hssec

qui tab goods, gen(indgoods)
drop indgoods1
qui tab wtfkey, gen(indwtf)
drop indwtf1
gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"

unab vars : lngoods lncurrnum indwtf* indgoods*
reg lnvalue lngoods lncurrnum
  est2vec expprodextd, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(rawdata:ols_long) replace
  uicorrftest
  est2vec expprodextd, r(rho delta delta_p delta_F alphabar alphabar_p alphabar_F total total_p total_F) name(rawdata:ols) replace
reg lnvalue lngoods lncurrnum indwtf*
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtf_long) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtf_long) replace
xtreg lnvalue lngoods lncurrnum indwtf*, i(hssec) fe
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtfhssec_long) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtfhssec_long) replace
xtreg lnvalue lngoods lncurrnum indwtf*, i(firm) fe
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtffirm_goods) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtffirm_goods) replace
areg lnvalue lngoods lncurrnum indwtf* [pw=value], absorb(firm)  // weighted fe regression
  est2vec expprodextd, addto(expprodextd) name(wghtdata:fewtffirm_goods) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(wghtdata:fewtffirm_goods) replace

reg lnvalue lngoods lncurrnum if value>=100
  est2vec expprodextd, addto(expprodextd) name(rawdata:ols_long_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:ols_long_ge100) replace
reg lnvalue lngoods lncurrnum indwtf* if value>=100
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtf_long_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtf_long_ge100) replace
xtreg lnvalue lngoods lncurrnum indwtf* if value>=100, i(hssec) fe
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtfhssec_long_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtfhssec_long_ge100) replace
xtreg lnvalue lngoods lncurrnum indwtf* if value>=100, i(firm) fe
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtffirm_goods_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtffirm_goods_ge100) replace
areg lnvalue lngoods lncurrnum indwtf* if value>=100 [pw=value], absorb(firm)  // weighted fe regression
  est2vec expprodextd, addto(expprodextd) name(wghtdata:fewtffirm_goods_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(wghtdata:fewtffirm_goods_ge100) replace

preserve
  replace value = value/1000
  collapse (mean) value (sd) sd_value=value (count) count_value=value, by(wtfkey goods currnum) fast
  gen lnvalue = log(value)
  gen lncurrnum = log(currnum)
  gen lngoods=ln(goods)
  egen mean_value = mean(value), by(goods currnum)
  label var value "Exports (US$ thsd fob)"
  label var sd_value "Std. dev. Exports (US$ thsd fob)"
  label var count "# of Firms with identical Scope"
  label var lnvalue "Log Exports (US$ thsd fob)"
  label var lncurrnum "Log Goods rank in firm (HS 6)"
  label var lngoods "Log number of goods (HS 6)"
  label var mean_value "Mean Exports (US$ thsd fob)"
  reg lnvalue lngoods lncurrnum
    est2vec expprodextd, addto(expprodextd) name(meandata:ols) replace
    uicorrftest
    est2vec expprodextd, raddto(expprodextd) name(meandata:ols) replace
  xtreg lnvalue lngoods lncurrnum, i(wtfkey) fe
    est2vec expprodextd, addto(expprodextd) name(meandata:fe_goods) replace
    uicorrftest
    est2vec expprodextd, raddto(expprodextd) name(meandata:fe_goods) replace
restore, preserve
  drop if value<100
  replace value = value/1000
  collapse (mean) value (sd) sd_value=value (count) count_value=value, by(wtfkey goods currnum) fast
  gen lnvalue = log(value)
  gen lncurrnum = log(currnum)
  gen lngoods=ln(goods)
  egen mean_value = mean(value), by(goods currnum)
  label var value "Exports (US$ thsd fob)"
  label var sd_value "Std. dev. Exports (US$ thsd fob)"
  label var count "# of Firms with identical Scope"
  label var lnvalue "Log Exports (US$ thsd fob)"
  label var lncurrnum "Log Goods rank in firm (HS 6)"
  label var lngoods "Log number of goods (HS 6)"
  label var mean_value "Mean Exports (US$ thsd fob)"
  reg lnvalue lngoods lncurrnum
    est2vec expprodextd, addto(expprodextd) name(meandata:ols_ge100) replace
    uicorrftest
    est2vec expprodextd, raddto(expprodextd) name(meandata:ols_ge100) replace
  xtreg lnvalue lngoods lncurrnum, i(wtfkey) fe
    est2vec expprodextd, addto(expprodextd) name(meandata:fe_goods_ge100) replace
    uicorrftest
    est2vec expprodextd, raddto(expprodextd) name(meandata:fe_goods_ge100) replace
restore
  
est2tex expprodextd, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

*}  // close `sec' loop
  
log close
set more off
