*! version 1.0.5   5aug2009  by Marc Muendler  muendler@ucsd.edu
*! version 1.1.1  14aug2009  by Marc Muendler  muendler@ucsd.edu
*! version 1.1.2  27jul2010  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 5g
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/chile-manffrms"
capture mkdir "braxpmkt/estmat/chile-manffrms"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-extd-nl-chile.log", replace

capture program drop uicorrftest
program define uicorrftest, rclass
  qui test lngoods = 0
  return scalar total_F = r(F)
  return scalar total_p = r(p)
  return scalar total = return(delta) + return(alphabar)
  qui test - lncurrnum - 1 = 0
  return scalar alphabar_F = r(F)
  return scalar alphabar_p = r(p)
  return scalar alphabar = - _b[lncurrnum] - 1
  qui test lngoods + lncurrnum = 0
  return scalar delta_F = r(F)
  return scalar delta_p = r(p)
  return scalar delta = _b[lngoods] + _b[lncurrnum]
  if "`e(cmd)'"=="xtreg" qui predict ui, u
  else qui gen ui = .
  capture corr ui lncurrnum
  drop ui
  return scalar rho = r(rho)
end

capture program drop nlprod
program nlprod
  syntax varlist(min=3 max=3) [aw fw iw] if, at(name)
  local lnvalue: word 1 of `varlist'
  local lngoods: word 2 of `varlist'
  local lncurrnum: word 3 of `varlist'
  // retrieve parameters from at
  tempname intcpt delta alphabar beta
  scalar `intcpt' = `at'[1,1]
  scalar `delta' = `at'[1,2]
  scalar `alphabar' = `at'[1,3]
  scalar `beta' = `at'[1,4]
  // temporary variables
  * tempvar iterm gterm rterm
  * generate double `iterm' = (`delta')*`lngoods' `if'
  * generate double `gterm' = (1+`alphabar')*log( exp(`lngoods')+`beta' ) `if'
  * generate double `rterm' = -(1+`alphabar')*log( exp(`lncurrnum')+`beta' ) `if'
  // fill in dependent variable
  * replace `lnvalue' = `intcpt'+`iterm'+`gterm'+`rterm' `if'
  replace `lnvalue' = `intcpt' + (`delta')*`lngoods' + (1+`alphabar')*log(exp(`lngoods')+`beta') - (1+`alphabar')*log(exp(`lncurrnum')+`beta') `if'
end

capture program drop nlfewtf
program nlfewtf
  syntax varlist(min=3 max=3) [aw fw iw] if, at(name)
  local lnvalue: word 1 of `varlist'
  local lngoods: word 2 of `varlist'
  local lncurrnum: word 3 of `varlist'
  // retrieve parameters from at
  tempname intcpt delta alphabar beta
  scalar `intcpt' = `at'[1,1]
  scalar `delta' = `at'[1,2]
  scalar `alphabar' = `at'[1,3]
  scalar `beta' = `at'[1,4]
  local j 4
  // fe wtf variable
  tempvar wtfterm
  local wtfrhs 0
  foreach coeff of global bwtf {
    tempname `coeff'
    local j = `j' + 1
    scalar ``coeff'' = `at'[1,`j']
    local var = subinstr("`coeff'","bwtf","indwtf",.)
    local wtfrhs "`wtfrhs' + ``coeff''*`var'"
    }
  generate double `wtfterm' = `wtfrhs' `if'
  // temporary variables
  * tempvar iterm gterm rterm
  * generate double `iterm' = (`delta')*`lngoods' `if'
  * generate double `gterm' = (1+`alphabar')*log( exp(`lngoods')+`beta' ) `if'
  * generate double `rterm' = -(1+`alphabar')*log( exp(`lncurrnum')+`beta' ) `if'
  // fill in dependent variable
  * replace `lnvalue' = `intcpt'+`iterm'+`gterm'+`rterm' `if'
  replace `lnvalue' = `intcpt' + (`delta')*`lngoods' + (1+`alphabar')*log(exp(`lngoods')+`beta') - (1+`alphabar')*log(exp(`lncurrnum')+`beta') + `wtfterm' `if'
end

capture program drop nlfewtfhssec
program nlfewtfhssec
  syntax varlist(min=3 max=3) [aw fw iw] if, at(name)
  local lnvalue: word 1 of `varlist'
  local lngoods: word 2 of `varlist'
  local lncurrnum: word 3 of `varlist'
  // retrieve parameters from at
  tempname intcpt delta alphabar beta
  scalar `intcpt' = `at'[1,1]
  scalar `delta' = `at'[1,2]
  scalar `alphabar' = `at'[1,3]
  scalar `beta' = `at'[1,4]
  local j 4
  // fe wtf variable
  tempvar wtfterm
  local wtfrhs 0
  foreach coeff of global bwtf {
    tempname `coeff'
    local j = `j' + 1
    scalar ``coeff'' = `at'[1,`j']
    local var = subinstr("`coeff'","bwtf","indwtf",.)
    local wtfrhs "`wtfrhs' + ``coeff''*`var'"
    }
  generate double `wtfterm' = `wtfrhs' `if'
  // fe hssec variable
  tempvar hssecterm1 hssecterm2
  local hssecrhs1 0
  local hssecrhs2 0
  foreach coeff of global bhssec {
    tempname `coeff'
    local j = `j' + 1
    scalar ``coeff'' = `at'[1,`j']
    local var = subinstr("`coeff'","bhssec","indhssec",.)
    local num = subinstr("`coeff'","bhssec","",.)
    if `num'<=200  local hssecrhs1 "`hssecrhs1' + ``coeff''*`var'"
    else           local hssecrhs2 "`hssecrhs2' + ``coeff''*`var'"
    }
  generate double `hssecterm1' = `hssecrhs1' `if'
  generate double `hssecterm2' = `hssecrhs2' `if'
  // temporary variables
  * tempvar iterm gterm rterm
  * generate double `iterm' = (`delta')*`lngoods' `if'
  * generate double `gterm' = (1+`alphabar')*log( exp(`lngoods')+`beta' ) `if'
  * generate double `rterm' = -(1+`alphabar')*log( exp(`lncurrnum')+`beta' ) `if'
  // fill in dependent variable
  * replace `lnvalue' = `intcpt'+`iterm'+`gterm'+`rterm' `if'
  replace `lnvalue' = `intcpt' + (`delta')*`lngoods' + (1+`alphabar')*log(exp(`lngoods')+`beta') - (1+`alphabar')*log(exp(`lncurrnum')+`beta') + `hssecterm1' + `hssecterm2' + `wtfterm' `if'
end


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

*foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {
local sec "chile-manffrms"

use "braxpmkt/secex/expprod-`sec'", clear

* create pseudo-sector information (largest HS2-digit is firm's sector)
gen str6 hs2dgt = string(hs6dgt)
replace hs2dgt = "0" + hs2dgt if length(hs2dgt)<6
replace hs2dgt = "0" + hs2dgt if length(hs2dgt)<6
replace hs2dgt = "0" + hs2dgt if length(hs2dgt)<6
replace hs2dgt = substr(hs2dgt,1,2)
sort firmid hs6dgt wtfkey
egen _sumhssec = sum(value), by(firmid hs2dgt)
egen _maxhssec = max(_sumhssec), by(firmid)
egen _modhssec = mode(hs2dgt), by(firmid) minmode  // assign minimum hs2dgt code if tie
sort firmid hs6dgt wtfkey
gen str2 _hssec = hs2dgt if _sumhssec==_maxhssec
replace _hssec = _modhssec if _hssec==""
qui count if _hssec==""
if `r(N)'>0  STOP  // incomplete sector definition
gen hssec = int(real(_hssec))
label var hssec "Main HS 2-digit sector"
drop hs2dgt _*
compress hssec

gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"
qui tab wtfkey, gen(indwtf) missing
drop indwtf1
qui tab hssec, gen(indhssec) missing
drop indhssec1

drop if lnvalue==. | lngoods==. | lncurrnum==.

* fe lists (bwtf bhssec)
foreach fetype in "wtf" "hssec" {
  foreach var of varlist ind`fetype'* {
    local newname = subinstr("`var'","ind`fetype'","b`fetype'",.)
    rename `var' `newname'
    }
  unab b`fetype' : b`fetype'*
  global b`fetype' "`b`fetype''"
  foreach var of varlist b`fetype'* {
    local oldname = subinstr("`var'","b`fetype'","ind`fetype'",.)
    rename `var' `oldname'
    }
  }

* initial values
xtreg lnvalue lngoods lncurrnum indwtf*, i(hssec) fe
uicorrftest

* nl
matrix ivals = (0, `r(delta)', `r(alphabar)', 0)
matrix colnames ivals = intcpt delta alphabar beta
matrix rownames ivals = ival
nl prod @ lnvalue lngoods lncurrnum, parameters(intcpt delta alphabar beta) initial(ivals)
est2vec expprodextdnl, vars(intcpt delta alphabar beta `bwtf') e(N r2 r2_a df_m df_r F converge) name(rawdata:nl) replace

* nl fewtf
local wtfcnt : list sizeof bwtf
matrix ivals = ivals , J(1,`wtfcnt',0)
matrix colnames ivals = intcpt delta alphabar beta `bwtf'
nl fewtf @ lnvalue lngoods lncurrnum, parameters(intcpt delta alphabar beta `bwtf') initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nlfewtf) replace

* nl fewtfhssec
local hsseccnt : list sizeof bhssec
matrix ivals = ivals , J(1,`hsseccnt',0)
matrix colnames ivals = intcpt delta alphabar beta `bwtf' `bhssec'
nl fewtfhssec @ lnvalue lngoods lncurrnum, parameters(intcpt delta alphabar beta `bwtf' `bhssec') initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nlfewtfhssec) replace

* initial values if value>=100 
reg lnvalue lngoods lncurrnum indwtf* if value>=100
uicorrftest

* nl if value>=100 
matrix ivals = (0, `r(delta)', `r(alphabar)', 0)
matrix colnames ivals = intcpt delta alphabar beta
matrix rownames ivals = ival
nl prod @ lnvalue lngoods lncurrnum if value>=100, parameters(intcpt delta alphabar beta) initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nl_ge100) replace

* nl fewtf if value>=100 
local wtfcnt : list sizeof bwtf
matrix ivals = ivals , J(1,`wtfcnt',0)
matrix colnames ivals = intcpt delta alphabar beta `bwtf'
nl fewtf @ lnvalue lngoods lncurrnum if value>=100, parameters(intcpt delta alphabar beta `bwtf') initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nlfewtf_ge100) replace

* nl fewtfhssec if value>=100 
local hsseccnt : list sizeof bhssec
matrix ivals = ivals , J(1,`hsseccnt',0)
matrix colnames ivals = intcpt delta alphabar beta `bwtf' `bhssec'
nl fewtfhssec @ lnvalue lngoods lncurrnum if value>=100, parameters(intcpt delta alphabar beta `bwtf' `bhssec') initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nlfewtfhssec_ge100) replace

foreach type in b se e {
  matsave expprodextdnl_`type', p(braxpmkt/estmat/`sec') replace dropall type(double)
  if "`type'"=="b" | "`type'"=="se"  matorder expprodextdnl_`type', m(expprodextdnl_`type') over ifr(delta alphabar beta)
  }

est2tex expprodextdnl, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

  
log close
set more off
