*! version 1.0.4  24jul2009  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.5  31jul2009  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.6  27jul2010  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 5g
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/srvc-firms"
capture mkdir "braxpmkt/eps/comrc-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/srvc-firms"
capture mkdir "braxpmkt/estmat/comrc-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-extd-nl.log", replace

capture program drop uicorrftest
program define uicorrftest, rclass
  qui test lngoods = 0
  return scalar total_F = r(F)
  return scalar total_p = r(p)
  return scalar total = return(delta) + return(alphabar)
  qui test - lncurrnum - 1 = 0
  return scalar alphabar_F = r(F)
  return scalar alphabar_p = r(p)
  return scalar alphabar = - _b[lncurrnum] - 1
  qui test lngoods + lncurrnum = 0
  return scalar delta_F = r(F)
  return scalar delta_p = r(p)
  return scalar delta = _b[lngoods] + _b[lncurrnum]
  if "`e(cmd)'"=="xtreg" qui predict ui, u
  else qui gen ui = .
  capture corr ui lncurrnum
  drop ui
  return scalar rho = r(rho)
end

capture program drop nlprod
program nlprod
  syntax varlist(min=3 max=3) [aw fw iw] if, at(name)
  local lnvalue: word 1 of `varlist'
  local lngoods: word 2 of `varlist'
  local lncurrnum: word 3 of `varlist'
  // retrieve parameters from at
  tempname intcpt delta alphabar beta
  scalar `intcpt' = `at'[1,1]
  scalar `delta' = `at'[1,2]
  scalar `alphabar' = `at'[1,3]
  scalar `beta' = `at'[1,4]
  // temporary variables
  * tempvar iterm gterm rterm
  * generate double `iterm' = (`delta')*`lngoods' `if'
  * generate double `gterm' = (1+`alphabar')*log( exp(`lngoods')+`beta' ) `if'
  * generate double `rterm' = -(1+`alphabar')*log( exp(`lncurrnum')+`beta' ) `if'
  // fill in dependent variable
  * replace `lnvalue' = `intcpt'+`iterm'+`gterm'+`rterm' `if'
  replace `lnvalue' = `intcpt' + (`delta')*`lngoods' + (1+`alphabar')*log(exp(`lngoods')+`beta') - (1+`alphabar')*log(exp(`lncurrnum')+`beta') `if'
end

capture program drop nlfewtf
program nlfewtf
  syntax varlist(min=3 max=3) [aw fw iw] if, at(name)
  local lnvalue: word 1 of `varlist'
  local lngoods: word 2 of `varlist'
  local lncurrnum: word 3 of `varlist'
  // retrieve parameters from at
  tempname intcpt delta alphabar beta
  scalar `intcpt' = `at'[1,1]
  scalar `delta' = `at'[1,2]
  scalar `alphabar' = `at'[1,3]
  scalar `beta' = `at'[1,4]
  local j 4
  // fe wtf variable
  tempvar wtfterm
  local wtfrhs 0
  foreach coeff of global bwtf {
    tempname `coeff'
    local j = `j' + 1
    scalar ``coeff'' = `at'[1,`j']
    local var = subinstr("`coeff'","bwtf","indwtf",.)
    local wtfrhs "`wtfrhs' + ``coeff''*`var'"
    }
  generate double `wtfterm' = `wtfrhs' `if'
  // temporary variables
  * tempvar iterm gterm rterm
  * generate double `iterm' = (`delta')*`lngoods' `if'
  * generate double `gterm' = (1+`alphabar')*log( exp(`lngoods')+`beta' ) `if'
  * generate double `rterm' = -(1+`alphabar')*log( exp(`lncurrnum')+`beta' ) `if'
  // fill in dependent variable
  * replace `lnvalue' = `intcpt'+`iterm'+`gterm'+`rterm' `if'
  replace `lnvalue' = `intcpt' + (`delta')*`lngoods' + (1+`alphabar')*log(exp(`lngoods')+`beta') - (1+`alphabar')*log(exp(`lncurrnum')+`beta') + `wtfterm' `if'
end

capture program drop nlfewtfcnae
program nlfewtfcnae
  syntax varlist(min=3 max=3) [aw fw iw] if, at(name)
  local lnvalue: word 1 of `varlist'
  local lngoods: word 2 of `varlist'
  local lncurrnum: word 3 of `varlist'
  // retrieve parameters from at
  tempname intcpt delta alphabar beta
  scalar `intcpt' = `at'[1,1]
  scalar `delta' = `at'[1,2]
  scalar `alphabar' = `at'[1,3]
  scalar `beta' = `at'[1,4]
  local j 4
  // fe wtf variable
  tempvar wtfterm
  local wtfrhs 0
  foreach coeff of global bwtf {
    tempname `coeff'
    local j = `j' + 1
    scalar ``coeff'' = `at'[1,`j']
    local var = subinstr("`coeff'","bwtf","indwtf",.)
    local wtfrhs "`wtfrhs' + ``coeff''*`var'"
    }
  generate double `wtfterm' = `wtfrhs' `if'
  // fe cnae variable
  tempvar cnaeterm1 cnaeterm2
  local cnaerhs1 0
  local cnaerhs2 0
  foreach coeff of global bcnae {
    tempname `coeff'
    local j = `j' + 1
    scalar ``coeff'' = `at'[1,`j']
    local var = subinstr("`coeff'","bcnae","indcnae",.)
    local num = subinstr("`coeff'","bcnae","",.)
    if `num'<=200  local cnaerhs1 "`cnaerhs1' + ``coeff''*`var'"
    else           local cnaerhs2 "`cnaerhs2' + ``coeff''*`var'"
    }
  generate double `cnaeterm1' = `cnaerhs1' `if'
  generate double `cnaeterm2' = `cnaerhs2' `if'
  // temporary variables
  * tempvar iterm gterm rterm
  * generate double `iterm' = (`delta')*`lngoods' `if'
  * generate double `gterm' = (1+`alphabar')*log( exp(`lngoods')+`beta' ) `if'
  * generate double `rterm' = -(1+`alphabar')*log( exp(`lncurrnum')+`beta' ) `if'
  // fill in dependent variable
  * replace `lnvalue' = `intcpt'+`iterm'+`gterm'+`rterm' `if'
  replace `lnvalue' = `intcpt' + (`delta')*`lngoods' + (1+`alphabar')*log(exp(`lngoods')+`beta') - (1+`alphabar')*log(exp(`lncurrnum')+`beta') + `cnaeterm1' + `cnaeterm2' + `wtfterm' `if'
end


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {

use "braxpmkt/secex/expprod-`sec'", clear

gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"
qui tab wtfkey, gen(indwtf) missing
drop indwtf1
qui tab cnae, gen(indcnae) missing
drop indcnae1

drop if lnvalue==. | lngoods==. | lncurrnum==.

* fe lists (bwtf bcnae)
foreach fetype in "wtf" "cnae" {
  foreach var of varlist ind`fetype'* {
    local newname = subinstr("`var'","ind`fetype'","b`fetype'",.)
    rename `var' `newname'
    }
  unab b`fetype' : b`fetype'*
  global b`fetype' "`b`fetype''"
  foreach var of varlist b`fetype'* {
    local oldname = subinstr("`var'","b`fetype'","ind`fetype'",.)
    rename `var' `oldname'
    }
  }

* initial values
xtreg lnvalue lngoods lncurrnum indwtf*, i(cnae) fe
uicorrftest

* nl
matrix ivals = (0, `r(delta)', `r(alphabar)', 0)
matrix colnames ivals = intcpt delta alphabar beta
matrix rownames ivals = ival
nl prod @ lnvalue lngoods lncurrnum, parameters(intcpt delta alphabar beta) initial(ivals)
est2vec expprodextdnl, vars(intcpt delta alphabar beta `bwtf' `bcnae') e(N r2 r2_a df_m df_r F converge) name(rawdata:nl) replace

* nl fewtf
local wtfcnt : list sizeof bwtf
matrix ivals = ivals , J(1,`wtfcnt',0)
matrix colnames ivals = intcpt delta alphabar beta `bwtf'
nl fewtf @ lnvalue lngoods lncurrnum, parameters(intcpt delta alphabar beta `bwtf') initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nlfewtf) replace

* nl fewtfcnae
local cnaecnt : list sizeof bcnae
matrix ivals = ivals , J(1,`cnaecnt',0)
matrix colnames ivals = intcpt delta alphabar beta `bwtf' `bcnae'
nl fewtfcnae @ lnvalue lngoods lncurrnum, parameters(intcpt delta alphabar beta `bwtf' `bcnae') initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nlfewtfcnae) replace

* initial values if value>=100 
xtreg lnvalue lngoods lncurrnum indwtf* if value>=100, i(cnae) fe
uicorrftest

* nl if value>=100 
matrix ivals = (0, `r(delta)', `r(alphabar)', 0)
matrix colnames ivals = intcpt delta alphabar beta
matrix rownames ivals = ival
nl prod @ lnvalue lngoods lncurrnum if value>=100, parameters(intcpt delta alphabar beta) initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nl_ge100) replace

* nl fewtf if value>=100 
local wtfcnt : list sizeof bwtf
matrix ivals = ivals , J(1,`wtfcnt',0)
matrix colnames ivals = intcpt delta alphabar beta `bwtf'
nl fewtf @ lnvalue lngoods lncurrnum if value>=100, parameters(intcpt delta alphabar beta `bwtf') initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nlfewtf_ge100) replace

* nl fewtfcnae if value>=100 
local cnaecnt : list sizeof bcnae
matrix ivals = ivals , J(1,`cnaecnt',0)
matrix colnames ivals = intcpt delta alphabar beta `bwtf' `bcnae'
nl fewtfcnae @ lnvalue lngoods lncurrnum if value>=100, parameters(intcpt delta alphabar beta `bwtf' `bcnae') initial(ivals)
est2vec expprodextdnl, addto(expprodextdnl) name(rawdata:nlfewtfcnae_ge100) replace

foreach type in b se e {
  matsave expprodextdnl_`type', p(braxpmkt/estmat/`sec') replace dropall type(double)
  if "`type'"=="b" | "`type'"=="se"  matorder expprodextdnl_`type', m(expprodextdnl_`type') over ifr(delta alphabar beta)
  }

est2tex expprodextdnl, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop
  
log close
set more off
