*! version 1.0.3  26feb2009  by Marc Muendler  muendler@ucsd.edu

version 8.2
set more off
set virtual on
clear
set mem 650m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/allsec"
capture mkdir "braxpmkt/eps/manf-goods"
capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/srvc-firms"
capture mkdir "braxpmkt/eps/comrc-firms"
capture mkdir "braxpmkt/eps/manf-ekk"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/srvc-firms"
capture mkdir "braxpmkt/estmat/comrc-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-extd.log", replace

capture program drop uicorrftest
program define uicorrftest, rclass
  qui test lngoods = 0
  return scalar total_F = r(F)
  return scalar total_p = r(p)
  return scalar total = return(delta) + return(alphabar)
  qui test - lncurrnum - 1 = 0
  return scalar alphabar_F = r(F)
  return scalar alphabar_p = r(p)
  return scalar alphabar = - _b[lncurrnum] - 1
  qui test lngoods + lncurrnum = 0
  return scalar delta_F = r(F)
  return scalar delta_p = r(p)
  return scalar delta = _b[lngoods] + _b[lncurrnum]
  if "`e(cmd)'"=="xtreg" qui predict ui, u
  else qui gen ui = .
  capture corr ui lncurrnum
  drop ui
  return scalar rho = r(rho)
end


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

foreach sec in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" {

use "braxpmkt/secex/expprod-`sec'", clear

qui tab goods, gen(indgoods)
drop indgoods1
qui tab wtfkey, gen(indwtf)
drop indwtf1
gen lngoods=ln(goods)
label var lngoods "Log number of goods (HS 6)"

unab vars : lngoods lncurrnum indwtf* indgoods*
reg lnvalue lngoods lncurrnum
  est2vec expprodextd, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(rawdata:ols_long) replace
  uicorrftest
  est2vec expprodextd, r(rho delta delta_p delta_F alphabar alphabar_p alphabar_F total total_p total_F) name(rawdata:ols) replace
reg lnvalue lngoods lncurrnum indwtf*
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtf_long) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtf_long) replace
xtreg lnvalue lngoods lncurrnum indwtf*, i(cnae) fe
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtfcnae_long) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtfcnae_long) replace
xtreg lnvalue lngoods lncurrnum indwtf*, i(firm) fe
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtffirm_goods) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtffirm_goods) replace
areg lnvalue lngoods lncurrnum indwtf* [pw=value], absorb(firm)  // weighted fe regression
  est2vec expprodextd, addto(expprodextd) name(wghtdata:fewtffirm_goods) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(wghtdata:fewtffirm_goods) replace

reg lnvalue lngoods lncurrnum if value>=100
  est2vec expprodextd, addto(expprodextd) name(rawdata:ols_long_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:ols_long_ge100) replace
reg lnvalue lngoods lncurrnum indwtf* if value>=100
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtf_long_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtf_long_ge100) replace
xtreg lnvalue lngoods lncurrnum indwtf* if value>=100, i(cnae) fe
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtfcnae_long_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtfcnae_long_ge100) replace
xtreg lnvalue lngoods lncurrnum indwtf* if value>=100, i(firm) fe
  est2vec expprodextd, addto(expprodextd) name(rawdata:fewtffirm_goods_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(rawdata:fewtffirm_goods_ge100) replace
areg lnvalue lngoods lncurrnum indwtf* if value>=100 [pw=value], absorb(firm)  // weighted fe regression
  est2vec expprodextd, addto(expprodextd) name(wghtdata:fewtffirm_goods_ge100) replace
  uicorrftest
  est2vec expprodextd, raddto(expprodextd) name(wghtdata:fewtffirm_goods_ge100) replace

preserve
  replace value = value/1000
  collapse (mean) value (sd) sd_value=value (count) count_value=value, by(wtfkey goods currnum) fast
  gen lnvalue = log(value)
  gen lncurrnum = log(currnum)
  gen lngoods=ln(goods)
  egen mean_value = mean(value), by(goods currnum)
  label var value "Exports (US$ thsd fob)"
  label var sd_value "Std. dev. Exports (US$ thsd fob)"
  label var count "# of Firms with identical Scope"
  label var lnvalue "Log Exports (US$ thsd fob)"
  label var lncurrnum "Log Goods rank in firm (HS 6)"
  label var lngoods "Log number of goods (HS 6)"
  label var mean_value "Mean Exports (US$ thsd fob)"
  reg lnvalue lngoods lncurrnum
    est2vec expprodextd, addto(expprodextd) name(meandata:ols) replace
    uicorrftest
    est2vec expprodextd, raddto(expprodextd) name(meandata:ols) replace
  xtreg lnvalue lngoods lncurrnum, i(wtfkey) fe
    est2vec expprodextd, addto(expprodextd) name(meandata:fe_goods) replace
    uicorrftest
    est2vec expprodextd, raddto(expprodextd) name(meandata:fe_goods) replace
  predict valuehat if e(sample), xbu
  replace valuehat = exp(valuehat)
  local i 0
  foreach goods in 32 16 8 4 {
    local i = `i' + 1
    qui summ count_value if goods==`goods' & wtfkey==218400
    local lbl`i' = `r(mean)'
    qui reg lnvalue lncurrnum if goods==`goods' & wtfkey==218400
    if `i'==1  est2vec expprodfit, vars(lncurrnum _cons) e(N r2 df_a df_r F_f) name(rawdata:ols_usa_`goods') replace
    else       est2vec expprodfit, addto(expprodfit) name(rawdata:ols_usa_`goods')
    capture drop valuehat`goods'
    qui predict valuehat`goods' if e(sample), xb
    qui replace valuehat`goods' = exp(valuehat`goods')
    }
  graph twoway scatter value currnum if goods==32 & wtfkey==218400, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==16 & wtfkey==218400 || scatter value currnum if goods==8 & wtfkey==218400 || scatter value currnum if goods==4 & wtfkey==218400, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')")) || line valuehat currnum if goods==32 & wtfkey==218400 || line valuehat currnum if goods==16 & wtfkey==218400 || line valuehat currnum if goods==8 & wtfkey==218400 || line valuehat currnum if goods==4 & wtfkey==218400  // usa
  graph export "braxpmkt/eps/`sec'/expprodextd_usa-4-32.eps", replace
  graph twoway scatter value currnum if goods==32 & wtfkey==218400, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==16 & wtfkey==218400 || scatter value currnum if goods==8 & wtfkey==218400 || scatter value currnum if goods==4 & wtfkey==218400, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')")) || line valuehat32 currnum if goods==32 & wtfkey==218400 || line valuehat16 currnum if goods==16 & wtfkey==218400 || line valuehat8 currnum if goods==8 & wtfkey==218400 || line valuehat4 currnum if goods==4 & wtfkey==218400  // usa
  graph export "braxpmkt/eps/`sec'/expprodfit_usa-4-32.eps", replace
  local i 0
  foreach goods in 32 16 8 4 {
    local i = `i' + 1
    qui summ count_value if goods==`goods' & wtfkey==330320
    local lbl`i' = `r(mean)'
    qui reg lnvalue lncurrnum if goods==`goods' & wtfkey==330320
    est2vec expprodfit, addto(expprodfit) name(rawdata:ols_argentina_`goods')
    capture drop valuehat`goods'
    qui predict valuehat`goods' if e(sample), xb
    qui replace valuehat`goods' = exp(valuehat`goods')
    }
  graph twoway scatter value currnum if goods==32 & wtfkey==330320, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==16 & wtfkey==330320 || scatter value currnum if goods==8 & wtfkey==330320 || scatter value currnum if goods==4 & wtfkey==330320, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')")) || line valuehat currnum if goods==32 & wtfkey==330320 || line valuehat currnum if goods==16 & wtfkey==330320 || line valuehat currnum if goods==8 & wtfkey==330320 || line valuehat currnum if goods==4 & wtfkey==330320  // argentina
  graph export "braxpmkt/eps/`sec'/expprodextd_argentina-4-32.eps", replace
  graph twoway scatter value currnum if goods==32 & wtfkey==330320, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==16 & wtfkey==330320 || scatter value currnum if goods==8 & wtfkey==330320 || scatter value currnum if goods==4 & wtfkey==330320, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')")) || line valuehat32 currnum if goods==32 & wtfkey==330320 || line valuehat16 currnum if goods==16 & wtfkey==330320 || line valuehat8 currnum if goods==8 & wtfkey==330320 || line valuehat4 currnum if goods==4 & wtfkey==330320  // usa
  graph export "braxpmkt/eps/`sec'/expprodfit_argentina-4-32.eps", replace
  local i 0
  foreach goods in 16 8 4 2 {
    local i = `i' + 1
    qui summ count_value if goods==`goods' & wtfkey==218400
    local lbl`i' = `r(mean)'
    qui reg lnvalue lncurrnum if goods==`goods' & wtfkey==218400
    if `goods'==2  est2vec expprodfit, addto(expprodfit) name(rawdata:ols_usa_`goods')
    capture drop valuehat`goods'
    qui predict valuehat`goods' if e(sample), xb
    qui replace valuehat`goods' = exp(valuehat`goods')
    }
  graph twoway scatter value currnum if goods==16 & wtfkey==218400, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==8 & wtfkey==218400 || scatter value currnum if goods==4 & wtfkey==218400 || scatter value currnum if goods==2 & wtfkey==218400, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')")) || line valuehat currnum if goods==16 & wtfkey==218400 || line valuehat currnum if goods==8 & wtfkey==218400 || line valuehat currnum if goods==4 & wtfkey==218400 || line valuehat currnum if goods==2 & wtfkey==218400  // usa
  graph export "braxpmkt/eps/`sec'/expprodextd_usa-2-16.eps", replace
  graph twoway scatter value currnum if goods==16 & wtfkey==218400, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==8 & wtfkey==218400 || scatter value currnum if goods==4 & wtfkey==218400 || scatter value currnum if goods==2 & wtfkey==218400, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')")) || line valuehat16 currnum if goods==16 & wtfkey==218400 || line valuehat8 currnum if goods==8 & wtfkey==218400 || line valuehat4 currnum if goods==4 & wtfkey==218400 || line valuehat2 currnum if goods==2 & wtfkey==218400  // usa
  graph export "braxpmkt/eps/`sec'/expprodfit_usa-2-16.eps", replace
  local i 0
  foreach goods in 16 8 4 2 {
    local i = `i' + 1
    qui summ count_value if goods==`goods' & wtfkey==330320
    local lbl`i' = `r(mean)'
    qui reg lnvalue lncurrnum if goods==`goods' & wtfkey==330320
    if `goods'==2  est2vec expprodfit, addto(expprodfit) name(rawdata:ols_argentina_`goods')
    capture drop valuehat`goods'
    qui predict valuehat`goods' if e(sample), xb
    qui replace valuehat`goods' = exp(valuehat`goods')
    }
  graph twoway scatter value currnum if goods==16 & wtfkey==330320, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==8 & wtfkey==330320 || scatter value currnum if goods==4 & wtfkey==330320 || scatter value currnum if goods==2 & wtfkey==330320, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')")) || line valuehat currnum if goods==16 & wtfkey==330320 || line valuehat currnum if goods==8 & wtfkey==330320 || line valuehat currnum if goods==4 & wtfkey==330320 || line valuehat currnum if goods==2 & wtfkey==330320  // argentina
  graph export "braxpmkt/eps/`sec'/expprodextd_argentina-2-16.eps", replace
  graph twoway scatter value currnum if goods==16 & wtfkey==330320, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==8 & wtfkey==330320 || scatter value currnum if goods==4 & wtfkey==330320 || scatter value currnum if goods==2 & wtfkey==330320, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')")) || line valuehat16 currnum if goods==16 & wtfkey==330320 || line valuehat8 currnum if goods==8 & wtfkey==330320 || line valuehat4 currnum if goods==4 & wtfkey==330320 || line valuehat2 currnum if goods==2 & wtfkey==330320  // argentina
  graph export "braxpmkt/eps/`sec'/expprodfit_argentina-2-16.eps", replace
restore, preserve
  drop if value<100
  replace value = value/1000
  collapse (mean) value (sd) sd_value=value (count) count_value=value, by(wtfkey goods currnum) fast
  gen lnvalue = log(value)
  gen lncurrnum = log(currnum)
  gen lngoods=ln(goods)
  egen mean_value = mean(value), by(goods currnum)
  label var value "Exports (US$ thsd fob)"
  label var sd_value "Std. dev. Exports (US$ thsd fob)"
  label var count "# of Firms with identical Scope"
  label var lnvalue "Log Exports (US$ thsd fob)"
  label var lncurrnum "Log Goods rank in firm (HS 6)"
  label var lngoods "Log number of goods (HS 6)"
  label var mean_value "Mean Exports (US$ thsd fob)"
  reg lnvalue lngoods lncurrnum
    est2vec expprodextd, addto(expprodextd) name(meandata:ols_ge100) replace
    uicorrftest
    est2vec expprodextd, raddto(expprodextd) name(meandata:ols_ge100) replace
  xtreg lnvalue lngoods lncurrnum, i(wtfkey) fe
    est2vec expprodextd, addto(expprodextd) name(meandata:fe_goods_ge100) replace
    uicorrftest
    est2vec expprodextd, raddto(expprodextd) name(meandata:fe_goods_ge100) replace
  predict valuehat if e(sample), xbu
  replace valuehat = exp(valuehat)
  local i 0
  foreach goods in 32 16 8 4 {
    local i = `i' + 1
    qui summ count_value if goods==`goods' & wtfkey==218400
    local lbl`i' = `r(mean)'
    qui reg lnvalue lncurrnum if goods==`goods' & wtfkey==218400
    if `i'==1  est2vec expprodfit, vars(lncurrnum _cons) e(N r2 df_a df_r F_f) name(rawdata_ge100:ols_usa_`goods') replace
    else       est2vec expprodfit, addto(expprodfit) name(rawdata_ge100:ols_usa_`goods')
    capture drop valuehat`goods'
    qui predict valuehat`goods' if e(sample), xb
    qui replace valuehat`goods' = exp(valuehat`goods')
    }
  graph twoway scatter value currnum if goods==32 & wtfkey==218400, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==16 & wtfkey==218400 || scatter value currnum if goods==8 & wtfkey==218400 || scatter value currnum if goods==4 & wtfkey==218400, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')")) || line valuehat currnum if goods==32 & wtfkey==218400 || line valuehat currnum if goods==16 & wtfkey==218400 || line valuehat currnum if goods==8 & wtfkey==218400 || line valuehat currnum if goods==4 & wtfkey==218400  // usa
  graph export "braxpmkt/eps/`sec'/expprodextd_usa-4-32_ge100.eps", replace
  graph twoway scatter value currnum if goods==32 & wtfkey==218400, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==16 & wtfkey==218400 || scatter value currnum if goods==8 & wtfkey==218400 || scatter value currnum if goods==4 & wtfkey==218400, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')")) || line valuehat32 currnum if goods==32 & wtfkey==218400 || line valuehat16 currnum if goods==16 & wtfkey==218400 || line valuehat8 currnum if goods==8 & wtfkey==218400 || line valuehat4 currnum if goods==4 & wtfkey==218400  // usa
  graph export "braxpmkt/eps/`sec'/expprodfit_usa-4-32_ge100.eps", replace
  local i 0
  foreach goods in 32 16 8 4 {
    local i = `i' + 1
    qui summ count_value if goods==`goods' & wtfkey==330320
    local lbl`i' = `r(mean)'
    qui reg lnvalue lncurrnum if goods==`goods' & wtfkey==330320
    est2vec expprodfit, addto(expprodfit) name(rawdata_ge100:ols_argentina_`goods')
    capture drop valuehat`goods'
    qui predict valuehat`goods' if e(sample), xb
    qui replace valuehat`goods' = exp(valuehat`goods')
    }
  graph twoway scatter value currnum if goods==32 & wtfkey==330320, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==16 & wtfkey==330320 || scatter value currnum if goods==8 & wtfkey==330320 || scatter value currnum if goods==4 & wtfkey==330320, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')")) || line valuehat currnum if goods==32 & wtfkey==330320 || line valuehat currnum if goods==16 & wtfkey==330320 || line valuehat currnum if goods==8 & wtfkey==330320 || line valuehat currnum if goods==4 & wtfkey==330320  // argentina
  graph export "braxpmkt/eps/`sec'/expprodextd_argentina-4-32_ge100.eps", replace
  graph twoway scatter value currnum if goods==32 & wtfkey==330320, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16 32, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==16 & wtfkey==330320 || scatter value currnum if goods==8 & wtfkey==330320 || scatter value currnum if goods==4 & wtfkey==330320, legend(order(4 3 2 1) label(4 "4-product Firms (`lbl4')") label(3 "8-product Firms (`lbl3')") label(2 "16-product Firms (`lbl2')") label(1 "32-product Firms (`lbl1')")) || line valuehat32 currnum if goods==32 & wtfkey==330320 || line valuehat16 currnum if goods==16 & wtfkey==330320 || line valuehat8 currnum if goods==8 & wtfkey==330320 || line valuehat4 currnum if goods==4 & wtfkey==330320  // usa
  graph export "braxpmkt/eps/`sec'/expprodfit_argentina-4-32_ge100.eps", replace
  local i 0
  foreach goods in 16 8 4 2 {
    local i = `i' + 1
    qui summ count_value if goods==`goods' & wtfkey==218400
    local lbl`i' = `r(mean)'
    qui reg lnvalue lncurrnum if goods==`goods' & wtfkey==218400
    if `goods'==2  est2vec expprodfit, addto(expprodfit) name(rawdata_ge100:ols_usa_`goods')
    capture drop valuehat`goods'
    qui predict valuehat`goods' if e(sample), xb
    qui replace valuehat`goods' = exp(valuehat`goods')
    }
  graph twoway scatter value currnum if goods==16 & wtfkey==218400, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==8 & wtfkey==218400 || scatter value currnum if goods==4 & wtfkey==218400 || scatter value currnum if goods==2 & wtfkey==218400, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')")) || line valuehat currnum if goods==16 & wtfkey==218400 || line valuehat currnum if goods==8 & wtfkey==218400 || line valuehat currnum if goods==4 & wtfkey==218400 || line valuehat currnum if goods==2 & wtfkey==218400  // usa
  graph export "braxpmkt/eps/`sec'/expprodextd_usa-2-16_ge100.eps", replace
  graph twoway scatter value currnum if goods==16 & wtfkey==218400, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==8 & wtfkey==218400 || scatter value currnum if goods==4 & wtfkey==218400 || scatter value currnum if goods==2 & wtfkey==218400, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')")) || line valuehat16 currnum if goods==16 & wtfkey==218400 || line valuehat8 currnum if goods==8 & wtfkey==218400 || line valuehat4 currnum if goods==4 & wtfkey==218400 || line valuehat2 currnum if goods==2 & wtfkey==218400  // usa
  graph export "braxpmkt/eps/`sec'/expprodfit_usa-2-16_ge100.eps", replace
  local i 0
  foreach goods in 16 8 4 2 {
    local i = `i' + 1
    qui summ count_value if goods==`goods' & wtfkey==330320
    local lbl`i' = `r(mean)'
    qui reg lnvalue lncurrnum if goods==`goods' & wtfkey==330320
    if `goods'==2  est2vec expprodfit, addto(expprodfit) name(rawdata_ge100:ols_argentina_`goods')
    capture drop valuehat`goods'
    qui predict valuehat`goods' if e(sample), xb
    qui replace valuehat`goods' = exp(valuehat`goods')
    }
  graph twoway scatter value currnum if goods==16 & wtfkey==330320, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==8 & wtfkey==330320 || scatter value currnum if goods==4 & wtfkey==330320 || scatter value currnum if goods==2 & wtfkey==330320, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')")) || line valuehat currnum if goods==16 & wtfkey==330320 || line valuehat currnum if goods==8 & wtfkey==330320 || line valuehat currnum if goods==4 & wtfkey==330320 || line valuehat currnum if goods==2 & wtfkey==330320  // argentina
  graph export "braxpmkt/eps/`sec'/expprodextd_argentina-2-16_ge100.eps", replace
  graph twoway scatter value currnum if goods==16 & wtfkey==330320, yscale(log) ytitle("Log Exports (US$ Thsd fob)") ylabel(1 10 100 1000 10000, nogrid) xscale(log) xlabel(1 2 4 8 16, nogrid) xtitle("Log Goods Rank in Firm (HS 6-digit)") graphregion(color(white)) scheme(sj) || scatter value currnum if goods==8 & wtfkey==330320 || scatter value currnum if goods==4 & wtfkey==330320 || scatter value currnum if goods==2 & wtfkey==330320, legend(order(4 3 2 1) label(4 "2-product Firms (`lbl4')") label(3 "4-product Firms (`lbl3')") label(2 "8-product Firms (`lbl2')") label(1 "16-product Firms (`lbl1')")) || line valuehat16 currnum if goods==16 & wtfkey==330320 || line valuehat8 currnum if goods==8 & wtfkey==330320 || line valuehat4 currnum if goods==4 & wtfkey==330320 || line valuehat2 currnum if goods==2 & wtfkey==330320  // argentina
  graph export "braxpmkt/eps/`sec'/expprodfit_argentina-2-16_ge100.eps", replace
restore
  
est2tex expprodextd, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall
est2tex expprodfit, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `sec' loop
  
log close
set more off
