*! version 1.2  06may2011  by Marc Muendler  muendler@ucsd.edu
*! version 2.3  06nov2015  by Marc Muendler  muendler@ucsd.edu

version 10.1
set more off
set virtual on
clear
capture clear matrix
set mem 1000m
set matsize 8000
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/poolsec"
capture mkdir "braxpmkt/estmat/poolsec"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-struct-2d.log", replace

local sec "manf-firms"

capture program drop twopart
program define twopart, eclass
  syntax varlist [in] [, ABS(name) VCE(namelist) Currnum(integer 1) Goods(integer 2) Level(integer 95)]
  tempname brepost Vrepost
  tempvar cnstrlnval
  qui xtreg `varlist' `in' if currnum==`currnum', fe i(`abs') vce(`vce')
  mat `brepost' = e(b)
  mat coleq `brepost' = reg1
  mat `Vrepost' = e(V)
  mat roweq `Vrepost' = reg1
  mat coleq `Vrepost' = reg1
  local N_reg1 = e(N)
  local r2_w_reg1 = e(r2_w)
  local rmvlst "`1' `2' `3'"
  local subvarlist : list varlist - rmvlst
  local adjsum ""
  foreach var of varlist `subvarlist' {
    if "`adjsum'"==""  local adjsum "_b[`var']*`var'"
    else               local adjsum "`adjsum' + _b[`var']*`var'"
    }
  qui gen double `cnstrlnval' = `1' - (`adjsum')
  qui xtreg `cnstrlnval' lncurrnum if goods==`goods', fe i(`abs') vce(`vce')
  local xrows = colsof(`brepost')
  local coleq : coleq `brepost'
  local coleq "`coleq' reg2"
  local xcols = `e(df_b)'+1
  mat `brepost' = `brepost', e(b)
  mat coleq `brepost' = `coleq'
  mat `Vrepost' = `Vrepost' , J(`xrows',`xcols',0) \ J(`xcols',`xrows',0) , e(V)
  local colnames : colfullnames `brepost'
  mat rownames `Vrepost' = `colnames'
  mat colnames `Vrepost' = `colnames'
  local N_reg2 = e(N)
  local r2_w_reg2 = e(r2_w)
  ereturn post `brepost' `Vrepost', depname(`1')
  ereturn scalar N_reg1 = `N_reg1'
  ereturn scalar N_reg2 = `N_reg2'
  ereturn scalar N = max(`N_reg1',`N_reg2')
  ereturn scalar r2_w_reg1 = `r2_w_reg1'
  ereturn scalar r2_w_reg2 = `r2_w_reg2'
  ereturn display, level(`level')
end

capture program drop ftest2d
program define ftest2d, rclass
  tempname V
  mat `V' = e(V)  
  qui test - [reg2]lncurrnum = 0
  return scalar alphasig_F = r(F)
  return scalar alphasig_p = r(p)
  return scalar alphasig_se = sqrt(`V'[rownumb(`V',"reg2:lncurrnum"),colnumb(`V',"reg2:lncurrnum")])
  return scalar alphasig = - _b[reg2:lncurrnum]
  qui test - [reg1]lnglblphi_pctl = 0
  return scalar thetatlde_F = r(F)
  return scalar thetatlde_p = r(p)
  return scalar thetatlde_se = (1/_b[reg1:lnglblphi_pctl]^2) * sqrt(`V'[rownumb(`V',"reg1:lnglblphi_pctl"),colnumb(`V',"reg1:lnglblphi_pctl")])  // Delta method
  return scalar thetatlde = - 1/_b[reg1:lnglblphi_pctl]
  qui test [reg1]lngoods_lac + [reg2]lncurrnum = 0
  return scalar delta_lac_F = r(F)
  return scalar delta_lac_p = r(p)
  return scalar delta_lac_se = sqrt(`V'[rownumb(`V',"reg1:lngoods_lac"),colnumb(`V',"reg1:lngoods_lac")]+`V'[rownumb(`V',"reg2:lncurrnum"),colnumb(`V',"reg2:lncurrnum")]+2*`V'[rownumb(`V',"reg1:lngoods_lac"),colnumb(`V',"reg2:lncurrnum")])
  return scalar delta_lac = _b[reg1:lngoods_lac] + _b[reg2:lncurrnum]
  qui test [reg1]lngoods_row + [reg2]lncurrnum = 0
  return scalar delta_row_F = r(F)
  return scalar delta_row_p = r(p)
  return scalar delta_row_se = sqrt(`V'[rownumb(`V',"reg1:lngoods_row"),colnumb(`V',"reg1:lngoods_row")]+`V'[rownumb(`V',"reg2:lncurrnum"),colnumb(`V',"reg2:lncurrnum")]+2*`V'[rownumb(`V',"reg1:lngoods_row"),colnumb(`V',"reg2:lncurrnum")])
  return scalar delta_row = _b[reg1:lngoods_row] + _b[reg2:lncurrnum]
  qui test [reg1]lngoods_lac - [reg1]lngoods_row = 0
  return scalar delta_dif_F = r(F)
  return scalar delta_dif_p = r(p)
  return scalar delta_dif_se = sqrt(`V'[rownumb(`V',"reg1:lngoods_lac"),colnumb(`V',"reg1:lngoods_lac")]+`V'[rownumb(`V',"reg1:lngoods_row"),colnumb(`V',"reg1:lngoods_row")]+2*`V'[rownumb(`V',"reg1:lngoods_lac"),colnumb(`V',"reg1:lngoods_row")])
  return scalar delta_dif = _b[reg1:lngoods_lac] - _b[reg1:lngoods_row]
end


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

use "braxpmkt/secex/prodsales-rais-2000-2delta.dta", clear

* sample br only
drop if subsmpl == "comrc-firms"
drop brcmrc_*

* regressions (for log file only)

xtreg lnvalue lngoods_lac lngoods_row lncurrnum indlac lnglblphi_pctl, fe i(firmid) vce(cluster cnae)

xtreg lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl if currnum==1, fe i(firmid) vce(cluster cnae)
gen double cnstr2_lnvalue = lnvalue - _b[indlac]*indlac - _b[lnglblphi_pctl]*lnglblphi_pctl
xtreg cnstr2_lnvalue lncurrnum if goods==2, fe i(firmid) vce(cluster cnae)

xtreg lnvalue lncurrnum indlac lnglblphi_pctl if goods==2, fe i(firmid) vce(cluster cnae)
gen double cnstr1_lnvalue = lnvalue - _b[indlac]*indlac - _b[lnglblphi_pctl]*lnglblphi_pctl
xtreg cnstr1_lnvalue lngoods_lac lngoods_row if currnum==1, fe i(firmid) vce(cluster cnae)

* regressions (reported)

twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(firmid) vce(cluster cnae) currnum(1) goods(2)
  est2vec expprodextd_strc2d, e(N_reg1 N_reg2 r2_w_reg1 r2_w_reg2) name(xtfirm:g1G2) replace
  ftest2d
  est2vec expprodextd_strc2d, r(delta_lac delta_lac_se delta_lac_p delta_lac_F delta_row delta_row_se delta_row_p delta_row_F alphasig alphasig_se alphasig_p alphasig_F thetatlde thetatlde_se thetatlde_p thetatlde_F delta_dif delta_dif_se delta_dif_p delta_dif_F) name(xtfirm:g1G2) replace
twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(cnae) currnum(1) goods(2)
  est2vec expprodextd_strc2d, addto(expprodextd_strc2d) name(xtcnae:g1G2) replace
  ftest2d
  est2vec expprodextd_strc2d, raddto(expprodextd_strc2d) name(xtcnae:g1G2) replace
twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(wtf) currnum(1) goods(2)
  est2vec expprodextd_strc2d, addto(expprodextd_strc2d) name(xtwtf:g1G2) replace
  ftest2d
  est2vec expprodextd_strc2d, raddto(expprodextd_strc2d) name(xtwtf:g1G2) replace
twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(firmid) vce(cluster cnae) currnum(2) goods(3)
  est2vec expprodextd_strc2d, addto(expprodextd_strc2d) name(xtfirm:g2G3) replace
  ftest2d
  est2vec expprodextd_strc2d, raddto(expprodextd_strc2d) name(xtfirm:g2G3) replace
twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(firmid) vce(cluster cnae) currnum(2) goods(2)
  est2vec expprodextd_strc2d, addto(expprodextd_strc2d) name(xtfirm:g2G2) replace
  ftest2d
  est2vec expprodextd_strc2d, raddto(expprodextd_strc2d) name(xtfirm:g2G2) replace
twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(firmid) vce(cluster cnae) currnum(4) goods(4)
  est2vec expprodextd_strc2d, addto(expprodextd_strc2d) name(xtfirm:g4G4) replace
  ftest2d
  est2vec expprodextd_strc2d, raddto(expprodextd_strc2d) name(xtfirm:g4G4) replace
twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(firmid) vce(cluster cnae) currnum(8) goods(8)
  est2vec expprodextd_strc2d, addto(expprodextd_strc2d) name(xtfirm:g8G8) replace
  ftest2d
  est2vec expprodextd_strc2d, raddto(expprodextd_strc2d) name(xtfirm:g8G8) replace
twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(firmid) vce(cluster cnae) currnum(16) goods(16)
  est2vec expprodextd_strc2d, addto(expprodextd_strc2d) name(xtfirm:g16G16) replace
  ftest2d
  est2vec expprodextd_strc2d, raddto(expprodextd_strc2d) name(xtfirm:g16G16) replace
twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(firmid) vce(cluster cnae) currnum(1) goods(16)
  est2vec expprodextd_strc2d, addto(expprodextd_strc2d) name(xtfirm:g1G16) replace
  ftest2d
  est2vec expprodextd_strc2d, raddto(expprodextd_strc2d) name(xtfirm:g1G16) replace
twopart lnvalue lngoods_lac lngoods_row indlac lnglblphi_pctl, abs(firmid) vce(cluster cnae) currnum(1) goods(32)
  est2vec expprodextd_strc2d, addto(expprodextd_strc2d) name(xtfirm:g1G32) replace
  ftest2d
  est2vec expprodextd_strc2d, raddto(expprodextd_strc2d) name(xtfirm:g1G32) replace
est2tex expprodextd_strc2d, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall preserve

* if Stata 13 or higher: reset to Stata 11 format
if _caller()>=13 {
  preserve
  use "braxpmkt/estmat/`sec'/expprodextd_strc2d_tbl.dta", clear
  saveold "braxpmkt/estmat/`sec'/expprodextd_strc2d_tbl.dta", replace version(11)
  restore
  }

log close
set more off
