*! version 1.2.3  05may2011  by Marc Muendler  muendler@ucsd.edu

version 10.1
set more off
set virtual on
clear
capture clear matrix
set mem 500m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/poolsec"
capture mkdir "braxpmkt/estmat/poolsec"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-struct-byisic.log", replace

local sec "poolsec"

capture program drop xtclstreg
program define xtclstreg, eclass
  syntax varlist [if] [in] [, FE I(varname) CLUSTER(varname)]
  tempname Vcluster Vi Vwhite Vrepost
  qui xtreg `varlist' `if' `in', fe i(`i') cluster(`cluster') nonest  // regression with `i'-fixed effects, clustering by `cluster'
  matrix `Vcluster' = e(V)
  qui xtreg `varlist' `if' `in', fe i(`i') cluster(`i')  // regression with `i'-fixed effects, clustering by i'
  matrix `Vi' = e(V)
  qui xtreg `varlist' `if' `in', fe i(`i') robust  // regression with `i'-fixed effects, robust standard errors
  matrix `Vwhite' = e(V)
  matrix `Vrepost' = `Vcluster' + `Vi' - `Vwhite'
  ereturn repost V = `Vrepost'
  * ereturn display
  xtreg
end

capture program drop uicorrftest
program define uicorrftest, rclass
  args prfxlst phitype blup
  if "`e(cmd)'"=="xtmixed" {
    local lastcol = colsof(expprodisic_strc_b)
    unab vars : b`phitype'_*
    foreach var of varlist `vars' {
      local lbl`var' : variable label `var'
      local lbl`var' = subinstr("`lbl`var''","BLUP r.e. for `blup': ","",.)
      if "`lbl`var''"~="_cons" {
        rename `var' b`phitype'_`lbl`var''
        qui summ b`phitype'_`lbl`var''
        mat expprodisic_strc_b[rownumb(expprodisic_strc_b,"`lbl`var''"),`lastcol'] = `r(mean)'
        mat expprodisic_strc_se[rownumb(expprodisic_strc_se,"`lbl`var''"),`lastcol'] = `r(sd)'/sqrt(`r(N)')
        }
      }
    foreach prfx in `prfxlst' {
      return scalar `prfx'_total = expprodisic_strc_b[rownumb(expprodisic_strc_b,"`prfx'_lngoods"),`lastcol']
      return scalar `prfx'_total_se = expprodisic_strc_se[rownumb(expprodisic_strc_se,"`prfx'_lngoods"),`lastcol']
      return scalar `prfx'_alphasig = - expprodisic_strc_b[rownumb(expprodisic_strc_b,"`prfx'_lncurrnum"),`lastcol']
      return scalar `prfx'_alphasig_se = expprodisic_strc_se[rownumb(expprodisic_strc_se,"`prfx'_lncurrnum"),`lastcol']
      return scalar `prfx'_delta = expprodisic_strc_b[rownumb(expprodisic_strc_b,"`prfx'_lngoods"),`lastcol'] + expprodisic_strc_b[rownumb(expprodisic_strc_b,"`prfx'_lncurrnum"),`lastcol']
      qui corr b`phitype'_`prfx'_lngoods b`phitype'_`prfx'_lncurrnum, covar
      return scalar `prfx'_delta_se = sqrt(`r(Var_1)'+`r(Var_2)'+2*`r(cov_12)')/sqrt(`r(N)')
      }
    }
  else {
    tempname V
    foreach prfx in `prfxlst' {
      mat `V' = e(V)  
      qui test - `prfx'_lncurrnum = 0
      return scalar `prfx'_alphasig_F = r(F)
      return scalar `prfx'_alphasig_p = r(p)
      return scalar `prfx'_alphasig_se = sqrt(`V'[rownumb(`V',"`prfx'_lncurrnum"),colnumb(`V',"`prfx'_lncurrnum")])
      return scalar `prfx'_alphasig = - _b[`prfx'_lncurrnum]
      qui test `prfx'_lngoods + `prfx'_lncurrnum = 0
      return scalar `prfx'_delta_F = r(F)
      return scalar `prfx'_delta_p = r(p)
      return scalar `prfx'_delta_se = sqrt(`V'[rownumb(`V',"`prfx'_lngoods"),colnumb(`V',"`prfx'_lngoods")]+`V'[rownumb(`V',"`prfx'_lncurrnum"),colnumb(`V',"`prfx'_lncurrnum")]+2*`V'[rownumb(`V',"`prfx'_lngoods"),colnumb(`V',"`prfx'_lncurrnum")])
      return scalar `prfx'_delta = _b[`prfx'_lngoods] + _b[`prfx'_lncurrnum]
      if "`e(cmd)'"=="xtreg"  qui predict ui, u
      else qui gen ui = .
      capture corr ui `prfx'_lncurrnum
      drop ui
      return scalar `prfx'_rho = r(rho)
    }
  }
end


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

use "braxpmkt/secex/prodsales-rais-2000-struct.dta", clear

* merge ISIC information
sort hs6dgt
merge hs6dgt using "braxpmkt/conc/hs2isic.dta", nokeep
tab _m
tab isic
drop _m
drop if isic<300 | isic>399 | isic==.
sort subsmpl firmid wtfkey hs6dgt
qui tab isic, gen(indisic)
unab vars : indisic*
local i 0
foreach var in `vars' {
  local i = `i'+1
  local code : variable label `var'
  local code = substr("`code'",9,3)
  * disp "`code'"
  rename indisic`i' indisic`code'
  local lbl : variable label indisic`code'
  local lbl = substr("`lbl'",14,.)
  label var indisic`code' "`lbl'"
  gen br`code'_lngoods = br_lngoods * indisic`code'
  local lbl : variable label br_lngoods
  label var br`code'_lngoods "Log # goods (HS 6) [ISIC `code']"
  gen br`code'_lncurrnum = br_lncurrnum * indisic`code'
  local lbl : variable label br_lncurrnum
  label var br`code'_lncurrnum "Log Prod. rank (HS 6) [ISIC `code']"
  }
drop indisic*

gen str firm_wtf = string(firmid) + "_" + substr(string(wtfkey),1,2)  // Firms and WTF regions (first two WTFkey digits)
encode firm_wtf, generate(firmwtf2)
preserve
  keep firm_wtf firmwtf2
  duplicates drop
  duplicates tag firmwtf2, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP  //  string encoding not unique
restore 
drop firm_wtf
label var firmwtf2 "Firm-destination category"
gen str cnae_wtf = string(cnae) + "_" + string(wtfkey)  // CNAE and WTF effect
encode cnae_wtf, generate(cnaewtf)
preserve
  keep cnae_wtf cnaewtf
  duplicates drop
  duplicates tag cnaewtf, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP  //  string encoding not unique
restore 
drop cnae_wtf
label var cnaewtf "CNAE-destination category"
qui tab subsmpl, gen(indsrc)
drop indsrc1
qui tab wtfkey, gen(indwtf)
drop indwtf1


* REGRESSIONS for br only, with CNAE-fixed effects
drop if subsmpl == "comrc-firms"
drop brcmrc_*
unab vars : br???_lngoods br_lncurrnum br???_lncurrnum lnphiratio* indwtf*
xtclstreg lnvalue br???_lngoods br_lncurrnum, i(cnaewtf) cluster(currnum) fe
  est2vec expprodisic_strc, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(disic:cnaeXwtf) replace
xtclstreg lnvalue br???_lngoods br_lncurrnum lnphiratio_pctl, i(cnaewtf) cluster(currnum) fe
  est2vec expprodisic_strc, addto(expprodisic_strc) name(disic:cnaeXwtf_phipctl) replace
xtclstreg lnvalue br???_lngoods br_lncurrnum lnphiratio_exp, i(cnaewtf) cluster(currnum) fe
  est2vec expprodisic_strc, addto(expprodisic_strc) name(disic:cnaeXwtf_phiexp) replace
xtclstreg lnvalue br???_lngoods br_lncurrnum lnphiratio_empl, i(cnaewtf) cluster(currnum) fe
  est2vec expprodisic_strc, addto(expprodisic_strc) name(disic:cnaeXwtf_phiempl) replace

xtclstreg lnvalue br???_lngoods br???_lncurrnum, i(cnaewtf) cluster(currnum) fe
  est2vec expprodisic_strc, addto(expprodisic_strc) name(daisic:cnaeXwtf) replace
xtclstreg lnvalue br???_lngoods br???_lncurrnum lnphiratio_pctl, i(cnaewtf) cluster(currnum) fe
  est2vec expprodisic_strc, addto(expprodisic_strc) name(daisic:cnaeXwtf_phipctl) replace
xtclstreg lnvalue br???_lngoods br???_lncurrnum lnphiratio_exp, i(cnaewtf) cluster(currnum) fe
  est2vec expprodisic_strc, addto(expprodisic_strc) name(daisic:cnaeXwtf_phiexp) replace
xtclstreg lnvalue br???_lngoods br???_lncurrnum lnphiratio_empl, i(cnaewtf) cluster(currnum) fe
  est2vec expprodisic_strc, addto(expprodisic_strc) name(daisic:cnaeXwtf_phiempl) replace

est2tex expprodisic_strc, p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall preserve


* if Stata 10.1 or higher: reset to Stata 9.2 format
if _caller()>=10 {
  preserve
  use "braxpmkt/estmat/`sec'/expprodisic_strc_tbl.dta", clear
  saveold "braxpmkt/estmat/`sec'/expprodisic_strc_tbl.dta", replace
  restore
  }

log close
set more off
