*! version 1.2.3  05jul2011  by Marc Muendler  muendler@ucsd.edu

version 10.1
set more off
set virtual on
clear
capture clear matrix
set mem 1000m
set matsize 8000
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/poolsec-ncm8"
capture mkdir "braxpmkt/estmat/poolsec-ncm8"

capture log close
log using "braxpmkt/logs/prodsales-regress-prodlvl-struct-ncm8.log", replace

local sec "poolsec"

capture program drop xtclstreg
program define xtclstreg, eclass
  syntax varlist [if] [in] [, FE I(varname) CLUSTER(varname)]
  tempname Vcluster Vi Vwhite Vrepost
  qui xtreg `varlist' `if' `in', fe i(`i') cluster(`cluster') nonest  // regression with `i'-fixed effects, clustering by `cluster'
  matrix `Vcluster' = e(V)
  qui xtreg `varlist' `if' `in', fe i(`i') cluster(`i')  // regression with `i'-fixed effects, clustering by i'
  matrix `Vi' = e(V)
  qui xtreg `varlist' `if' `in', fe i(`i') robust  // regression with `i'-fixed effects, robust standard errors
  matrix `Vwhite' = e(V)
  matrix `Vrepost' = `Vcluster' + `Vi' - `Vwhite'
  ereturn repost V = `Vrepost'
  * ereturn display
  xtreg
end

capture program drop uicorrftest
program define uicorrftest, rclass
  args prfxlst phitype blup
  if "`e(cmd)'"=="xtmixed" {
    local lastcol = colsof(expprodextd_strc_b)
    unab vars : b`phitype'_*
    foreach var of varlist `vars' {
      local lbl`var' : variable label `var'
      local lbl`var' = subinstr("`lbl`var''","BLUP r.e. for `blup': ","",.)
      if "`lbl`var''"~="_cons" {
        rename `var' b`phitype'_`lbl`var''
        qui summ b`phitype'_`lbl`var''
        mat expprodextd_strc_b[rownumb(expprodextd_strc_b,"`lbl`var''"),`lastcol'] = `r(mean)'
        mat expprodextd_strc_se[rownumb(expprodextd_strc_se,"`lbl`var''"),`lastcol'] = `r(sd)'/sqrt(`r(N)')
        }
      }
    foreach prfx in `prfxlst' {
      return scalar `prfx'_total = expprodextd_strc_b[rownumb(expprodextd_strc_b,"`prfx'_lngoods"),`lastcol']
      return scalar `prfx'_total_se = expprodextd_strc_se[rownumb(expprodextd_strc_se,"`prfx'_lngoods"),`lastcol']
      return scalar `prfx'_alphasig = - expprodextd_strc_b[rownumb(expprodextd_strc_b,"`prfx'_lncurrnum"),`lastcol']
      return scalar `prfx'_alphasig_se = expprodextd_strc_se[rownumb(expprodextd_strc_se,"`prfx'_lncurrnum"),`lastcol']
      return scalar `prfx'_delta = expprodextd_strc_b[rownumb(expprodextd_strc_b,"`prfx'_lngoods"),`lastcol'] + expprodextd_strc_b[rownumb(expprodextd_strc_b,"`prfx'_lncurrnum"),`lastcol']
      qui corr b`phitype'_`prfx'_lngoods b`phitype'_`prfx'_lncurrnum, covar
      return scalar `prfx'_delta_se = sqrt(`r(Var_1)'+`r(Var_2)'+2*`r(cov_12)')/sqrt(`r(N)')
      }
    }
  else {
    tempname V
    foreach prfx in `prfxlst' {
      mat `V' = e(V)  
      qui test - `prfx'_lncurrnum = 0
      return scalar `prfx'_alphasig_F = r(F)
      return scalar `prfx'_alphasig_p = r(p)
      return scalar `prfx'_alphasig_se = sqrt(`V'[rownumb(`V',"`prfx'_lncurrnum"),colnumb(`V',"`prfx'_lncurrnum")])
      return scalar `prfx'_alphasig = - _b[`prfx'_lncurrnum]
      qui test `prfx'_lngoods + `prfx'_lncurrnum = 0
      return scalar `prfx'_delta_F = r(F)
      return scalar `prfx'_delta_p = r(p)
      return scalar `prfx'_delta_se = sqrt(`V'[rownumb(`V',"`prfx'_lngoods"),colnumb(`V',"`prfx'_lngoods")]+`V'[rownumb(`V',"`prfx'_lncurrnum"),colnumb(`V',"`prfx'_lncurrnum")]+2*`V'[rownumb(`V',"`prfx'_lngoods"),colnumb(`V',"`prfx'_lncurrnum")])
      return scalar `prfx'_delta = _b[`prfx'_lngoods] + _b[`prfx'_lncurrnum]
      if "`e(cmd)'"=="xtreg"  qui predict ui, u
      else qui gen ui = .
      capture corr ui `prfx'_lncurrnum
      drop ui
      return scalar `prfx'_rho = r(rho)
    }
  }
end

capture program drop uicorrnofdi
program define uicorrnofdi, rclass
  args prfxlst phitype blup
  if "`e(cmd)'"=="xtmixed" {
    local lastcol = colsof(expprdnofdi_strc_b)
    unab vars : b`phitype'_*
    foreach var of varlist `vars' {
      local lbl`var' : variable label `var'
      local lbl`var' = subinstr("`lbl`var''","BLUP r.e. for `blup': ","",.)
      if "`lbl`var''"~="_cons" {
        rename `var' b`phitype'_`lbl`var''
        qui summ b`phitype'_`lbl`var''
        mat expprdnofdi_strc_b[rownumb(expprdnofdi_strc_b,"`lbl`var''"),`lastcol'] = `r(mean)'
        mat expprdnofdi_strc_se[rownumb(expprdnofdi_strc_se,"`lbl`var''"),`lastcol'] = `r(sd)'/sqrt(`r(N)')
        }
      }
    foreach prfx in `prfxlst' {
      return scalar `prfx'_total = expprdnofdi_strc_b[rownumb(expprdnofdi_strc_b,"`prfx'_lngoods"),`lastcol']
      return scalar `prfx'_total_se = expprdnofdi_strc_se[rownumb(expprdnofdi_strc_se,"`prfx'_lngoods"),`lastcol']
      return scalar `prfx'_alphasig = - expprdnofdi_strc_b[rownumb(expprdnofdi_strc_b,"`prfx'_lncurrnum"),`lastcol']
      return scalar `prfx'_alphasig_se = expprdnofdi_strc_se[rownumb(expprdnofdi_strc_se,"`prfx'_lncurrnum"),`lastcol']
      return scalar `prfx'_delta = expprdnofdi_strc_b[rownumb(expprdnofdi_strc_b,"`prfx'_lngoods"),`lastcol'] + expprdnofdi_strc_b[rownumb(expprdnofdi_strc_b,"`prfx'_lncurrnum"),`lastcol']
      qui corr b`phitype'_`prfx'_lngoods b`phitype'_`prfx'_lncurrnum, covar
      return scalar `prfx'_delta_se = sqrt(`r(Var_1)'+`r(Var_2)'+2*`r(cov_12)')/sqrt(`r(N)')
      }
    }
  else {
    tempname V
    foreach prfx in `prfxlst' {
      mat `V' = e(V)  
      qui test - `prfx'_lncurrnum = 0
      return scalar `prfx'_alphasig_F = r(F)
      return scalar `prfx'_alphasig_p = r(p)
      return scalar `prfx'_alphasig_se = sqrt(`V'[rownumb(`V',"`prfx'_lncurrnum"),colnumb(`V',"`prfx'_lncurrnum")])
      return scalar `prfx'_alphasig = - _b[`prfx'_lncurrnum]
      qui test `prfx'_lngoods + `prfx'_lncurrnum = 0
      return scalar `prfx'_delta_F = r(F)
      return scalar `prfx'_delta_p = r(p)
      return scalar `prfx'_delta_se = sqrt(`V'[rownumb(`V',"`prfx'_lngoods"),colnumb(`V',"`prfx'_lngoods")]+`V'[rownumb(`V',"`prfx'_lncurrnum"),colnumb(`V',"`prfx'_lncurrnum")]+2*`V'[rownumb(`V',"`prfx'_lngoods"),colnumb(`V',"`prfx'_lncurrnum")])
      return scalar `prfx'_delta = _b[`prfx'_lngoods] + _b[`prfx'_lncurrnum]
      if "`e(cmd)'"=="xtreg"  qui predict ui, u
      else qui gen ui = .
      capture corr ui `prfx'_lncurrnum
      drop ui
      return scalar `prfx'_rho = r(rho)
    }
  }
end


// PRODUCT SALES AND EXPORTER SCOPE BY FIRM AND COUNTRY

use "braxpmkt/secex/prodsales-rais-2000-struct-ncm8.dta", clear

gen str firm_wtf = string(firmid) + "_" + substr(string(wtfkey),1,2)  // Firms and WTF regions (first two WTFkey digits)
encode firm_wtf, generate(firmwtf2)
preserve
  keep firm_wtf firmwtf2
  duplicates drop
  duplicates tag firmwtf2, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP  //  string encoding not unique
restore 
drop firm_wtf
label var firmwtf2 "Firm-destination category"
gen str cnae_wtf = string(cnae) + "_" + string(wtfkey)  // CNAE and WTF effect
encode cnae_wtf, generate(cnaewtf)
preserve
  keep cnae_wtf cnaewtf
  duplicates drop
  duplicates tag cnaewtf, gen(_dupl)
  qui count if _dupl>0
  if `r(N)'>0  STOP  //  string encoding not unique
restore 
drop cnae_wtf
label var cnaewtf "CNAE-destination category"
qui tab subsmpl, gen(indsrc)
drop indsrc1
qui tab wtfkey, gen(indwtf)
drop indwtf1


* REGRESSIONS for br brcmrc, with CNAE-fixed effects
unab vars : br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum lnphiratio* indsrc* indwtf*
xtclstreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc*, i(cnaewtf) cluster(currnum) fe
  est2vec expprodextd_pool, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(xt:cnaeXwtf) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_pool, r(br_rho br_delta br_delta_se br_delta_p br_delta_F br_alphasig br_alphasig_se br_alphasig_p br_alphasig_F brcmrc_rho brcmrc_delta brcmrc_delta_se brcmrc_delta_p brcmrc_delta_F brcmrc_alphasig brcmrc_alphasig_se brcmrc_alphasig_p brcmrc_alphasig_F) name(xt:cnaeXwtf) replace
xtreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc* indwtf*, i(firmid) fe  // no two-way cluster b/c matrix not positive definite
  est2vec expprodextd_pool, addto(expprodextd_pool) name(xt:firm_noclst) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_pool, raddto(expprodextd_pool) name(xt:firm_noclst) replace
xtclstreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum indsrc*, i(firmwtf2) cluster(currnum) fe
  est2vec expprodextd_pool, addto(expprodextd_pool) name(xt:firmwtf2) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_pool, raddto(expprodextd_pool) name(xt:firmwtf2) replace
xtclstreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum lnphiratio_pctl indsrc*, i(cnaewtf) cluster(currnum) fe
  est2vec expprodextd_pool, addto(expprodextd_pool) name(xt:cnaeXwtf_phipctl) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_pool, raddto(expprodextd_pool) name(xt:cnaeXwtf_phipctl) replace
xtclstreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum lnphiratio_exp indsrc*, i(cnaewtf) cluster(currnum) fe
  est2vec expprodextd_pool, addto(expprodextd_pool) name(xt:cnaeXwtf_phiexp) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_pool, raddto(expprodextd_pool) name(xt:cnaeXwtf_phiexp) replace
xtclstreg lnvalue br_lngoods br_lncurrnum brcmrc_lngoods brcmrc_lncurrnum lnphiratio_empl indsrc*, i(cnaewtf) cluster(currnum) fe
  est2vec expprodextd_pool, addto(expprodextd_pool) name(xt:cnaeXwtf_phiempl) replace
  uicorrftest "br brcmrc"
  est2vec expprodextd_pool, raddto(expprodextd_pool) name(xt:cnaeXwtf_phiempl) replace

est2tex expprodextd_pool, p(braxpmkt/estmat/`sec'-ncm8) replace level(90 95 99) mark(starse) dropall preserve


* REGRESSIONS for br only, with CNAE-fixed effects
drop if subsmpl == "comrc-firms"
drop brcmrc_*
unab vars : br_lngoods br_lncurrnum lnphiratio* indwtf*
xtclstreg lnvalue br_lngoods br_lncurrnum, i(cnaewtf) cluster(currnum) fe
  est2vec expprodextd_strc, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(xt:cnaeXwtf) replace
  uicorrftest "br"
  est2vec expprodextd_strc, r(br_rho br_delta br_delta_se br_delta_p br_delta_F br_alphasig br_alphasig_se br_alphasig_p br_alphasig_F) name(xt:cnaeXwtf) replace
xtreg lnvalue br_lngoods br_lncurrnum indwtf*, i(firmid) fe  // no two-way cluster b/c matrix not positive definite
  est2vec expprodextd_strc, addto(expprodextd_strc) name(xt:firm_noclst) replace
  uicorrftest "br"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(xt:firm_noclst) replace
xtclstreg lnvalue br_lngoods br_lncurrnum, i(firmwtf2) cluster(currnum) fe
  est2vec expprodextd_strc, addto(expprodextd_strc) name(xt:firmwtf2) replace
  uicorrftest "br"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(xt:firmwtf2) replace
xtclstreg lnvalue br_lngoods br_lncurrnum lnphiratio_pctl, i(cnaewtf) cluster(currnum) fe
  est2vec expprodextd_strc, addto(expprodextd_strc) name(xt:cnaeXwtf_phipctl) replace
  uicorrftest "br"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(xt:cnaeXwtf_phipctl) replace
xtclstreg lnvalue br_lngoods br_lncurrnum lnphiratio_exp, i(cnaewtf) cluster(currnum) fe
  est2vec expprodextd_strc, addto(expprodextd_strc) name(xt:cnaeXwtf_phiexp) replace
  uicorrftest "br"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(xt:cnaeXwtf_phiexp) replace
xtclstreg lnvalue br_lngoods br_lncurrnum lnphiratio_empl, i(cnaewtf) cluster(currnum) fe
  est2vec expprodextd_strc, addto(expprodextd_strc) name(xt:cnaeXwtf_phiempl) replace
  uicorrftest "br"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(xt:cnaeXwtf_phiempl) replace
xtmixed lnvalue lnphiratio_pctl indwtf* || cnae: br_lngoods br_lncurrnum, covariance(unstructured)
  est2vec expprodextd_strc, addto(expprodextd_strc) name(mx:wtf_rcnae_phipctl) replace
  predict bpctl_*, reffects level(cnae)
  summ bpctl_*
  uicorrftest "br" "pctl" "cnae"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(mx:wtf_rcnae_phipctl) replace
xtmixed lnvalue lnphiratio_exp indwtf* || cnae: br_lngoods br_lncurrnum, covariance(unstructured)
  est2vec expprodextd_strc, addto(expprodextd_strc) name(mx:wtf_rcnae_phiexp) replace
  predict bexp_*, reffects level(cnae)
  summ bexp_*
  uicorrftest "br" "exp" "cnae"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(mx:wtf_rcnae_phiexp) replace
xtmixed lnvalue lnphiratio_empl indwtf* || cnae: br_lngoods br_lncurrnum, covariance(unstructured)
  est2vec expprodextd_strc, addto(expprodextd_strc) name(mx:wtf_rcnae_phiempl) replace
  predict bempl_*, reffects level(cnae)
  summ bempl_*
  uicorrftest "br" "empl" "cnae"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(mx:wtf_rcnae_phiempl) replace
xtrc lnvalue br_lngoods br_lncurrnum lnphiratio_pctl, i(cnaewtf)
  est2vec expprodextd_strc, addto(expprodextd_strc) name(rc:cnaeXwtf_phipctl) replace
  uicorrftest "br"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(rc:cnaeXwtf_phipctl) replace
xtrc lnvalue br_lngoods br_lncurrnum lnphiratio_exp, i(cnaewtf)
  est2vec expprodextd_strc, addto(expprodextd_strc) name(rc:cnaeXwtf_phiexp) replace
  uicorrftest "br"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(rc:cnaeXwtf_phiexp) replace
xtrc lnvalue br_lngoods br_lncurrnum lnphiratio_empl, i(cnaewtf)
  est2vec expprodextd_strc, addto(expprodextd_strc) name(rc:cnaeXwtf_phiempl) replace
  uicorrftest "br"
  est2vec expprodextd_strc, raddto(expprodextd_strc) name(rc:cnaeXwtf_phiempl) replace

est2tex expprodextd_strc, p(braxpmkt/estmat/`sec'-ncm8) replace level(90 95 99) mark(starse) dropall preserve


* REGRESSIONS for br and NON-MNEs only, with CNAE-fixed effects
drop bpctl_* bexp_* bempl_*
unab vars : br_lngoods br_lncurrnum lnphiratio* indwtf*
xtclstreg lnvalue br_lngoods br_lncurrnum if indfdicc==0, i(cnaewtf) cluster(currnum) fe
  est2vec expprdnofdi_strc, vars(`vars' _cons) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(xt:cnaeXwtf) replace
  uicorrftest "br"
  est2vec expprdnofdi_strc, r(br_rho br_delta br_delta_se br_delta_p br_delta_F br_alphasig br_alphasig_se br_alphasig_p br_alphasig_F) name(xt:cnaeXwtf) replace
xtclstreg lnvalue br_lngoods br_lncurrnum lnphiratio_pctl if indfdicc==0, i(cnaewtf) cluster(currnum) fe
  est2vec expprdnofdi_strc, addto(expprdnofdi_strc) name(xt:cnaeXwtf_phipctl) replace
  uicorrftest "br"
  est2vec expprdnofdi_strc, raddto(expprdnofdi_strc) name(xt:cnaeXwtf_phipctl) replace
xtclstreg lnvalue br_lngoods br_lncurrnum lnphiratio_empl if indfdicc==0, i(cnaewtf) cluster(currnum) fe
  est2vec expprdnofdi_strc, addto(expprdnofdi_strc) name(xt:cnaeXwtf_phiempl) replace
  uicorrftest "br"
  est2vec expprdnofdi_strc, raddto(expprdnofdi_strc) name(xt:cnaeXwtf_phiempl) replace
xtmixed lnvalue lnphiratio_pctl indwtf* || cnae: br_lngoods br_lncurrnum if indfdicc==0, covariance(unstructured)
  est2vec expprdnofdi_strc, addto(expprdnofdi_strc) name(mx:wtf_rcnae_phipctl) replace
  predict bpctl_*, reffects level(cnae)
  summ bpctl_*
  uicorrnofdi "br" "pctl" "cnae"
  est2vec expprdnofdi_strc, raddto(expprdnofdi_strc) name(mx:wtf_rcnae_phipctl) replace

est2tex expprdnofdi_strc, p(braxpmkt/estmat/`sec'-ncm8) replace level(90 95 99) mark(starse) dropall preserve


* if Stata 10.1 or higher: reset to Stata 9.2 format
if _caller()>=10 {
  preserve
  use "braxpmkt/estmat/`sec'-ncm8/expprodextd_pool_tbl.dta", clear
  saveold "braxpmkt/estmat/`sec'-ncm8/expprodextd_pool_tbl.dta", replace
  use "braxpmkt/estmat/`sec'-ncm8/expprodextd_strc_tbl.dta", clear
  saveold "braxpmkt/estmat/`sec'-ncm8/expprodextd_strc_tbl.dta", replace
  use "braxpmkt/estmat/`sec'-ncm8/expprdnofdi_strc_tbl.dta", clear
  saveold "braxpmkt/estmat/`sec'-ncm8/expprdnofdi_strc_tbl.dta", replace
  restore
  }

log close
set more off
