*! version 1.0.2  16sep2007  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 100m
set trace off

cd "$root"

capture mkdir "braxpmkt/estmat/allsec"
capture mkdir "braxpmkt/estmat/manf-goods"
capture mkdir "braxpmkt/estmat/manf-firms"
capture mkdir "braxpmkt/estmat/manf-ekk"

capture log close
log using "braxpmkt/logs/prodsales-ttest.log", replace

foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" {

foreach sec in "allsec" "manf-goods" "manf-firms" "manf-ekk" {


// Goods rankings

* matrix preparation
matload meanexp_`region'_tbl, p(braxpmkt/tex/`sec') over dropall missing(.)
matorder meanexp_`region'_tbl, m(meanexp_`region'_tbl) over ifr(1 2 3 4 5 6 7 8 9 10)
mat ttestexp_`region'_tbl = J(10,10,.)
local rownames :  rowfullnames meanexp_`region'_tbl
local colnames :  colfullnames meanexp_`region'_tbl
matrix rownames ttestexp_`region'_tbl = `rownames'
matrix colnames ttestexp_`region'_tbl = `colnames'
mat drop meanexp_`region'_tbl

use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina

collapse (sum) value, by(firmid cnae hs6dgt)
replace value = value/1000000
label var value "Exports (US$ mill fob)"
egen goods = count(hs6dgt), by(firmid)
label var goods "Exporter scope (HS 6-digit)"
gsort firmid -value
by firmid: gen currnum=_n
label var currnum "Current goods rank (HS 6-digit)"
compress

* test one row of table braxpmkt/tex/`sec'/meanexp_`region'_tbl against other row
keep if goods<=10
reshape wide value, i(firmid cnae hs6dgt currnum) j(goods)
forvalues j = 1/10 {
  mat ttestexp_`region'_tbl[`j',`j'] = -1
  local jpl1 = `j' + 1
  forvalues i = `jpl1'/10 {
    qui ttest value`j' = value`i'  if currnum==`j', unpaired  // column `j': test row `j' against row `i'
    if `r(p)'<.05 mat ttestexp_`region'_tbl[`i',`j']=1
    else          mat ttestexp_`region'_tbl[`i',`j']=0
    }
  }
est2tex ttestexp_`region', ready fancy p(braxpmkt/tex/`sec') replace dropall


}  // close `sec' loop

}  // close `region' loop
