*! version 1.0.3  08oct2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.0.4  29may2007  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 500m
set trace off
set matsize 300

cd "$root"

capture mkdir "braxpmkt/estmat/chile-manffrms"

capture log close
log using "braxpmkt/logs/prodsales-xtreg-fullspec-chile.log", replace


// FIRM-DESTINATION DATA

foreach region in "world" "mercosur" "oecd90" "nonoecd90" {

* loop over different sector definitions has been eliminated (manf-firms only)
local sec="chile-manffrms"

use firmid hs6dgt isic2 wtfkey indoecd90 value using "braxpmkt/chile/prodsales-data-2000-chile.dta", clear
drop if value==0

* select products and firms
keep if isic2>=300 & isic2<=399   // manufacturing firms and products

* worldwide export activity by firm
tempfile ww
preserve
  tempfile wwgoods
  collapse (sum) value, by(firmid hs6dgt) fast
  collapse (sum) gwwsales=value (count) wwgoods=value, by(firmid) fast
  replace gwwsales = gwwsales/1000000
  label var wwgoods "Worldwide No. of prod. (HS 6)"
  label var gwwsales "Worldwide exports (US$ mill)"
  sort firmid
  save `wwgoods'
restore, preserve
  tempfile wwdest
  gen byte indmerc = ( wtfkey==330320 | wtfkey==336000 | wtfkey==338580 )
  label var indmerc "Indic.: Mercosur member"
  collapse (sum) value (count) wwgoods=value, by(firmid wtfkey indoecd90 indmerc) fast
  replace value = value/1000000
  gen oecdsales = indoecd90*value
  gen mercsales = indmerc*value
  collapse (sum) wwsales=value oecdsales mercsales (count) wwdest=wtfkey, by(firmid) fast
  gen byte ind0oecd = (oecdsales==0)
  gen byte ind0merc = (mercsales==0)
  label var wwsales "Worldwide exports (US$ mill)"
  label var oecdsales "OECD exports (US$ mill)"
  label var mercsales "Mercosur exports (US$ mill)"
  label var wwdest "Worldwide No. of Destinations"
  label var ind0oecd "Indic.: Zero OECD exports"
  label var ind0merc "Indic.: Zero Mercosur exports"
  sort firmid
  save `wwdest'
restore, preserve
  use `wwgoods', clear
  merge firmid using `wwdest'
  qui count if _m~=3
  if `r(N)'>0  STOP
  gen _chk = wwsales - gwwsales
  qui summ _chk
  if abs(`r(sum)')>1e-10  STOP
  drop _m _chk gwwsales
  gen wwgsales=wwsales/wwgoods
  label var wwgsales "Wrldw. exp./prod. (US$ mill)"
  gen lnwwgoods = ln(wwgoods)
  label var lnwwgoods "Log Wrldw. No. of prod. (HS 6)"
  gen lnwwsales = ln(wwsales)
  label var lnwwsales "Log Wrldw. Exp. (US$ mill)"
  gen lnoecdsales = ln(oecdsales)
  replace lnoecdsales = 0 if ind0oecd==1
  label var lnoecdsales "Log nonzero OECD Exp. (US$ mill)"
  gen lnmercsales = ln(mercsales)
  replace lnmercsales = 0 if ind0merc==1
  label var lnmercsales "Log nonz. Mrcos. Exp. (US$ mill)"
  gen lnwwdest = ln(wwdest)
  label var lnwwdest "Log Wrldw. No. of Destinations"
  gen lnwwgsales = ln(wwgsales)
  label var lnwwgsales "Log Wrldw. Exp./prod. (US$ mill)"
  compress
  sort firmid
  save `ww'
restore

sort firmid
merge firmid using `ww'
tab _m
drop _m

/* 
sort firmid
merge firmid using `rais', nokeep
tab _m
drop _m
*/

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina

collapse (sum) wtfsales=value (count) wtfgoods=value, by(firmid wtfkey wwgoods wwsales oecdsales mercsales wwdest wwgsales ind0oecd ind0merc lnwwgoods lnwwsales lnoecdsales lnmercsales lnwwdest lnwwgsales) fast
drop if wtfsales==0
replace wtfsales = wtfsales/1000000
label var wtfgoods "Number of goods (HS 6-digit)"
label var wtfsales "Total exports (US$ mill fob)"
gen wtfgsales=wtfsales/wtfgoods
label var wtfgsales "Exports per good (US$ mill fob)"

gen lngoods=ln(wtfgoods)
label var lngoods "Log number of goods (HS 6)"
gen lnsumsales=ln(wtfsales)
label var lnsumsales "Log total exports (US$ mill fob)"
gen lngsales=ln(wtfgsales)
label var lngsales "Log exports/good (US$ mill fob)"
drop wtfsales wtfgoods wtfgsales

* destination country dummies
qui tab wtfkey, gen(wtfkey_)
* excluded country: either USA or Argentina (depending on country group)
if "`region'"=="world" | "`region'"=="oecd90" { // drop dummy for USA (wtfkey==USA)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==USA"  drop wtfkey_`i'
    }
  }
if "`region'"=="mercosur" | "`region'"=="nonoecd90" { // drop dummy for Argentina (wtfkey==Argentina)
  sort wtfkey
  qui count if wtfkey~=wtfkey[_n-1]
  local maxcntry = `r(N)'
  forvalues i = 1/`maxcntry' {
    local lblname :  variable label wtfkey_`i'
    if "`lblname'"=="wtfkey==Argentina"  drop wtfkey_`i'
    }
  }

* interaction variables
gen lngoods2 = lngoods*lngoods
gen lngoods3 = lngoods2*lngoods
gen lngoods4 = lngoods2*lngoods2
gen lngoods5 = lngoods4*lngoods
gen lngoods6 = lngoods3*lngoods3
label var lngoods2 "Squared Log number of goods"
label var lngoods3 "Cubic Log number of goods"
label var lngoods4 "Quartic Log number of goods"
label var lngoods5 "Pentic Log number of goods"
label var lngoods6 "Hexic Log number of goods"
gen lngoods_lnwwdest = lngoods*lnwwdest
label var lngoods_lnwwdest "Log # Goods X Log # ww. Dest."

xtreg lngsales lngoods lngoods2 lngoods3 lngoods4 lngoods5 lngoods_lnwwdest wtfkey_*, fe i(firmid)
* disp in green "F test that all u_i=0:  F(" in yellow `e(df_a)' in green ", " in yellow `e(df_r)' in green ") = " in yellow %9.2f  `e(F_f)' in green "  Prob > F = " in yellow %9.4f Ftail(`e(df_a)',`e(df_r)',`e(F_f)')
est2vec frmdst_fullspec_`region', v(lngoods lngoods2 lngoods3 lngoods4 lngoods5 lngoods6 lngoods_lnwwdest lngoods_lnnpis lngoods_indcoll) e(N N_g r2 r2_w r2_b r2_o g_min g_avg g_max corr sigma_u sigma_e rho df_a df_r F_f) name(lngoods5_interact) replace

xtreg lngsales lngoods lngoods2 lngoods3 lngoods4 lngoods_lnwwdest wtfkey_*, fe i(firmid)
est2vec frmdst_fullspec_`region', addto(frmdst_fullspec_`region') name(lngoods4_interact) replace

xtreg lngsales lngoods lngoods2 lngoods3 lngoods4 lngoods5 wtfkey_*, fe i(firmid)
est2vec frmdst_fullspec_`region', addto(frmdst_fullspec_`region') name(lngoods5) replace

xtreg lngsales lngoods lngoods2 lngoods3 lngoods4 wtfkey_*, fe i(firmid)
est2vec frmdst_fullspec_`region', addto(frmdst_fullspec_`region') name(lngoods4) replace

est2tex frmdst_fullspec_`region', fancy p(braxpmkt/estmat/`sec') replace level(90 95 99) mark(starse) dropall

}  // close `region' loop


log close
cd "$home"
