*! version 1.0.1  19may2010  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.1  22nov2010  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 100m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/matlab"

capture log close
log using "braxpmkt/logs/matlab-prodsales-stats.log", replace

// MATLAB GENERATED OBSERVATIONS

* all numbers in 1,000 US$

* insheet using "braxpmkt/matlab/variables.csv", comma clear
* Data=[Percentile; Good2; Sales2; AvGood2; AvSalesAcross2; AvSales2]
*          v1         v2     v3      v4          v5            v6
* rename v1 pctl
* rename v2 goods
* rename v3 sumsales
* rename v4 mean_goods
* rename v5 wmean_gsales
* rename v6 mean_sumsales

insheet using "braxpmkt/matlab/variables3.csv", comma clear
rename percentile pctl
gen sumsales = goods * avsales
rename avgoods mean_goods
rename avscale wmean_gsales
rename avsales mean_sumsales
gen inv_pctl = 100 - pctl*100
label var goods "Exporter scope (HS 6-digit)"
replace sumsales=sumsales/1000
label var sumsales "Total exports (US$ mill fob)"  // -old
label var mean_goods "Mean Exporter Scope"
replace wmean_gsales=wmean_gsales/1000*1000
label var wmean_gsales "Firms' Mean Product Scale"  // US$ thsd fob
replace mean_sumsales=mean_sumsales/1000
label var mean_sumsales "Firms' Mean Total Exports"  // US$ mill fob
order pctl goods sumsales mean_goods wmean_gsales

* goods-pcgoods-usa
label var pctl "Percentile of Firms (Scope)"
graph twoway scatter goods pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Number of Products Shipped") yscale(log) ylabel(1 10 100 1000) ytick(1 10 100 1000) yline(1 10 100 1000, lcolor(gs13)) ytitle("Number of Products (HS 6-digit)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
graph export "braxpmkt/eps/matlab/goods-pcgoods-usa.eps", replace

* sumsales-pcsales-usa
label var pctl "Percentile of Firms (Exports)"
graph twoway scatter sumsales pctl, xlabel(0 .05 .10 .25 .50 .75 .80 .85 .90 .95 1) xtitle("Firm Percentile in Total Exports") yscale(log) ylabel(.00001 .001 .01 .1 1 10 100 1000) ytick(.00001 .0001 .001 .01 .1 1 10 100 1000) yline(.00001 .0001 .001 .01 .1 1 10 100 1000, lcolor(gs13)) ytitle("Total Exports (US$ million fob)") graphregion(color(white)) scheme(sj) msymbol(smcircle)
graph export "braxpmkt/eps/matlab/sumsales-pcsales-usa.eps", replace

* avgsumsales-pcsales-usa
label var pctl "Cumulative Percentile of Firms (Exports)"
graph twoway scatter mean_sumsales inv_pctl, yaxis(1) yscale(log axis(1) range(1 1000)) ylabel(1 10 100 1000, nogrid axis(1)) yline(1 10 100 1000, lcolor(gs14) axis(1)) ytitle("Mean Exports (US$ million fob)", axis(1)) msymbol(smsquare_hollow) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj)
graph export "braxpmkt/eps/matlab/avgsumsales-pcsales-usa.eps", replace

* avgscope-wgsales-pcsales-usa
label var pctl "Cumulative Percentile of Firms (Exports)"
foreach i in 1 50 90 95 {
  local ypos`i' = mean_goods[`i']*.9
  local xpos`i' = inv_pctl[`i']
  if `ypos`i''==.  local ypos`i'=0
  if `xpos`i''==.  local xpos`i'=0
  }
graph twoway scatter mean_goods inv_pctl, yaxis(1) yscale(log axis(1) range(1 10000)) ylabel(1 2 4 16 64, nogrid axis(1)) yline(1 2 4 16 64, lcolor(gs13) axis(1)) ytitle("Mean Number of Products", axis(1)) msymbol(smcircle_hollow) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter wmean_gsales inv_pctl, yaxis(2) yscale(log axis(2) range(1 10000)) ylabel(100 1000 10000, nogrid axis(2)) yline(1 100 1000 10000, lcolor(gs14) axis(2)) ytitle("Mean Exports/Product (US$ thsd fob)", axis(2)) msymbol(smsquare_hollow) text(`ypos1' `xpos1' "p>=1" `ypos50' `xpos50' "p>=50" `ypos90' `xpos90' "p>=90" `ypos95' `xpos95' "p>=95", placement(bottom) size(vsmall))
graph export "braxpmkt/eps/matlab/avgscope-wgsales-pcsales-usa.eps", replace

log close
set more off
