*! version 1.1  07jul2011  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 100m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/manf-firms-ncm8"
capture mkdir "braxpmkt/eps/comrc-firms-ncm8"
capture mkdir "braxpmkt/tex/manf-firms-ncm8"
capture mkdir "braxpmkt/tex/comrc-firms-ncm8"

capture log close
log using "braxpmkt/logs/prodsales-finalize-nmc8.log", replace


// PARETO GRAPH ACROSS ALL COUNTRIES

foreach sec in "manf-firms" "comrc-firms" {

use "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'-ncm8", clear
drop if wtfkey<10  // drop aggregate regions
sort wtfkey pctl
by wtfkey: gen byte pctlcnt = _N
label var pctlcnt "Exist. percentiles for dest."  // Less than 100 for destinations with less than 100 exporters

* OECD dummies
gen byte indoecd90=0
label var indoecd90 "Indic.: OECD member 1990"
replace indoecd90=1 if wtfkey==710360 // Australia 7 June 1971
replace indoecd90=1 if wtfkey==550400 // Austria 29 September 1961 
replace indoecd90=1 if wtfkey==530560 // Belgium-Lux 13 September 1961, 7 December 1961
replace indoecd90=1 if wtfkey==211240 // Canada 10 April 1961
replace indoecd90=1 if wtfkey==532080 // Denmark 30 May 1961
replace indoecd90=1 if wtfkey==552460 // Finland 28 January 1969
replace indoecd90=1 if wtfkey==532500 // France,Monac 7 August 1961
replace indoecd90=1 if wtfkey==532760 // Germany 27 September 1961
replace indoecd90=1 if wtfkey==533000 // Greece 27 September 1961
replace indoecd90=1 if wtfkey==553520 // Iceland 5 June 1961
replace indoecd90=1 if wtfkey==533720 // Ireland 7 August 1961
replace indoecd90=1 if wtfkey==533800 // Italy 29 March 1962
replace indoecd90=1 if wtfkey==413920 // Japan 28 April 1964
replace indoecd90=1 if wtfkey==535280 // Netherlands 13 November 1961
replace indoecd90=1 if wtfkey==715540 // New Zealand 29 May 1973
replace indoecd90=1 if wtfkey==555780 // Norway 4 July 1961
replace indoecd90=1 if wtfkey==536200 // Portugal 4 August 1961
replace indoecd90=1 if wtfkey==537240 // Spain 3 August 1961
replace indoecd90=1 if wtfkey==557520 // Sweden 28 September 1961
replace indoecd90=1 if wtfkey==557560 // Switz.Liecht 28 September 1961
replace indoecd90=1 if wtfkey==447920 // Turkey 2 August 1961
replace indoecd90=1 if wtfkey==538260 // UK 2 May 1961
replace indoecd90=1 if wtfkey==218400 // USA 12 April 1961

* count countries with 100 or more firms 
sort wtfkey pctl
count if wtfkey~=wtfkey[_n-1] & indoecd==0
count if wtfkey~=wtfkey[_n-1] & indoecd==1
count if wtfkey~=wtfkey[_n-1] & pctlcnt==100
count if wtfkey~=wtfkey[_n-1] & pctlcnt==100 & indoecd==0
count if wtfkey~=wtfkey[_n-1] & pctlcnt==100 & indoecd==1

* Top 70 countries with more than 100 firms in world, using seven averages for groups of 10 countries at a time
preserve
keep if pctlcnt==100
gsort -totexp pctl
gen byte _dummy = ( wtfkey~=wtfkey[_n-1] )
gen int rankexp = _dummy in 1
replace rankexp = _dummy + rankexp[_n-1] if _n>1
egen _min = min(rankexp), by(wtfkey)
egen _max = max(rankexp), by(wtfkey)
qui count if _min~=_max
if `r(N)'>0  STOP
drop _dummy _min _max
label var rankexp "Dest. rank in tot. exp."
sort wtfkey pctl
by wtfkey: replace pctl = _n
gen byte groupof10 = int(rankexp/10-.1)+1
label var groupof10 "Dest. 10-country-group by rank"
compress
collapse (mean) mean_sumsales mean_goods wmean_gsales, by(pctl groupof10) fast
label var mean_sumsales "Firms' Mean Total Exports"
label var mean_goods "Mean Exporter Scope"
label var wmean_gsales "Firms' Mean Product Scale"
gen lblgoods  = "top " + string(groupof10*10-9) + "-" + string(groupof10*10) if pctl==2
gen lblgsales = "top " + string(groupof10*10-9) + "-" + string(groupof10*10) if pctl==2
replace lblgoods = "" if groupof10~=1 & groupof10~=6 & groupof10~=7
replace lblgsales = "" if groupof10~=1 & groupof10~=2 & groupof10~=7
graph twoway scatter mean_goods pctl, yaxis(1) yscale(log axis(1) range(1 10000)) ylabel(1 2 4 16 64, nogrid axis(1)) yline(1 2 4 16 64, lcolor(gs13) axis(1)) ytitle("Log Mean Number of Products", axis(1)) msymbol(smcircle_hollow) mlabel(lblgoods) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Log Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter wmean_gsales pctl, yaxis(2) yscale(log axis(2) range(1 10000)) ylabel(1 100 1000 10000, nogrid axis(2)) yline(1 100 1000 10000, lcolor(gs14) axis(2)) ytitle("Log Mean Exports/Product (US$ thsd fob)", axis(2)) msymbol(smsquare_hollow) mlabel(lblgsales)
graph export "braxpmkt/eps/`sec'-ncm8/avgscope-wgsales-pcsales-world-ingroups.eps", replace
restore

}  // close sec loop


log close
set more off
