*! version 1.0.3  21dec2007  by Marc Muendler     muendler@ucsd.edu
*! version 1.1.1  21dec2008  by Marc Muendler     muendler@ucsd.edu
*! version 1.2.1  20nov2010  by Marc Muendler     muendler@ucsd.edu
*! version 1.2.3  29jan2012  by Marc Muendler     muendler@ucsd.edu

version 8
set more off
set virtual on
clear
set mem 100m
set matsize 800
set trace off

cd "$root"

capture mkdir "braxpmkt/eps/manf-firms"
capture mkdir "braxpmkt/eps/comrc-firms"
capture mkdir "braxpmkt/tex/manf-firms"
capture mkdir "braxpmkt/tex/comrc-firms"

capture log close
log using "braxpmkt/logs/prodsales-finalize.log", replace


// RELEVANCE OF COUNTRIES FOR WORLD EXPORTS

* WTF country mapping
tempfile wdimap
use wdi* wtf* using "brazaux/conc/countries/country-table.dta", clear
drop if wdicountry==""
* Drop unused country codes in WTF data 2000
drop if wtfkey==138960 | wtfkey==447200 | wtfkey==558960 | wtfkey==582000 | wtfkey==582780 | wtfkey==688100
* Backward compatibility with country-table 2007-04-13
drop if ( wtfkey==368960 & wdikey=="ASM" ) | ( wtfkey==368960 & wdikey=="GUM" ) | ( wtfkey==450000 & wdikey=="TMP" ) | ( wtfkey== . & wdikey=="IMY" )
replace wdicountry="GERMANY" if ( wtfkey==532760 & wdikey=="DEU") 
replace wdicountry="GERMANY" if ( wtfkey==532800 & wdikey=="DEU") 
replace wdikey="" if ( wtfkey==532760 & wdikey=="DEU") 
replace wdikey="" if ( wtfkey==532800 & wdikey=="DEU") 
replace wdicountry="UNITED STATES" if ( wtfkey==368960 & wdikey=="PRI" )
replace wdikey="USA" if ( wtfkey==368960 & wdikey=="PRI" )
* Compatibility with SECEX
replace wtfkey=532760 if wtfkey==532800  // SECEX compatibility: Former West Germany reset to Germany
replace wtfcountry="Germany" if wtfkey==532760
replace wtfkey=481560 if wtfkey==481561 | wtfkey==481562  // SECEX compatibility: China FTZ and SC reset to China
replace wtfcountry="China" if wtfkey==481560
replace wtfkey=448870 if wtfkey==448860  // SECEX compatibility: Former Yemen AR reset to Yemen
replace wtfcountry="Yemen" if wtfkey==448870
replace wtfkey=582210 if wtfkey==598900 | wtfkey==598910  // SECEX compatibility: Former Yugoslavia and Yugoslavia reset to Serbia and Montenegro (E Europe NES)
replace wtfcountry="E Europe NES" if wtfkey==582210
replace wtfkey=725400 if wtfkey==166380  // SECEX compatibility: Fr Ind O reset to New Calednia
replace wtfcountry="New Calednia" if wtfkey==725400
* Remove nonunique WDI-WTF mappings
sort wdicountry wtfkey
drop if ( wdicountry==wdicountry[_n-1] | wdicountry==wdicountry[_n+1] ) & wtfcountry=="Oth.Oceania"  // Norway mapped from Norway only, not from Antarctica
drop if ( wdicountry==wdicountry[_n-1] | wdicountry==wdicountry[_n+1] ) & wtfcountry=="US NES"  // US mapped from US only, not from US NES
duplicates drop
sort wtfkey wdicountry
drop if ( wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1] ) & wdicountry==""
sort wdicountry wtfkey
drop if ( wdicountry==wdicountry[_n-1] | wdicountry==wdicountry[_n+1] ) & wtfkey==.
sort wtfkey wdicountry
list if wtfkey==wtfkey[_n-1] | wtfkey==wtfkey[_n+1]
sort wdicountry wtfkey
list if wdicountry==wdicountry[_n-1] | wdicountry==wdicountry[_n+1]
replace wtfkey=358960 if wdicountry=="ARUBA"  // backward compatibility with 2007-04-13
replace wdicountry="GUINEA-BISSEAU" if wtfkey==166240  // backward compatibility with 2007-04-13
replace wdicountry="YUGOSLAVIA, FED. REP." if wtfkey==582210  // backward compatibility with 2007-04-13
sort wdicountry wtfkey
save `wdimap'

* WDI Data (undeflated) for 2000
tempfile wdidata
use wdicountry year population gdp_usd if year==2000 using "fdilabor/countries/ext-data.dta", clear
drop year
duplicates drop  // zero observations are duplicates
sort wdicountry
joinby wdicountry using `wdimap', _merge(_merge) unmatched(both)
tab wdicountry if _m==2
drop if _m==2
drop wdi* wtfcountry
order wtfkey
sort wtfkey
qui do "braxpmkt/conc/wtfkey.do"
label values wtfkey wtfkey
drop _merge
sort wtfkey
save `wdidata'

* WTF trade flow data 2000
use icode importer ecode exporter value using "$extdata/brazaux/intl/nber/wtf00.dta", clear
drop if icode=="100000" | icode=="999990" | ecode=="100000" | ecode=="999990" // world or intl organizations
collapse (sum) value, by(ecode exporter) fast
gen wtfkey = real(ecode)
drop ecode
label var wtfkey "Six-digit WTF code"
rename exporter wtfcountry
label var wtfcountry "Country name WTF (English)"
rename value exports
label var exports "Exports from source"
replace wtfkey=481560 if wtfkey==481561 | wtfkey==481562  // SECEX compatibility: China FTZ and SC reset to China
replace wtfcountry="China" if wtfkey==481560
replace wtfkey=532760 if wtfkey==532800  // SECEX compatibility: Former West Germany reset to Germany
replace wtfcountry="Germany" if wtfkey==532760
replace wtfkey=448870 if wtfkey==448860  // SECEX compatibility: Former Yemen AR reset to Yemen
replace wtfcountry="Yemen" if wtfkey==448870
replace wtfkey=582210 if wtfkey==598900 | wtfkey==598910  // SECEX compatibility: Former Yugoslavia and Yugoslavia reset to Serbia and Montenegro (E Europe NES)
replace wtfcountry="E Europe NES" if wtfkey==582210
collapse (sum) exports, by(wtfkey wtfcountry) fast
label var exports "Exports from source"
sort wtfkey
merge wtfkey using `wdidata'
tab _m
drop _m
gen exp_pop = exports/population
label var exp_pop "Exports per capita"
gen exp_gdp = exports/gdp_usd
label var exp_gdp "Exports/GDP"
egen rank_exp=rank(exports), unique
label var rank_exp "Rank of Exports"
egen rank_exp_pop=rank(exp_pop), unique
label var rank_exp_pop "Rank of Exports per capita"
egen rank_exp_gdp=rank(exp_gdp), unique
label var rank_exp_gdp "Rank of Exports/GDP"

summ rank*
gsort -rank_exp
list wtfcountry rank_exp if wtfcountry=="Brazil"
gsort -rank_exp_pop
list wtfcountry rank_exp_pop if wtfcountry=="Brazil"
gsort -rank_exp_gdp
list wtfcountry rank_exp_gdp if wtfcountry=="Brazil"


// CODEBOOK INFORMATION ON ESTIMATION SAMPLE

foreach sec in "manf-firms" "comrc-firms" {

foreach region in "usa" "argentina" "top20th" "oecd90" "nonoecd90" "mercosur" "world" {

use firmid cnae hs6dgt isic2 wtfkey indoecd90 value using "braxpmkt/secex/prodsales-data-2000.dta", clear

* select products and firms
if "`sec'"=="allsec"      keep if 1                          // all products and firms
if "`sec'"=="manf-goods"  keep if isic2>=300 & isic2<=399    // manufacturing products
if "`sec'"=="manf-firms"  keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products
if "`sec'"=="srvc-firms"  keep if cnae>=37000 & cnae~=. & isic2>=300 & isic2<=399       // services firms and manufacturing products (firms non-agricultural, non-mining, non-manufacturing)
if "`sec'"=="comrc-firms" keep if cnae>=50000 & cnae<=52999 & isic2>=300 & isic2<=399   // retail/wholesale firms and manufacturing products
if "`sec'"=="manf-ekk"    keep if cnae>=15000 & cnae<=36999  // manufacturing firms

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina
if "`region'"=="top20th" & "`sec'"=="allsec"      keep if wtfkey==557560 // exports to Switz.Liecht
if "`region'"=="top20th" & "`sec'"=="manf-goods"  keep if wtfkey==586430 // exports to Russian Fed
if "`region'"=="top20th" & "`sec'"=="manf-firms"  keep if wtfkey==481560 // exports to China
if "`region'"=="top20th" & "`sec'"=="srvc-firms"  keep if wtfkey==368960 // exports to US NES
if "`region'"=="top20th" & "`sec'"=="comrc-firms" keep if wtfkey==211240 // exports to Canada
if "`region'"=="top20th" & "`sec'"=="manf-ekk"    keep if wtfkey==454100 // exports to Korea Rep.
if "`region'"=="top25th" & "`sec'"=="allsec"      keep if wtfkey==330680 // exports to Bolivia
if "`region'"=="top25th" & "`sec'"=="manf-goods"  keep if wtfkey==710360 // exports to Australia
if "`region'"=="top25th" & "`sec'"=="manf-firms"  keep if wtfkey==586430 // exports to Russian Fed
if "`region'"=="top25th" & "`sec'"=="srvc-firms"  keep if wtfkey==453440 // exports to China HK SAR
if "`region'"=="top25th" & "`sec'"=="comrc-firms" keep if wtfkey==352140 // exports to Dominican Rp
if "`region'"=="top25th" & "`sec'"=="manf-ekk"    keep if wtfkey==446820 // exports to Saudi Arabia

disp
disp in gr "Sector: " in ye "`sec'"
disp in gr "Region: " in ye "`region'"
disp in gr "Export values: " in ye "all"
codebook firm hs6dgt wtfkey

disp in gr "Export values: " in ye "non-zero only"
drop if value==0
codebook firm cnae hs6dgt wtfkey

collapse (sum) value, by(firmid cnae hs6dgt) fast  // collapse over destinations
collapse (sum) sumsales=value (count) goods=value, by(firmid cnae) fast  // collapse over goods
label var sumsales "Total exports (US$ mill fob)"
label var goods "Exporter scope (HS 6-digit)"
local mingoods 5
qui summ sumsales, meanonly
local firmno = `r(N)'
local totsales = `r(sum)'
qui summ sumsales, meanonly, if goods>=`mingoods'
disp in gr "Sector: " in ye "`sec'"
disp in gr "Region: " in ye "`region'"
disp in gr "Share of exporters with more than: " in ye "`mingoods'" in gr " products: " in ye `r(N)'/`firmno'
disp in gr "Share of total exports by exporters with more than: " in ye "`mingoods'" in gr " products: " in ye `r(sum)'/`totsales'

}  // close `sec' loop

}  // close `region' loop


// CONCENTRATION OF EXPORTS AT HS-8 DIGIT LEVEL

use firmid wtfkey prodctid value using "braxpmkt/secex/firms-2000-ncm8dgt.dta", clear
collapse (sum) value, by(firmid prodctid) fast
collapse (sum) wwsales=value (count) wwgoods=value, by(firmid) fast
replace wwsales = wwsales/1000000
label var wwgoods "Worldwide No. of prod. (NCM 8)"
label var wwsales "Worldwide exports (US$ mill)"
local mingoods 5
qui summ wwsales, meanonly
local firmno = `r(N)'
local totsales = `r(sum)'
qui summ wwsales, meanonly, if wwgoods>=`mingoods'
disp in gr "Share of exporters with more than: " in ye "`mingoods'" in gr " products: " in ye `r(N)'/`firmno'
disp in gr "Share of total exports by exporters with more than: " in ye "`mingoods'" in gr " products: " in ye `r(sum)'/`totsales'


// PARETO GRAPH REGRESSIONS FOR GROUP OF SIX

local sec "manf-firms"

foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top20th" {

matload cumT_`region'_tbl, p(braxpmkt/tex/`sec') over missing(.) dropall
svmat cumT_`region'_tbl
local cols = colsof(cumT_`region'_tbl)
local colnames : colnames cumT_`region'_tbl
tokenize `colnames'
forvalues i = 1/`cols' {
  rename cumT_`region'_tbl`i' ``i''
  }
gen wmean_gsales = mean_sumsales/mean_goods
gen pctl = freq*100
replace mean_gsales = mean_gsales*1000
replace wmean_gsales = wmean_gsales*1000
order count freq pctl mean_sumsales mean_goods
label var mean_goods "Mean Exporter Scope"
label var count "# of Firms with min. scope"
label var freq "Share of Firms with min. scope"
label var mean_sumsales "Firms' Mean Total Exports"
label var mean_gsales "Firms' Mean Product Scale" // (US$ thsd fob)
label var wmean_gsales "Firms' Mean Product Scale" // (US$ thsd fob)
label var pctl "Cumulative Percentile of Firms"

gen x_axis = log(100-pctl)
gen rev_x_axis = log(pctl)
gen ln_mean_goods = log(mean_goods)
gen ln_wmean_gsales = log(wmean_gsales)
label var x_axis "Log Percentile (1-Pr on x-axis)"
label var rev_x_axis "Log Percentile (as if Pr on x-axis)"
label var ln_mean_goods "Log Mean Exporter Scope"
label var ln_wmean_gsales "Log Mean Product Scale"

disp
disp in gr "Sector: " in ye "`sec'"
disp in gr "Region: " in ye "`region'"
regress ln_mean_goods rev_x_axis
disp in gr "ln_mean_goods = " in ye %9.3f _b[_cons]+ln(100)*_b[rev_x_axis] in gr " + " in ye %9.3f -_b[rev_x_axis] in gr " * rev_x_axis"
* graph twoway scatter ln_mean_goods rev_x_axis, yaxis(1) yscale(axis(1) range(0 9.2103404)) ylabel(0 "1" 1.3862944 "4" 2.7725887 "16" 5.5451774 "256" 6.9314718 "1024", nogrid axis(1)) yline(0 1.3862944 2.7725887 5.5451774, lcolor(gs13) axis(1)) ytitle("Log Mean Number of Products", axis(1)) msymbol(smcircle_hollow) xlabel(0 "1" 2.3025851 "10" 4.6051702 "100") xtitle("Log Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || lfitci ln_mean_goods rev_x_axis, clpattern(solid)
regress ln_wmean_gsales rev_x_axis
disp in gr "ln_wmean_gsales = " in ye %9.3f _b[_cons]+ln(100)*_b[rev_x_axis] in gr " + " in ye %9.3f -_b[rev_x_axis] in gr " * rev_x_axis"
* graph twoway scatter ln_wmean_gsales rev_x_axis, yaxis(1) yscale(axis(1) range(0 9.2103404)) ylabel(0 "1" 4.6051702 "100" 6.9077553 "1000" 9.2103404 "10000", nogrid axis(1)) yline(0 4.6051702 6.9077553 9.2103404, lcolor(gs13) axis(1)) ytitle("Log Mean Exports/Product (US$ thsd fob)", axis(1)) msymbol(smcircle_hollow) xlabel(0 "1" 2.3025851 "10" 4.6051702 "100") xtitle("Log Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || lfitci ln_wmean_gsales rev_x_axis, clpattern(solid)

gen rev_x_axis_sq = rev_x_axis*rev_x_axis
gen rev_x_axis_cb = rev_x_axis_sq*rev_x_axis
label var rev_x_axis "Squared Log Percentile"
label var rev_x_axis "Cubic Log Percentile"

regress ln_mean_goods rev_x_axis rev_x_axis_sq rev_x_axis_cb
est2vec lngoods_cpctl_`region', vars(rev_x_axis rev_x_axis_sq rev_x_axis_cb _cons) e(N r2) name(lngoods_cubic) replace
test rev_x_axis_sq rev_x_axis_cb
est2vec lngoods_cpctl_`region', r(F p df df_r) name(lngoods_cubic)

regress ln_mean_goods rev_x_axis rev_x_axis_sq
est2vec lngoods_cpctl_`region', addto(lngoods_cpctl_`region') name(lngoods_square)
test rev_x_axis_sq
est2vec lngoods_cpctl_`region', raddto(lngoods_cpctl_`region') name(lngoods_square)

regress ln_mean_goods rev_x_axis
est2vec lngoods_cpctl_`region', addto(lngoods_cpctl_`region') name(lngoods_ols)
est2vec lngoods_cpctl_`region', raddto(lngoods_cpctl_`region') name(lngoods_ols)

regress ln_wmean_gsales rev_x_axis rev_x_axis_sq rev_x_axis_cb
est2vec lngsales_cpctl_`region', vars(rev_x_axis rev_x_axis_sq rev_x_axis_cb _cons) e(N r2) name(lngsales_cubic) replace
test rev_x_axis_sq rev_x_axis_cb
est2vec lngsales_cpctl_`region', r(F p df df_r) name(lngsales_cubic)

regress ln_wmean_gsales rev_x_axis rev_x_axis_sq
est2vec lngsales_cpctl_`region', addto(lngsales_cpctl_`region') name(lngsales_square)
test rev_x_axis_sq
est2vec lngsales_cpctl_`region', raddto(lngsales_cpctl_`region') name(lngsales_square)

regress ln_wmean_gsales rev_x_axis
est2vec lngsales_cpctl_`region', addto(lngsales_cpctl_`region') name(lngsales_ols)
est2vec lngsales_cpctl_`region', raddto(lngsales_cpctl_`region') name(lngsales_ols)

* save results
est2tex lngoods_cpctl_`region', fancy p(braxpmkt/tex/`sec') replace level(90 95 99) mark(starse) dropall
est2tex lngsales_cpctl_`region', fancy p(braxpmkt/tex/`sec') replace level(90 95 99) mark(starse) dropall
foreach type in b se e r {
  mat drop lngoods_cpctl_`region'_`type' lngsales_cpctl_`region'_`type'
  }
mat drop cumT_`region'_tbl

}  // close `region' loop


// SUMMARY STATISTICS ON PARETO GRAPHS

local sec "manf-firms"

use "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'", clear
drop if wtfkey<10  // drop aggregate regions
sort wtfkey pctl
by wtfkey: gen byte pctlcnt = _N
label var pctlcnt "Exist. percentiles for dest."  // Less than 100 for destinations with less than 100 exporters

sort wtfkey pctl
by wtfkey: keep if _n==_N
drop pctl freq
gsort -totnum
list wtfkey if _n<=10
gsort -totexp
list wtfkey if _n<=10

* Summary of scope and scale means across countries
summ mean_goods wmean_gsales
summ mean_goods wmean_gsales if _n<=2   // top two destinations in terms of total exports
summ mean_goods wmean_gsales if _n<=20  // top 20 destinations in terms of total exports
summ mean_goods wmean_gsales if _n<=70  // top 70 destinations in terms of total exports

* Summary of regression coefficients across countries
summ bscope bscale delta if _n<=2    // top two destinations in terms of total exports
summ bscope bscale delta if _n<=20   // top 20 destinations in terms of total exports
summ bscope bscale delta if _n<=70   // top 70 destinations in terms of total exports
summ bscope bscale delta if delta~=. // all destinations with sufficient obs. for scale and scope regressions
summ bscope bscale delta if pctlcnt==100  // all destinations with more than 100 firms
summ bscope bscale delta if r2scope>=.95 & r2scale>=.95 & pctlcnt==100  // all destinations with 95% fits and more than 100 firms
summ bscope bscale delta if bscope<0 & bscale<0 & pctlcnt==100  // all destinations with negative slopes and more than 100 firms
summ bscope bscale delta [aw=totnum] if pctlcnt==100  // all destinations with more than 100 firms, weighted by firm counts
summ bscope bscale delta [aw=totexp] if pctlcnt==100  // all destinations with more than 100 firms, weighted by total exports


// PARETO GRAPHS AND REGRESSIONS ACROSS ALL COUNTRIES

foreach sec in "manf-firms" "comrc-firms" {

use "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'", clear
drop if wtfkey<10  // drop aggregate regions
sort wtfkey pctl
by wtfkey: gen byte pctlcnt = _N
label var pctlcnt "Exist. percentiles for dest."  // Less than 100 for destinations with less than 100 exporters

* OECD dummies
gen byte indoecd90=0
label var indoecd90 "Indic.: OECD member 1990"
replace indoecd90=1 if wtfkey==710360 // Australia 7 June 1971
replace indoecd90=1 if wtfkey==550400 // Austria 29 September 1961 
replace indoecd90=1 if wtfkey==530560 // Belgium-Lux 13 September 1961, 7 December 1961
replace indoecd90=1 if wtfkey==211240 // Canada 10 April 1961
replace indoecd90=1 if wtfkey==532080 // Denmark 30 May 1961
replace indoecd90=1 if wtfkey==552460 // Finland 28 January 1969
replace indoecd90=1 if wtfkey==532500 // France,Monac 7 August 1961
replace indoecd90=1 if wtfkey==532760 // Germany 27 September 1961
replace indoecd90=1 if wtfkey==533000 // Greece 27 September 1961
replace indoecd90=1 if wtfkey==553520 // Iceland 5 June 1961
replace indoecd90=1 if wtfkey==533720 // Ireland 7 August 1961
replace indoecd90=1 if wtfkey==533800 // Italy 29 March 1962
replace indoecd90=1 if wtfkey==413920 // Japan 28 April 1964
replace indoecd90=1 if wtfkey==535280 // Netherlands 13 November 1961
replace indoecd90=1 if wtfkey==715540 // New Zealand 29 May 1973
replace indoecd90=1 if wtfkey==555780 // Norway 4 July 1961
replace indoecd90=1 if wtfkey==536200 // Portugal 4 August 1961
replace indoecd90=1 if wtfkey==537240 // Spain 3 August 1961
replace indoecd90=1 if wtfkey==557520 // Sweden 28 September 1961
replace indoecd90=1 if wtfkey==557560 // Switz.Liecht 28 September 1961
replace indoecd90=1 if wtfkey==447920 // Turkey 2 August 1961
replace indoecd90=1 if wtfkey==538260 // UK 2 May 1961
replace indoecd90=1 if wtfkey==218400 // USA 12 April 1961

* count countries with 100 or more firms 
sort wtfkey pctl
count if wtfkey~=wtfkey[_n-1] & indoecd==0
count if wtfkey~=wtfkey[_n-1] & indoecd==1
count if wtfkey~=wtfkey[_n-1] & pctlcnt==100
count if wtfkey~=wtfkey[_n-1] & pctlcnt==100 & indoecd==0
count if wtfkey~=wtfkey[_n-1] & pctlcnt==100 & indoecd==1

* Top 70 countries with more than 100 firms in world, using seven averages for groups of 10 countries at a time
preserve
keep if pctlcnt==100
gsort -totexp pctl
gen byte _dummy = ( wtfkey~=wtfkey[_n-1] )
gen int rankexp = _dummy in 1
replace rankexp = _dummy + rankexp[_n-1] if _n>1
egen _min = min(rankexp), by(wtfkey)
egen _max = max(rankexp), by(wtfkey)
qui count if _min~=_max
if `r(N)'>0  STOP
drop _dummy _min _max
label var rankexp "Dest. rank in tot. exp."
sort wtfkey pctl
by wtfkey: replace pctl = _n
gen byte groupof10 = int(rankexp/10-.1)+1
label var groupof10 "Dest. 10-country-group by rank"
compress
collapse (mean) mean_sumsales mean_goods wmean_gsales, by(pctl groupof10) fast
label var mean_sumsales "Firms' Mean Total Exports"
label var mean_goods "Mean Exporter Scope"
label var wmean_gsales "Firms' Mean Product Scale"
gen lblgoods  = "top " + string(groupof10*10-9) + "-" + string(groupof10*10) if pctl==2
gen lblgsales = "top " + string(groupof10*10-9) + "-" + string(groupof10*10) if pctl==2
replace lblgoods = "" if groupof10~=1 & groupof10~=6 & groupof10~=7
replace lblgsales = "" if groupof10~=1 & groupof10~=2 & groupof10~=7
graph twoway scatter mean_goods pctl, yaxis(1) yscale(log axis(1) range(1 10000)) ylabel(1 2 4 16 64, nogrid axis(1)) yline(1 2 4 16 64, lcolor(gs13) axis(1)) ytitle("Log Mean Number of Products", axis(1)) msymbol(smcircle_hollow) mlabel(lblgoods) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Log Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter wmean_gsales pctl, yaxis(2) yscale(log axis(2) range(1 10000)) ylabel(1 100 1000 10000, nogrid axis(2)) yline(1 100 1000 10000, lcolor(gs14) axis(2)) ytitle("Log Mean Exports/Product (US$ thsd fob)", axis(2)) msymbol(smsquare_hollow) mlabel(lblgsales)
graph export "braxpmkt/eps/`sec'/avgscope-wgsales-pcsales-world-ingroups.eps", replace
restore

* Top 49 countries with more than 100 firms in non-OECD, using five averages for groups of 10 countries at a time
preserve
keep if indoecd90==0 & pctlcnt==100
gsort -totexp pctl
gen byte _dummy = ( wtfkey~=wtfkey[_n-1] )
gen int rankexp = _dummy in 1
replace rankexp = _dummy + rankexp[_n-1] if _n>1
egen _min = min(rankexp), by(wtfkey)
egen _max = max(rankexp), by(wtfkey)
qui count if _min~=_max
if `r(N)'>0  STOP
drop _dummy _min _max
label var rankexp "Dest. rank in tot. exp."
sort wtfkey pctl
by wtfkey: replace pctl = _n
gen byte groupof10 = int(rankexp/10-.1)+1
label var groupof10 "Dest. 10-country-group by rank"
compress
collapse (mean) mean_sumsales mean_goods wmean_gsales, by(pctl groupof10) fast
label var mean_sumsales "Firms' Mean Total Exports"
label var mean_goods "Mean Exporter Scope"
label var wmean_gsales "Firms' Mean Product Scale"
gen lblgoods  = "top " + string(groupof10*10-9) + "-" + string(groupof10*10) if pctl==2
gen lblgsales = "top " + string(groupof10*10-9) + "-" + string(groupof10*10) if pctl==2
replace lblgoods = "" if groupof10~=1 & groupof10~=2 & groupof10~=4
replace lblgsales = "" if groupof10~=1 & groupof10~=2 & groupof10~=3 & groupof10~=4
graph twoway scatter mean_goods pctl, yaxis(1) yscale(log axis(1) range(1 10000)) ylabel(1 2 4 16 64, nogrid axis(1)) yline(1 2 4 16 64, lcolor(gs13) axis(1)) ytitle("Log Mean Number of Products", axis(1)) msymbol(smcircle_hollow) mlabel(lblgoods) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Log Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter wmean_gsales pctl, yaxis(2) yscale(log axis(2) range(1 10000)) ylabel(1 100 1000 10000, nogrid axis(2)) yline(1 100 1000 10000, lcolor(gs14) axis(2)) ytitle("Log Mean Exports/Product (US$ thsd fob)", axis(2)) msymbol(smsquare_hollow) mlabel(lblgsales)
graph export "braxpmkt/eps/`sec'/avgscope-wgsales-pcsales-nonoecd90-ingroups.eps", replace
restore

* Top 20 countries with more than 100 firms in OECD, using five averages for groups of 10 countries at a time
preserve
keep if indoecd90==1 & pctlcnt==100
gsort -totexp pctl
gen byte _dummy = ( wtfkey~=wtfkey[_n-1] )
gen int rankexp = _dummy in 1
replace rankexp = _dummy + rankexp[_n-1] if _n>1
egen _min = min(rankexp), by(wtfkey)
egen _max = max(rankexp), by(wtfkey)
qui count if _min~=_max
if `r(N)'>0  STOP
drop _dummy _min _max
label var rankexp "Dest. rank in tot. exp."
sort wtfkey pctl
by wtfkey: replace pctl = _n
gen byte groupof10 = int(rankexp/10-.1)+1
label var groupof10 "Dest. 10-country-group by rank"
drop if rank>20
compress
collapse (mean) mean_sumsales mean_goods wmean_gsales, by(pctl groupof10) fast
label var mean_sumsales "Firms' Mean Total Exports"
label var mean_goods "Mean Exporter Scope"
label var wmean_gsales "Firms' Mean Product Scale"
gen lblgoods  = "top " + string(groupof10*10-9) + "-" + string(groupof10*10) if pctl==2
gen lblgsales = "top " + string(groupof10*10-9) + "-" + string(groupof10*10) if pctl==2
graph twoway scatter mean_goods pctl, yaxis(1) yscale(log axis(1) range(1 10000)) ylabel(1 2 4 16 64, nogrid axis(1)) yline(1 2 4 16 64, lcolor(gs13) axis(1)) ytitle("Log Mean Number of Products", axis(1)) msymbol(smcircle_hollow) mlabel(lblgoods) xscale(log reverse) xlabel(.1 1 10 100) xtitle("Log Firm Percentiles in Total Exports from the Top") graphregion(color(white)) scheme(sj) || scatter wmean_gsales pctl, yaxis(2) yscale(log axis(2) range(1 10000)) ylabel(1 100 1000 10000, nogrid axis(2)) yline(1 100 1000 10000, lcolor(gs14) axis(2)) ytitle("Log Mean Exports/Product (US$ thsd fob)", axis(2)) msymbol(smsquare_hollow) mlabel(lblgsales)
graph export "braxpmkt/eps/`sec'/avgscope-wgsales-pcsales-oecd90-ingroups.eps", replace
restore

}  // close `sec' loop


// PARETO-GRAPH RELATED OVERALL REGRESSIONS

local sec "manf-firms"

foreach region in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top20th" {
local bscope ""
local bscale ""
local delta ""

use "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'", clear
drop if wtfkey<10  // drop aggregate regions
sort wtfkey pctl
by wtfkey: gen byte pctlcnt = _N
label var pctlcnt "Exist. percentiles for dest."  // Less than 100 for destinations with less than 100 exporters

// OECD dummies
gen byte indoecd90=0
label var indoecd90 "Indic.: OECD member 1990"
replace indoecd90=1 if wtfkey==710360 // Australia 7 June 1971
replace indoecd90=1 if wtfkey==550400 // Austria 29 September 1961 
replace indoecd90=1 if wtfkey==530560 // Belgium-Lux 13 September 1961, 7 December 1961
replace indoecd90=1 if wtfkey==211240 // Canada 10 April 1961
replace indoecd90=1 if wtfkey==532080 // Denmark 30 May 1961
replace indoecd90=1 if wtfkey==552460 // Finland 28 January 1969
replace indoecd90=1 if wtfkey==532500 // France,Monac 7 August 1961
replace indoecd90=1 if wtfkey==532760 // Germany 27 September 1961
replace indoecd90=1 if wtfkey==533000 // Greece 27 September 1961
replace indoecd90=1 if wtfkey==553520 // Iceland 5 June 1961
replace indoecd90=1 if wtfkey==533720 // Ireland 7 August 1961
replace indoecd90=1 if wtfkey==533800 // Italy 29 March 1962
replace indoecd90=1 if wtfkey==413920 // Japan 28 April 1964
replace indoecd90=1 if wtfkey==535280 // Netherlands 13 November 1961
replace indoecd90=1 if wtfkey==715540 // New Zealand 29 May 1973
replace indoecd90=1 if wtfkey==555780 // Norway 4 July 1961
replace indoecd90=1 if wtfkey==536200 // Portugal 4 August 1961
replace indoecd90=1 if wtfkey==537240 // Spain 3 August 1961
replace indoecd90=1 if wtfkey==557520 // Sweden 28 September 1961
replace indoecd90=1 if wtfkey==557560 // Switz.Liecht 28 September 1961
replace indoecd90=1 if wtfkey==447920 // Turkey 2 August 1961
replace indoecd90=1 if wtfkey==538260 // UK 2 May 1961
replace indoecd90=1 if wtfkey==218400 // USA 12 April 1961

* select destinations
if "`region'"=="world"     keep if wtfkey~=0     // worldwide exports (keep individual destinations)
if "`region'"=="mercosur"  keep if wtfkey==330320 | wtfkey==336000 | wtfkey==338580  // Argentina, Paraguay, Uruguay; 1990
if "`region'"=="oecd90"    keep if indoecd90==1  // exports to group of 1990-OECD members
if "`region'"=="nonoecd90" keep if indoecd90==0  // exports to group of 1990-OECD non-members
if "`region'"=="usa"       keep if wtfkey==218400  // exports to USA
if "`region'"=="argentina" keep if wtfkey==330320  // exports to Argentina
if "`region'"=="top20th" & "`sec'"=="allsec"     keep if wtfkey==557560  // exports to Switz.Liecht
if "`region'"=="top20th" & "`sec'"=="manf-goods" keep if wtfkey==586430  // exports to Russian Fed
if "`region'"=="top20th" & "`sec'"=="manf-firms" keep if wtfkey==481560  // exports to China
if "`region'"=="top20th" & "`sec'"=="manf-ekk"   keep if wtfkey==454100  // exports to Korea Rep.
if "`region'"=="top25th" & "`sec'"=="allsec"     keep if wtfkey==330680  // exports to Bolivia
if "`region'"=="top25th" & "`sec'"=="manf-goods" keep if wtfkey==710360  // exports to Australia
if "`region'"=="top25th" & "`sec'"=="manf-firms" keep if wtfkey==586430  // exports to Russian Fed
if "`region'"=="top25th" & "`sec'"=="manf-ekk"   keep if wtfkey==446820  // exports to Saudi Arabia

keep if pctlcnt == 100  // keep only 70 destinations with at least 100 firms
drop pctl
gen pctl = freq*100
label var pctl "Cumulative Percentile of Firms"
sort wtfkey pctl
by wtfkey: gen _icpt_goods = mean_goods if _n==1
by wtfkey: gen _icpt_gsales = wmean_gsales if _n==1
egen icpt_goods = min(_icpt_goods), by(wtfkey)
egen icpt_gsales = min(_icpt_gsales), by(wtfkey)
label var icpt_goods "Exp. Scope at Intrcpt. 1st pctl."
label var icpt_gsales "Prd. Scale at Intrcpt. 1st pctl."
drop _icpt*
gen rev_x_axis = log(pctl)
label var rev_x_axis "Log Percentile (as if Pr on x-axis)"
* gen ln_mean_goods = log(mean_goods/icpt_goods)
* gen ln_wmean_gsales = log(wmean_gsales/icpt_gsales)
* label var ln_mean_goods "Log Mean Exporter Scope (ls. Intcpt.)"
* label var ln_wmean_gsales "Log Mean Product Scale (ls. Intcpt.)"
gen ln_mean_goods = log(mean_goods)
gen ln_wmean_gsales = log(wmean_gsales)
label var ln_mean_goods "Log Mean Exporter Scope"
label var ln_wmean_gsales "Log Mean Product Scale"
keep wtfkey pctl rev_x_axis ln_mean_goods ln_wmean_gsales totnum totexp

gen rev_x_axis_sq = rev_x_axis*rev_x_axis
gen rev_x_axis_cb = rev_x_axis_sq*rev_x_axis
label var rev_x_axis "Squared Log Percentile"
label var rev_x_axis "Cubic Log Percentile"

gen byte equal = 1
disp
disp in gr "Sector: " in ye "`sec'"
disp in gr "Region: " in ye "`region'"
capture qui xtreg ln_mean_goods rev_x_axis, fe i(wtfkey)
if _rc==0  local bscope = _b[rev_x_axis]
capture qui xtreg ln_wmean_gsales rev_x_axis, fe i(wtfkey)
if _rc==0  local bscale = _b[rev_x_axis]
if _rc==0  local delta = 1 + `bscale'/`bscope'
disp in gr "Delta under " in ye "Dest. FE" in gr " (no weights): " in ye %9.3f `delta'
foreach weight in equal totnum totexp {
  qui regress ln_mean_goods rev_x_axis [aw=`weight']
  local bscope = _b[rev_x_axis]
  qui regress ln_wmean_gsales rev_x_axis [aw=`weight']
  local bscale = _b[rev_x_axis]
  local delta = 1 + `bscale'/`bscope'
  disp in gr "Delta under " in ye "`weight'" in gr " weights: " in ye %9.3f `delta'
  }
drop equal

regress ln_mean_goods rev_x_axis rev_x_axis_sq rev_x_axis_cb [aw=totexp]
est2vec lngoods_wcpctl_`region', vars(rev_x_axis rev_x_axis_sq rev_x_axis_cb _cons) e(N r2) name(lngoods_cubic) replace
test rev_x_axis_sq rev_x_axis_cb
est2vec lngoods_wcpctl_`region', r(F p df df_r) name(lngoods_cubic)

regress ln_mean_goods rev_x_axis rev_x_axis_sq [aw=totexp]
est2vec lngoods_wcpctl_`region', addto(lngoods_wcpctl_`region') name(lngoods_square)
test rev_x_axis_sq
est2vec lngoods_wcpctl_`region', raddto(lngoods_wcpctl_`region') name(lngoods_square)

regress ln_mean_goods rev_x_axis [aw=totexp]
est2vec lngoods_wcpctl_`region', addto(lngoods_wcpctl_`region') name(lngoods_ols)
est2vec lngoods_wcpctl_`region', raddto(lngoods_wcpctl_`region') name(lngoods_ols)

regress ln_wmean_gsales rev_x_axis rev_x_axis_sq rev_x_axis_cb [aw=totexp]
est2vec lngsales_wcpctl_`region', vars(rev_x_axis rev_x_axis_sq rev_x_axis_cb _cons) e(N r2) name(lngsales_cubic) replace
test rev_x_axis_sq rev_x_axis_cb
est2vec lngsales_wcpctl_`region', r(F p df df_r) name(lngsales_cubic)

regress ln_wmean_gsales rev_x_axis rev_x_axis_sq [aw=totexp]
est2vec lngsales_wcpctl_`region', addto(lngsales_wcpctl_`region') name(lngsales_square)
test rev_x_axis_sq
est2vec lngsales_wcpctl_`region', raddto(lngsales_wcpctl_`region') name(lngsales_square)

regress ln_wmean_gsales rev_x_axis [aw=totexp]
est2vec lngsales_wcpctl_`region', addto(lngsales_wcpctl_`region') name(lngsales_ols)
est2vec lngsales_wcpctl_`region', raddto(lngsales_wcpctl_`region') name(lngsales_ols)

* save results
est2tex lngoods_wcpctl_`region', fancy p(braxpmkt/tex/`sec') replace level(90 95 99) mark(starse) dropall
est2tex lngsales_wcpctl_`region', fancy p(braxpmkt/tex/`sec') replace level(90 95 99) mark(starse) dropall
foreach type in b se e r {
  mat drop lngoods_wcpctl_`region'_`type' lngsales_wcpctl_`region'_`type'
  }

}  // close `region' loop


log close
set more off
