*! version 1.1  27sep2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.2  21nov2010  by Marc Muendler  muendler@ucsd.edu
*! version 1.3  20jul2011  by Marc Muendler  muendler@ucsd.edu

version 9.2
clear
set logtype text
set more off
set matsize 200
set mem 500m

capture log close
log using "braxpmkt/logs/simulation-tex-eps.log", replace

tempfile simrslt
* insheet using "braxpmkt/matlab/workbook2.csv", comma names clear
* keep hightheta v5 lowtheta v12 v13 v18 v23
* rename hightheta country
* label var country "Country (AM10)"
* rename v5 decl_all25_hit
* rename lowtheta decl_1st25_hit
* rename v12 decl_all25_lot
* rename v13 decl_1st25_lot
* rename v18 decl_tau10_lot
* rename v23 decl_tau10_hit
* foreach var of varlist decl_tau10_lot decl_tau10_hit {
*   gen _`var' = real(`var')
*   drop `var'
*   rename _`var' `var'
*   }
insheet using "braxpmkt/matlab/workbook3.csv", comma names clear
keep hightheta v5 lowtheta v12 v13 iceebergtradecostshightheta v23
rename hightheta country
label var country "Country (AM10)"
rename v5 decl_all25_hit
rename lowtheta decl_1st25_hit
rename v12 decl_all25_lot
rename v13 decl_1st25_lot
rename iceebergtradecostshightheta decl_tau10_lot
rename v23 decl_tau10_hit
foreach var of varlist decl_tau10_lot decl_tau10_hit {
  gen _`var' = real(`var')
  drop `var'
  rename _`var' `var'
  }
label var decl_all25_lot "25% drop: All Fxd Cost (theta=4)"
label var decl_1st25_lot "25% drop: 1st Fxd Cost (theta=4)"
label var decl_all25_hit "25% drop: All Fxd Cost (theta=8)"
label var decl_1st25_hit "25% drop: 1st Fxd Cost (theta=8)"
label var decl_tau10_lot "10% drop: Varable Cost (theta=4)"
label var decl_tau10_hit "10% drop: Varable Cost (theta=8)"
drop if country==""
preserve
  tempfile mean
  collapse (mean) decl_all25* decl_1st25* decl_tau10*, fast
  gen str12 country = "_WorldAvg"
  order country
  save `mean'
restore
append using `mean'
rename country _country
encode _country, gen(country) label(am10)
drop _country
drop if country==. & decl_all25_hit==. & decl_1st25_hit==. & decl_all25_lot==. & decl_1st25_lot==. & decl_tau10_lot==. & decl_tau10_hit==.
order country
sort country
save `simrslt'


*** TABLES ***

* prepare table for high theta
use country decl_1st25_hit decl_1st25_lot decl_all25_hit decl_all25_lot using `simrslt'
order country decl_1st25_hit decl_all25_hit decl_1st25_lot decl_all25_lot
rename country am10
qui label save am10 using "braxpmkt/tex/am10", replace
foreach var in decl_1st25_hit decl_1st25_lot decl_all25_hit decl_all25_lot {
  replace `var' = (`var' - 1)*100  // use percentage change
  }
count
local splthlf1 = int(`r(N)'/2)  // first column shorter if odd number of countries
local splthlf2 = `splthlf1' + 1
preserve 
  keep in 1/`splthlf1'
  save "braxpmkt/tex/simul25_tbl", replace
  matload simul25_tbl, p(braxpmkt/tex) missing(.) dropall rowname(am10)
  mat simul25_col1 = simul25_tbl
  mat colnames simul25_col1 = decl_1st25_hit_1 decl_all25_hit_1 decl_1st25_lot_1 decl_all25_lot_1
  mat drop simul25_tbl
restore, preserve
  keep in `splthlf2'/L
  save "braxpmkt/tex/simul25_tbl", replace
  matload simul25_tbl, p(braxpmkt/tex) missing(.) dropall rowname(am10)
  mat simul25_col2 = simul25_tbl
  mat colnames simul25_col2 = decl_1st25_hit_2 decl_all25_hit_2 decl_1st25_lot_2 decl_all25_lot_2
  mat drop simul25_tbl
restore
* write out left panel
mat rename simul25_col1 simul25_tbl
est2tex simul25, replace dropall ready vallabel(am10) p(braxpmkt/tex) fancy digits(2)
mat rename simul25_tbl simul25_col1
preserve
* write out right panel
mat rename simul25_col2 simul25_tbl
est2tex simul25, replace dropall preserve ready vallabel(am10) p(braxpmkt/tex) fancy digits(2)
mat rename simul25_tbl simul25_col2
restore
rename _rowname country_1
merge using "braxpmkt/tex/simul25_tbl"
rename _rowname country_2
drop _m
qui do "braxpmkt/tex/am10.do"
foreach pnl in 1 2 {
  gen _country_`pnl' = real(country_`pnl')
  label values _country_`pnl' am10
  drop country_`pnl'
  decode _country_`pnl', generate(country_`pnl')
  drop _country_`pnl'
  }
order country_1 decl_1st25_hit_1 decl_all25_hit_1 decl_1st25_lot_1 decl_all25_lot_1 country_2 decl_1st25_hit_2 decl_all25_hit_2 decl_1st25_lot_2 decl_all25_lot_2
save "braxpmkt/tex/simul25_tbl", replace

* make TeX table (from est2tex.ado)
local precision = 10^(-2)
local digits = length(string(`precision'))-1
local addzeros = "`addzeros'" + "0"
local incr = "r"
local explic = "l"
local extracols "2 4 7"
local toknum 0
if "`extracols'" ~= "" {
  tokenize "`extracols'"
  local toknum : word count `extracols'
  forvalues i = 1/`toknum' {
    confirm integer number ``i''
    }
  }
rename country_1 _rowname
qui replace _rowname = subinstr(_rowname,"_","-",length(_rowname))
unab colname : *
local remlst "_rowname country_2"
local mainlst : list colname - remlst
local remlst "_rowname"
local colname : list colname - remlst
tokenize "`mainlst'"
local colmax :  word count `mainlst'
forvalues vari = 1/`colmax' {
  local strlen = `digits' + 1
  qui gen str`strlen' s_``vari'' = ""
  qui replace ``vari'' = sign(``vari'') * int( (1/`precision') * abs(``vari'') + .5) * `precision'       if ``vari''~=. & abs(``vari'') >= `precision'
  qui replace ``vari'' = sign(``vari'') * int( (10/`precision') * abs(``vari'') + .5) * `precision'/10   if ``vari''~=. & abs(``vari'') < `precision' & abs(``vari'') >=`precision'/10
  qui replace s_``vari'' = "" if ``vari''==.
  qui replace s_``vari'' = string(``vari'') if ``vari''~=.
  qui replace s_``vari'' = string(``vari'') + "00000" if ( ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 5 & index(s_``vari'',".")~=0 ) | ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 5 & length(s_``vari'')>1 & substr(s_``vari'',1,1)=="." ) ) & substr(_rowname,1,2)~="e(" & substr(_rowname,1,2)~="r("
  qui replace s_``vari'' = string(``vari'') + "0000" if ( ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 4 & index(s_``vari'',".")~=0 ) | ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 4 & length(s_``vari'')>1 & substr(s_``vari'',1,1)=="." ) ) & substr(_rowname,1,2)~="e(" & substr(_rowname,1,2)~="r("
  qui replace s_``vari'' = string(``vari'') + "000" if ( ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 3 & index(s_``vari'',".")~=0 ) | ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 3 & length(s_``vari'')>1 & substr(s_``vari'',1,1)=="." ) ) & substr(_rowname,1,2)~="e(" & substr(_rowname,1,2)~="r("
  qui replace s_``vari'' = string(``vari'') + "00" if ( ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 2 & index(s_``vari'',".")~=0 ) | ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 2 & length(s_``vari'')>1 & substr(s_``vari'',1,1)=="." ) ) & substr(_rowname,1,2)~="e(" & substr(_rowname,1,2)~="r("
  qui replace s_``vari'' = string(``vari'') + "0" if ( ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 1 & index(s_``vari'',".")~=0 ) | ( ( length(s_``vari'') - index(s_``vari'',".") ) == `digits' - 1 & length(s_``vari'')>1 & substr(s_``vari'',1,1)=="." ) ) & substr(_rowname,1,2)~="e(" & substr(_rowname,1,2)~="r("
  qui count if index(string(``vari''),".")~=0
  if `r(N)'>0 {
    qui replace s_``vari'' = string(``vari'') + ".`addzeros'" if index(s_``vari'',".")==0 & ``vari''~=. & substr(_rowname,1,2)~="e(" & substr(_rowname,1,2)~="r(" & substr(_rowname,-4,2)~="e(" & substr(_rowname,-4,2)~="r(" & `digits'~=0
    qui replace s_``vari'' = substr(s_``vari'',2,length(s_``vari'')) if substr(s_``vari'',1,2)=="0." 
    }
  }
rename country_2 s_country_2
keep _rowname s_*
order _rowname s_*_1 s_*_2
disp "`colname'"
tokenize `colname'
local colmax : word count `colname'
replace _rowname = _rowname + " &"
forvalues vari = 1/`colmax' {
  qui replace s_``vari'' = subinstr(s_``vari'',"_","-",length(s_``vari''))
  if `vari' < `colmax'   qui replace s_``vari'' = s_``vari'' + " &"
  if `vari' == `colmax'  qui replace s_``vari'' = s_``vari'' + " \" + "\" if _n < _N
  local explic = "`explic'" + "`incr'"
  }
foreach vari in `extracols' {
  if `vari' < `colmax'  qui replace s_``vari'' = s_``vari'' + "&"
  local explic = "`explic'" + "`incr'"
  }
local fancy "fancy"
    if "`fancy'" == "fancy" & "`plain'"=="" {
        qui gen int _line = _n
        order _line
        qui expand 6 in 1
        quietly summ _line
        qui expand 3 if _line==`r(max)'
        sort _line
        qui drop _line
        qui replace _rowname = "\begin{tabular*}{\textwidth}{@{\extracolsep{\fill}}`explic'}" if _n == 1
        qui replace _rowname = "" if _n == 2
        local vardsp = subinstr("`1'","_","-",length("`1'"))
        if "`collabels'"~="" & "`labl1'"~=""  local vardsp = "`labl1'"
        qui replace s_`1' = "& \multicolumn{1}{`incr'}{`vardsp'} &" if _n == 2
        local coltabl = `colmax' + 1 + `toknum'
        qui replace _rowname = "\cline{2-`coltabl'}" if _n == 3
        qui replace _rowname = "" if _n == 4
        qui replace s_`1' = "& \multicolumn{1}{`incr'}{(1)\mbox{\ }} &" if _n == 4
        qui replace _rowname = "\hline\"+"\"+"[-10pt]" if _n == 5
        forvalues vari = 1/`colmax' {
            qui replace s_``vari'' = "" if _n == 1
            qui replace s_``vari'' = "" if _n == 3
            qui replace s_``vari'' = "" if _n == 5
            if `vari'>1 & `vari'<`colmax' {
                local vardsp = subinstr("``vari''","_","-",length("``vari''"))
                if "`collabels'"~="" & "`labl`vari''"~=""  local vardsp = "`labl`vari''"
                qui replace s_``vari'' = "\multicolumn{1}{`incr'}{`vardsp'} &" if _n == 2
                qui replace s_``vari'' = "\multicolumn{1}{`incr'}{(`vari')\mbox{\ }} &" if _n == 4
                }
            qui replace s_``vari'' = "" if _n == _N-1
            qui replace s_``vari'' = "" if _n == _N
        }
        local vardsp = subinstr("``colmax''","_","-",length("``colmax''"))
        if "`collabels'"~="" & "`labl`colmax''"~=""  local vardsp = "`labl`colmax''"
        qui replace s_``colmax'' = "\multicolumn{1}{`incr'}{`vardsp'} \" + "\" if _n == 2
        qui replace s_``colmax'' = "\multicolumn{1}{`incr'}{(`colmax')} \" + "\" if _n == 4
        qui replace s_``colmax'' = s_``colmax'' + " \" + "\" if _n == _N-2
        qui replace _rowname = " ["+"2pt"+"]"+"\hline\hline" if _n == _N-1
        qui replace _rowname = "\end{tabular*}%" if _n == _N
        foreach vari in `extracols' {
            if `vari' < `colmax'  {
              qui replace s_``vari'' = s_``vari'' + "&" if _n == 2
              qui replace s_``vari'' = s_``vari'' + "&" if _n == 4
              }
        }
    }
outsheet using "braxpmkt/tex/simul25.tex", noquote nonames replace

log close
