*! version 1.0.1  30apr2011  by Marc Muendler  muendler@ucsd.edu
*! version 1.0.2  23jul2011  by Marc Muendler  muendler@ucsd.edu
*! version 1.1.2  31jul2011  by Marc Muendler  muendler@ucsd.edu

version 9.2
clear
set logtype text
set more off
set matsize 200
set mem 500m

capture log close
log using "braxpmkt/logs/thetatilda.log", replace


/* COUNTRY DATA */

* national accounts
tempfile natacc
use "braxpmkt/ext/country-data-2000.dta", clear
foreach var of varlist gdp_usd gdp_cap_usd consum_expend_usd hh_consum_expend_usd {
  local lbl : variable label `var'
  replace `var' = `var'/1000
  local lbl = subinstr("`lbl'","[curr. USD]","(US$ thsd)",.)
  label var `var' "`lbl'"
  }
sort wtfkey
save `natacc'

* absorption
tempfile tabsorp
use wtfkey tabsorp using "braxpmkt/secex/replication-data-2000.dta", clear
duplicates drop
replace tabsorp = tabsorp/1000
label var tabsorp "Manuf. absorption (US$ thsd)"
sort wtfkey
save `tabsorp'

* final WTF file with distance
tempfile wtffile
use `natacc', clear
merge wtfkey using `tabsorp'
tab _m
drop _m 
sort wtfkey
merge wtfkey using "braxpmkt/ext/distance-data.dta"
tab _m
drop _m 
sort wtfkey
save `wtffile'


/* THETA TILDA ESTIMATES */

use "braxpmkt/secex/avgscope-wgsales-pcsales-manf-firms.dta", clear
gen ln_mean_sumsales = log(mean_sumsales)
gen rev_x_axis = log(pctl)
gen ln_mean_goods = log(mean_goods)
label var ln_mean_sumsales "Log Mean Total Exports" // (log US$ thsd fob)
label var rev_x_axis "Log Percentile (Pr on x-axis)"
label var ln_mean_goods "Log Mean Exporter Scope"

* Individual regressions World as whole

regress ln_mean_sumsales rev_x_axis if wtfkey==0  // world total
disp 1/_b[rev_x_axis]  // thetatilda
regress ln_mean_sumsales rev_x_axis if wtfkey==0 & pctl>50  // world total, upper 50 percent of firms
disp 1/_b[rev_x_axis]  // thetatilda
regress ln_mean_sumsales rev_x_axis if wtfkey==0 & pctl>90  // world total, upper 10 percent of firms
disp 1/_b[rev_x_axis]  // thetatilda
regress ln_mean_sumsales rev_x_axis if wtfkey==0 & pctl>95  // world total, upper 5 percent of firms
disp 1/_b[rev_x_axis]  // thetatilda

* Individual regressions Pooled country sample, OLS

reg ln_mean_sumsales rev_x_axis if wtfkey>=100000 & totnum>=100 // countries with at least 100 firms (wtfkey 0 1 2 3 are aggregates)
disp 1/_b[rev_x_axis]  // thetatilda
reg ln_mean_sumsales rev_x_axis if wtfkey>=100000 & totnum>=100 & pctl>50 // countries with at least 100 firms, upper 50 percent of firms (wtfkey 0 1 2 3 are aggregates)
disp 1/_b[rev_x_axis]  // thetatilda
reg ln_mean_sumsales rev_x_axis if wtfkey>=100000 & totnum>=100 & pctl>90 // countries with at least 100 firms, upper 10 percent of firms (wtfkey 0 1 2 3 are aggregates)
disp 1/_b[rev_x_axis]  // thetatilda
reg ln_mean_sumsales rev_x_axis if wtfkey>=100000 & totnum>=100 & pctl>95 // countries with at least 100 firms, upper 5 percent of firms (wtfkey 0 1 2 3 are aggregates)
disp 1/_b[rev_x_axis]  // thetatilda

* Individual regressions Pooled country sample, random-coefficients model

xtrc ln_mean_sumsales rev_x_axis if wtfkey>=100000 & totnum>=100, i(wtfkey) // countries with at least 100 firms (wtfkey 0 1 2 3 are aggregates)
disp 1/_b[rev_x_axis]  // thetatilda
xtrc ln_mean_sumsales rev_x_axis if wtfkey>=100000 & totnum>=100 & pctl>50, i(wtfkey) // countries with at least 100 firms, upper 50 percent of firms (wtfkey 0 1 2 3 are aggregates)
disp 1/_b[rev_x_axis]  // thetatilda
xtrc ln_mean_sumsales rev_x_axis if wtfkey>=100000 & totnum>=100 & pctl>90, i(wtfkey) // countries with at least 100 firms, upper 10 percent of firms (wtfkey 0 1 2 3 are aggregates)
disp 1/_b[rev_x_axis]  // thetatilda
xtrc ln_mean_sumsales rev_x_axis if wtfkey>=100000 & totnum>=100 & pctl>95, i(wtfkey) // countries with at least 100 firms, upper 5 percent of firms (wtfkey 0 1 2 3 are aggregates)
disp 1/_b[rev_x_axis]  // thetatilda

* Average slope coefficient of "log of mean" OLS regressions, unconditional
keep if totnum>=100 & wtfkey>=100000
sort wtfkey
count if wtfkey~=wtfkey[_n-1]
local cntrynum = `r(N)'
mat thetatilda = J(`cntrynum',4,.)
mat colnames thetatilda = 0 50 90 95
gen int cntrynum = int((_n-1)/100) + 1
local rownames = ""
forvalues i = 1/`cntrynum' {
  qui summ wtfkey if cntrynum==`i', meanonly
  local cntry = `r(mean)'
  local lbladd : label wtfkey `cntry'
  local lbladd = lower(subinstr(subinstr(subinstr(subinstr("`lbladd'",":","",.)," ","",.),".","",.),",","",.))
  local rownames "`rownames' `lbladd'"
  foreach col in 0 50 90 95 {
    qui regress ln_mean_sumsales rev_x_axis if cntrynum==`i' & pctl>`col'
    mat thetatilda[`i',colnumb(thetatilda,"`col'")] = 1/_b[rev_x_axis]
    }
  }
mat rownames thetatilda = `rownames'
mat thetatildamean = J(`cntrynum',1,1)' * thetatilda /`cntrynum'
mat rownames thetatildamean = r(mean)
* mat list thetatilda
* mat list thetatildamean
mat thetatilda = thetatilda \ thetatildamean
mat drop thetatildamean
mat list thetatilda

* Average slope coefficient of "mean of log" OLS regressions, unconditional
keep if totnum>=100 & wtfkey>=100000
sort wtfkey
count if wtfkey~=wtfkey[_n-1]
local cntrynum = `r(N)'
mat thetatilda_u = J(`cntrynum',4,.)
mat colnames thetatilda_u = 0 50 90 95
local rownames = ""
forvalues i = 1/`cntrynum' {
  qui summ wtfkey if cntrynum==`i', meanonly
  local cntry = `r(mean)'
  local lbladd : label wtfkey `cntry'
  local lbladd = lower(subinstr(subinstr(subinstr(subinstr("`lbladd'",":","",.)," ","",.),".","",.),",","",.))
  local rownames "`rownames' `lbladd'"
  foreach col in 0 50 90 95 {
    qui reg mean_lnsumsales rev_x_axis if cntrynum==`i' & pctl>`col'
    mat thetatilda_u[`i',colnumb(thetatilda_u,"`col'")] = 1/_b[rev_x_axis]
    }
  }
mat rownames thetatilda_u = `rownames'
mat thetatildamean_u = J(`cntrynum',1,1)' * thetatilda_u /`cntrynum'
mat rownames thetatildamean_u = r(mean)
* mat list thetatilda_u
* mat list thetatildamean_u
mat thetatilda_u = thetatilda_u \ thetatildamean_u
mat drop thetatildamean_u
mat list thetatilda_u

* Average slope coefficient of "mean of log" OLS regressions, conditional on average H(G)^(-(sigma-1))
keep if totnum>=100 & wtfkey>=100000
sort wtfkey
count if wtfkey~=wtfkey[_n-1]
local cntrynum = `r(N)'
mat thetatilda_g = J(`cntrynum',4,.)
mat colnames thetatilda_g = 0 50 90 95
local rownames = ""
forvalues i = 1/`cntrynum' {
  qui summ wtfkey if cntrynum==`i', meanonly
  local cntry = `r(mean)'
  local lbladd : label wtfkey `cntry'
  local lbladd = lower(subinstr(subinstr(subinstr(subinstr("`lbladd'",":","",.)," ","",.),".","",.),",","",.))
  local rownames "`rownames' `lbladd'"
  foreach col in 0 50 90 95 {
    qui reg mean_lnsumsales rev_x_axis mean_lncaphsig if cntrynum==`i' & pctl>`col'
    mat thetatilda_g[`i',colnumb(thetatilda_g,"`col'")] = 1/_b[rev_x_axis]
    }
  }
mat rownames thetatilda_g = `rownames'
mat thetatildamean_g = J(`cntrynum',1,1)' * thetatilda_g /`cntrynum'
mat rownames thetatildamean_g = r(mean)
* mat list thetatilda_g
* mat list thetatildamean_g
mat thetatilda_g = thetatilda_g \ thetatildamean_g
mat drop thetatildamean_g
mat list thetatilda_g


/* F-BAR ESTIMATES FROM T-BAR */

* Tabulation of Mean Sales by Destination (similar to %03/prodsales-avgscope-wgsales-pcsales-bycountry.do)

local thetatilda = 1.21
local sigma_1 = 7.61
local sigma_2 = 5.13

local tbar_by_fbar_1 = `thetatilda' * `sigma_1' / (`thetatilda'-1)
local tbar_by_fbar_2 = `thetatilda' * `sigma_2' / (`thetatilda'-1)

use firmid cnae hs6dgt isic2 wtfkey value indoecd90 using "braxpmkt/secex/prodsales-data-2000.dta", clear
drop if value==0
keep if cnae>=15000 & cnae<=36999 & isic2>=300 & isic2<=399   // manufacturing firms and products (`sec' is "manf-firms")

sort firmid wtfkey hs6dgt
gsort firmid wtfkey -value
by firmid wtfkey: gen gndidx = _n
egen goods = max(gndidx), by(firmid)
label var gndidx "Product rank (HS 6-digit)"
label var goods  "Exporter scope (HS 6-digit)"
collapse (sum) sumsales=value (count) goods=value, by(firmid cnae wtfkey) fast  // collapse over goods
drop if sumsales==0
replace sumsales = sumsales/1000
label var goods "Exporter scope (HS 6-digit)"
label var sumsales "Total exports (US$ thsd fob)"
gen gsales=sumsales/goods
label var gsales "Exports per product (US$ thsd fob)"

collapse (mean) mean_sumsales=sumsales, by(wtfkey) fast  // collapse firms
label var mean_sumsales "Mean Total exports (US$ thsd fob)"

gen fbar_1 = mean_sumsales/`tbar_by_fbar_1'
gen fbar_2 = mean_sumsales/`tbar_by_fbar_2'
label var fbar_1 "Mean Fixed costs (US$ thsd) [sigma=7.61]"
label var fbar_2 "Mean Fixed costs (US$ thsd) [sigma=5.13]"

sort wtfkey
merge wtfkey using `wtffile'
tab _m
drop _m
order wtfkey mean_sumsales fbar_1 fbar_2 population gdp_usd gdp_cap_usd consum_expend_usd hh_consum_expend_usd tabsorp distcit distw dis_int lndist contig comlang_off avg_comlang_off indoecd90 indoecd00
sort wtfkey

save "braxpmkt/secex/fbar-2000-manf-firms.dta", replace
outsheet using "braxpmkt/secex/fbar-2000-manf-firms.csv", comma replace

log close
