version 9.2

clear
capture clear matrix
set more off
set virtual on
set trace off
set matsize 800
set mem 1g

// check temporary directory
* ! export STATATMP=/data/tmp
* tempfile findout
* disp "`findout'"
* if substr("`findout'",1,10)~="/data/tmp/"  STOP  // default /tmp/ too small to use

global root "g:/data"
* global root "/u/home/marcm/ext"
* global root "//acsnfs3.ucsd.edu/econgrad/muendler"
* global root "//acsnfs4.ucsd.edu/unix-home/econgrad/marcm"
global home "g:/data"
* global home "/u/home/marcm/ext"
* global home "//acsnfs3.ucsd.edu/econgrad/muendler"
* global home "//acsnfs4.ucsd.edu/unix-home/econgrad/marcm"
global extdata "//rais.ucsd.edu/marcm/ext"
* global extdata "g:/data"
* global extdata "/u/home/marcm/ext"
* global extdata "//acsnfs3.ucsd.edu/econgrad/muendler"
* global extdata "//acsnfs4.ucsd.edu/unix-home/econgrad/marcm"

cd "$home"
program drop _all
adopath + "braxpmkt/%stata/ado"
qui do "braxpmkt/%stata/ado/%Read-tabl2tex.do"

capture mkdir "braxpmkt/logs"
capture mkdir "braxpmkt/secex"
capture mkdir "braxpmkt/ext"
capture mkdir "braxpmkt/eps"
capture mkdir "braxpmkt/tex"
capture mkdir "braxpmkt/estmat"


* STEP 1: EXTERNAL DATA AND CONCORDANCES
*---------------------------------------

* do "braxpmkt/%stata/%01ext-prep/wtf-data.do"
    /* PREPARE WTF-NBER DATA (originals span 1986 to 2000) */
    /* INPUT:  "brazaux/intl/nber/wtf00.dta" */
    /* OUTPUT: "braxpmkt/ext/wtf-data-2000.dta" */
    /*   Logs: "braxpmkt/logs/wtf-data.log" */ 

* do "braxpmkt/%stata/%01ext-prep/wtf-data-chile.do"
    /* PREPARE WTF-NBER DATA (originals span 1986 to 2000) */
    /* INPUT:  "brazaux/intl/nber/wtf00.dta" */
    /* OUTPUT: "braxpmkt/ext/wtf-data-2000-chile.dta" */
    /*   Logs: "braxpmkt/logs/wtf-data-chile.log" */ 

* do "braxpmkt/%stata/%01ext-prep/unido-data-read.do"  // similar to "fdilabor/%stata/%00prepare-external/unido-data-read.do"
    /* PREPARE UNIDO DATA (originals span 1963 to 2005) */
    /* INPUT  "fdilabor/wages/indstat3-2005-isic-rev2-complete-natl-curr.csv" 
              "fdilabor/wages/indstat3-2005-isic-rev2-complete-us-dollars.csv"
              "braxpmkt/conc/unido-countries.dct"
              "braxpmkt/conc/unido-countries.txt" */
    /* OUTPUT
       Data:  "braxpmkt/ext/unido-2000-undefl-natl-curr.dta"
              "braxpmkt/ext/unido-2000-undefl-us-dollars.dta"
       Logs:  "braxpmkt/logs/unido-data-read.log"
       Progs: "braxpmkt/conc/unido-isic2.do"
              "braxpmkt/conc/unido-un3num.do" */

* do "braxpmkt/%stata/%01ext-prep/prep-harmonized-system-6dgt.do"
    /* CREATES HARMONIZED SYSTEM 6-DIGIT CODES */
    /* INPUT:  "braxpmkt/conc/hs97.6.txt"
               "braxpmkt/conc/hs97.6.dct" */
    /* OUTPUT: "braxpmkt/conc/hs6dgt.do"
          Log: "braxpmkt/logs/prep-harmonized-system-6dgt.log" */ 

* do "braxpmkt/%stata/%01ext-prep/hs2isic.do"
    /* PREPARE HS TO ISIC2 CONCORDANCE */
    /* INPUT:  "braxpmkt/conc/hs_isic.txt"
               "braxpmkt/conc/unido-isic2.do"
               "braxpmkt/conc/hs6dgt.do" */
    /* OUTPUT: "braxpmkt/conc/hs2isic.dta"
         Logs: "braxpmkt/logs/hs2isic.log" */ 

* do "braxpmkt/%stata/%01ext-prep/hs2sitc.do"
    /* PREPARE HS TO SITC CONCORDANCE */
    /* INPUT:  "braxpmkt/conc/tcommoditiess2.txt"
               "braxpmkt/conc/hts.sitc2"
               "braxpmkt/conc/hts.sitc2.dct" */
    /* OUTPUT: "braxpmkt/conc/hs2sitc.dta"
         Logs: "braxpmkt/logs/hs2sitc.log" */ 

* do "braxpmkt/%stata/%01ext-prep/sitc2isic.do"
    /* PREPARE SITC-4-digit TO ISIC2 CONCORDANCE */
    /* INPUT:  "braxpmkt/conc/tcommoditiess2.txt"
               "braxpmkt/conc/isic_rev_2_english_structure.txt"
               "braxpmkt/conc/isic.dct"
               "braxpmkt/conc/sitc2.isic2.txt"
               "braxpmkt/conc/sitc2isic.dct"
               "braxpmkt/conc/hs2isic.dta"
               "braxpmkt/conc/hs2sitc.dta"
               "braxpmkt/ext/wtf-data-2000.dta" */
    /* OUTPUT: "braxpmkt/conc/sitc2isic.dta"
               "c:/documents and settings/marc/my documents/computing/website econ.ucsd.edu/download/conc/sitc2isic.dta"
               "c:/documents and settings/marc/my documents/computing/website econ.ucsd.edu/download/conc/sitc2isic.csv"
         Logs: "braxpmkt/logs/sitc2isic.log"
        Progs: "braxpmkt/conc/isic2.do"
               "braxpmkt/conc/sitc4dgt.do" */

* do "braxpmkt/%stata/%01ext-prep/sector-country-data-2000.do"
    /* ASSEMBLE WTF AND UNIDO DATA */
    /* INPUT:  "brazaux/intl/nber/wtf00.dta"
               "brazaux/conc/countries/country-table.dta"
               "braxpmkt/conc/sitc2isic.dta"
               "braxpmkt/conc/hs2sitc.dta"
               "braxpmkt/ext/unido-2000-undefl-us-dollars.dta"
               "braxpmkt/ext/wtf-data-2000.dta" */
    /* OUTPUT: "braxpmkt/ext/sector-country-data-conc-2000.dta"
               "braxpmkt/ext/sector-country-data-2000.dta"
         Logs: "braxpmkt/logs/sector-country-data-2000.log"
        Progs: "braxpmkt/conc/wtfkey.do" */

* do "braxpmkt/%stata/%01ext-prep/sector-country-data-2000-chile.do"
    /* ASSEMBLE WTF AND UNIDO DATA */
    /* INPUT:  "brazaux/intl/nber/wtf00.dta"
               "brazaux/conc/countries/country-table.dta"
               "braxpmkt/conc/sitc2isic.dta"
               "braxpmkt/conc/hs2sitc.dta"
               "braxpmkt/ext/unido-2000-undefl-us-dollars.dta"
               "braxpmkt/ext/wtf-data-2000-chile.dta" */
    /* OUTPUT: "braxpmkt/ext/sector-country-data-conc-2000-chile.dta"
               "braxpmkt/ext/sector-country-data-2000-chile.dta"
         Logs: "braxpmkt/logs/sector-country-data-2000-chile.log"
        Progs: "braxpmkt/conc/wtfkey-chile.do" */

* do "braxpmkt/%stata/%01ext-prep/country-data-2000.do"
    /* ASSEMBLE WDI DATA */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "fdilabor/countries/ext-data.dta" */
    /* OUTPUT: "braxpmkt/ext/country-data-2000.dta"
         Logs: "braxpmkt/logs/country-data-2000.log" */

* do "braxpmkt/%stata/%01ext-prep/simulation-data-2000.do"
    /* ASSEMBLE SIMULATION-RELATED WTF, WDI AND UNIDO DATA */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "brazaux/intl/nber/wtf00.dta"
               "braxpmkt/conc/sitc2.isic2.txt"
               "braxpmkt/conc/sitc2isic.dct"
               "braxpmkt/conc/wtfkey.do"
               "braxpmkt/ext/uncomtrade/uncomtrade-india-2000.csv"
               "braxpmkt/ext/wdi-gdf-data.csv"
               "braxpmkt/ext/unido-2000-undefl-us-dollars.dta"
               "braxpmkt/ext/sector-country-data-2000.dta"
               "braxpmkt/ext/ibge-pia/valorbruto-pianova.csv" */
    /* OUTPUT: "braxpmkt/ext/simulation-data-2000.dta"
               "braxpmkt/matlab/gdp_00.csv"
               "braxpmkt/matlab/catb_00.csv"
               "braxpmkt/matlab/trade_00.csv"
         Logs: "braxpmkt/logs/simulation-data-2000.log" */

* do "braxpmkt/%stata/%01ext-prep/simulation-data-2000-smplslct.do"
    /* SELECT SUBSAMPLES OF COUNTRIES WITH RELIABLE INFORMATION */
    /* INPUT:  "braxpmkt/ext/simulation-data-2000.dta" */
    /* OUTPUT: "braxpmkt/ext/simulation-data-2000-slct.dta"
               "braxpmkt/ext/simulation-data-2000-minset.dta"
               "braxpmkt/matlab/gdp_00r.csv"
               "braxpmkt/matlab/catb_00r.csv"
               "braxpmkt/matlab/trade_00r.csv"
               "braxpmkt/matlab/gamma_00r.csv"
               "braxpmkt/matlab/mfab_00r.csv"
               "braxpmkt/matlab/gdp_00m.csv"
               "braxpmkt/matlab/catb_00m.csv"
               "braxpmkt/matlab/trade_00m.csv"
               "braxpmkt/matlab/gamma_00m.csv"
               "braxpmkt/matlab/beta_00m.csv"
               "braxpmkt/matlab/mfab_00m.csv"
         Logs: "braxpmkt/logs/simulation-data-2000-smplslct.log" */

* do "braxpmkt/%stata/%01ext-prep/distance-data.do"
    /* ASSEMBLE CEPII DATA */
    /* INPUT:  "fdilabor/countries/geo_cepii.dta"
               "fdilabor/countries/dist_cepii.dta"
               "braxpmkt/conc/wtfkey.do" */
    /* OUTPUT: "braxpmkt/ext/distance-data.dta"
         Logs: "braxpmkt/logs/distance-data.log" */

* do "braxpmkt/%stata/%01ext-prep/distance-data-chile.do"
    /* ASSEMBLE CEPII DATA */
    /* INPUT:  "fdilabor/countries/geo_cepii.dta"
               "fdilabor/countries/dist_cepii.dta"
               "braxpmkt/conc/wtfkey-chile.do" */
    /* OUTPUT: "braxpmkt/ext/distance-data-chile.dta"
         Logs: "braxpmkt/logs/distance-data-chile.log" */

* do "braxpmkt/%stata/%01ext-prep/product-data.do"
    /* ASSEMBLE GOODS INFORMATION AT HS 2-DIGIT LEVEL */
    /* INPUT:  "brazaux/intl/balassa-compadv-isic2.dta"
               "brazaux/intl/nber/wtf00.dta"
               "braxpmkt/ext/rauch-classification-rev2.csv"
               "braxpmkt/conc/hs2isic.dta"
               "braxpmkt/conc/hs2sitc.dta"
               "braxpmkt/conc/wtfkey.do" */
    /* OUTPUT: "braxpmkt/ext/product-data.dta"
         Logs: "braxpmkt/logs/product-data.log" */

* do "braxpmkt/%stata/%01ext-prep/product-data-chile.do"
    /* ASSEMBLE GOODS INFORMATION AT HS 2-DIGIT LEVEL */
    /* INPUT:  "brazaux/intl/nber/wtf00.dta"
               "braxpmkt/ext/rauch-classification-rev2.csv"
               "braxpmkt/conc/hs2isic.dta"
               "braxpmkt/conc/hs2sitc.dta"
               "braxpmkt/conc/wtfkey-chile.do" */
    /* OUTPUT: "braxpmkt/ext/product-data-chile.dta"
         Logs: "braxpmkt/logs/product-data-chile.log" */


* STEP 2: SECEX (AND RAIS) DATA
*------------------------------

* do "braxpmkt/%stata/%02secex-prep/rais-cnpj-cnae.do"
    /* OBTAINS A FIRM'S SECTOR AND WORKFORCE INFORMATION FOR 2000 AND 2001 FROM RAIS */
    /* INPUT:  "rais/base-agg/cnpjradic/aggcnpj_`i'" (where `i' in a b c d e f g h i j) */
    /* OUTPUT: "braxpmkt/secex/rais-cnpj-cnae-2000.dta"
               "braxpmkt/secex/rais-cnpj-cnae-2001.dta" */
    /*    Log: "braxpmkt/logs/rais-cnpj-cnae.log" */ 

* do "braxpmkt/%stata/%02secex-prep/prep-firms-2000-2001.do"
    /* READS AND PREPARES FIRM DATA FOR 2000 AND 2001 */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "secex/csv/exp00.csv"
               "secex/csv/exp01_emp.csv" */
    /* OUTPUT: "braxpmkt/secex/firms-2000.dta"
               "braxpmkt/secex/firms-2000-ncm8dgt.dta"
               "braxpmkt/secex/firms-2001.dta" */
    /*    Log: "braxpmkt/logs/prep-firms-2000-2001.log" */ 

* do "braxpmkt/%stata/%02secex-prep/complete-hs2isic-conc-2000.do"
    /* COMPLETES THE DEFECTIVE HS-TO-ISIC MAPPING FOR SECEX 2000 */
    /* INPUT:  "braxpmkt/secex/firms-2000.dta"
               "braxpmkt/conc/hs2isic.dta" */
    /* OUTPUT: "braxpmkt/conc/hs2isic-2000.dta" */
    /*    Log: "braxpmkt/logs/complete-hs2isic-conc-2000.log" */ 

* do "braxpmkt/%stata/%02secex-prep/replication-data-2000.do"
    /* PREPARES EKK-REPLICATION DATA FOR 2000 */
    /* INPUT:  "brazcomp/filters/cnae-isic2.dta"
               "braxpmkt/conc/unido-isic2.do"
               "braxpmkt/secex/firms-2000.dta"
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta"
               "braxpmkt/ekk/ekk-sic-isic2-conc.csv"
               "braxpmkt/ext/sector-country-data-2000.dta"
               "braxpmkt/ext/country-data-2000.dta" */
    /* OUTPUT: "braxpmkt/secex/replication-data-2000.dta" */
    /*    Log: "braxpmkt/logs/replication-data-2000.log" */ 

* do "braxpmkt/%stata/%02secex-prep/replication-data-2000-ncm8.do"
    /* PREPARES EKK-REPLICATION DATA FOR 2000, COMMON MERCOSUR NOMENCLATURE 8-DIGIT */
    /* INPUT:  "brazcomp/filters/cnae-isic2.dta"
               "braxpmkt/conc/unido-isic2.do"
               "braxpmkt/secex/firms-2000.dta"
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta"
               "braxpmkt/ekk/ekk-sic-isic2-conc.csv"
               "braxpmkt/ext/sector-country-data-2000.dta"
               "braxpmkt/ext/country-data-2000.dta" */
    /* OUTPUT: "braxpmkt/secex/replication-data-2000-ncm8.dta" */
    /*    Log: "braxpmkt/logs/replication-data-2000-ncm8.log" */ 

* do "braxpmkt/%stata/%02secex-prep/replication-data-2000-expitems.do"
    /* PREPARES EKK-COMPARISON DATA FOR 2000 USING EXPORT ITEMS (EXPORTER-PRODUCTS) */
    /* INPUT:  "brazcomp/filters/cnae-isic2.dta"
               "braxpmkt/conc/unido-isic2.do"
               "braxpmkt/secex/firms-2000.dta"
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta"
               "braxpmkt/ekk/ekk-sic-isic2-conc.csv"
               "braxpmkt/ext/sector-country-data-2000.dta"
               "braxpmkt/ext/country-data-2000.dta" */
    /* OUTPUT: "braxpmkt/secex/replication-data-2000-expitems.dta" */
    /*    Log: "braxpmkt/logs/replication-data-2000-expitems.log" */ 

* do "braxpmkt/%stata/%02secex-prep/replication-data-2000-chile.do"
    /* PREPARES EKK-REPLICATION DATA FOR CHILE 2000 */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "braxpmkt/chile/exports-2000.dta"
               "braxpmkt/conc/unido-isic2.do"
               "braxpmkt/conc/hs2isic.dta"
               "braxpmkt/conc/adhoc-hs2isic.csv"
               "braxpmkt/ekk/ekk-sic-isic2-conc.csv"
               "braxpmkt/ext/country-data-2000.dta"
               "braxpmkt/ext/sector-country-data-2000-chile.dta" */
    /* OUTPUT: "braxpmkt/chile/replication-data-2000-chile.dta" */
    /*    Log: "braxpmkt/logs/replication-data-2000-chile.log" */ 

* do "braxpmkt/%stata/%02secex-prep/replication-data-2000-expitems-chile.do"
    /* PREPARES EKK-COMPARISON DATA FOR CHILE 2000 USING EXPORT ITEMS (EXPORTER-PRODUCTS) */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "braxpmkt/chile/exports-2000.dta"
               "braxpmkt/conc/unido-isic2.do"
               "braxpmkt/conc/hs2isic.dta"
               "braxpmkt/conc/adhoc-hs2isic.csv"
               "braxpmkt/ekk/ekk-sic-isic2-conc.csv"
               "braxpmkt/ext/sector-country-data-2000-chile.dta"
               "braxpmkt/ext/country-data-2000.dta" */
    /* OUTPUT: "braxpmkt/chile/replication-data-2000-expitems-chile.dta" */
    /*    Log: "braxpmkt/logs/replication-data-2000-expitems-chile.log" */ 

* do "braxpmkt/%stata/%02secex-prep/prodsales-data-2000.do"
    /* PREPARES PRODUCT-LEVEL EXPORTS DATA FOR 2000 */
    /* INPUT:  "braxpmkt/secex/firms-2000.dta"
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta"
               "braxpmkt/conc/hs2isic-2000.dta"
               "braxpmkt/ext/country-data-2000.dta" 
               "braxpmkt/ext/sector-country-data-2000.dta"
               "braxpmkt/ext/distance-data.dta" */
    /* OUTPUT: "braxpmkt/secex/prodsales-data-2000.dta" */
    /*    Log: "braxpmkt/logs/prodsales-data-2000.log" */ 

* do "braxpmkt/%stata/%02secex-prep/prodsales-data-2000-hs2isic.do"
    /* PREPARES PRODUCT-LEVEL EXPORTS DATA FOR 2000 */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta"  */
    /* OUTPUT: "braxpmkt/secex/prodsales-data-2000-hs2isic.dta" */
    /*    Log: "braxpmkt/logs/prodsales-data-2000-hs2isic.log" */ 
    
* do "braxpmkt/%stata/%02secex-prep/prodsales-rais-2000-addons.do"
    /* PREPARES RAIS AND BCB-FDI INFORMATION TO ADD TO EXPORTS DATA FOR 2000 */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta"
               "brazaux/auxil/minwage.dta"
               "rais/base-agg/cnpjradic/aggcnpj_`i'" (where `i' in a b c d e f g h i j)
               "rais/bcb-fdi/all-fdi.dta" 
               "brazhimr/estmat/plantfe/firmpred-edu-allsec-2000.dta" */
    /* OUTPUT: "braxpmkt/secex/prodsales-rais-2000-addons.dta" */
    /*    Log: "braxpmkt/logs/prodsales-rais-2000-addons.log" */ 

* do "braxpmkt/%stata/%02secex-prep/prodsales-data-2000-ncm8.do"
    /* PREPARES PRODUCT-LEVEL EXPORTS DATA FOR 2000, COMMON MERCOSUR NOMENCLATURE 8-DIGIT */
    /* INPUT:  "braxpmkt/secex/firms-2000.dta"
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta"
               "braxpmkt/conc/hs2isic-2000.dta"
               "braxpmkt/ext/country-data-2000.dta" 
               "braxpmkt/ext/sector-country-data-2000.dta"
               "braxpmkt/ext/distance-data.dta" */
    /* OUTPUT: "braxpmkt/secex/prodsales-data-2000-ncm8.dta" */
    /*    Log: "braxpmkt/logs/prodsales-data-2000-ncm8.log" */ 

* do "braxpmkt/%stata/%02secex-prep/prodsales-data-2000-chile.do"
    /* PREPARES PRODUCT-LEVEL EXPORTS DATA FOR 2000 */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "braxpmkt/chile/exports-2000.dta"
               "braxpmkt/conc/hs2isic.dta"
               "braxpmkt/conc/hs-chile.dta"
               "braxpmkt/conc/adhoc-hs2isic.csv"
               "braxpmkt/ext/country-data-2000.dta"
               "braxpmkt/ext/sector-country-data-2000-chile.dta"
               "braxpmkt/ext/distance-data-chile.dta"
               "braxpmkt/conc/wtfkey-chile.do"
               "braxpmkt/conc/hs6dgt.do" */
    /* OUTPUT: "braxpmkt/chile/prodsales-data-2000-chile.dta"
               "braxpmkt/conc/unmatched-hs6dgt-chile.csv"
               "braxpmkt/conc/unmatched-hs6dgt-names-chile.csv" */
    /*    Log: "braxpmkt/logs/prodsales-data-2000-chile.log" */ 


* STEP 3: DESCRIPTIVE STATISTICS
*-------------------------------

* do "braxpmkt/%stata/%03desc-stats/replication-stats.do"
    /* REPLICATION OF BJRS (JEP 2007), BRS (UNPUBL 08), AND EKK (AER 2004) (also see ekk/marc1.do and ekk/marc2.do) */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "brazcomp/filters/cnae-isic2.dta"
               "brazcomp/filters/cnae2naic-loose.dta"
               "braxpmkt/conc/unido-isic2.do"
               "braxpmkt/conc/wtfkey-chile.do"
               "braxpmkt/bjrs/bjrs07-tab2.tex"
               "braxpmkt/bjrs/bjrs07-tab`tab'.tex" (where `tab' in 4a 4b 4c)
               "braxpmkt/chile/exports-2000.dta"
               "braxpmkt/chile/prodsales-data-2000-chile.dta"
               "braxpmkt/chile/replication-data-2000-chile.dta"
               "braxpmkt/ekk/ekk-sic-isic2-conc.csv"
               "braxpmkt/ekk/ekk04-tab1a.tex"
               "braxpmkt/ekk/ekk04-tab1b.tex"
               "braxpmkt/ekk/ekk04-tab2.tex"
               "braxpmkt/ekk/ekk04-reg.tex"
               "braxpmkt/ext/country-data-2000.dta"
               "braxpmkt/ext/distance-data.dta"
               "braxpmkt/secex/firms-2000.dta"
               "braxpmkt/secex/firms-2000-ncm8dgt.dta"
               "braxpmkt/secex/prodsales-data-2000.dta"
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta"
               "braxpmkt/secex/replication-data-2000.dta"
               "rais/base-agg/cnae/aggsec.csv" */
    /* OUTPUT: 
          eps: "braxpmkt/eps/manf-ekk/ekk-fig1.eps"
               "braxpmkt/eps/manf-ekk/ekk-fig3.eps"
               "braxpmkt/eps/manf-ekk/ekk-fig3-lfit.eps"
               "braxpmkt/eps/manf-ekk/ekk-fig3-scope-lfit.eps"
               "braxpmkt/eps/manf-ekk/ekk-fig3-scope-pershare-lfit.eps"
               "braxpmkt/eps/manf-ekk-chile/ekk-fig1.eps"
               "braxpmkt/eps/manf-ekk-chile/ekk-fig3.eps"
               "braxpmkt/eps/manf-ekk-chile/ekk-fig3-lfit.eps"
               "braxpmkt/eps/manf-ekk-chile/ekk-fig3-scope-lfit.eps"
               "braxpmkt/eps/manf-ekk-chile/ekk-fig3-scope-pershare-lfit.eps"
          TeX: "braxpmkt/estmat/manf-bjrs/bjrshs6_regam.tex"
               "braxpmkt/estmat/manf-bjrs/bjrshs6_regam_pop.tex"
               "braxpmkt/estmat/manf-bjrs/bjrsncm8_regam.tex"
               "braxpmkt/estmat/manf-bjrs-chile/bjrshs6_regam.tex"
               "braxpmkt/estmat/manf-bjrs-chile/bjrshs8_regam.tex"
               "braxpmkt/estmat/manf-bjrs/bjrshs6_reg.tex"
               "braxpmkt/estmat/manf-bjrs/brshs6_regrev.tex"
               "braxpmkt/estmat/manf-bjrs/brshs6_regrev_pop.tex"
               "braxpmkt/estmat/manf-bjrs/bjrsncm8_reg.tex"
               "braxpmkt/estmat/manf-bjrs/brsncm8_regrev.tex"
               "braxpmkt/estmat/manf-bjrs-chile/bjrshs6_reg.tex"
               "braxpmkt/estmat/manf-bjrs-chile/brshs6_regrev.tex"
               "braxpmkt/estmat/manf-bjrs-chile/bjrshs8_reg.tex"
               "braxpmkt/estmat/manf-bjrs-chile/brshs8_regrev.tex"
               "braxpmkt/estmat/manf-bjrs/brshs6_regrev.tex"
               "braxpmkt/estmat/manf-bjrs/brshs6_regrev_pop.tex"
               "braxpmkt/estmat/manf-ekk/ekk_reg.tex"
               "braxpmkt/tex/manf-bjrs/bjrs_tab2.tex"
               "braxpmkt/tex/manf-bjrs/bjrs_tab4a.tex"
               "braxpmkt/tex/manf-bjrs/bjrs_tab4b.tex"
               "braxpmkt/tex/manf-bjrs/bjrs_tab4c.tex"
               "braxpmkt/tex/manf-ekk/ekk_tab1a.tex"
               "braxpmkt/tex/manf-ekk/ekk_tab1b.tex"
               "braxpmkt/tex/manf-ekk/ekk_tab2.tex"
               "braxpmkt/tex/manf-ekk/ekk_reg.tex"
        Progs: "braxpmkt/tex/manf-bjrs/naicbjrs.do"
               "braxpmkt/tex/manf-ekk/sicekk.do" */
    /*    Log: "braxpmkt/logs/replication-stats.log" */ 

* do "braxpmkt/%stata/%03desc-stats/replication-stats-expitems.do"
    /* EXTENSION OF EKK (AER 2004) TO EXPORT ITEMS */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "braxpmkt/chile/replication-data-2000-expitems-chile.dta"
               "braxpmkt/chile/replication-data-2000-chile.dta"
               "braxpmkt/secex/replication-data-2000-expitems.dta"
               "braxpmkt/secex/replication-data-2000.dta"
               "braxpmkt/tex/manf-ekk/ekk_tab2_tbl.dta"
               "braxpmkt/tex/manf-ekk/ekk_reg_tbl.dta" */
    /* OUTPUT: 
          eps: "braxpmkt/eps/manf-ekk/expitem-fig1.eps"
               "braxpmkt/eps/manf-ekk/expitem-fig3.eps"
               "braxpmkt/eps/manf-ekk-chile/expitem-fig3.eps"
               "braxpmkt/eps/manf-ekk/expitem-scope-lambda.eps"
               "braxpmkt/eps/manf-ekk/expitem-scope-totexports.eps"
               "braxpmkt/eps/manf-ekk/expitem-scope-absorpt.eps"
               "braxpmkt/eps/manf-ekk-chile/expitem-scope-lambda.eps"
               "braxpmkt/eps/manf-ekk-chile/expitem-scope-totexports.eps"
               "braxpmkt/eps/manf-ekk-chile/expitem-scope-absorpt.eps"
          TeX: "braxpmkt/tex/manf-ekk/expitem_tab2.tex"
               "braxpmkt/estmat/manf-ekk/expitem_reg.tex"
               "braxpmkt/tex/manf-ekk/expitem_reg.tex"
               "braxpmkt/estmat/manf-ekk-chile/expitem_reg.tex" */
    /*    Log: "braxpmkt/logs/replication-stats-expitems.log" */

* do "braxpmkt/%stata/%03desc-stats/extension-stats.do"
    /* STATISTICS BEYOND EKK (AER 2004) (see ekk/marc1.do and ekk/marc2.do) */
    /* INPUT:  "braxpmkt/secex/replication-data-2000.dta" */
    /* OUTPUT: . */
    /*    Log: "braxpmkt/logs/extension-stats.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-prelim.do"
    /* BASIC PRODUCT SALES STATISTICS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/tex/`sec'/relstats_prelim.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-prelim.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-prelim-ncm8.do"
    /* BASIC PRODUCT SALES STATISTICS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000-ncm8.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/tex/`sec'-ncm8/relstats_prelim.tex" (where `sec' in "manf-firms" "comrc-firms")
          Log: "braxpmkt/logs/prodsales-prelim-ncm8.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-prelim-chile.do"
    /* BASIC PRODUCT SALES STATISTICS */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/tex/chile-manffrms/`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
          Log: "braxpmkt/logs/prodsales-prelim-chile.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-stats.do"
    /* PRODUCT SALES STATISTICS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" 
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta" */
    /* OUTPUT: "braxpmkt/eps/manf-firms/sumsales-pcsales-usa.dta"
               "braxpmkt/eps/manf-firms/goods-pcgoods-usa.dta"
               "braxpmkt/eps/manf-firms/avgscope-totexp-pcscope-`region'.dta" (where `region' in "usa" "argentina")
               "braxpmkt/eps/manf-firms/avgscope-totexp-pcsales-`region'.dta" (where `region' in "usa" "argentina")
               "braxpmkt/eps/manf-firms/avgscope-wgsales-pcsales-`region'.dta" (where `region' in "usa" "argentina")
          eps: "braxpmkt/eps/`sec'/avgscope-totexp-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/avgscope-wgsales-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/avgsumsales-pcsales-`region'.eps"  (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/avgscope-totexp-pcsales-`region'.eps"  (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/avgscope-wgsales-pcsales-`region'.eps"  (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/avgscope-gsales-pcsales-`region'.eps"  (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/histogram-goods-25-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/histogram-goods-10to25-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/histogram-goods-25to100-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/sumsales-pcsales-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/goods-pcsales-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/gsales-pcsales-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/goods-pcgoods-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/goods-pcsales-`region'-cwhiskers.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/goods-pcsales-`region'-mean.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/goods-pcnpis-`region'-mean.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/gsales-pcgsales-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/goods-sumsales-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/gsales-sumsales-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/`sec'/gsales-goods-`region'.eps"  (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
          TeX: "braxpmkt/tex/`sec'/`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/`sec'/`stat'exp_`region'.tex" (where `stat' in "mean" "sd" "count", `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/`sec'/relstats_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/`sec'/histT_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/`sec'/cumT_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/`sec'/hist_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/`sec'/cum_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/`sec'/goods_pcgoods_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/`sec'/goods_pcsales_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
          Log: "braxpmkt/logs/prodsales-stats.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-stats-ncm8.do"
    /* PRODUCT SALES STATISTICS, COMMON MERCOSUR NOMENCLATURE 8-DIGIT */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000-ncm8.dta" 
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta" */
    /* OUTPUT: "braxpmkt/eps/manf-firms-ncm8/sumsales-pcsales-usa.dta"
               "braxpmkt/eps/manf-firms-ncm8/goods-pcgoods-usa.dta"
               "braxpmkt/eps/manf-firms-ncm8/avgscope-totexp-pcscope-`region'.dta" (where `region' in "usa" "argentina")
               "braxpmkt/eps/manf-firms-ncm8/avgscope-totexp-pcsales-`region'.dta" (where `region' in "usa" "argentina")
               "braxpmkt/eps/manf-firms-ncm8/avgscope-wgsales-pcsales-`region'.dta" (where `region' in "usa" "argentina")
          eps: "braxpmkt/eps/`sec'-ncm8/avgscope-totexp-pcscope-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/avgscope-wgsales-pcscope-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/avgsumsales-pcsales-`region'.eps"  (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/avgscope-totexp-pcsales-`region'.eps"  (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/avgscope-wgsales-pcsales-`region'.eps"  (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/avgscope-gsales-pcsales-`region'.eps"  (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/histogram-goods-25-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/histogram-goods-10to25-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/histogram-goods-25to100-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/sumsales-pcsales-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/goods-pcsales-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/gsales-pcsales-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/goods-pcgoods-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/goods-pcsales-`region'-cwhiskers.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/goods-pcsales-`region'-mean.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/goods-pcnpis-`region'-mean.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/gsales-pcgsales-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/goods-sumsales-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/gsales-sumsales-`region'.eps" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/eps/`sec'-ncm8/gsales-goods-`region'.eps"  (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
          TeX: "braxpmkt/tex/`sec'-ncm8/`region'.tex" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/tex/`sec'-ncm8/`stat'exp_`region'.tex" (where `stat' in "mean" "sd" "count", `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/tex/`sec'-ncm8/relstats_`region'.tex" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/tex/`sec'-ncm8/histT_`region'.tex" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/tex/`sec'-ncm8/cumT_`region'.tex" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/tex/`sec'-ncm8/hist_`region'.tex" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/tex/`sec'-ncm8/cum_`region'.tex" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/tex/`sec'-ncm8/goods_pcgoods_`region'.tex" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
               "braxpmkt/tex/`sec'-ncm8/goods_pcsales_`region'.tex" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina")
          Log: "braxpmkt/logs/prodsales-stats-ncm8.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-stats-chile.do"
    /* PRODUCT SALES STATISTICS */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT: 
          eps: "braxpmkt/eps/chile-manffrms/avgscope-totexp-pcscope-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/avgscope-wgsales-pcscope-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/avgscope-totexp-pcsales-`region'.eps"  (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/avgscope-wgsales-pcsales-`region'.eps"  (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/avgscope-gsales-pcsales-`region'.eps"  (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/histogram-goods-25-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/histogram-goods-10to25-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/histogram-goods-25to100-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/sumsales-pcsales-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/goods-pcsales-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/gsales-pcsales-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/goods-pcgoods-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/goods-pcsales-`region'-cwhiskers.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/goods-pcsales-`region'-mean.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/goods-pcnpis-`region'-mean.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/gsales-pcgsales-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/goods-sumsales-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/gsales-sumsales-`region'.eps" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/eps/chile-manffrms/gsales-goods-`region'.eps"  (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
          TeX: "braxpmkt/tex/chile-manffrms/`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/chile-manffrms/`stat'exp_`region'.tex" (where `stat' in "mean" "sd" "count", chile-manffrms in "allsec" "manf-goods" "manf-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/chile-manffrms/relstats_`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/chile-manffrms/histT_`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/chile-manffrms/cumT_`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/chile-manffrms/hist_`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/chile-manffrms/cum_`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/chile-manffrms/goods_pcgoods_`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
               "braxpmkt/tex/chile-manffrms/goods_pcsales_`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top25th")
          Log: "braxpmkt/logs/prodsales-stats-chile.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-graphs.do"
    /* PRODUCT SALES GRAPHS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" */
    /* OUTPUT: "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/eps/manf-firms/expprod_usa-4-32.dta"
          eps: "braxpmkt/eps/`sec'/expprod_`region'-4-32.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/expprod_`region'-2-16.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/expprod-4-32.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/eps/`sec'/expprod-2-16.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Tex: "braxpmkt/estmat/`sec'/expprod_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/estmat/`sec'/expprod.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-graphs.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-graphs-ncm8.do"
    /* PRODUCT SALES GRAPHS, COMMON MERCOSUR NOMENCLATURE 8-DIGIT */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000-ncm8.dta" */
    /* OUTPUT: "braxpmkt/secex/expprod-`sec'-ncm8.dta" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/eps/manf-firms/expprod_usa-4-32.dta"
          eps: "braxpmkt/eps/`sec'-ncm8/expprod_`region'-4-32.eps" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/eps/`sec'-ncm8/expprod_`region'-2-16.eps" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/eps/`sec'-ncm8/expprod-4-32.eps" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/eps/`sec'-ncm8/expprod-2-16.eps" (where `sec' in "manf-firms" "comrc-firms")
          Tex: "braxpmkt/estmat/`sec'-ncm8/expprod_`region'.tex" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/estmat/`sec'-ncm8/expprod.tex" (where `sec' in "manf-firms" "comrc-firms")
          Log: "braxpmkt/logs/prodsales-graphs-ncm8.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-graphs-chile.do"
    /* PRODUCT SALES GRAPHS */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT: "braxpmkt/secex/expprod-chile-manffrms.dta"
          eps: "braxpmkt/eps/chile-manffrms/expprod_`region'-4-32.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/chile-manffrms/expprod_`region'-2-16.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/chile-manffrms/expprod-4-32.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/eps/chile-manffrms/expprod-2-16.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Tex: "braxpmkt/estmat/chile-manffrms/expprod_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/estmat/chile-manffrms/expprod.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-graphs-chile.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-desc-reg.do"
    /* DESCRIPTIVE REGRESSIONS RELATED TO PRODUCT SALES GRAPHS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta"
               "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" "chile-manffrms") */
    /* OUTPUT: .
          Tex: "braxpmkt/estmat/`sec'/expminval_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/estmat/`sec'/expminval.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" "chile-manffrms")
          Log: "braxpmkt/logs/prodsales-desc-reg.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-tables.do"
    /* PRODUCT SALES TABLES */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/secex/prodsales-data-2000.dta"
               "braxpmkt/%stata/rowlbl-braxpmkt.tex" */
    /* OUTPUT: 
          Tex: "braxpmkt/tex/`sec'/expprodcnt.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/expprodsel_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "usa" "argentina")
          Log: "braxpmkt/logs/prodsales-tables.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-tables-ncm8.do"
    /* PRODUCT SALES TABLES, COMMON MERCOSUR NOMENCLATURE 8-DIGIT */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'-ncm8.dta" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/secex/prodsales-data-2000-ncm8.dta"
               "braxpmkt/%stata/rowlbl-braxpmkt.tex" */
    /* OUTPUT: 
          Tex: "braxpmkt/tex/`sec'-ncm8/expprodcnt.tex" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/tex/`sec'-ncm8/expprodsel_`region'.tex" (where `sec' in "manf-firms" "comrc-firms", `region' in "usa" "argentina")
          Log: "braxpmkt/logs/prodsales-tables-ncm8.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-tables-chile.do"
    /* PRODUCT SALES TABLES */
    /* INPUT:  "braxpmkt/secex/expprod-chile-manffrms.dta"
               "braxpmkt/secex/prodsales-data-2000-chile.dta"
               "braxpmkt/%stata/rowlbl-braxpmkt.tex" */
    /* OUTPUT: 
          Tex: "braxpmkt/tex/chile-manffrms/expprodcnt.tex"
               "braxpmkt/tex/chile-manffrms/expprodsel_`region'.tex" (where `region' in "usa" "argentina")
          Log: "braxpmkt/logs/prodsales-tables-chile.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-stats-bycountry.do"
    /* PRODUCT SALES STATISTICS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" */
    /* OUTPUT: 
          eps: "braxpmkt/eps/`sec'/avgscope-totexp-pcscope-allcountries.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/eps/`sec'/avgscope-wgsales-pcscope-allcountries.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-stats-bycountry.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-stats-bycountry-chile.do"
    /* PRODUCT SALES STATISTICS */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT: 
          eps: "braxpmkt/eps/chile-manffrms/avgscope-totexp-pcscope-allcountries.eps"
               "braxpmkt/eps/chile-manffrms/avgscope-wgsales-pcscope-allcountries.eps"
          Log: "braxpmkt/logs/prodsales-stats-bycountry-chile.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-stats-byfirmtype.do"
    /* PRODUCT SALES STATISTICS BY FIRMTYPE */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" */
    /* OUTPUT: 
          eps: "braxpmkt/eps/`sec'/bywwdest-avgscope-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/bywwdest-totexp-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/bywwdest-wgsales-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/byindcoll-avgscope-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/byindcoll-totexp-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/byindcoll-wgsales-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/bynpis-avgscope-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/bynpis-totexp-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/bynpis-wgsales-pcscope-`region'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
          Log: "braxpmkt/logs/prodsales-stats-byfirmtype.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-stats-byfirmtype-chile.do"
    /* PRODUCT SALES STATISTICS BY FIRMTYPE */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT: 
          eps: "braxpmkt/eps/chile-manffrms/bywwdest-avgscope-pcscope-`region'.eps" (where `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/chile-manffrms/bywwdest-totexp-pcscope-`region'.eps" (where `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/chile-manffrms/bywwdest-wgsales-pcscope-`region'.eps" (where `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
          Log: "braxpmkt/logs/prodsales-stats-byfirmtype-chile.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-goods-pcsales-bycountry.do"
    /* EXPORTER SCOPE AND TOTAL EXPORTS DISTRIBUTION */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" 
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta" */
    /* OUTPUT: "braxpmkt/secex/scope-pctl-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
          eps: "braxpmkt/eps/`sec'/bycntry/goods-pcsales-`cntry'-mean.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `cntry' is wtfkey)
          Log: "braxpmkt/logs/prodsales-goods-pcsales-bycountry.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-goods-pcsales-bycountry-chile.do"
    /* EXPORTER SCOPE AND TOTAL EXPORTS DISTRIBUTION */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta"*/
    /* OUTPUT: "braxpmkt/chile/scope-pctl-chile-manffrms.dta"
          eps: "braxpmkt/eps/chile-manffrms/bycntry/goods-pcsales-`cntry'-mean.eps" (`cntry' is wtfkey)
          Log: "braxpmkt/logs/prodsales-goods-pcsales-bycountry-chile.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-avgscope-wgsales-pcsales-bycountry.do"
    /* EXPORTER SCOPE AND TOTAL EXPORTS DISTRIBUTION */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" */
    /* OUTPUT: "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          eps: "braxpmkt/eps/`sec'/bycntry/avgscope-wgsales-pcsales-`cntry'.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" and `cntry' is wtfkey)
          Log: "braxpmkt/logs/prodsales-avgscope-wgsales-pcsales-bycountry.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-avgscope-wgsales-pcsales-bycountry-ncm8.do"
    /* EXPORTER SCOPE AND TOTAL EXPORTS DISTRIBUTION */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000-ncm8.dta" */
    /* OUTPUT: "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'-ncm8.dta" (where `sec' in "manf-firms")
          eps: "braxpmkt/eps/`sec'-ncm8/bycntry/avgscope-wgsales-pcsales-`cntry'.eps" (inactive; where `sec' in "manf-firms" "comrc-firms" and `cntry' is wtfkey)
          Log: "braxpmkt/logs/prodsales-avgscope-wgsales-pcsales-bycountry-ncm8.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-avgscope-wgsales-pcsales-bycountry-chile.do"
    /* EXPORTER SCOPE AND TOTAL EXPORTS DISTRIBUTION */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT: "braxpmkt/chile/avgscope-wgsales-pcsales-chile-manffrms.dta"
          eps: "braxpmkt/eps/chile-manffrms/bycntry/avgscope-wgsales-pcsales-`cntry'.eps" (`cntry' is wtfkey)
          Log: "braxpmkt/logs/prodsales-avgscope-wgsales-pcsales-bycountry-chile.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-product-dispersion.do"
    /* PRODUCT GROUP DISPERSION AND SCOPE ASSOCIATIONS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta"
               "brazaux/conc/sec/cnae2dgt-subsibge-manual.csv"
               "braxpmkt/%stata/rowlbl-braxpmkt.tex" */
    /* OUTPUT: 
          Do: "braxpmkt/conc/cnae2dgt.do"
          TeX: "braxpmkt/tex/`sec'/dispers_hs`lvl'.tex" (where `lvl' in 2 4; `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/lnhs`lvl'grps_lngoods.tex" (where `lvl' in 2 4; `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk"; and untransposed b se e matrices)
          eps: "braxpmkt/eps/`sec'/lnhs`lvl'grps-lngoods.eps" (where `lvl' in 2 4; `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") */
    /*    Log: "braxpmkt/logs/prodsales-product-dispersion.log" */ 

* do "braxpmkt/%stata/%03desc-stats/prodsales-product-dispersion-chile.do"
    /* PRODUCT GROUP DISPERSION AND SCOPE ASSOCIATIONS */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta"
               "brazaux/conc/sec/cnae2dgt-subsibge-manual.csv"
               "braxpmkt/%stata/rowlbl-braxpmkt.tex" */
    /* OUTPUT: 
          TeX: "braxpmkt/tex/chile-manffrms/dispers_hs`lvl'.tex" (where `lvl' in 2 4)
               "braxpmkt/tex/chile-manffrms/lnhs`lvl'grps_lngoods.tex" (where `lvl' in 2 4; and untransposed b se e matrices)
          eps: "braxpmkt/eps/chile-manffrms/lnhs`lvl'grps-lngoods.eps" (where `lvl' in 2 4) */
    /*    Log: "braxpmkt/logs/prodsales-product-dispersion-chile.log" */ 

* do "braxpmkt/%stata/%03desc-stats/outside-data-files.do"
    /* REPLICATION CODE FOR OUTSIDE DATA AND CESIFO PAPER */
    /* INPUT:  "braxpmkt/secex/firms-2000.dta"
               "braxpmkt/conc/hs2isic.dta" */
    /* OUTPUT: "$inpath/outside-testdata.dta" ($inpath "braxpmkt/ext")
               "$inpath/hs2isic.dta" ($inpath "braxpmkt/ext") */
    /*    Log: . */ 

* do "braxpmkt/%stata/%03desc-stats/outside-data.do"
    /* REPLICATION CODE FOR OUTSIDE DATA AND CESIFO PAPER */
    /* INPUT:  "$inpath/outside-testdata.dta"
               "$inpath/hs2isic.dta" */
    /* OUTPUT: .
          eps: "$outpath/ekk-fig1.eps"
               "$outpath/sumsales-pcsales-usa.eps"
               "$outpath/goods-pcgoods-usa.eps"
          TeX: . */
    /*    Log: "$outpath/outside-data.log" */ 


* STEP 4: REGRESSIONS
*--------------------

* do "braxpmkt/%stata/%04regress/prep-prodlvl-2delta.do"
    /* PREPARE BRAZIL DATA FOR OLS PRODUCT SALES REGRESSIONS IN DISCRETE-GOODS MODEL */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/secex/prodsales-rais-2000-addons.dta" */
    /* OUTPUT: "braxpmkt/secex/prodsales-rais-2000-2delta.dta"
          Log: "braxpmkt/logs/prep-prodlvl-2delta.log" */ 

* do "braxpmkt/%stata/%04regress/prep-prodlvl-struct.do"
    /* PREPARE BRAZIL DATA FOR STRUCTURAL PRODUCT SALES REGRESSIONS IN DISCRETE-GOODS MODEL */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/secex/prodsales-rais-2000-addons.dta" */
    /* OUTPUT: "braxpmkt/secex/prodsales-rais-2000-struct.dta"
          Log: "braxpmkt/logs/prep-prodlvl-struct.log" */ 

* do "braxpmkt/%stata/%04regress/prep-prodlvl-struct-ncm8.do"
    /* PREPARE BRAZIL DATA FOR STRUCTURAL PRODUCT SALES REGRESSIONS IN DISCRETE-GOODS MODEL AT NCM-8 */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'-ncm8.dta" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/secex/prodsales-rais-2000-addons.dta" */
    /* OUTPUT: "braxpmkt/secex/prodsales-rais-2000-struct-ncm8.dta"
          Log: "braxpmkt/logs/prep-prodlvl-struct-ncm8.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-ttest.do"
    /* PRODUCT SALES T-TESTS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta"
               "braxpmkt/tex/`sec'/meanexp_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") */
    /* OUTPUT: 
          TeX: "braxpmkt/tex/`sec'/ttestexp_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") */
    /*    Log: "braxpmkt/logs/prodsales-ttest.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress.do"
    /* PRODUCT SALES REGRESSIONS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/estmat/`sec'/frm_scalscop_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") 
               "braxpmkt/estmat/`sec'/frmdst_scalscop_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") 
               "braxpmkt/estmat/`sec'/frmdstprd_scalscop_`region'" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") */
    /*    Log: "braxpmkt/logs/prodsales-regress.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-chile.do"
    /* PRODUCT SALES REGRESSIONS */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/estmat/chile-manffrms/frm_scalscop_`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") 
               "braxpmkt/estmat/chile-manffrms/frmdst_scalscop_`region'.tex" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") 
               "braxpmkt/estmat/chile-manffrms/frmdstprd_scalscop_`region'" (`region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") */
    /*    Log: "braxpmkt/logs/prodsales-regress-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-cntry-by-cntry.do"
    /* PRODUCT SALES REGRESSIONS COUNTRY BY COUNTRY */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/estmat/`sec'/frm_scalscop_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk", `region' in "world") */
    /*    Log: "braxpmkt/logs/prodsales-regress-cntry-by-cntry.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-firm-cntry-correlates.do"
    /* PRODUCT SALES REGRESSIONS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta"
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/estmat/`sec'/xtwtf_frmdst_world.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/xtfrm_frmdst_world.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/estmat/`sec'/xtwtf_frmdst_scop_world.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/estmat/`sec'/xtfrm_frmdst_scop_world.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") */
    /*    Log: "braxpmkt/logs/prodsales-firm-cntry-correlates.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-firm-cntry-correlates-chile.do"
    /* PRODUCT SALES REGRESSIONS */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/estmat/chile-manffrms/xtwtf_frmdst_world.tex"
               "braxpmkt/estmat/chile-manffrms/xtfrm_frmdst_world.tex" 
               "braxpmkt/estmat/chile-manffrms/xtwtf_frmdst_scop_world.tex" 
               "braxpmkt/estmat/chile-manffrms/xtfrm_frmdst_scop_world.tex" */
    /*    Log: "braxpmkt/logs/prodsales-firm-cntry-correlates-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-product-correlates.do"
    /* PRODUCT SALES REGRESSIONS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta"
               "braxpmkt/ext/product-data.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/estmat/`sec'/xths2_frmdstprd_world.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/estmat/`sec'/xths2_frmdstprd_scop_world.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") */
    /*    Log: "braxpmkt/logs/prodsales-product-correlates.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-product-correlates-chile.do"
    /* PRODUCT SALES REGRESSIONS */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta"
               "braxpmkt/ext/product-data-chile.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/estmat/chile-manffrms/xths2_frmdstprd_world.tex" 
               "braxpmkt/estmat/chile-manffrms/xths2_frmdstprd_scop_world.tex" */
    /*    Log: "braxpmkt/logs/prodsales-product-correlates-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-xtreg-fullspec.do"
    /* PRODUCT SALES REGRESSIONS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta" 
               "braxpmkt/secex/rais-cnpj-cnae-2000.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/estmat/`sec'/frmdst_fullspec_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") */
    /*    Log: "braxpmkt/logs/prodsales-xtreg-fullspec.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-xtreg-fullspec-chile.do"
    /* PRODUCT SALES REGRESSIONS */
    /* INPUT:  "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT:
          TeX: "braxpmkt/estmat/chile-manffrms/frmdst_fullspec_`region'.tex" (where `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") */
    /*    Log: "braxpmkt/logs/prodsales-xtreg-fullspec-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-goods-pcsales-spearman.do"
    /* EXPORTER SCOPE AND TOTAL EXPORTS DISTRIBUTION */
    /* INPUT:  "braxpmkt/secex/scope-pctl-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/secex/prodsales-data-2000.dta" */
    /* OUTPUT:
          TeX: "braxpmkt/estmat/`sec'/pcsales_corr.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/estmat/`sec'/lnscope_pctl.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/xtwtf_lnscope_pctl.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/lnscope_wtfchar.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-goods-pcsales-spearman.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-goods-pcsales-spearman-chile.do"
    /* EXPORTER SCOPE AND TOTAL EXPORTS DISTRIBUTION */
    /* INPUT:  "braxpmkt/chile/scope-pctl-chile-manffrms.dta"
               "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT:
          TeX: "braxpmkt/estmat/chile-manffrms/pcsales_corr.tex" 
               "braxpmkt/estmat/chile-manffrms/lnscope_pctl.tex"
               "braxpmkt/estmat/chile-manffrms/xtwtf_lnscope_pctl.tex"
               "braxpmkt/estmat/chile-manffrms/lnscope_wtfchar.tex"
          Log: "braxpmkt/logs/prodsales-goods-pcsales-spearman-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-extd.do"
    /* PRODUCT SALES REGRESSIONS, EXTENDED (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk") */
    /* OUTPUT:
          eps: "braxpmkt/eps/`sec'/expprodextd_`country'-4-32.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" and `country' in "usa" "argentina")
               "braxpmkt/eps/`sec'/expprodfit_`country'-4-32.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" and `country' in "usa" "argentina")
               "braxpmkt/eps/`sec'/expprodextd_`country'-2-16.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" and `country' in "usa" "argentina") 
               "braxpmkt/eps/`sec'/expprodfit_`country'-2-16.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" and `country' in "usa" "argentina") 
               "braxpmkt/eps/`sec'/expprodextd_`country'-4-32_ge100.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" and `country' in "usa" "argentina") 
               "braxpmkt/eps/`sec'/expprodfit_`country'-4-32_ge100.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" and `country' in "usa" "argentina") 
               "braxpmkt/eps/`sec'/expprodextd_`country'-2-16_ge100.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" and `country' in "usa" "argentina") 
               "braxpmkt/eps/`sec'/expprodfit_`country'-2-16_ge100.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" and `country' in "usa" "argentina") 
          TeX: "braxpmkt/estmat/`sec'/expprodextd.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/expprodfit.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-extd-chile.do"
    /* PRODUCT SALES REGRESSIONS, EXTENDED (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs-chile.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-chile-manffrms.dta" */
    /* OUTPUT: 
          TeX: "braxpmkt/estmat/chile-manffrms/expprodextd.tex"
               "braxpmkt/estmat/chile-manffrms/expprodfit.tex"
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-discrete.do"
    /* PRODUCT SALES REGRESSIONS, FOR DISCRETE-GOODS MODEL (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do and prodsales-graphs-chile.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "manf-firms" "chile-manffrms" "comrc-firms") */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/poolsec/expprodextd_d.tex"
               "braxpmkt/estmat/poolsec/expprodextd_di.tex"
               "braxpmkt/estmat/poolsec/expprodextd_dibr.tex"
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-discrete.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-discrete-byisic.do"
    /* PRODUCT SALES REGRESSIONS BY INDUSTRY, FOR DISCRETE-GOODS MODEL (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do and prodsales-graphs-chile.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "manf-firms" "chile-manffrms" "comrc-firms") */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/poolsec/expprodisic_dibr.tex"
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-discrete-byisic.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-struct.do"   // use Stata 10.2 or higher, use server with matsize 8000
    /* PRODUCT SALES REGRESSIONS, FOR DISCRETE-GOODS MODEL (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do and prodsales-graphs-chile.do, using same data) */
    /* INPUT:  "braxpmkt/secex/prodsales-rais-2000-struct.dta" */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/poolsec/expprodextd_pool.tex"
               "braxpmkt/estmat/poolsec/expprodextd_strc.tex"
               "braxpmkt/estmat/poolsec/expprdnofdi_strc.tex"
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-struct.log" */ 
          
    do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-struct-2d.do"   // use Stata 10.2 or higher, use server with matsize 8000
    /* PRODUCT SALES REGRESSIONS, FOR DISCRETE-GOODS MODEL (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do, using same data) */
    /* INPUT:  "braxpmkt/secex/prodsales-rais-2000-2delta.dta" */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/poolsec/expprodextd_strc2d.tex"
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-struct-2d.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-struct-byisic.do"   // use Stata 10.2 or higher
    /* PRODUCT SALES REGRESSIONS BY INDUSTRY, FOR DISCRETE-GOODS MODEL (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do and prodsales-graphs-chile.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "manf-firms")
               "braxpmkt/secex/prodsales-rais-2000-addons.dta" */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/poolsec/expprodisic_strc.tex"
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-struct-byisic.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-struct-ncm8.do"   // use Stata 10.2 or higher, use server with matsize 8000
    /* PRODUCT SALES REGRESSIONS, FOR DISCRETE-GOODS MODEL AND COMMON MERCOSUR NOMENCLATURE 8-DIGIT (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do and prodsales-graphs-chile.do, using same data) */
    /* INPUT:  "braxpmkt/secex/prodsales-rais-2000-struct-ncm8.dta" */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/poolsec-ncm8/expprodextd_pool.tex"
               "braxpmkt/estmat/poolsec-ncm8/expprodextd_strc.tex"
               "braxpmkt/estmat/poolsec-ncm8/expprdnofdi_strc.tex"
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-struct-ncm8.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-byctry.do"
    /* PRODUCT SALES REGRESSIONS WITH COUNTRY-SPECIFIC MARKET-ENTRY ELASTICITY */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/secex/prodsales-data-2000.dta" */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/`sec'/expprodctry.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/expproddelta.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-byctry.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-byctry-chile.do"
    /* PRODUCT SALES REGRESSIONS WITH COUNTRY-SPECIFIC MARKET-ENTRY ELASTICITY */
    /* INPUT:  "braxpmkt/secex/expprod-chile-manffrms.dta"
               "braxpmkt/chile/prodsales-data-2000-chile.dta" */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/chile-manffrms/expprodctry.tex"
               "braxpmkt/estmat/chile-manffrms/expproddelta.tex"
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-byctry-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-corr-prodlvl-delta-byctry.do"
    /* CORRELATIONS BETWEEN COUNTRY-SPECIFIC MARKET-ENTRY ELASTICITIES */
    /* INPUT:  "braxpmkt/estmat/`sec'/expprodctry.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk" "chile-manffrms")
               "braxpmkt/estmat/chile-manffrms/expprodctry.tex" */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/chile-manffrms/expprodctry.tex"
               "braxpmkt/estmat/chile-manffrms/expproddelta.tex"
          Log: "braxpmkt/logs/prodsales-corr-prodlvl-delta-byctry.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-extd-nl.do"
    /* PRODUCT SALES REGRESSIONS, EXTENDED (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk") */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/`sec'/expprodextdnl.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-nl.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-graphs-extd-nl.do"
    /* PRODUCT SALES GRAPHS */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk") */
    /* OUTPUT: 
          eps: "braxpmkt/eps/`sec'/expprod_`region'-4-32.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/expprod_`region'-2-16.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina")
               "braxpmkt/eps/`sec'/expprod-4-32.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/eps/`sec'/expprod-2-16.eps" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-regress-graphs-extd-nl.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-extd-nl-chile.do"
    /* PRODUCT SALES REGRESSIONS, EXTENDED (similar to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-chile-manffrms.dta" */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/chile-manffrms/expprodextdnl.tex"
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-nl-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-graphs-extd-nl-chile.do"
    /* PRODUCT SALES GRAPHS */
    /* INPUT:  "braxpmkt/secex/expprod-chile-manffrms.dta" */
    /* OUTPUT: 
          eps: "braxpmkt/eps/chile-manffrms/expprod_`region'-4-32.eps" 
               "braxpmkt/eps/chile-manffrms/expprod_`region'-2-16.eps" 
               "braxpmkt/eps/chile-manffrms/expprod-4-32.eps" 
               "braxpmkt/eps/chile-manffrms/expprod-2-16.eps" 
          Log: "braxpmkt/logs/prodsales-regress-graphs-extd-nl-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-discrete-nl.do"
    /* NON-LINEAR PRODUCT SALES REGRESSIONS, FOR DISCRETE-GOODS MODEL (related to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do and prodsales-graphs-chile.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk") */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/`sec'/expprodintgnl.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-discrete-nl.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-discrete-nl-restricted.do"
    /* NON-LINEAR PRODUCT SALES REGRESSIONS, FOR DISCRETE-GOODS MODEL (related to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do and prodsales-graphs-chile.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-`sec'.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk") */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/`sec'/expprdintgnlr.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-discrete-nl-restricted.log" */ 

* do "braxpmkt/%stata/%04regress/prodsales-regress-prodlvl-discrete-nl-restricted-chile.do"
    /* NON-LINEAR PRODUCT SALES REGRESSIONS, FOR DISCRETE-GOODS MODEL (related to braxpmkt/%stata/%03desc-stats/prodsales-graphs.do and prodsales-graphs-chile.do, using same data) */
    /* INPUT:  "braxpmkt/secex/expprod-chile-manffrms.dta" */
    /* OUTPUT: 
          Tex: "braxpmkt/estmat/chile-manffrms/expprdintgnlr.tex" 
          Log: "braxpmkt/logs/prodsales-regress-prodlvl-extd-discrete-nl-restricted-chile.log" */ 

* do "braxpmkt/%stata/%04regress/prep-expprod-4matlab.do"
    /* PREPARE BRAZIL DATA FOR TRANSFER TO MATLAB ESTIMATION */
    /* INPUT:  "braxpmkt/secex/expprod-manf-firms.dta" */
    /* OUTPUT: "braxpmkt/matlab/smm/g`g'.csv" (where `g' is the local product rank)
               "braxpmkt/matlab/smm/_frmlist.csv"
               "braxpmkt/matlab/smm/_wtflist.csv"
          Log: "braxpmkt/logs/prep-expprod-4matlab.log" */ 


* STEP 5: LATEX TABLES
*---------------------

* do "braxpmkt/%stata/%05tables/expshare-struct.do"
    /* FINAL STATISTICS AND TABLES FOR ARGUMENTS IN THE PAPER */
    /* INPUT:  "brazaux/conc/countries/country-table.dta" 
               "brazaux/conc/countries/country-table.dta" */
    /* OUTPUT: .
          Log: "braxpmkt/logs/expshare-struct.log" */ 


* do "braxpmkt/%stata/%05tables/prodsales-finalize.do"
    /* FINAL STATISTICS AND TABLES FOR ARGUMENTS IN THE PAPER */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "brazaux/intl/nber/wtf00.dta"
               "fdilabor/countries/ext-data.dta"
               "braxpmkt/secex/prodsales-data-2000.dta"
               "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'.dta" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/tex/`sec'/cumT_`region'_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/`sec'/relstats_`region'_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90") */
    /* OUTPUT:
          eps: "braxpmkt/eps/manf-firms/avgscope-wgsales-pcsales-`region'-ingroups.eps" (where `region' in "world" "oecd90" "nonoecd90")
          TeX: "braxpmkt/tex/`sec'/lngoods_cpctl_`region'.tex" (where `sec' in "manf-firms" and `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/`sec'/lngsales_cpctl_`region'.tex" (where `sec' in "manf-firms" and `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/`sec'/lngoods_wcpctl_`region'.tex" (where `sec' in "manf-firms" and `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/`sec'/lngsales_wcpctl_`region'.tex" (where `sec' in "manf-firms" and `region' in "world" "mercosur" "oecd90" "nonoecd90")
          Log: "braxpmkt/logs/prodsales-finalize.log" */ 

* do "braxpmkt/%stata/%05tables/prodsales-finalize-ncm8.do"
    /* FINAL STATISTICS AND TABLES FOR ARGUMENTS IN THE PAPER */
    /* INPUT:  "braxpmkt/secex/avgscope-wgsales-pcsales-`sec'.dta" (where `sec' in "manf-firms" "comrc-firms") */
    /* OUTPUT:
          eps: "braxpmkt/eps/manf-firms-ncm8/avgscope-wgsales-pcsales-world-ingroups.eps"
          Log: "braxpmkt/logs/prodsales-finalize-ncm8.log" */ 

* do "braxpmkt/%stata/%05tables/prodsales-finalize-chile.do"
    /* FINAL STATISTICS AND TABLES FOR ARGUMENTS IN THE PAPER */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "brazaux/intl/nber/wtf00.dta"
               "fdilabor/countries/ext-data.dta"
               "braxpmkt/chile/prodsales-data-2000-chile.dta"
               "braxpmkt/tex/chile-manffrms/cumT_`region'_tbl.dta"
               "braxpmkt/tex/chile-manffrms/relstats_`region'_tbl.dta" (where `region' in "world" "mercosur" "oecd90" "nonoecd90") */
    /* OUTPUT:
          eps: "braxpmkt/eps/chile-manffrms/avgscope-wgsales-pcsales-`region'-ingroups.eps" (where `region' in "world" "oecd90" "nonoecd90")
          TeX: "braxpmkt/tex/chile-manffrms/lngoods_cpctl_`region'.tex" (where `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/chile-manffrms/lngsales_cpctl_`region'.tex" (where `region' in "world" "mercosur" "oecd90" "nonoecd90")
          Log: "braxpmkt/logs/prodsales-finalize-chile.log" */ 

* do "braxpmkt/%stata/%05tables/matlab-prodsales-stats.do"
    /* PRODUCT SALES STATISTICS */
    /* INPUT:  "braxpmkt/matlab/variables3.csv"
               "braxpmkt/eps/manf-firms/sumsales-pcsales-usa.dta" (informing matlab code)
               "braxpmkt/eps/manf-firms/goods-pcgoods-usa.dta" (informing matlab code)
               "braxpmkt/eps/manf-firms/avgscope-wgsales-pcsales-usa.dta" (informing matlab code) */
    /* OUTPUT: 
          eps: "braxpmkt/eps/matlab/sumsales-pcsales-usa.eps"
               "braxpmkt/eps/matlab/goods-pcsales-usa.eps"
               "braxpmkt/eps/matlab/avgscope-wgsales-pcsales-usa.eps"
               "braxpmkt/eps/matlab/avgsumsales-pcsales-usa.eps"
          Log: "braxpmkt/logs/matlab-prodsales-stats.log" */ 

* do "braxpmkt/%stata/%05tables/tex-tables.do"
    /* TABLES FOR BRAZIL (DESCRIPTIVES AND PRODUCT SALES REGRESSIONS) */
    /* INPUT:  "braxpmkt/tex/`sec'/relstats_`region'_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina" "top20th" "prelim")
               "braxpmkt/tex/`sec'-ncm8/relstats_`region'_tbl.dta" (where `sec' in "manf-firms" "comrc-firms", `region' in "world" "usa" "argentina" "prelim")
               "braxpmkt/tex/`sec'/`stat'exp_`region'_tbl.dta" (where `stat' in "mean" "sd" "count", `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") 
               "braxpmkt/tex/`sec'/`region'_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90") 
               "braxpmkt/estmat/`sec'/expminval`region'_tbl" (`sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region in "" "_usa" "_argentina")
               "braxpmkt/estmat/`sec'/`type'_scalscop_`region'_tbl.dta" (where `type' in "frm" "frmdst" "frmdstprd", `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/manf-ekk/braxpmkt/tex/manf-ekk/expitem_reg_tbl.dta" 
               "braxpmkt/estmat/`sec'/xtwtf_frmdst_world_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/estmat/`sec'/xtwtf_frmdst_scop_world_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/xtfrm_frmdst_world_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/estmat/`sec'/xtfrm_frmdst_scop_world_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/xths2_frmdstprd_world_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/estmat/`sec'/xths2_frmdstprd_scop_world_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/frmdst_fullspec_`region'_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" and `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/estmat/`sec'/pcsales_corr_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/estmat/`sec'/lnscope_pctl_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/xtwtf_lnscope_pctl_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/lnscope_wtfchar_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/expprod_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/estmat/`sec'/expprod_nl_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/lngoods_cpctl_`region'_tbl.dta" (where `sec' in "manf-firms" and `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/`sec'/lngsales_cpctl_`region'_tbl.dta" (where `sec' in "manf-firms" and `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/`sec'/topsh_`region'_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk" and `region' in "usa" "argentina" "world")
               "braxpmkt/%stata/rowlbl-braxpmkt.tex" */
    /* OUTPUT:
          TeX: "braxpmkt/tex/`sec'/relstats.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/relstats_draft.tex" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/tex/`sec'-ncm8/relstats.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "srvc-firms" "comrc-firms" "manf-ekk")
               "braxpmkt/tex/`sec'-ncm8/relstats_draft.tex" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/tex/`sec'/expprod_`region'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") 
               "braxpmkt/tex/`sec'/desc_`sec'.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")  
               "braxpmkt/tex/`sec'/scalscop.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/tex/`sec'/scalscop_draft.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/tex/manf-ekk/ekkscop_reg.tex"
               "braxpmkt/tex/manf-ekk/ekkexts_reg.tex"
               "braxpmkt/tex/`sec'/xtwtf.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/xtfrm.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/tex/`sec'/xths2.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/xths2.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/frmdst_fullspec.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/pcsales_corr.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/tex/`sec'/lnscope_pctl.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/xtwtf_lnscope_pctl.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") 
               "braxpmkt/tex/`sec'/pareto_cpctl.tex" (where `sec' is "manf-firms" only)
               "braxpmkt/tex/`sec'/pareto_wcpctl.tex" (where `sec' is "manf-firms" only)
               "braxpmkt/tex/`sec'/expprod.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/expprod_nl.tex" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk")
               "braxpmkt/tex/`sec'/topsh_tbl.dta" (where `sec' in "allsec" "manf-goods" "manf-firms" "manf-ekk") */
    /*    Log: "braxpmkt/logs/tex-tables.log" */ 

* do "braxpmkt/%stata/%05tables/tex-tables-chile.do"
    /* TABLES FOR CHILE (DESCRIPTIVES AND PRODUCT SALES REGRESSIONS) */
    /* INPUT:  "braxpmkt/tex/chile-manffrms/relstats_`region'_tbl.dta" (where `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/chile-manffrms/`stat'exp_`region'_tbl.dta" (where `stat' in "mean" "sd" "count", `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") 
               "braxpmkt/tex/chile-manffrms/`region'_tbl.dta" (where `region' in "world" "mercosur" "oecd90" "nonoecd90") 
               "braxpmkt/estmat/chile-manffrms/`type'_scalscop_`region'_tbl.dta" (where `type' in "frm" "frmdst" "frmdstprd", `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/manf-ekk/braxpmkt/tex/manf-ekk/expitem_reg_tbl.dta" 
               "braxpmkt/estmat/chile-manffrms/xtwtf_frmdst_world_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/xtwtf_frmdst_scop_world_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/xtfrm_frmdst_world_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/xtfrm_frmdst_scop_world_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/xths2_frmdstprd_world_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/xths2_frmdstprd_scop_world_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/pcsales_corr_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/lnscope_pctl_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/xtwtf_lnscope_pctl_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/lnscope_wtfchar_tbl.dta"
               "braxpmkt/estmat/chile-manffrms/expprod_tbl.dta" 
               "braxpmkt/tex/chile-manffrms/lngoods_cpctl_`region'.tex" (where `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/chile-manffrms/lngsales_cpctl_`region'.tex" (where `region' in "world" "mercosur" "oecd90" "nonoecd90")
               "braxpmkt/tex/chile-manffrms/topsh_`region'_tbl.dta" (where `region' in "usa" "argentina" "world")
               "braxpmkt/%stata/rowlbl-braxpmkt.tex" */
    /* OUTPUT:
          TeX: "braxpmkt/tex/chile-manffrms/relstats.tex"
               "braxpmkt/tex/chile-manffrms/relstats_draft.tex"
               "braxpmkt/tex/chile-manffrms/expprod_`region'.tex" (where `region' in "world" "mercosur" "oecd90" "nonoecd90" "usa" "argentina") 
               "braxpmkt/tex/chile-manffrms/desc_`sec'.tex" 
               "braxpmkt/tex/chile-manffrms/scalscop.tex"
               "braxpmkt/tex/chile-manffrms/scalscop_draft.tex"
               "braxpmkt/tex/manf-ekk/ekkscop_reg.tex"
               "braxpmkt/tex/manf-ekk/ekkexts_reg.tex"
               "braxpmkt/tex/chile-manffrms/xtwtf.tex"
               "braxpmkt/tex/chile-manffrms/xtfrm.tex"
               "braxpmkt/tex/chile-manffrms/xths2.tex"
               "braxpmkt/tex/chile-manffrms/pcsales_corr.tex"
               "braxpmkt/tex/chile-manffrms/lnscope_pctl.tex"
               "braxpmkt/tex/chile-manffrms/xtwtf_lnscope_pctl.tex"
               "braxpmkt/tex/chile-manffrms/pareto_cpctl.tex"
               "braxpmkt/tex/chile-manffrms/pareto_wcpctl.tex"
               "braxpmkt/tex/chile-manffrms/topsh.tex" */
    /*    Log: "braxpmkt/logs/tex-tables-chile.log" */ 

    do "braxpmkt/%stata/%05tables/tex-tables-paper.do"
    /* TABLES FOR PAPER DRAFTS (DESCRIPTIVES AND PRODUCT SALES REGRESSIONS) */
    /* INPUT:  "braxpmkt/tex/`sec'/relstats_draft_tbl.dta" (where `sec' in "manf-firms" "comrc-firms" "chile-manffrms")
               "braxpmkt/tex/`sec'-ncm8/relstats_draft_tbl.dta" (where `sec' in "manf-firms" "comrc-firms")
               "braxpmkt/tex/`sec'/pareto_wcpctl_tbl.dta" (where `sec' in "manf-firms" "chile-manffrms")
               "braxpmkt/tex/`sec'/lnscope_pctl_tbl.dta" (where `sec' in "manf-firms" "chile-manffrms")
               "braxpmkt/tex/`sec'/scalscop_tbl.dta" (where `sec' in "manf-firms" "chile-manffrms")
               "braxpmkt/tex/`sec'/scalscop_draft_tbl.dta" (where `sec' in "manf-firms" "chile-manffrms")
               "braxpmkt/tex/`sec'/xtwtf_tbl.dta" (where `sec' in "manf-firms" "chile-manffrms")
               "braxpmkt/tex/`sec'/xths2_tbl.dta" (where `sec' in "manf-firms" "chile-manffrms")
               "braxpmkt/estmat/`sec'/frm_scalscop_world_tbl.dta" (where `sec' in "manf-firms" "comrc-firms" "srvc-firms" "chile-manffrms")
               "braxpmkt/estmat/`sec'/frmdst_scalscop_world_tbl.dta" (where `sec' in "manf-firms" "comrc-firms" "srvc-firms" "chile-manffrms")
               "braxpmkt/estmat/`sec'/expprod_tbl.dta" (where `sec' in "manf-firms" "comrc-firms" "chile-manffrms")
               "braxpmkt/estmat/`sec'/expprodextd_tbl.dta" (where `sec' in "manf-firms" "comrc-firms" "chile-manffrms")
               "braxpmkt/estmat/`sec'/expprodextdnl_tbl.dta" (where `sec' in "manf-firms" "comrc-firms" "chile-manffrms")
               "braxpmkt/estmat/`sec'/expprdintgnlr_tbl.dta" (where `sec' in "manf-firms" "comrc-firms" "chile-manffrms")
               "braxpmkt/estmat/poolsec/expprodextd_di_tbl.dta"
               "braxpmkt/estmat/poolsec/expprodextd_dibr_tbl.dta"
               "braxpmkt/estmat/poolsec/expprodextd_d_tbl.dta"
               "braxpmkt/estmat/poolsec/expprodisic_dibr_tbl.dta"
               "braxpmkt/estmat/poolsec/expprodextd_strc_tbl.dta"
               "braxpmkt/estmat/poolsec/expprdnofdi_strc_tbl.dta"
               "braxpmkt/estmat/poolsec/expprodextd_strc2d_tbl.dta"
               "braxpmkt/%stata/rowlbl-braxpmkt.tex"
               "braxpmkt/conc/isic.do" */
    /* OUTPUT:
          TeX: "braxpmkt/tex/paper/relstats_paper.tex"
               "braxpmkt/tex/paper/relstats_aea.tex"
               "braxpmkt/tex/paper/relstats_submit.tex"
               "braxpmkt/tex/paper/relstats_qje.tex"
               "braxpmkt/tex/paper/relstats_brcl.tex"
               "braxpmkt/tex/paper/relstats_ncm8.tex"
               "braxpmkt/tex/paper/pareto_wcpctl.tex"
               "braxpmkt/tex/paper/lnscope_pctl.tex"
               "braxpmkt/tex/paper/scalscop_paper.tex"
               "braxpmkt/tex/paper/scalscop_short.tex"
               "braxpmkt/tex/paper/scalscop_long.tex"
               "braxpmkt/tex/paper/xtwtf.tex"
               "braxpmkt/tex/paper/xths2.tex" 
               "braxpmkt/tex/paper/expprod_paper.tex" 
               "braxpmkt/tex/paper/expprod_aea.tex"
               "braxpmkt/tex/paper/expprod_ces.tex"
               "braxpmkt/tex/paper/expprod_ces_ge100.tex"
               "braxpmkt/tex/paper/expprodnl_paper.tex"
               "braxpmkt/tex/paper/expprodintgi.tex"
               "braxpmkt/tex/paper/expprodintgi_qje.tex"
               "braxpmkt/tex/paper/expprodintg.tex"
               "braxpmkt/tex/paper/expprodintg_ge100.tex"
               "braxpmkt/tex/paper/expprodisic.tex"
               "braxpmkt/tex/paper/expprdintgnlr.tex"
               "braxpmkt/tex/paper/expprodint_restud.tex"
               "braxpmkt/tex/paper/expprdnofdi_restud.tex"
               "braxpmkt/tex/paper/expprodint_aej.tex" */
    /*    Log: "braxpmkt/logs/tex-tables-paper.log" */ 

* do "braxpmkt/%stata/%05tables/thetatilda.do"
    /* PROCESS SIMULATION RESULTS AS TABLES AND GRAPHS */
    /* INPUT:  "braxpmkt/secex/prodsales-data-2000.dta"
               "braxpmkt/secex/replication-data-2000.dta"
               "braxpmkt/secex/avgscope-wgsales-pcsales-manf-firms.dta"
               "braxpmkt/ext/country-data-2000.dta"
               "braxpmkt/ext/distance-data.dta" */
    /* OUTPUT: "braxpmkt/secex/fbar-2000-manf-firms.dta" */
    /*    Log: "braxpmkt/logs/thetatilda.log" */ 

* do "braxpmkt/%stata/%05tables/simulation-tex-eps.do"
    /* PROCESS SIMULATION RESULTS AS TABLES AND GRAPHS */
    /* INPUT:  "braxpmkt/matlab/workbook3.csv"
               "braxpmkt/ext/simulation-data-2000.dta" */
    /* OUTPUT:
          TeX: "braxpmkt/tex/simul25.tex" */
    /*    Log: "braxpmkt/logs/simulation-tex-eps.log" */ 
